/*===- TableGen'erated file -------------------------------------*- C++ -*-===*\
|*                                                                            *|
|* Assembly Matcher Source Fragment                                           *|
|*                                                                            *|
|* Automatically generated file, do not edit!                                 *|
|* From: AMDGPU.td                                                            *|
|*                                                                            *|
\*===----------------------------------------------------------------------===*/


#ifdef GET_ASSEMBLER_HEADER
#undef GET_ASSEMBLER_HEADER
  // This should be included into the middle of the declaration of
  // your subclasses implementation of MCTargetAsmParser.
  FeatureBitset ComputeAvailableFeatures(const FeatureBitset &FB) const;
  void convertToMCInst(unsigned Kind, MCInst &Inst, unsigned Opcode,
                       const OperandVector &Operands,
                       const SmallBitVector &OptionalOperandsMask,
                       ArrayRef<unsigned> DefaultsOffset);
  void convertToMapAndConstraints(unsigned Kind,
                           const OperandVector &Operands) override;
  unsigned MatchInstructionImpl(const OperandVector &Operands,
                                MCInst &Inst,
                                uint64_t &ErrorInfo,
                                FeatureBitset &MissingFeatures,
                                bool matchingInlineAsm,
                                unsigned VariantID = 0);
  unsigned MatchInstructionImpl(const OperandVector &Operands,
                                MCInst &Inst,
                                uint64_t &ErrorInfo,
                                bool matchingInlineAsm,
                                unsigned VariantID = 0) {
    FeatureBitset MissingFeatures;
    return MatchInstructionImpl(Operands, Inst, ErrorInfo, MissingFeatures,
                                matchingInlineAsm, VariantID);
  }

  ParseStatus MatchOperandParserImpl(
    OperandVector &Operands,
    StringRef Mnemonic,
    bool ParseForAllFeatures = false);
  ParseStatus tryCustomParseOperand(
    OperandVector &Operands,
    unsigned MCK);

#endif // GET_ASSEMBLER_HEADER


#ifdef GET_OPERAND_DIAGNOSTIC_TYPES
#undef GET_OPERAND_DIAGNOSTIC_TYPES

#endif // GET_OPERAND_DIAGNOSTIC_TYPES


#ifdef GET_REGISTER_MATCHER
#undef GET_REGISTER_MATCHER

// Bits for subtarget features that participate in instruction matching.
enum SubtargetFeatureBits : uint8_t {
  Feature_isGFX6Bit = 162,
  Feature_isGFX6GFX7Bit = 163,
  Feature_isGFX6GFX7GFX10Bit = 167,
  Feature_isGFX6GFX7GFX10PlusBit = 168,
  Feature_isGFX7OnlyBit = 173,
  Feature_isGFX7GFX10Bit = 171,
  Feature_isGFX7GFX10GFX11Bit = 172,
  Feature_isGFX7GFX8GFX9Bit = 169,
  Feature_isGFX6GFX7GFX8GFX9Bit = 164,
  Feature_isGFX6GFX7GFX8GFX9NotGFX90ABit = 166,
  Feature_isGFX6GFX7GFX8GFX9GFX10Bit = 165,
  Feature_isNotGFX12PlusBit = 203,
  Feature_isGFX7GFX8GFX9GFX10Bit = 170,
  Feature_isGFX8GFX9GFX10GFX11Bit = 177,
  Feature_isGFX7PlusBit = 174,
  Feature_isGFX8PlusBit = 181,
  Feature_isGFX8OnlyBit = 180,
  Feature_isGFX9PlusBit = 185,
  Feature_isGFX9OnlyBit = 184,
  Feature_isGCN3ExcludingGFX90ABit = 161,
  Feature_isGFX90APlusBit = 197,
  Feature_isNotGFX90APlusBit = 204,
  Feature_isGFX8GFX9NotGFX90ABit = 178,
  Feature_isGFX90AOnlyBit = 196,
  Feature_isGFX908orGFX90ABit = 199,
  Feature_isGFX940PlusBit = 200,
  Feature_isNotGFX940PlusBit = 205,
  Feature_HasGFX950InstsBit = 88,
  Feature_HasPermlane16SwapBit = 112,
  Feature_HasPermlane32SwapBit = 113,
  Feature_isGFX8GFX9NotGFX940Bit = 179,
  Feature_isGFX8GFX9Bit = 175,
  Feature_isGFX10OnlyBit = 188,
  Feature_isGFX10PlusBit = 189,
  Feature_isGFX10GFX11Bit = 187,
  Feature_isGFX10Before1030Bit = 186,
  Feature_isGFX9GFX10Bit = 182,
  Feature_isGFX9GFX10GFX11Bit = 183,
  Feature_isGFX8GFX9GFX10Bit = 176,
  Feature_isGFX11OnlyBit = 190,
  Feature_isGFX11PlusBit = 191,
  Feature_isGFX12OnlyBit = 193,
  Feature_isGFX12Not12_50Bit = 192,
  Feature_isGFX12PlusBit = 194,
  Feature_isGFX12PlusNot12_50Bit = 195,
  Feature_isGFX125xOnlyBit = 198,
  Feature_isGFX1250PlusBit = 202,
  Feature_isNotGFX1250PlusBit = 206,
  Feature_isGFX940orGFX1250Bit = 201,
  Feature_HasIEEEMinimumMaximumInstsBit = 90,
  Feature_HasMinimum3Maximum3F32Bit = 106,
  Feature_HasMinimum3Maximum3F16Bit = 105,
  Feature_HasMin3Max3PKF16Bit = 104,
  Feature_HasMinimum3Maximum3PKF16Bit = 107,
  Feature_HasFlatAddressSpaceBit = 69,
  Feature_HasFlatBufferGlobalAtomicFaddF64InstBit = 71,
  Feature_HasAtomicFMinFMaxF32GlobalInstsBit = 17,
  Feature_HasAtomicFMinFMaxF64GlobalInstsBit = 19,
  Feature_HasAtomicFMinFMaxF32FlatInstsBit = 16,
  Feature_HasAtomicFMinFMaxF64FlatInstsBit = 18,
  Feature_HasAtomicCondSubClampFlatInstsBit = 13,
  Feature_HasLdsAtomicAddF64Bit = 94,
  Feature_HasFlatGlobalInstsBit = 73,
  Feature_HasFlatScratchInstsBit = 74,
  Feature_HasScalarFlatScratchInstsBit = 133,
  Feature_HasD16LoadStoreBit = 35,
  Feature_HasFlatScratchSTModeBit = 75,
  Feature_HasFlatScratchSVSModeBit = 76,
  Feature_HasFlatGVSModeBit = 72,
  Feature_HasGFX10_AEncodingBit = 86,
  Feature_HasGFX10_BEncodingBit = 87,
  Feature_HasUnpackedD16VMemBit = 143,
  Feature_HasPackedD16VMemBit = 110,
  Feature_HasRestrictedSOffsetBit = 122,
  Feature_HasUnrestrictedSOffsetBit = 144,
  Feature_D16PreservesUnusedBitsBit = 0,
  Feature_HasMTBUFInstsBit = 99,
  Feature_HasFormattedMUBUFInstsBit = 84,
  Feature_HasExportInstsBit = 59,
  Feature_HasVINTERPEncodingBit = 146,
  Feature_HasDSAddTidBit = 42,
  Feature_HasLDSFPAtomicAddF32Bit = 93,
  Feature_HasAddNoCarryInstsBit = 6,
  Feature_Has16BitInstsBit = 1,
  Feature_HasTrue16BitInstsBit = 141,
  Feature_NotHasTrue16BitInstsBit = 156,
  Feature_UseRealTrue16InstsBit = 160,
  Feature_NotUseRealTrue16InstsBit = 158,
  Feature_UseFakeTrue16InstsBit = 159,
  Feature_HasD16Writes32BitVgprBit = 36,
  Feature_NotHasD16Writes32BitVgprBit = 152,
  Feature_HasBF16TransInstsBit = 27,
  Feature_HasBF16ConversionInstsBit = 25,
  Feature_HasBF16PackedInstsBit = 26,
  Feature_HasVOP3PInstsBit = 147,
  Feature_HasSDWA8Bit = 124,
  Feature_HasSDWA9Bit = 125,
  Feature_HasSDWA10Bit = 126,
  Feature_HasDPPBit = 39,
  Feature_HasDPP8Bit = 40,
  Feature_HasDPALU_DPPBit = 38,
  Feature_HasPackedFP32OpsBit = 111,
  Feature_HasPkMovB32Bit = 117,
  Feature_HasFmaakFmamkF32InstsBit = 80,
  Feature_HasFmaakFmamkF64InstsBit = 81,
  Feature_HasAddMinMaxInstsBit = 5,
  Feature_HasPkAddMinMaxInstsBit = 114,
  Feature_HasPkMinMax3InstsBit = 116,
  Feature_HasSGetShaderCyclesInstBit = 127,
  Feature_HasImageInstsBit = 91,
  Feature_HasExtendedImageInstsBit = 60,
  Feature_HasR128A16Bit = 121,
  Feature_HasA16Bit = 4,
  Feature_HasG16Bit = 85,
  Feature_HasDPP16Bit = 41,
  Feature_HasIntClampBit = 92,
  Feature_HasMadMixInstsBit = 101,
  Feature_HasScalarStoresBit = 134,
  Feature_HasScalarAtomicsBit = 132,
  Feature_HasNoSdstCMPXBit = 109,
  Feature_HasSdstCMPXBit = 135,
  Feature_HasVGPRIndexModeBit = 145,
  Feature_HasMovrelBit = 108,
  Feature_HasFmaMixInstsBit = 79,
  Feature_HasFmaMixBF16InstsBit = 78,
  Feature_HasDLInstsBit = 37,
  Feature_HasFmacF64InstBit = 82,
  Feature_HasDot1InstsBit = 45,
  Feature_HasDot2InstsBit = 46,
  Feature_HasDot3InstsBit = 47,
  Feature_HasDot4InstsBit = 48,
  Feature_HasDot5InstsBit = 49,
  Feature_HasDot6InstsBit = 50,
  Feature_HasDot7InstsBit = 51,
  Feature_HasDot8InstsBit = 52,
  Feature_HasDot9InstsBit = 53,
  Feature_HasDot10InstsBit = 54,
  Feature_HasDot11InstsBit = 55,
  Feature_HasDot12InstsBit = 56,
  Feature_HasDot13InstsBit = 57,
  Feature_HasGetWaveIdInstBit = 89,
  Feature_HasMAIInstsBit = 98,
  Feature_NotHasMAIInstsBit = 154,
  Feature_HasSMemRealTimeBit = 128,
  Feature_HasSMemTimeInstBit = 129,
  Feature_HasShaderCyclesRegisterBit = 137,
  Feature_HasFP8InstsBit = 68,
  Feature_HasFP8ConversionInstsBit = 65,
  Feature_HasCubeInstsBit = 30,
  Feature_HasLerpInstBit = 96,
  Feature_HasSadInstsBit = 131,
  Feature_HasQsadInstsBit = 120,
  Feature_HasCvtNormInstsBit = 31,
  Feature_HasCvtPkNormVOP2InstsBit = 33,
  Feature_HasCvtPkNormVOP3InstsBit = 34,
  Feature_HasFP8E5M3InstsBit = 67,
  Feature_NotHasFP8E5M3InstsBit = 153,
  Feature_HasPkFmacF16InstBit = 115,
  Feature_HasMadMacF32InstsBit = 100,
  Feature_HasFmaLegacy32Bit = 77,
  Feature_HasFmacLegacy32Bit = 83,
  Feature_HasAtomicDsPkAdd16InstsBit = 15,
  Feature_HasAtomicDsCondSubClampInstsBit = 14,
  Feature_HasAtomicFlatPkAdd16InstsBit = 22,
  Feature_HasAtomicFaddRtnInstsBit = 21,
  Feature_HasAtomicFaddNoRtnInstsBit = 20,
  Feature_HasAtomicBufferGlobalPkAddF16NoRtnInstsBit = 11,
  Feature_HasAtomicBufferGlobalPkAddF16InstsBit = 10,
  Feature_HasAtomicGlobalPkAddBF16InstBit = 23,
  Feature_HasAtomicBufferPkAddBF16InstBit = 12,
  Feature_HasFlatAtomicFaddF32InstBit = 70,
  Feature_HasDefaultComponentZeroBit = 44,
  Feature_HasDefaultComponentBroadcastBit = 43,
  Feature_HasDsSrc2InstsBit = 58,
  Feature_HasAddPC64InstBit = 7,
  Feature_HasUnalignedAccessModeBit = 142,
  Feature_HasSALUFloatInstsBit = 123,
  Feature_NotHasSALUFloatInstsBit = 155,
  Feature_HasPseudoScalarTransBit = 119,
  Feature_HasBitOp3InstsBit = 29,
  Feature_HasTanhInstsBit = 138,
  Feature_HasTensorCvtLutInstsBit = 139,
  Feature_HasTransposeLoadF4F6InstsBit = 140,
  Feature_HasPrngInstBit = 118,
  Feature_HasBVHDualAndBVH8InstsBit = 28,
  Feature_Has64BitLiteralsBit = 2,
  Feature_Has1024AddressableVGPRsBit = 3,
  Feature_HasMcastLoadInstsBit = 103,
  Feature_HasWaitXcntBit = 149,
  Feature_HasFP8ConversionScaleInstsBit = 66,
  Feature_HasBF8ConversionScaleInstsBit = 24,
  Feature_HasFP4ConversionScaleInstsBit = 63,
  Feature_HasFP6BF6ConversionScaleInstsBit = 64,
  Feature_HasF16BF16ToFP6BF6ConversionScaleInstsBit = 61,
  Feature_HasCvtPkF16F32InstBit = 32,
  Feature_HasF32ToF16BF16ConversionSRInstsBit = 62,
  Feature_HasXF32InstsBit = 150,
  Feature_HasVmemPrefInstsBit = 148,
  Feature_HasAshrPkInstsBit = 9,
  Feature_HasLshlAddU64InstBit = 97,
  Feature_HasAddSubU64InstsBit = 8,
  Feature_HasMadU32InstBit = 102,
  Feature_HasLdsBarrierArriveAtomicBit = 95,
  Feature_HasSetPrioIncWgInstBit = 136,
  Feature_HasSWakeupBarrierBit = 130,
  Feature_NeedsAlignedVGPRsBit = 151,
  Feature_NotNeedsAlignedVGPRsBit = 157,
  Feature_isWave32Bit = 207,
  Feature_isWave64Bit = 209,
  Feature_isWave32StrictBit = 208,
  Feature_isWave64StrictBit = 210,
};

#endif // GET_REGISTER_MATCHER


#ifdef GET_SUBTARGET_FEATURE_NAME
#undef GET_SUBTARGET_FEATURE_NAME

// User-level names for subtarget features that participate in
// instruction matching.
static const char *getSubtargetFeatureName(uint64_t Val) {
  switch(Val) {
  case Feature_isGFX6Bit: return "";
  case Feature_isGFX6GFX7Bit: return "";
  case Feature_isGFX6GFX7GFX10Bit: return "";
  case Feature_isGFX6GFX7GFX10PlusBit: return "";
  case Feature_isGFX7OnlyBit: return "";
  case Feature_isGFX7GFX10Bit: return "";
  case Feature_isGFX7GFX10GFX11Bit: return "";
  case Feature_isGFX7GFX8GFX9Bit: return "";
  case Feature_isGFX6GFX7GFX8GFX9Bit: return "";
  case Feature_isGFX6GFX7GFX8GFX9NotGFX90ABit: return "";
  case Feature_isGFX6GFX7GFX8GFX9GFX10Bit: return "";
  case Feature_isNotGFX12PlusBit: return "";
  case Feature_isGFX7GFX8GFX9GFX10Bit: return "";
  case Feature_isGFX8GFX9GFX10GFX11Bit: return "";
  case Feature_isGFX7PlusBit: return "";
  case Feature_isGFX8PlusBit: return "";
  case Feature_isGFX8OnlyBit: return "";
  case Feature_isGFX9PlusBit: return "";
  case Feature_isGFX9OnlyBit: return "";
  case Feature_isGCN3ExcludingGFX90ABit: return "";
  case Feature_isGFX90APlusBit: return "";
  case Feature_isNotGFX90APlusBit: return "";
  case Feature_isGFX8GFX9NotGFX90ABit: return "";
  case Feature_isGFX90AOnlyBit: return "";
  case Feature_isGFX908orGFX90ABit: return "";
  case Feature_isGFX940PlusBit: return "";
  case Feature_isNotGFX940PlusBit: return "";
  case Feature_HasGFX950InstsBit: return "";
  case Feature_HasPermlane16SwapBit: return "";
  case Feature_HasPermlane32SwapBit: return "";
  case Feature_isGFX8GFX9NotGFX940Bit: return "";
  case Feature_isGFX8GFX9Bit: return "";
  case Feature_isGFX10OnlyBit: return "";
  case Feature_isGFX10PlusBit: return "";
  case Feature_isGFX10GFX11Bit: return "";
  case Feature_isGFX10Before1030Bit: return "";
  case Feature_isGFX9GFX10Bit: return "";
  case Feature_isGFX9GFX10GFX11Bit: return "";
  case Feature_isGFX8GFX9GFX10Bit: return "";
  case Feature_isGFX11OnlyBit: return "";
  case Feature_isGFX11PlusBit: return "";
  case Feature_isGFX12OnlyBit: return "";
  case Feature_isGFX12Not12_50Bit: return "";
  case Feature_isGFX12PlusBit: return "";
  case Feature_isGFX12PlusNot12_50Bit: return "";
  case Feature_isGFX125xOnlyBit: return "";
  case Feature_isGFX1250PlusBit: return "";
  case Feature_isNotGFX1250PlusBit: return "";
  case Feature_isGFX940orGFX1250Bit: return "";
  case Feature_HasIEEEMinimumMaximumInstsBit: return "";
  case Feature_HasMinimum3Maximum3F32Bit: return "";
  case Feature_HasMinimum3Maximum3F16Bit: return "";
  case Feature_HasMin3Max3PKF16Bit: return "";
  case Feature_HasMinimum3Maximum3PKF16Bit: return "";
  case Feature_HasFlatAddressSpaceBit: return "";
  case Feature_HasFlatBufferGlobalAtomicFaddF64InstBit: return "";
  case Feature_HasAtomicFMinFMaxF32GlobalInstsBit: return "";
  case Feature_HasAtomicFMinFMaxF64GlobalInstsBit: return "";
  case Feature_HasAtomicFMinFMaxF32FlatInstsBit: return "";
  case Feature_HasAtomicFMinFMaxF64FlatInstsBit: return "";
  case Feature_HasAtomicCondSubClampFlatInstsBit: return "";
  case Feature_HasLdsAtomicAddF64Bit: return "";
  case Feature_HasFlatGlobalInstsBit: return "";
  case Feature_HasFlatScratchInstsBit: return "";
  case Feature_HasScalarFlatScratchInstsBit: return "";
  case Feature_HasD16LoadStoreBit: return "";
  case Feature_HasFlatScratchSTModeBit: return "";
  case Feature_HasFlatScratchSVSModeBit: return "";
  case Feature_HasFlatGVSModeBit: return "";
  case Feature_HasGFX10_AEncodingBit: return "";
  case Feature_HasGFX10_BEncodingBit: return "";
  case Feature_HasUnpackedD16VMemBit: return "";
  case Feature_HasPackedD16VMemBit: return "";
  case Feature_HasRestrictedSOffsetBit: return "";
  case Feature_HasUnrestrictedSOffsetBit: return "";
  case Feature_D16PreservesUnusedBitsBit: return "";
  case Feature_HasMTBUFInstsBit: return "";
  case Feature_HasFormattedMUBUFInstsBit: return "";
  case Feature_HasExportInstsBit: return "";
  case Feature_HasVINTERPEncodingBit: return "";
  case Feature_HasDSAddTidBit: return "";
  case Feature_HasLDSFPAtomicAddF32Bit: return "";
  case Feature_HasAddNoCarryInstsBit: return "";
  case Feature_Has16BitInstsBit: return "";
  case Feature_HasTrue16BitInstsBit: return "";
  case Feature_NotHasTrue16BitInstsBit: return "";
  case Feature_UseRealTrue16InstsBit: return "";
  case Feature_NotUseRealTrue16InstsBit: return "";
  case Feature_UseFakeTrue16InstsBit: return "";
  case Feature_HasD16Writes32BitVgprBit: return "";
  case Feature_NotHasD16Writes32BitVgprBit: return "";
  case Feature_HasBF16TransInstsBit: return "";
  case Feature_HasBF16ConversionInstsBit: return "";
  case Feature_HasBF16PackedInstsBit: return "";
  case Feature_HasVOP3PInstsBit: return "";
  case Feature_HasSDWA8Bit: return "";
  case Feature_HasSDWA9Bit: return "";
  case Feature_HasSDWA10Bit: return "";
  case Feature_HasDPPBit: return "";
  case Feature_HasDPP8Bit: return "";
  case Feature_HasDPALU_DPPBit: return "";
  case Feature_HasPackedFP32OpsBit: return "";
  case Feature_HasPkMovB32Bit: return "";
  case Feature_HasFmaakFmamkF32InstsBit: return "";
  case Feature_HasFmaakFmamkF64InstsBit: return "";
  case Feature_HasAddMinMaxInstsBit: return "";
  case Feature_HasPkAddMinMaxInstsBit: return "";
  case Feature_HasPkMinMax3InstsBit: return "";
  case Feature_HasSGetShaderCyclesInstBit: return "";
  case Feature_HasImageInstsBit: return "";
  case Feature_HasExtendedImageInstsBit: return "";
  case Feature_HasR128A16Bit: return "";
  case Feature_HasA16Bit: return "";
  case Feature_HasG16Bit: return "";
  case Feature_HasDPP16Bit: return "";
  case Feature_HasIntClampBit: return "";
  case Feature_HasMadMixInstsBit: return "";
  case Feature_HasScalarStoresBit: return "";
  case Feature_HasScalarAtomicsBit: return "";
  case Feature_HasNoSdstCMPXBit: return "";
  case Feature_HasSdstCMPXBit: return "";
  case Feature_HasVGPRIndexModeBit: return "";
  case Feature_HasMovrelBit: return "";
  case Feature_HasFmaMixInstsBit: return "";
  case Feature_HasFmaMixBF16InstsBit: return "";
  case Feature_HasDLInstsBit: return "";
  case Feature_HasFmacF64InstBit: return "";
  case Feature_HasDot1InstsBit: return "";
  case Feature_HasDot2InstsBit: return "";
  case Feature_HasDot3InstsBit: return "";
  case Feature_HasDot4InstsBit: return "";
  case Feature_HasDot5InstsBit: return "";
  case Feature_HasDot6InstsBit: return "";
  case Feature_HasDot7InstsBit: return "";
  case Feature_HasDot8InstsBit: return "";
  case Feature_HasDot9InstsBit: return "";
  case Feature_HasDot10InstsBit: return "";
  case Feature_HasDot11InstsBit: return "";
  case Feature_HasDot12InstsBit: return "";
  case Feature_HasDot13InstsBit: return "";
  case Feature_HasGetWaveIdInstBit: return "";
  case Feature_HasMAIInstsBit: return "";
  case Feature_NotHasMAIInstsBit: return "";
  case Feature_HasSMemRealTimeBit: return "";
  case Feature_HasSMemTimeInstBit: return "";
  case Feature_HasShaderCyclesRegisterBit: return "";
  case Feature_HasFP8InstsBit: return "";
  case Feature_HasFP8ConversionInstsBit: return "";
  case Feature_HasCubeInstsBit: return "";
  case Feature_HasLerpInstBit: return "";
  case Feature_HasSadInstsBit: return "";
  case Feature_HasQsadInstsBit: return "";
  case Feature_HasCvtNormInstsBit: return "";
  case Feature_HasCvtPkNormVOP2InstsBit: return "";
  case Feature_HasCvtPkNormVOP3InstsBit: return "";
  case Feature_HasFP8E5M3InstsBit: return "";
  case Feature_NotHasFP8E5M3InstsBit: return "";
  case Feature_HasPkFmacF16InstBit: return "";
  case Feature_HasMadMacF32InstsBit: return "";
  case Feature_HasFmaLegacy32Bit: return "";
  case Feature_HasFmacLegacy32Bit: return "";
  case Feature_HasAtomicDsPkAdd16InstsBit: return "";
  case Feature_HasAtomicDsCondSubClampInstsBit: return "";
  case Feature_HasAtomicFlatPkAdd16InstsBit: return "";
  case Feature_HasAtomicFaddRtnInstsBit: return "";
  case Feature_HasAtomicFaddNoRtnInstsBit: return "";
  case Feature_HasAtomicBufferGlobalPkAddF16NoRtnInstsBit: return "";
  case Feature_HasAtomicBufferGlobalPkAddF16InstsBit: return "";
  case Feature_HasAtomicGlobalPkAddBF16InstBit: return "";
  case Feature_HasAtomicBufferPkAddBF16InstBit: return "";
  case Feature_HasFlatAtomicFaddF32InstBit: return "";
  case Feature_HasDefaultComponentZeroBit: return "";
  case Feature_HasDefaultComponentBroadcastBit: return "";
  case Feature_HasDsSrc2InstsBit: return "";
  case Feature_HasAddPC64InstBit: return "";
  case Feature_HasUnalignedAccessModeBit: return "";
  case Feature_HasSALUFloatInstsBit: return "";
  case Feature_NotHasSALUFloatInstsBit: return "";
  case Feature_HasPseudoScalarTransBit: return "";
  case Feature_HasBitOp3InstsBit: return "";
  case Feature_HasTanhInstsBit: return "";
  case Feature_HasTensorCvtLutInstsBit: return "";
  case Feature_HasTransposeLoadF4F6InstsBit: return "";
  case Feature_HasPrngInstBit: return "";
  case Feature_HasBVHDualAndBVH8InstsBit: return "";
  case Feature_Has64BitLiteralsBit: return "";
  case Feature_Has1024AddressableVGPRsBit: return "";
  case Feature_HasMcastLoadInstsBit: return "";
  case Feature_HasWaitXcntBit: return "";
  case Feature_HasFP8ConversionScaleInstsBit: return "";
  case Feature_HasBF8ConversionScaleInstsBit: return "";
  case Feature_HasFP4ConversionScaleInstsBit: return "";
  case Feature_HasFP6BF6ConversionScaleInstsBit: return "";
  case Feature_HasF16BF16ToFP6BF6ConversionScaleInstsBit: return "";
  case Feature_HasCvtPkF16F32InstBit: return "";
  case Feature_HasF32ToF16BF16ConversionSRInstsBit: return "";
  case Feature_HasXF32InstsBit: return "";
  case Feature_HasVmemPrefInstsBit: return "";
  case Feature_HasAshrPkInstsBit: return "";
  case Feature_HasLshlAddU64InstBit: return "";
  case Feature_HasAddSubU64InstsBit: return "";
  case Feature_HasMadU32InstBit: return "";
  case Feature_HasLdsBarrierArriveAtomicBit: return "";
  case Feature_HasSetPrioIncWgInstBit: return "";
  case Feature_HasSWakeupBarrierBit: return "";
  case Feature_NeedsAlignedVGPRsBit: return "";
  case Feature_NotNeedsAlignedVGPRsBit: return "";
  case Feature_isWave32Bit: return "";
  case Feature_isWave64Bit: return "";
  case Feature_isWave32StrictBit: return "";
  case Feature_isWave64StrictBit: return "";
  default: return "(unknown)";
  }
}

#endif // GET_SUBTARGET_FEATURE_NAME


#ifdef GET_MATCHER_IMPLEMENTATION
#undef GET_MATCHER_IMPLEMENTATION

static void applyMnemonicAliases(StringRef &Mnemonic, const FeatureBitset &Features, unsigned VariantID) {
  switch (VariantID) {
  case 0:
      switch (Mnemonic.size()) {
      default: break;
      case 13:	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_cmp_tru_f", 11) != 0)
          break;
        switch (Mnemonic[11]) {
        default: break;
        case '1':	 // 1 string to match.
          if (Mnemonic[12] != '6')
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_tru_f16"
            Mnemonic = "v_cmp_t_f16";
          else if (Features.test(Feature_isGFX11OnlyBit))
            Mnemonic = "v_cmp_t_f16";
          return;
        case '3':	 // 1 string to match.
          if (Mnemonic[12] != '2')
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_tru_f32"
            Mnemonic = "v_cmp_t_f32";
          return;
        case '6':	 // 1 string to match.
          if (Mnemonic[12] != '4')
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_tru_f64"
            Mnemonic = "v_cmp_t_f64";
          return;
        }
        break;
      case 14:	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_cmpx_tru_f", 12) != 0)
          break;
        switch (Mnemonic[12]) {
        default: break;
        case '1':	 // 1 string to match.
          if (Mnemonic[13] != '6')
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_tru_f16"
            Mnemonic = "v_cmpx_t_f16";
          else if (Features.test(Feature_isGFX11OnlyBit))
            Mnemonic = "v_cmpx_t_f16";
          return;
        case '3':	 // 1 string to match.
          if (Mnemonic[13] != '2')
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_tru_f32"
            Mnemonic = "v_cmpx_t_f32";
          return;
        case '6':	 // 1 string to match.
          if (Mnemonic[13] != '4')
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_tru_f64"
            Mnemonic = "v_cmpx_t_f64";
          return;
        }
        break;
      case 15:	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_cmp_", 6) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case 'f':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "_f16_t16", 8) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_f_f16_t16"
            Mnemonic = "v_cmp_f_f16";
          return;
        case 'o':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "_f16_t16", 8) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_o_f16_t16"
            Mnemonic = "v_cmp_o_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_cmp_o_f16";
          return;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "_f16_t16", 8) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_u_f16_t16"
            Mnemonic = "v_cmp_u_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_cmp_u_f16";
          return;
        }
        break;
      case 16:	 // 21 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_cmp", 5) != 0)
          break;
        switch (Mnemonic[5]) {
        default: break;
        case '_':	 // 18 strings to match.
          switch (Mnemonic[6]) {
          default: break;
          case 'e':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+7, "q_", 2) != 0)
              break;
            switch (Mnemonic[9]) {
            default: break;
            case 'f':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_eq_f16_t16"
                Mnemonic = "v_cmp_eq_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_eq_f16";
              return;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_eq_i16_t16"
                Mnemonic = "v_cmp_eq_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_eq_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_eq_u16_t16"
                Mnemonic = "v_cmp_eq_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_eq_u16";
              return;
            }
            break;
          case 'g':	 // 6 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case 'e':	 // 3 strings to match.
              if (Mnemonic[8] != '_')
                break;
              switch (Mnemonic[9]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ge_f16_t16"
                  Mnemonic = "v_cmp_ge_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_ge_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ge_i16_t16"
                  Mnemonic = "v_cmp_ge_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_ge_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ge_u16_t16"
                  Mnemonic = "v_cmp_ge_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_ge_u16";
                return;
              }
              break;
            case 't':	 // 3 strings to match.
              if (Mnemonic[8] != '_')
                break;
              switch (Mnemonic[9]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_gt_f16_t16"
                  Mnemonic = "v_cmp_gt_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_gt_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_gt_i16_t16"
                  Mnemonic = "v_cmp_gt_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_gt_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_gt_u16_t16"
                  Mnemonic = "v_cmp_gt_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_gt_u16";
                return;
              }
              break;
            }
            break;
          case 'l':	 // 7 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case 'e':	 // 3 strings to match.
              if (Mnemonic[8] != '_')
                break;
              switch (Mnemonic[9]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_le_f16_t16"
                  Mnemonic = "v_cmp_le_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_le_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_le_i16_t16"
                  Mnemonic = "v_cmp_le_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_le_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_le_u16_t16"
                  Mnemonic = "v_cmp_le_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_le_u16";
                return;
              }
              break;
            case 'g':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_lg_f16_t16"
                Mnemonic = "v_cmp_lg_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_lg_f16";
              return;
            case 't':	 // 3 strings to match.
              if (Mnemonic[8] != '_')
                break;
              switch (Mnemonic[9]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_lt_f16_t16"
                  Mnemonic = "v_cmp_lt_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_lt_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_lt_i16_t16"
                  Mnemonic = "v_cmp_lt_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_lt_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_lt_u16_t16"
                  Mnemonic = "v_cmp_lt_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_lt_u16";
                return;
              }
              break;
            }
            break;
          case 'n':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "e_", 2) != 0)
              break;
            switch (Mnemonic[9]) {
            default: break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ne_i16_t16"
                Mnemonic = "v_cmp_ne_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_ne_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ne_u16_t16"
                Mnemonic = "v_cmp_ne_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_ne_u16";
              return;
            }
            break;
          }
          break;
        case 'x':	 // 3 strings to match.
          if (Mnemonic[6] != '_')
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "_f16_t16", 8) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_f_f16_t16"
              Mnemonic = "v_cmpx_f_f16";
            return;
          case 'o':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "_f16_t16", 8) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_o_f16_t16"
              Mnemonic = "v_cmpx_o_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmpx_o_f16";
            return;
          case 'u':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "_f16_t16", 8) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_u_f16_t16"
              Mnemonic = "v_cmpx_u_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmpx_u_f16";
            return;
          }
          break;
        }
        break;
      case 17:	 // 24 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_cmp", 5) != 0)
          break;
        switch (Mnemonic[5]) {
        default: break;
        case '_':	 // 6 strings to match.
          if (Mnemonic[6] != 'n')
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'e':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "q_f16_t16", 9) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_neq_f16_t16"
              Mnemonic = "v_cmp_neq_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmp_neq_f16";
            return;
          case 'g':	 // 2 strings to match.
            switch (Mnemonic[8]) {
            default: break;
            case 'e':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_nge_f16_t16"
                Mnemonic = "v_cmp_nge_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_nge_f16";
              return;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ngt_f16_t16"
                Mnemonic = "v_cmp_ngt_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_ngt_f16";
              return;
            }
            break;
          case 'l':	 // 3 strings to match.
            switch (Mnemonic[8]) {
            default: break;
            case 'e':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_nle_f16_t16"
                Mnemonic = "v_cmp_nle_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_nle_f16";
              return;
            case 'g':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_nlg_f16_t16"
                Mnemonic = "v_cmp_nlg_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_nlg_f16";
              return;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_nlt_f16_t16"
                Mnemonic = "v_cmp_nlt_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_nlt_f16";
              return;
            }
            break;
          }
          break;
        case 'x':	 // 18 strings to match.
          if (Mnemonic[6] != '_')
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'e':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+8, "q_", 2) != 0)
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'f':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_eq_f16_t16"
                Mnemonic = "v_cmpx_eq_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_eq_f16";
              return;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_eq_i16_t16"
                Mnemonic = "v_cmpx_eq_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_eq_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_eq_u16_t16"
                Mnemonic = "v_cmpx_eq_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_eq_u16";
              return;
            }
            break;
          case 'g':	 // 6 strings to match.
            switch (Mnemonic[8]) {
            default: break;
            case 'e':	 // 3 strings to match.
              if (Mnemonic[9] != '_')
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ge_f16_t16"
                  Mnemonic = "v_cmpx_ge_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_ge_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ge_i16_t16"
                  Mnemonic = "v_cmpx_ge_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_ge_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ge_u16_t16"
                  Mnemonic = "v_cmpx_ge_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_ge_u16";
                return;
              }
              break;
            case 't':	 // 3 strings to match.
              if (Mnemonic[9] != '_')
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_gt_f16_t16"
                  Mnemonic = "v_cmpx_gt_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_gt_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_gt_i16_t16"
                  Mnemonic = "v_cmpx_gt_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_gt_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_gt_u16_t16"
                  Mnemonic = "v_cmpx_gt_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_gt_u16";
                return;
              }
              break;
            }
            break;
          case 'l':	 // 7 strings to match.
            switch (Mnemonic[8]) {
            default: break;
            case 'e':	 // 3 strings to match.
              if (Mnemonic[9] != '_')
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_le_f16_t16"
                  Mnemonic = "v_cmpx_le_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_le_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_le_i16_t16"
                  Mnemonic = "v_cmpx_le_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_le_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_le_u16_t16"
                  Mnemonic = "v_cmpx_le_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_le_u16";
                return;
              }
              break;
            case 'g':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_lg_f16_t16"
                Mnemonic = "v_cmpx_lg_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_lg_f16";
              return;
            case 't':	 // 3 strings to match.
              if (Mnemonic[9] != '_')
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_lt_f16_t16"
                  Mnemonic = "v_cmpx_lt_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_lt_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_lt_i16_t16"
                  Mnemonic = "v_cmpx_lt_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_lt_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_lt_u16_t16"
                  Mnemonic = "v_cmpx_lt_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_lt_u16";
                return;
              }
              break;
            }
            break;
          case 'n':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+8, "e_", 2) != 0)
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ne_i16_t16"
                Mnemonic = "v_cmpx_ne_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_ne_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ne_u16_t16"
                Mnemonic = "v_cmpx_ne_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_ne_u16";
              return;
            }
            break;
          }
          break;
        }
        break;
      case 18:	 // 9 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_cmp", 5) != 0)
          break;
        switch (Mnemonic[5]) {
        default: break;
        case '_':	 // 3 strings to match.
          switch (Mnemonic[6]) {
          default: break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "_f16_fake16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_f_f16_fake16"
              Mnemonic = "v_cmp_f_f16";
            return;
          case 'o':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "_f16_fake16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_o_f16_fake16"
              Mnemonic = "v_cmp_o_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmp_o_f16";
            return;
          case 'u':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "_f16_fake16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_u_f16_fake16"
              Mnemonic = "v_cmp_u_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmp_u_f16";
            return;
          }
          break;
        case 'x':	 // 6 strings to match.
          if (memcmp(Mnemonic.data()+6, "_n", 2) != 0)
            break;
          switch (Mnemonic[8]) {
          default: break;
          case 'e':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+9, "q_f16_t16", 9) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_neq_f16_t16"
              Mnemonic = "v_cmpx_neq_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmpx_neq_f16";
            return;
          case 'g':	 // 2 strings to match.
            switch (Mnemonic[9]) {
            default: break;
            case 'e':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_nge_f16_t16"
                Mnemonic = "v_cmpx_nge_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_nge_f16";
              return;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ngt_f16_t16"
                Mnemonic = "v_cmpx_ngt_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_ngt_f16";
              return;
            }
            break;
          case 'l':	 // 3 strings to match.
            switch (Mnemonic[9]) {
            default: break;
            case 'e':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_nle_f16_t16"
                Mnemonic = "v_cmpx_nle_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_nle_f16";
              return;
            case 'g':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_nlg_f16_t16"
                Mnemonic = "v_cmpx_nlg_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_nlg_f16";
              return;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_nlt_f16_t16"
                Mnemonic = "v_cmpx_nlt_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_nlt_f16";
              return;
            }
            break;
          }
          break;
        }
        break;
      case 19:	 // 22 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_cmp", 5) != 0)
          break;
        switch (Mnemonic[5]) {
        default: break;
        case '_':	 // 19 strings to match.
          switch (Mnemonic[6]) {
          default: break;
          case 'c':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "lass_f16_t16", 12) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_class_f16_t16"
              Mnemonic = "v_cmp_class_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmp_class_f16";
            return;
          case 'e':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+7, "q_", 2) != 0)
              break;
            switch (Mnemonic[9]) {
            default: break;
            case 'f':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_eq_f16_fake16"
                Mnemonic = "v_cmp_eq_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_eq_f16";
              return;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_eq_i16_fake16"
                Mnemonic = "v_cmp_eq_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_eq_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_eq_u16_fake16"
                Mnemonic = "v_cmp_eq_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_eq_u16";
              return;
            }
            break;
          case 'g':	 // 6 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case 'e':	 // 3 strings to match.
              if (Mnemonic[8] != '_')
                break;
              switch (Mnemonic[9]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ge_f16_fake16"
                  Mnemonic = "v_cmp_ge_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_ge_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ge_i16_fake16"
                  Mnemonic = "v_cmp_ge_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_ge_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ge_u16_fake16"
                  Mnemonic = "v_cmp_ge_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_ge_u16";
                return;
              }
              break;
            case 't':	 // 3 strings to match.
              if (Mnemonic[8] != '_')
                break;
              switch (Mnemonic[9]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_gt_f16_fake16"
                  Mnemonic = "v_cmp_gt_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_gt_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_gt_i16_fake16"
                  Mnemonic = "v_cmp_gt_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_gt_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_gt_u16_fake16"
                  Mnemonic = "v_cmp_gt_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_gt_u16";
                return;
              }
              break;
            }
            break;
          case 'l':	 // 7 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case 'e':	 // 3 strings to match.
              if (Mnemonic[8] != '_')
                break;
              switch (Mnemonic[9]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_le_f16_fake16"
                  Mnemonic = "v_cmp_le_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_le_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_le_i16_fake16"
                  Mnemonic = "v_cmp_le_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_le_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_le_u16_fake16"
                  Mnemonic = "v_cmp_le_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_le_u16";
                return;
              }
              break;
            case 'g':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "_f16_fake16", 11) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_lg_f16_fake16"
                Mnemonic = "v_cmp_lg_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_lg_f16";
              return;
            case 't':	 // 3 strings to match.
              if (Mnemonic[8] != '_')
                break;
              switch (Mnemonic[9]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_lt_f16_fake16"
                  Mnemonic = "v_cmp_lt_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_lt_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_lt_i16_fake16"
                  Mnemonic = "v_cmp_lt_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_lt_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_lt_u16_fake16"
                  Mnemonic = "v_cmp_lt_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_lt_u16";
                return;
              }
              break;
            }
            break;
          case 'n':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "e_", 2) != 0)
              break;
            switch (Mnemonic[9]) {
            default: break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ne_i16_fake16"
                Mnemonic = "v_cmp_ne_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_ne_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ne_u16_fake16"
                Mnemonic = "v_cmp_ne_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_ne_u16";
              return;
            }
            break;
          }
          break;
        case 'x':	 // 3 strings to match.
          if (Mnemonic[6] != '_')
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "_f16_fake16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_f_f16_fake16"
              Mnemonic = "v_cmpx_f_f16";
            return;
          case 'o':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "_f16_fake16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_o_f16_fake16"
              Mnemonic = "v_cmpx_o_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmpx_o_f16";
            return;
          case 'u':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "_f16_fake16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_u_f16_fake16"
              Mnemonic = "v_cmpx_u_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmpx_u_f16";
            return;
          }
          break;
        }
        break;
      case 20:	 // 25 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_cmp", 5) != 0)
          break;
        switch (Mnemonic[5]) {
        default: break;
        case '_':	 // 6 strings to match.
          if (Mnemonic[6] != 'n')
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'e':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "q_f16_fake16", 12) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_neq_f16_fake16"
              Mnemonic = "v_cmp_neq_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmp_neq_f16";
            return;
          case 'g':	 // 2 strings to match.
            switch (Mnemonic[8]) {
            default: break;
            case 'e':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_fake16", 11) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_nge_f16_fake16"
                Mnemonic = "v_cmp_nge_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_nge_f16";
              return;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_fake16", 11) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ngt_f16_fake16"
                Mnemonic = "v_cmp_ngt_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_ngt_f16";
              return;
            }
            break;
          case 'l':	 // 3 strings to match.
            switch (Mnemonic[8]) {
            default: break;
            case 'e':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_fake16", 11) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_nle_f16_fake16"
                Mnemonic = "v_cmp_nle_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_nle_f16";
              return;
            case 'g':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_fake16", 11) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_nlg_f16_fake16"
                Mnemonic = "v_cmp_nlg_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_nlg_f16";
              return;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_fake16", 11) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_nlt_f16_fake16"
                Mnemonic = "v_cmp_nlt_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_nlt_f16";
              return;
            }
            break;
          }
          break;
        case 'x':	 // 19 strings to match.
          if (Mnemonic[6] != '_')
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'c':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "lass_f16_t16", 12) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_class_f16_t16"
              Mnemonic = "v_cmpx_class_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmpx_class_f16";
            return;
          case 'e':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+8, "q_", 2) != 0)
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'f':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_eq_f16_fake16"
                Mnemonic = "v_cmpx_eq_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_eq_f16";
              return;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_eq_i16_fake16"
                Mnemonic = "v_cmpx_eq_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_eq_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_eq_u16_fake16"
                Mnemonic = "v_cmpx_eq_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_eq_u16";
              return;
            }
            break;
          case 'g':	 // 6 strings to match.
            switch (Mnemonic[8]) {
            default: break;
            case 'e':	 // 3 strings to match.
              if (Mnemonic[9] != '_')
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ge_f16_fake16"
                  Mnemonic = "v_cmpx_ge_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_ge_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ge_i16_fake16"
                  Mnemonic = "v_cmpx_ge_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_ge_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ge_u16_fake16"
                  Mnemonic = "v_cmpx_ge_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_ge_u16";
                return;
              }
              break;
            case 't':	 // 3 strings to match.
              if (Mnemonic[9] != '_')
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_gt_f16_fake16"
                  Mnemonic = "v_cmpx_gt_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_gt_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_gt_i16_fake16"
                  Mnemonic = "v_cmpx_gt_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_gt_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_gt_u16_fake16"
                  Mnemonic = "v_cmpx_gt_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_gt_u16";
                return;
              }
              break;
            }
            break;
          case 'l':	 // 7 strings to match.
            switch (Mnemonic[8]) {
            default: break;
            case 'e':	 // 3 strings to match.
              if (Mnemonic[9] != '_')
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_le_f16_fake16"
                  Mnemonic = "v_cmpx_le_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_le_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_le_i16_fake16"
                  Mnemonic = "v_cmpx_le_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_le_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_le_u16_fake16"
                  Mnemonic = "v_cmpx_le_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_le_u16";
                return;
              }
              break;
            case 'g':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_fake16", 11) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_lg_f16_fake16"
                Mnemonic = "v_cmpx_lg_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_lg_f16";
              return;
            case 't':	 // 3 strings to match.
              if (Mnemonic[9] != '_')
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_lt_f16_fake16"
                  Mnemonic = "v_cmpx_lt_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_lt_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_lt_i16_fake16"
                  Mnemonic = "v_cmpx_lt_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_lt_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_lt_u16_fake16"
                  Mnemonic = "v_cmpx_lt_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_lt_u16";
                return;
              }
              break;
            }
            break;
          case 'n':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+8, "e_", 2) != 0)
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ne_i16_fake16"
                Mnemonic = "v_cmpx_ne_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_ne_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ne_u16_fake16"
                Mnemonic = "v_cmpx_ne_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_ne_u16";
              return;
            }
            break;
          }
          break;
        }
        break;
      case 21:	 // 6 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_cmpx_n", 8) != 0)
          break;
        switch (Mnemonic[8]) {
        default: break;
        case 'e':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+9, "q_f16_fake16", 12) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_neq_f16_fake16"
            Mnemonic = "v_cmpx_neq_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_cmpx_neq_f16";
          return;
        case 'g':	 // 2 strings to match.
          switch (Mnemonic[9]) {
          default: break;
          case 'e':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "_f16_fake16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_nge_f16_fake16"
              Mnemonic = "v_cmpx_nge_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmpx_nge_f16";
            return;
          case 't':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "_f16_fake16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ngt_f16_fake16"
              Mnemonic = "v_cmpx_ngt_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmpx_ngt_f16";
            return;
          }
          break;
        case 'l':	 // 3 strings to match.
          switch (Mnemonic[9]) {
          default: break;
          case 'e':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "_f16_fake16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_nle_f16_fake16"
              Mnemonic = "v_cmpx_nle_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmpx_nle_f16";
            return;
          case 'g':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "_f16_fake16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_nlg_f16_fake16"
              Mnemonic = "v_cmpx_nlg_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmpx_nlg_f16";
            return;
          case 't':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "_f16_fake16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_nlt_f16_fake16"
              Mnemonic = "v_cmpx_nlt_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmpx_nlt_f16";
            return;
          }
          break;
        }
        break;
      case 22:	 // 1 string to match.
        if (memcmp(Mnemonic.data()+0, "v_cmp_class_f16_fake16", 22) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_class_f16_fake16"
          Mnemonic = "v_cmp_class_f16";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_cmp_class_f16";
        return;
      case 23:	 // 1 string to match.
        if (memcmp(Mnemonic.data()+0, "v_cmpx_class_f16_fake16", 23) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_class_f16_fake16"
          Mnemonic = "v_cmpx_class_f16";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_cmpx_class_f16";
        return;
      }
    break;
  case 1:
      switch (Mnemonic.size()) {
      default: break;
      case 13:	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_cmp_tru_f", 11) != 0)
          break;
        switch (Mnemonic[11]) {
        default: break;
        case '1':	 // 1 string to match.
          if (Mnemonic[12] != '6')
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_tru_f16"
            Mnemonic = "v_cmp_t_f16";
          else if (Features.test(Feature_isGFX11OnlyBit))
            Mnemonic = "v_cmp_t_f16";
          return;
        case '3':	 // 1 string to match.
          if (Mnemonic[12] != '2')
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_tru_f32"
            Mnemonic = "v_cmp_t_f32";
          return;
        case '6':	 // 1 string to match.
          if (Mnemonic[12] != '4')
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_tru_f64"
            Mnemonic = "v_cmp_t_f64";
          return;
        }
        break;
      case 14:	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_cmpx_tru_f", 12) != 0)
          break;
        switch (Mnemonic[12]) {
        default: break;
        case '1':	 // 1 string to match.
          if (Mnemonic[13] != '6')
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_tru_f16"
            Mnemonic = "v_cmpx_t_f16";
          else if (Features.test(Feature_isGFX11OnlyBit))
            Mnemonic = "v_cmpx_t_f16";
          return;
        case '3':	 // 1 string to match.
          if (Mnemonic[13] != '2')
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_tru_f32"
            Mnemonic = "v_cmpx_t_f32";
          return;
        case '6':	 // 1 string to match.
          if (Mnemonic[13] != '4')
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_tru_f64"
            Mnemonic = "v_cmpx_t_f64";
          return;
        }
        break;
      case 15:	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_cmp_", 6) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case 'f':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "_f16_t16", 8) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_f_f16_t16"
            Mnemonic = "v_cmp_f_f16";
          return;
        case 'o':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "_f16_t16", 8) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_o_f16_t16"
            Mnemonic = "v_cmp_o_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_cmp_o_f16";
          return;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "_f16_t16", 8) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_u_f16_t16"
            Mnemonic = "v_cmp_u_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_cmp_u_f16";
          return;
        }
        break;
      case 16:	 // 21 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_cmp", 5) != 0)
          break;
        switch (Mnemonic[5]) {
        default: break;
        case '_':	 // 18 strings to match.
          switch (Mnemonic[6]) {
          default: break;
          case 'e':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+7, "q_", 2) != 0)
              break;
            switch (Mnemonic[9]) {
            default: break;
            case 'f':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_eq_f16_t16"
                Mnemonic = "v_cmp_eq_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_eq_f16";
              return;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_eq_i16_t16"
                Mnemonic = "v_cmp_eq_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_eq_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_eq_u16_t16"
                Mnemonic = "v_cmp_eq_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_eq_u16";
              return;
            }
            break;
          case 'g':	 // 6 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case 'e':	 // 3 strings to match.
              if (Mnemonic[8] != '_')
                break;
              switch (Mnemonic[9]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ge_f16_t16"
                  Mnemonic = "v_cmp_ge_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_ge_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ge_i16_t16"
                  Mnemonic = "v_cmp_ge_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_ge_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ge_u16_t16"
                  Mnemonic = "v_cmp_ge_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_ge_u16";
                return;
              }
              break;
            case 't':	 // 3 strings to match.
              if (Mnemonic[8] != '_')
                break;
              switch (Mnemonic[9]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_gt_f16_t16"
                  Mnemonic = "v_cmp_gt_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_gt_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_gt_i16_t16"
                  Mnemonic = "v_cmp_gt_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_gt_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_gt_u16_t16"
                  Mnemonic = "v_cmp_gt_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_gt_u16";
                return;
              }
              break;
            }
            break;
          case 'l':	 // 7 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case 'e':	 // 3 strings to match.
              if (Mnemonic[8] != '_')
                break;
              switch (Mnemonic[9]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_le_f16_t16"
                  Mnemonic = "v_cmp_le_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_le_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_le_i16_t16"
                  Mnemonic = "v_cmp_le_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_le_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_le_u16_t16"
                  Mnemonic = "v_cmp_le_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_le_u16";
                return;
              }
              break;
            case 'g':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_lg_f16_t16"
                Mnemonic = "v_cmp_lg_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_lg_f16";
              return;
            case 't':	 // 3 strings to match.
              if (Mnemonic[8] != '_')
                break;
              switch (Mnemonic[9]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_lt_f16_t16"
                  Mnemonic = "v_cmp_lt_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_lt_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_lt_i16_t16"
                  Mnemonic = "v_cmp_lt_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_lt_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_lt_u16_t16"
                  Mnemonic = "v_cmp_lt_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_lt_u16";
                return;
              }
              break;
            }
            break;
          case 'n':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "e_", 2) != 0)
              break;
            switch (Mnemonic[9]) {
            default: break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ne_i16_t16"
                Mnemonic = "v_cmp_ne_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_ne_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ne_u16_t16"
                Mnemonic = "v_cmp_ne_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_ne_u16";
              return;
            }
            break;
          }
          break;
        case 'x':	 // 3 strings to match.
          if (Mnemonic[6] != '_')
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "_f16_t16", 8) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_f_f16_t16"
              Mnemonic = "v_cmpx_f_f16";
            return;
          case 'o':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "_f16_t16", 8) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_o_f16_t16"
              Mnemonic = "v_cmpx_o_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmpx_o_f16";
            return;
          case 'u':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "_f16_t16", 8) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_u_f16_t16"
              Mnemonic = "v_cmpx_u_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmpx_u_f16";
            return;
          }
          break;
        }
        break;
      case 17:	 // 24 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_cmp", 5) != 0)
          break;
        switch (Mnemonic[5]) {
        default: break;
        case '_':	 // 6 strings to match.
          if (Mnemonic[6] != 'n')
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'e':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "q_f16_t16", 9) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_neq_f16_t16"
              Mnemonic = "v_cmp_neq_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmp_neq_f16";
            return;
          case 'g':	 // 2 strings to match.
            switch (Mnemonic[8]) {
            default: break;
            case 'e':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_nge_f16_t16"
                Mnemonic = "v_cmp_nge_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_nge_f16";
              return;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ngt_f16_t16"
                Mnemonic = "v_cmp_ngt_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_ngt_f16";
              return;
            }
            break;
          case 'l':	 // 3 strings to match.
            switch (Mnemonic[8]) {
            default: break;
            case 'e':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_nle_f16_t16"
                Mnemonic = "v_cmp_nle_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_nle_f16";
              return;
            case 'g':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_nlg_f16_t16"
                Mnemonic = "v_cmp_nlg_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_nlg_f16";
              return;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_nlt_f16_t16"
                Mnemonic = "v_cmp_nlt_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_nlt_f16";
              return;
            }
            break;
          }
          break;
        case 'x':	 // 18 strings to match.
          if (Mnemonic[6] != '_')
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'e':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+8, "q_", 2) != 0)
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'f':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_eq_f16_t16"
                Mnemonic = "v_cmpx_eq_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_eq_f16";
              return;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_eq_i16_t16"
                Mnemonic = "v_cmpx_eq_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_eq_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_eq_u16_t16"
                Mnemonic = "v_cmpx_eq_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_eq_u16";
              return;
            }
            break;
          case 'g':	 // 6 strings to match.
            switch (Mnemonic[8]) {
            default: break;
            case 'e':	 // 3 strings to match.
              if (Mnemonic[9] != '_')
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ge_f16_t16"
                  Mnemonic = "v_cmpx_ge_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_ge_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ge_i16_t16"
                  Mnemonic = "v_cmpx_ge_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_ge_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ge_u16_t16"
                  Mnemonic = "v_cmpx_ge_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_ge_u16";
                return;
              }
              break;
            case 't':	 // 3 strings to match.
              if (Mnemonic[9] != '_')
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_gt_f16_t16"
                  Mnemonic = "v_cmpx_gt_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_gt_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_gt_i16_t16"
                  Mnemonic = "v_cmpx_gt_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_gt_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_gt_u16_t16"
                  Mnemonic = "v_cmpx_gt_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_gt_u16";
                return;
              }
              break;
            }
            break;
          case 'l':	 // 7 strings to match.
            switch (Mnemonic[8]) {
            default: break;
            case 'e':	 // 3 strings to match.
              if (Mnemonic[9] != '_')
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_le_f16_t16"
                  Mnemonic = "v_cmpx_le_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_le_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_le_i16_t16"
                  Mnemonic = "v_cmpx_le_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_le_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_le_u16_t16"
                  Mnemonic = "v_cmpx_le_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_le_u16";
                return;
              }
              break;
            case 'g':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_lg_f16_t16"
                Mnemonic = "v_cmpx_lg_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_lg_f16";
              return;
            case 't':	 // 3 strings to match.
              if (Mnemonic[9] != '_')
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_lt_f16_t16"
                  Mnemonic = "v_cmpx_lt_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_lt_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_lt_i16_t16"
                  Mnemonic = "v_cmpx_lt_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_lt_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_lt_u16_t16"
                  Mnemonic = "v_cmpx_lt_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_lt_u16";
                return;
              }
              break;
            }
            break;
          case 'n':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+8, "e_", 2) != 0)
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ne_i16_t16"
                Mnemonic = "v_cmpx_ne_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_ne_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ne_u16_t16"
                Mnemonic = "v_cmpx_ne_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_ne_u16";
              return;
            }
            break;
          }
          break;
        }
        break;
      case 18:	 // 9 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_cmp", 5) != 0)
          break;
        switch (Mnemonic[5]) {
        default: break;
        case '_':	 // 3 strings to match.
          switch (Mnemonic[6]) {
          default: break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "_f16_fake16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_f_f16_fake16"
              Mnemonic = "v_cmp_f_f16";
            return;
          case 'o':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "_f16_fake16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_o_f16_fake16"
              Mnemonic = "v_cmp_o_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmp_o_f16";
            return;
          case 'u':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "_f16_fake16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_u_f16_fake16"
              Mnemonic = "v_cmp_u_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmp_u_f16";
            return;
          }
          break;
        case 'x':	 // 6 strings to match.
          if (memcmp(Mnemonic.data()+6, "_n", 2) != 0)
            break;
          switch (Mnemonic[8]) {
          default: break;
          case 'e':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+9, "q_f16_t16", 9) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_neq_f16_t16"
              Mnemonic = "v_cmpx_neq_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmpx_neq_f16";
            return;
          case 'g':	 // 2 strings to match.
            switch (Mnemonic[9]) {
            default: break;
            case 'e':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_nge_f16_t16"
                Mnemonic = "v_cmpx_nge_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_nge_f16";
              return;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ngt_f16_t16"
                Mnemonic = "v_cmpx_ngt_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_ngt_f16";
              return;
            }
            break;
          case 'l':	 // 3 strings to match.
            switch (Mnemonic[9]) {
            default: break;
            case 'e':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_nle_f16_t16"
                Mnemonic = "v_cmpx_nle_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_nle_f16";
              return;
            case 'g':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_nlg_f16_t16"
                Mnemonic = "v_cmpx_nlg_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_nlg_f16";
              return;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "_f16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_nlt_f16_t16"
                Mnemonic = "v_cmpx_nlt_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_nlt_f16";
              return;
            }
            break;
          }
          break;
        }
        break;
      case 19:	 // 22 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_cmp", 5) != 0)
          break;
        switch (Mnemonic[5]) {
        default: break;
        case '_':	 // 19 strings to match.
          switch (Mnemonic[6]) {
          default: break;
          case 'c':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "lass_f16_t16", 12) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_class_f16_t16"
              Mnemonic = "v_cmp_class_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmp_class_f16";
            return;
          case 'e':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+7, "q_", 2) != 0)
              break;
            switch (Mnemonic[9]) {
            default: break;
            case 'f':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_eq_f16_fake16"
                Mnemonic = "v_cmp_eq_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_eq_f16";
              return;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_eq_i16_fake16"
                Mnemonic = "v_cmp_eq_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_eq_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_eq_u16_fake16"
                Mnemonic = "v_cmp_eq_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_eq_u16";
              return;
            }
            break;
          case 'g':	 // 6 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case 'e':	 // 3 strings to match.
              if (Mnemonic[8] != '_')
                break;
              switch (Mnemonic[9]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ge_f16_fake16"
                  Mnemonic = "v_cmp_ge_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_ge_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ge_i16_fake16"
                  Mnemonic = "v_cmp_ge_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_ge_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ge_u16_fake16"
                  Mnemonic = "v_cmp_ge_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_ge_u16";
                return;
              }
              break;
            case 't':	 // 3 strings to match.
              if (Mnemonic[8] != '_')
                break;
              switch (Mnemonic[9]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_gt_f16_fake16"
                  Mnemonic = "v_cmp_gt_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_gt_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_gt_i16_fake16"
                  Mnemonic = "v_cmp_gt_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_gt_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_gt_u16_fake16"
                  Mnemonic = "v_cmp_gt_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_gt_u16";
                return;
              }
              break;
            }
            break;
          case 'l':	 // 7 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case 'e':	 // 3 strings to match.
              if (Mnemonic[8] != '_')
                break;
              switch (Mnemonic[9]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_le_f16_fake16"
                  Mnemonic = "v_cmp_le_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_le_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_le_i16_fake16"
                  Mnemonic = "v_cmp_le_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_le_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_le_u16_fake16"
                  Mnemonic = "v_cmp_le_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_le_u16";
                return;
              }
              break;
            case 'g':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "_f16_fake16", 11) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_lg_f16_fake16"
                Mnemonic = "v_cmp_lg_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_lg_f16";
              return;
            case 't':	 // 3 strings to match.
              if (Mnemonic[8] != '_')
                break;
              switch (Mnemonic[9]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_lt_f16_fake16"
                  Mnemonic = "v_cmp_lt_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_lt_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_lt_i16_fake16"
                  Mnemonic = "v_cmp_lt_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_lt_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_lt_u16_fake16"
                  Mnemonic = "v_cmp_lt_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmp_lt_u16";
                return;
              }
              break;
            }
            break;
          case 'n':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "e_", 2) != 0)
              break;
            switch (Mnemonic[9]) {
            default: break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ne_i16_fake16"
                Mnemonic = "v_cmp_ne_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_ne_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ne_u16_fake16"
                Mnemonic = "v_cmp_ne_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_ne_u16";
              return;
            }
            break;
          }
          break;
        case 'x':	 // 3 strings to match.
          if (Mnemonic[6] != '_')
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "_f16_fake16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_f_f16_fake16"
              Mnemonic = "v_cmpx_f_f16";
            return;
          case 'o':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "_f16_fake16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_o_f16_fake16"
              Mnemonic = "v_cmpx_o_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmpx_o_f16";
            return;
          case 'u':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "_f16_fake16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_u_f16_fake16"
              Mnemonic = "v_cmpx_u_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmpx_u_f16";
            return;
          }
          break;
        }
        break;
      case 20:	 // 25 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_cmp", 5) != 0)
          break;
        switch (Mnemonic[5]) {
        default: break;
        case '_':	 // 6 strings to match.
          if (Mnemonic[6] != 'n')
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'e':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "q_f16_fake16", 12) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_neq_f16_fake16"
              Mnemonic = "v_cmp_neq_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmp_neq_f16";
            return;
          case 'g':	 // 2 strings to match.
            switch (Mnemonic[8]) {
            default: break;
            case 'e':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_fake16", 11) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_nge_f16_fake16"
                Mnemonic = "v_cmp_nge_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_nge_f16";
              return;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_fake16", 11) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_ngt_f16_fake16"
                Mnemonic = "v_cmp_ngt_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_ngt_f16";
              return;
            }
            break;
          case 'l':	 // 3 strings to match.
            switch (Mnemonic[8]) {
            default: break;
            case 'e':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_fake16", 11) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_nle_f16_fake16"
                Mnemonic = "v_cmp_nle_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_nle_f16";
              return;
            case 'g':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_fake16", 11) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_nlg_f16_fake16"
                Mnemonic = "v_cmp_nlg_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_nlg_f16";
              return;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_fake16", 11) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_nlt_f16_fake16"
                Mnemonic = "v_cmp_nlt_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmp_nlt_f16";
              return;
            }
            break;
          }
          break;
        case 'x':	 // 19 strings to match.
          if (Mnemonic[6] != '_')
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'c':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "lass_f16_t16", 12) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_class_f16_t16"
              Mnemonic = "v_cmpx_class_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmpx_class_f16";
            return;
          case 'e':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+8, "q_", 2) != 0)
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'f':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_eq_f16_fake16"
                Mnemonic = "v_cmpx_eq_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_eq_f16";
              return;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_eq_i16_fake16"
                Mnemonic = "v_cmpx_eq_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_eq_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_eq_u16_fake16"
                Mnemonic = "v_cmpx_eq_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_eq_u16";
              return;
            }
            break;
          case 'g':	 // 6 strings to match.
            switch (Mnemonic[8]) {
            default: break;
            case 'e':	 // 3 strings to match.
              if (Mnemonic[9] != '_')
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ge_f16_fake16"
                  Mnemonic = "v_cmpx_ge_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_ge_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ge_i16_fake16"
                  Mnemonic = "v_cmpx_ge_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_ge_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ge_u16_fake16"
                  Mnemonic = "v_cmpx_ge_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_ge_u16";
                return;
              }
              break;
            case 't':	 // 3 strings to match.
              if (Mnemonic[9] != '_')
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_gt_f16_fake16"
                  Mnemonic = "v_cmpx_gt_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_gt_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_gt_i16_fake16"
                  Mnemonic = "v_cmpx_gt_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_gt_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_gt_u16_fake16"
                  Mnemonic = "v_cmpx_gt_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_gt_u16";
                return;
              }
              break;
            }
            break;
          case 'l':	 // 7 strings to match.
            switch (Mnemonic[8]) {
            default: break;
            case 'e':	 // 3 strings to match.
              if (Mnemonic[9] != '_')
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_le_f16_fake16"
                  Mnemonic = "v_cmpx_le_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_le_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_le_i16_fake16"
                  Mnemonic = "v_cmpx_le_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_le_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_le_u16_fake16"
                  Mnemonic = "v_cmpx_le_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_le_u16";
                return;
              }
              break;
            case 'g':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_f16_fake16", 11) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_lg_f16_fake16"
                Mnemonic = "v_cmpx_lg_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_lg_f16";
              return;
            case 't':	 // 3 strings to match.
              if (Mnemonic[9] != '_')
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_lt_f16_fake16"
                  Mnemonic = "v_cmpx_lt_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_lt_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_lt_i16_fake16"
                  Mnemonic = "v_cmpx_lt_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_lt_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_lt_u16_fake16"
                  Mnemonic = "v_cmpx_lt_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cmpx_lt_u16";
                return;
              }
              break;
            }
            break;
          case 'n':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+8, "e_", 2) != 0)
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ne_i16_fake16"
                Mnemonic = "v_cmpx_ne_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_ne_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ne_u16_fake16"
                Mnemonic = "v_cmpx_ne_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cmpx_ne_u16";
              return;
            }
            break;
          }
          break;
        }
        break;
      case 21:	 // 6 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_cmpx_n", 8) != 0)
          break;
        switch (Mnemonic[8]) {
        default: break;
        case 'e':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+9, "q_f16_fake16", 12) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_neq_f16_fake16"
            Mnemonic = "v_cmpx_neq_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_cmpx_neq_f16";
          return;
        case 'g':	 // 2 strings to match.
          switch (Mnemonic[9]) {
          default: break;
          case 'e':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "_f16_fake16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_nge_f16_fake16"
              Mnemonic = "v_cmpx_nge_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmpx_nge_f16";
            return;
          case 't':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "_f16_fake16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_ngt_f16_fake16"
              Mnemonic = "v_cmpx_ngt_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmpx_ngt_f16";
            return;
          }
          break;
        case 'l':	 // 3 strings to match.
          switch (Mnemonic[9]) {
          default: break;
          case 'e':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "_f16_fake16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_nle_f16_fake16"
              Mnemonic = "v_cmpx_nle_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmpx_nle_f16";
            return;
          case 'g':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "_f16_fake16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_nlg_f16_fake16"
              Mnemonic = "v_cmpx_nlg_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmpx_nlg_f16";
            return;
          case 't':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "_f16_fake16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_nlt_f16_fake16"
              Mnemonic = "v_cmpx_nlt_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cmpx_nlt_f16";
            return;
          }
          break;
        }
        break;
      case 22:	 // 1 string to match.
        if (memcmp(Mnemonic.data()+0, "v_cmp_class_f16_fake16", 22) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_class_f16_fake16"
          Mnemonic = "v_cmp_class_f16";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_cmp_class_f16";
        return;
      case 23:	 // 1 string to match.
        if (memcmp(Mnemonic.data()+0, "v_cmpx_class_f16_fake16", 23) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_class_f16_fake16"
          Mnemonic = "v_cmpx_class_f16";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_cmpx_class_f16";
        return;
      }
    break;
  case 2:
    break;
  case 3:
    break;
  case 4:
      switch (Mnemonic.size()) {
      default: break;
      case 9:	 // 1 string to match.
        if (memcmp(Mnemonic.data()+0, "v_nop_dpp", 9) != 0)
          break;
        Mnemonic = "v_nop";	 // "v_nop_dpp"
        return;
      case 13:	 // 19 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_", 2) != 0)
          break;
        switch (Mnemonic[2]) {
        default: break;
        case 'c':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+3, "os_f", 4) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "6_dpp", 5) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_cos_f16_dpp"
              Mnemonic = "v_cos_f16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "2_dpp", 5) != 0)
              break;
            Mnemonic = "v_cos_f32";	 // "v_cos_f32_dpp"
            return;
          }
          break;
        case 'e':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+3, "xp_f", 4) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "6_dpp", 5) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_exp_f16_dpp"
              Mnemonic = "v_exp_f16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "2_dpp", 5) != 0)
              break;
            Mnemonic = "v_exp_f32";	 // "v_exp_f32_dpp"
            return;
          }
          break;
        case 'l':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+3, "og_f", 4) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "6_dpp", 5) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_log_f16_dpp"
              Mnemonic = "v_log_f16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "2_dpp", 5) != 0)
              break;
            Mnemonic = "v_log_f32";	 // "v_log_f32_dpp"
            return;
          }
          break;
        case 'm':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+3, "ov_b", 4) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "6_dpp", 5) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_mov_b16_dpp"
              Mnemonic = "v_mov_b16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "2_dpp", 5) != 0)
              break;
            Mnemonic = "v_mov_b32";	 // "v_mov_b32_dpp"
            return;
          case '6':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "4_dpp", 5) != 0)
              break;
            if (Features.test(Feature_isGFX940orGFX1250Bit))	 // "v_mov_b64_dpp"
              Mnemonic = "v_mov_b64";
            return;
          }
          break;
        case 'n':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+3, "ot_b", 4) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "6_dpp", 5) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_not_b16_dpp"
              Mnemonic = "v_not_b16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "2_dpp", 5) != 0)
              break;
            Mnemonic = "v_not_b32";	 // "v_not_b32_dpp"
            return;
          }
          break;
        case 'r':	 // 6 strings to match.
          switch (Mnemonic[3]) {
          default: break;
          case 'c':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+4, "p_f", 3) != 0)
              break;
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "6_dpp", 5) != 0)
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_rcp_f16_dpp"
                Mnemonic = "v_rcp_f16";
              return;
            case '3':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "2_dpp", 5) != 0)
                break;
              Mnemonic = "v_rcp_f32";	 // "v_rcp_f32_dpp"
              return;
            case '6':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "4_dpp", 5) != 0)
                break;
              Mnemonic = "v_rcp_f64";	 // "v_rcp_f64_dpp"
              return;
            }
            break;
          case 's':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+4, "q_f", 3) != 0)
              break;
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "6_dpp", 5) != 0)
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_rsq_f16_dpp"
                Mnemonic = "v_rsq_f16";
              return;
            case '3':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "2_dpp", 5) != 0)
                break;
              Mnemonic = "v_rsq_f32";	 // "v_rsq_f32_dpp"
              return;
            case '6':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "4_dpp", 5) != 0)
                break;
              Mnemonic = "v_rsq_f64";	 // "v_rsq_f64_dpp"
              return;
            }
            break;
          }
          break;
        case 's':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+3, "in_f", 4) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "6_dpp", 5) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_sin_f16_dpp"
              Mnemonic = "v_sin_f16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "2_dpp", 5) != 0)
              break;
            Mnemonic = "v_sin_f32";	 // "v_sin_f32_dpp"
            return;
          }
          break;
        }
        break;
      case 14:	 // 18 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_", 2) != 0)
          break;
        switch (Mnemonic[2]) {
        default: break;
        case 'c':	 // 4 strings to match.
          switch (Mnemonic[3]) {
          default: break;
          case 'e':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+4, "il_f", 4) != 0)
              break;
            switch (Mnemonic[8]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "6_dpp", 5) != 0)
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_ceil_f16_dpp"
                Mnemonic = "v_ceil_f16";
              return;
            case '3':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "2_dpp", 5) != 0)
                break;
              Mnemonic = "v_ceil_f32";	 // "v_ceil_f32_dpp"
              return;
            case '6':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "4_dpp", 5) != 0)
                break;
              if (Features.test(Feature_isGFX7PlusBit))	 // "v_ceil_f64_dpp"
                Mnemonic = "v_ceil_f64";
              return;
            }
            break;
          case 'o':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "s_bf16_dpp", 10) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_cos_bf16_dpp"
              Mnemonic = "v_cos_bf16";
            return;
          }
          break;
        case 'e':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "xp_bf16_dpp", 11) != 0)
            break;
          if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_exp_bf16_dpp"
            Mnemonic = "v_exp_bf16";
          return;
        case 'f':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+3, "fb", 2) != 0)
            break;
          switch (Mnemonic[5]) {
          default: break;
          case 'h':	 // 2 strings to match.
            if (Mnemonic[6] != '_')
              break;
            switch (Mnemonic[7]) {
            default: break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "32_dpp", 6) != 0)
                break;
              Mnemonic = "v_ffbh_i32";	 // "v_ffbh_i32_dpp"
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "32_dpp", 6) != 0)
                break;
              Mnemonic = "v_ffbh_u32";	 // "v_ffbh_u32_dpp"
              return;
            }
            break;
          case 'l':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+6, "_b32_dpp", 8) != 0)
              break;
            Mnemonic = "v_ffbl_b32";	 // "v_ffbl_b32_dpp"
            return;
          }
          break;
        case 'l':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "og_bf16_dpp", 11) != 0)
            break;
          if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_log_bf16_dpp"
            Mnemonic = "v_log_bf16";
          return;
        case 'p':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "rng_b32_dpp", 11) != 0)
            break;
          if (Features.test(Feature_HasPrngInstBit))	 // "v_prng_b32_dpp"
            Mnemonic = "v_prng_b32";
          return;
        case 'r':	 // 2 strings to match.
          switch (Mnemonic[3]) {
          default: break;
          case 'c':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "p_bf16_dpp", 10) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rcp_bf16_dpp"
              Mnemonic = "v_rcp_bf16";
            return;
          case 's':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "q_bf16_dpp", 10) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rsq_bf16_dpp"
              Mnemonic = "v_rsq_bf16";
            return;
          }
          break;
        case 's':	 // 4 strings to match.
          switch (Mnemonic[3]) {
          default: break;
          case 'i':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "n_bf16_dpp", 10) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sin_bf16_dpp"
              Mnemonic = "v_sin_bf16";
            return;
          case 'q':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+4, "rt_f", 4) != 0)
              break;
            switch (Mnemonic[8]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "6_dpp", 5) != 0)
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_sqrt_f16_dpp"
                Mnemonic = "v_sqrt_f16";
              return;
            case '3':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "2_dpp", 5) != 0)
                break;
              Mnemonic = "v_sqrt_f32";	 // "v_sqrt_f32_dpp"
              return;
            case '6':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "4_dpp", 5) != 0)
                break;
              Mnemonic = "v_sqrt_f64";	 // "v_sqrt_f64_dpp"
              return;
            }
            break;
          }
          break;
        case 't':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+3, "anh_f", 5) != 0)
            break;
          switch (Mnemonic[8]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+9, "6_dpp", 5) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasTanhInstsBit))	 // "v_tanh_f16_dpp"
              Mnemonic = "v_tanh_f16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+9, "2_dpp", 5) != 0)
              break;
            if (Features.test(Feature_HasTanhInstsBit))	 // "v_tanh_f32_dpp"
              Mnemonic = "v_tanh_f32";
            return;
          }
          break;
        }
        break;
      case 15:	 // 15 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_", 2) != 0)
          break;
        switch (Mnemonic[2]) {
        default: break;
        case 'b':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "frev_b32_dpp", 12) != 0)
            break;
          Mnemonic = "v_bfrev_b32";	 // "v_bfrev_b32_dpp"
          return;
        case 'f':	 // 6 strings to match.
          switch (Mnemonic[3]) {
          default: break;
          case 'l':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+4, "oor_f", 5) != 0)
              break;
            switch (Mnemonic[9]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "6_dpp", 5) != 0)
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_floor_f16_dpp"
                Mnemonic = "v_floor_f16";
              return;
            case '3':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "2_dpp", 5) != 0)
                break;
              Mnemonic = "v_floor_f32";	 // "v_floor_f32_dpp"
              return;
            case '6':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "4_dpp", 5) != 0)
                break;
              if (Features.test(Feature_isGFX7PlusBit))	 // "v_floor_f64_dpp"
                Mnemonic = "v_floor_f64";
              return;
            }
            break;
          case 'r':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+4, "act_f", 5) != 0)
              break;
            switch (Mnemonic[9]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "6_dpp", 5) != 0)
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_fract_f16_dpp"
                Mnemonic = "v_fract_f16";
              return;
            case '3':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "2_dpp", 5) != 0)
                break;
              Mnemonic = "v_fract_f32";	 // "v_fract_f32_dpp"
              return;
            case '6':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "4_dpp", 5) != 0)
                break;
              Mnemonic = "v_fract_f64";	 // "v_fract_f64_dpp"
              return;
            }
            break;
          }
          break;
        case 'r':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+3, "ndne_f", 6) != 0)
            break;
          switch (Mnemonic[9]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "6_dpp", 5) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_rndne_f16_dpp"
              Mnemonic = "v_rndne_f16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "2_dpp", 5) != 0)
              break;
            Mnemonic = "v_rndne_f32";	 // "v_rndne_f32_dpp"
            return;
          case '6':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "4_dpp", 5) != 0)
              break;
            if (Features.test(Feature_isGFX7PlusBit))	 // "v_rndne_f64_dpp"
              Mnemonic = "v_rndne_f64";
            return;
          }
          break;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "qrt_bf16_dpp", 12) != 0)
            break;
          if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sqrt_bf16_dpp"
            Mnemonic = "v_sqrt_bf16";
          return;
        case 't':	 // 4 strings to match.
          switch (Mnemonic[3]) {
          default: break;
          case 'a':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "nh_bf16_dpp", 11) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_tanh_bf16_dpp"
              Mnemonic = "v_tanh_bf16";
            return;
          case 'r':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+4, "unc_f", 5) != 0)
              break;
            switch (Mnemonic[9]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "6_dpp", 5) != 0)
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_trunc_f16_dpp"
                Mnemonic = "v_trunc_f16";
              return;
            case '3':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "2_dpp", 5) != 0)
                break;
              Mnemonic = "v_trunc_f32";	 // "v_trunc_f32_dpp"
              return;
            case '6':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "4_dpp", 5) != 0)
                break;
              if (Features.test(Feature_isGFX7PlusBit))	 // "v_trunc_f64_dpp"
                Mnemonic = "v_trunc_f64";
              return;
            }
            break;
          }
          break;
        }
        break;
      case 17:	 // 32 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_", 2) != 0)
          break;
        switch (Mnemonic[2]) {
        default: break;
        case 'c':	 // 23 strings to match.
          switch (Mnemonic[3]) {
          default: break;
          case 'o':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "s_f16_t16_dpp", 13) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cos_f16_t16_dpp"
              Mnemonic = "v_cos_f16_t16";
            return;
          case 'v':	 // 22 strings to match.
            if (memcmp(Mnemonic.data()+4, "t_", 2) != 0)
              break;
            switch (Mnemonic[6]) {
            default: break;
            case 'f':	 // 14 strings to match.
              switch (Mnemonic[7]) {
              default: break;
              case '1':	 // 5 strings to match.
                if (memcmp(Mnemonic.data()+8, "6_", 2) != 0)
                  break;
                switch (Mnemonic[10]) {
                default: break;
                case 'b':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+11, "f8_dpp", 6) != 0)
                    break;
                  if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_f16_bf8_dpp"
                    Mnemonic = "v_cvt_f16_bf8";
                  return;
                case 'f':	 // 2 strings to match.
                  switch (Mnemonic[11]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (memcmp(Mnemonic.data()+12, "2_dpp", 5) != 0)
                      break;
                    if (Features.test(Feature_NotHasTrue16BitInstsBit))	 // "v_cvt_f16_f32_dpp"
                      Mnemonic = "v_cvt_f16_f32";
                    return;
                  case 'p':	 // 1 string to match.
                    if (memcmp(Mnemonic.data()+12, "8_dpp", 5) != 0)
                      break;
                    if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_f16_fp8_dpp"
                      Mnemonic = "v_cvt_f16_fp8";
                    return;
                  }
                  break;
                case 'i':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+11, "16_dpp", 6) != 0)
                    break;
                  if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_cvt_f16_i16_dpp"
                    Mnemonic = "v_cvt_f16_i16";
                  return;
                case 'u':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+11, "16_dpp", 6) != 0)
                    break;
                  if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_cvt_f16_u16_dpp"
                    Mnemonic = "v_cvt_f16_u16";
                  return;
                }
                break;
              case '3':	 // 6 strings to match.
                if (memcmp(Mnemonic.data()+8, "2_", 2) != 0)
                  break;
                switch (Mnemonic[10]) {
                default: break;
                case 'b':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+11, "f8_dpp", 6) != 0)
                    break;
                  if (Features.test(Feature_HasFP8ConversionInstsBit))	 // "v_cvt_f32_bf8_dpp"
                    Mnemonic = "v_cvt_f32_bf8";
                  return;
                case 'f':	 // 3 strings to match.
                  switch (Mnemonic[11]) {
                  default: break;
                  case '1':	 // 1 string to match.
                    if (memcmp(Mnemonic.data()+12, "6_dpp", 5) != 0)
                      break;
                    if (Features.test(Feature_NotHasTrue16BitInstsBit))	 // "v_cvt_f32_f16_dpp"
                      Mnemonic = "v_cvt_f32_f16";
                    return;
                  case '6':	 // 1 string to match.
                    if (memcmp(Mnemonic.data()+12, "4_dpp", 5) != 0)
                      break;
                    Mnemonic = "v_cvt_f32_f64";	 // "v_cvt_f32_f64_dpp"
                    return;
                  case 'p':	 // 1 string to match.
                    if (memcmp(Mnemonic.data()+12, "8_dpp", 5) != 0)
                      break;
                    if (Features.test(Feature_HasFP8ConversionInstsBit))	 // "v_cvt_f32_fp8_dpp"
                      Mnemonic = "v_cvt_f32_fp8";
                    return;
                  }
                  break;
                case 'i':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+11, "32_dpp", 6) != 0)
                    break;
                  Mnemonic = "v_cvt_f32_i32";	 // "v_cvt_f32_i32_dpp"
                  return;
                case 'u':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+11, "32_dpp", 6) != 0)
                    break;
                  Mnemonic = "v_cvt_f32_u32";	 // "v_cvt_f32_u32_dpp"
                  return;
                }
                break;
              case '6':	 // 3 strings to match.
                if (memcmp(Mnemonic.data()+8, "4_", 2) != 0)
                  break;
                switch (Mnemonic[10]) {
                default: break;
                case 'f':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+11, "32_dpp", 6) != 0)
                    break;
                  Mnemonic = "v_cvt_f64_f32";	 // "v_cvt_f64_f32_dpp"
                  return;
                case 'i':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+11, "32_dpp", 6) != 0)
                    break;
                  Mnemonic = "v_cvt_f64_i32";	 // "v_cvt_f64_i32_dpp"
                  return;
                case 'u':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+11, "32_dpp", 6) != 0)
                    break;
                  Mnemonic = "v_cvt_f64_u32";	 // "v_cvt_f64_u32_dpp"
                  return;
                }
                break;
              }
              break;
            case 'i':	 // 4 strings to match.
              switch (Mnemonic[7]) {
              default: break;
              case '1':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+8, "6_f16_dpp", 9) != 0)
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_cvt_i16_f16_dpp"
                  Mnemonic = "v_cvt_i16_f16";
                return;
              case '3':	 // 3 strings to match.
                if (memcmp(Mnemonic.data()+8, "2_", 2) != 0)
                  break;
                switch (Mnemonic[10]) {
                default: break;
                case 'f':	 // 2 strings to match.
                  switch (Mnemonic[11]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (memcmp(Mnemonic.data()+12, "2_dpp", 5) != 0)
                      break;
                    Mnemonic = "v_cvt_i32_f32";	 // "v_cvt_i32_f32_dpp"
                    return;
                  case '6':	 // 1 string to match.
                    if (memcmp(Mnemonic.data()+12, "4_dpp", 5) != 0)
                      break;
                    Mnemonic = "v_cvt_i32_f64";	 // "v_cvt_i32_f64_dpp"
                    return;
                  }
                  break;
                case 'i':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+11, "16_dpp", 6) != 0)
                    break;
                  if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_i32_i16_dpp"
                    Mnemonic = "v_cvt_i32_i16";
                  return;
                }
                break;
              }
              break;
            case 'u':	 // 4 strings to match.
              switch (Mnemonic[7]) {
              default: break;
              case '1':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+8, "6_f16_dpp", 9) != 0)
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_cvt_u16_f16_dpp"
                  Mnemonic = "v_cvt_u16_f16";
                return;
              case '3':	 // 3 strings to match.
                if (memcmp(Mnemonic.data()+8, "2_", 2) != 0)
                  break;
                switch (Mnemonic[10]) {
                default: break;
                case 'f':	 // 2 strings to match.
                  switch (Mnemonic[11]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (memcmp(Mnemonic.data()+12, "2_dpp", 5) != 0)
                      break;
                    Mnemonic = "v_cvt_u32_f32";	 // "v_cvt_u32_f32_dpp"
                    return;
                  case '6':	 // 1 string to match.
                    if (memcmp(Mnemonic.data()+12, "4_dpp", 5) != 0)
                      break;
                    Mnemonic = "v_cvt_u32_f64";	 // "v_cvt_u32_f64_dpp"
                    return;
                  }
                  break;
                case 'u':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+11, "16_dpp", 6) != 0)
                    break;
                  if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_u32_u16_dpp"
                    Mnemonic = "v_cvt_u32_u16";
                  return;
                }
                break;
              }
              break;
            }
            break;
          }
          break;
        case 'e':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "xp_f16_t16_dpp", 14) != 0)
            break;
          if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_exp_f16_t16_dpp"
            Mnemonic = "v_exp_f16_t16";
          return;
        case 'l':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "og_f16_t16_dpp", 14) != 0)
            break;
          if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_log_f16_t16_dpp"
            Mnemonic = "v_log_f16_t16";
          return;
        case 'm':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+3, "ov", 2) != 0)
            break;
          switch (Mnemonic[5]) {
          default: break;
          case '_':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+6, "b16_t16_dpp", 11) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_mov_b16_t16_dpp"
              Mnemonic = "v_mov_b16_t16";
            return;
          case 'r':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+6, "el", 2) != 0)
              break;
            switch (Mnemonic[8]) {
            default: break;
            case 'd':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_b32_dpp", 8) != 0)
                break;
              if (Features.test(Feature_HasMovrelBit))	 // "v_movreld_b32_dpp"
                Mnemonic = "v_movreld_b32";
              return;
            case 's':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_b32_dpp", 8) != 0)
                break;
              if (Features.test(Feature_HasMovrelBit))	 // "v_movrels_b32_dpp"
                Mnemonic = "v_movrels_b32";
              return;
            }
            break;
          }
          break;
        case 'n':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "ot_b16_t16_dpp", 14) != 0)
            break;
          if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_not_b16_t16_dpp"
            Mnemonic = "v_not_b16_t16";
          return;
        case 'r':	 // 2 strings to match.
          switch (Mnemonic[3]) {
          default: break;
          case 'c':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "p_f16_t16_dpp", 13) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_rcp_f16_t16_dpp"
              Mnemonic = "v_rcp_f16_t16";
            return;
          case 's':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "q_f16_t16_dpp", 13) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_rsq_f16_t16_dpp"
              Mnemonic = "v_rsq_f16_t16";
            return;
          }
          break;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "in_f16_t16_dpp", 14) != 0)
            break;
          if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_sin_f16_t16_dpp"
            Mnemonic = "v_sin_f16_t16";
          return;
        }
        break;
      case 18:	 // 11 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_", 2) != 0)
          break;
        switch (Mnemonic[2]) {
        default: break;
        case 'c':	 // 3 strings to match.
          switch (Mnemonic[3]) {
          default: break;
          case 'e':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "il_f16_t16_dpp", 14) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_ceil_f16_t16_dpp"
              Mnemonic = "v_ceil_f16_t16";
            return;
          case 'o':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "s_bf16_t16_dpp", 14) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_cos_bf16_t16_dpp"
              Mnemonic = "v_cos_bf16_t16";
            return;
          case 'v':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "t_f32_bf16_dpp", 14) != 0)
              break;
            if (Features.test(Feature_HasBF16ConversionInstsBit) && Features.test(Feature_HasGFX950InstsBit))	 // "v_cvt_f32_bf16_dpp"
              Mnemonic = "v_cvt_f32_bf16";
            return;
          }
          break;
        case 'e':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "xp_bf16_t16_dpp", 15) != 0)
            break;
          if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_exp_bf16_t16_dpp"
            Mnemonic = "v_exp_bf16_t16";
          return;
        case 'l':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "og_bf16_t16_dpp", 15) != 0)
            break;
          if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_log_bf16_t16_dpp"
            Mnemonic = "v_log_bf16_t16";
          return;
        case 'm':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "ovrelsd_b32_dpp", 15) != 0)
            break;
          if (Features.test(Feature_HasMovrelBit))	 // "v_movrelsd_b32_dpp"
            Mnemonic = "v_movrelsd_b32";
          return;
        case 'r':	 // 2 strings to match.
          switch (Mnemonic[3]) {
          default: break;
          case 'c':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "p_bf16_t16_dpp", 14) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rcp_bf16_t16_dpp"
              Mnemonic = "v_rcp_bf16_t16";
            return;
          case 's':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "q_bf16_t16_dpp", 14) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rsq_bf16_t16_dpp"
              Mnemonic = "v_rsq_bf16_t16";
            return;
          }
          break;
        case 's':	 // 2 strings to match.
          switch (Mnemonic[3]) {
          default: break;
          case 'i':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "n_bf16_t16_dpp", 14) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sin_bf16_t16_dpp"
              Mnemonic = "v_sin_bf16_t16";
            return;
          case 'q':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "rt_f16_t16_dpp", 14) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_sqrt_f16_t16_dpp"
              Mnemonic = "v_sqrt_f16_t16";
            return;
          }
          break;
        case 't':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "anh_f16_t16_dpp", 15) != 0)
            break;
          if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasTanhInstsBit))	 // "v_tanh_f16_t16_dpp"
            Mnemonic = "v_tanh_f16_t16";
          return;
        }
        break;
      case 19:	 // 15 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_", 2) != 0)
          break;
        switch (Mnemonic[2]) {
        default: break;
        case 'f':	 // 2 strings to match.
          switch (Mnemonic[3]) {
          default: break;
          case 'l':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "oor_f16_t16_dpp", 15) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_floor_f16_t16_dpp"
              Mnemonic = "v_floor_f16_t16";
            return;
          case 'r':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "act_f16_t16_dpp", 15) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_fract_f16_t16_dpp"
              Mnemonic = "v_fract_f16_t16";
            return;
          }
          break;
        case 'l':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "og_clamp_f32_dpp", 16) != 0)
            break;
          if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_log_clamp_f32_dpp"
            Mnemonic = "v_log_clamp_f32";
          return;
        case 'r':	 // 6 strings to match.
          switch (Mnemonic[3]) {
          default: break;
          case 'c':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+4, "p_", 2) != 0)
              break;
            switch (Mnemonic[6]) {
            default: break;
            case 'c':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+7, "lamp_f", 6) != 0)
                break;
              switch (Mnemonic[13]) {
              default: break;
              case '3':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+14, "2_dpp", 5) != 0)
                  break;
                if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_rcp_clamp_f32_dpp"
                  Mnemonic = "v_rcp_clamp_f32";
                return;
              case '6':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+14, "4_dpp", 5) != 0)
                  break;
                if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_rcp_clamp_f64_dpp"
                  Mnemonic = "v_rcp_clamp_f64";
                return;
              }
              break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "flag_f32_dpp", 12) != 0)
                break;
              Mnemonic = "v_rcp_iflag_f32";	 // "v_rcp_iflag_f32_dpp"
              return;
            }
            break;
          case 'n':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "dne_f16_t16_dpp", 15) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_rndne_f16_t16_dpp"
              Mnemonic = "v_rndne_f16_t16";
            return;
          case 's':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+4, "q_clamp_f", 9) != 0)
              break;
            switch (Mnemonic[13]) {
            default: break;
            case '3':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+14, "2_dpp", 5) != 0)
                break;
              if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_rsq_clamp_f32_dpp"
                Mnemonic = "v_rsq_clamp_f32";
              return;
            case '6':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+14, "4_dpp", 5) != 0)
                break;
              if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_rsq_clamp_f64_dpp"
                Mnemonic = "v_rsq_clamp_f64";
              return;
            }
            break;
          }
          break;
        case 's':	 // 4 strings to match.
          switch (Mnemonic[3]) {
          default: break;
          case 'a':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+4, "t_pk", 4) != 0)
              break;
            switch (Mnemonic[8]) {
            default: break;
            case '4':	 // 2 strings to match.
              if (Mnemonic[9] != '_')
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "4_i8_dpp", 8) != 0)
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_i4_i8_dpp"
                  Mnemonic = "v_sat_pk4_i4_i8";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "4_u8_dpp", 8) != 0)
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_u4_u8_dpp"
                  Mnemonic = "v_sat_pk4_u4_u8";
                return;
              }
              break;
            case '_':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "u8_i16_dpp", 10) != 0)
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX9PlusBit))	 // "v_sat_pk_u8_i16_dpp"
                Mnemonic = "v_sat_pk_u8_i16";
              return;
            }
            break;
          case 'q':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "rt_bf16_t16_dpp", 15) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sqrt_bf16_t16_dpp"
              Mnemonic = "v_sqrt_bf16_t16";
            return;
          }
          break;
        case 't':	 // 2 strings to match.
          switch (Mnemonic[3]) {
          default: break;
          case 'a':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "nh_bf16_t16_dpp", 15) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_tanh_bf16_t16_dpp"
              Mnemonic = "v_tanh_bf16_t16";
            return;
          case 'r':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "unc_f16_t16_dpp", 15) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_trunc_f16_t16_dpp"
              Mnemonic = "v_trunc_f16_t16";
            return;
          }
          break;
        }
        break;
      case 20:	 // 25 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_", 2) != 0)
          break;
        switch (Mnemonic[2]) {
        default: break;
        case 'c':	 // 10 strings to match.
          switch (Mnemonic[3]) {
          default: break;
          case 'o':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "s_f16_fake16_dpp", 16) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cos_f16_fake16_dpp"
              Mnemonic = "v_cos_f16_fake16";
            return;
          case 'v':	 // 9 strings to match.
            if (memcmp(Mnemonic.data()+4, "t_", 2) != 0)
              break;
            switch (Mnemonic[6]) {
            default: break;
            case 'f':	 // 4 strings to match.
              if (memcmp(Mnemonic.data()+7, "32_ubyte", 8) != 0)
                break;
              switch (Mnemonic[15]) {
              default: break;
              case '0':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+16, "_dpp", 4) != 0)
                  break;
                Mnemonic = "v_cvt_f32_ubyte0";	 // "v_cvt_f32_ubyte0_dpp"
                return;
              case '1':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+16, "_dpp", 4) != 0)
                  break;
                Mnemonic = "v_cvt_f32_ubyte1";	 // "v_cvt_f32_ubyte1_dpp"
                return;
              case '2':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+16, "_dpp", 4) != 0)
                  break;
                Mnemonic = "v_cvt_f32_ubyte2";	 // "v_cvt_f32_ubyte2_dpp"
                return;
              case '3':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+16, "_dpp", 4) != 0)
                  break;
                Mnemonic = "v_cvt_f32_ubyte3";	 // "v_cvt_f32_ubyte3_dpp"
                return;
              }
              break;
            case 'o':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "ff_f32_i4_dpp", 13) != 0)
                break;
              Mnemonic = "v_cvt_off_f32_i4";	 // "v_cvt_off_f32_i4_dpp"
              return;
            case 'p':	 // 4 strings to match.
              if (memcmp(Mnemonic.data()+7, "k_f", 3) != 0)
                break;
              switch (Mnemonic[10]) {
              default: break;
              case '1':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+11, "6_", 2) != 0)
                  break;
                switch (Mnemonic[13]) {
                default: break;
                case 'b':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+14, "f8_dpp", 6) != 0)
                    break;
                  if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_pk_f16_bf8_dpp"
                    Mnemonic = "v_cvt_pk_f16_bf8";
                  return;
                case 'f':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+14, "p8_dpp", 6) != 0)
                    break;
                  if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_pk_f16_fp8_dpp"
                    Mnemonic = "v_cvt_pk_f16_fp8";
                  return;
                }
                break;
              case '3':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+11, "2_", 2) != 0)
                  break;
                switch (Mnemonic[13]) {
                default: break;
                case 'b':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+14, "f8_dpp", 6) != 0)
                    break;
                  if (Features.test(Feature_HasFP8ConversionInstsBit))	 // "v_cvt_pk_f32_bf8_dpp"
                    Mnemonic = "v_cvt_pk_f32_bf8";
                  return;
                case 'f':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+14, "p8_dpp", 6) != 0)
                    break;
                  if (Features.test(Feature_HasFP8ConversionInstsBit))	 // "v_cvt_pk_f32_fp8_dpp"
                    Mnemonic = "v_cvt_pk_f32_fp8";
                  return;
                }
                break;
              }
              break;
            }
            break;
          }
          break;
        case 'e':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+3, "xp_", 3) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "16_fake16_dpp", 13) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_exp_f16_fake16_dpp"
              Mnemonic = "v_exp_f16_fake16";
            return;
          case 'l':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "egacy_f32_dpp", 13) != 0)
              break;
            if (Features.test(Feature_isGFX7GFX8GFX9Bit))	 // "v_exp_legacy_f32_dpp"
              Mnemonic = "v_exp_legacy_f32";
            return;
          }
          break;
        case 'f':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+3, "rexp_mant_f", 11) != 0)
            break;
          switch (Mnemonic[14]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+15, "6_dpp", 5) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_frexp_mant_f16_dpp"
              Mnemonic = "v_frexp_mant_f16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+15, "2_dpp", 5) != 0)
              break;
            Mnemonic = "v_frexp_mant_f32";	 // "v_frexp_mant_f32_dpp"
            return;
          case '6':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+15, "4_dpp", 5) != 0)
              break;
            Mnemonic = "v_frexp_mant_f64";	 // "v_frexp_mant_f64_dpp"
            return;
          }
          break;
        case 'l':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+3, "og_", 3) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "16_fake16_dpp", 13) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_log_f16_fake16_dpp"
              Mnemonic = "v_log_f16_fake16";
            return;
          case 'l':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "egacy_f32_dpp", 13) != 0)
              break;
            if (Features.test(Feature_isGFX7GFX8GFX9Bit))	 // "v_log_legacy_f32_dpp"
              Mnemonic = "v_log_legacy_f32";
            return;
          }
          break;
        case 'm':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+3, "ov", 2) != 0)
            break;
          switch (Mnemonic[5]) {
          default: break;
          case '_':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+6, "b16_fake16_dpp", 14) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_mov_b16_fake16_dpp"
              Mnemonic = "v_mov_b16_fake16";
            return;
          case 'r':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+6, "elsd_2_b32_dpp", 14) != 0)
              break;
            if (Features.test(Feature_isGFX10PlusBit))	 // "v_movrelsd_2_b32_dpp"
              Mnemonic = "v_movrelsd_2_b32";
            return;
          }
          break;
        case 'n':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "ot_b16_fake16_dpp", 17) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_not_b16_fake16_dpp"
            Mnemonic = "v_not_b16_fake16";
          return;
        case 'r':	 // 4 strings to match.
          switch (Mnemonic[3]) {
          default: break;
          case 'c':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+4, "p_", 2) != 0)
              break;
            switch (Mnemonic[6]) {
            default: break;
            case 'f':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "16_fake16_dpp", 13) != 0)
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_rcp_f16_fake16_dpp"
                Mnemonic = "v_rcp_f16_fake16";
              return;
            case 'l':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "egacy_f32_dpp", 13) != 0)
                break;
              if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_rcp_legacy_f32_dpp"
                Mnemonic = "v_rcp_legacy_f32";
              return;
            }
            break;
          case 's':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+4, "q_", 2) != 0)
              break;
            switch (Mnemonic[6]) {
            default: break;
            case 'f':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "16_fake16_dpp", 13) != 0)
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_rsq_f16_fake16_dpp"
                Mnemonic = "v_rsq_f16_fake16";
              return;
            case 'l':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "egacy_f32_dpp", 13) != 0)
                break;
              if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_rsq_legacy_f32_dpp"
                Mnemonic = "v_rsq_legacy_f32";
              return;
            }
            break;
          }
          break;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "in_f16_fake16_dpp", 17) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_sin_f16_fake16_dpp"
            Mnemonic = "v_sin_f16_fake16";
          return;
        }
        break;
      case 21:	 // 21 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_", 2) != 0)
          break;
        switch (Mnemonic[2]) {
        default: break;
        case 'c':	 // 14 strings to match.
          switch (Mnemonic[3]) {
          default: break;
          case 'e':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "il_f16_fake16_dpp", 17) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_ceil_f16_fake16_dpp"
              Mnemonic = "v_ceil_f16_fake16";
            return;
          case 'o':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "s_bf16_fake16_dpp", 17) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_cos_bf16_fake16_dpp"
              Mnemonic = "v_cos_bf16_fake16";
            return;
          case 'v':	 // 12 strings to match.
            if (memcmp(Mnemonic.data()+4, "t_", 2) != 0)
              break;
            switch (Mnemonic[6]) {
            default: break;
            case 'f':	 // 7 strings to match.
              switch (Mnemonic[7]) {
              default: break;
              case '1':	 // 5 strings to match.
                if (memcmp(Mnemonic.data()+8, "6_", 2) != 0)
                  break;
                switch (Mnemonic[10]) {
                default: break;
                case 'b':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+11, "f8_t16_dpp", 10) != 0)
                    break;
                  if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_f16_bf8_t16_dpp"
                    Mnemonic = "v_cvt_f16_bf8_t16";
                  return;
                case 'f':	 // 2 strings to match.
                  switch (Mnemonic[11]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (memcmp(Mnemonic.data()+12, "2_t16_dpp", 9) != 0)
                      break;
                    if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_f16_f32_t16_dpp"
                      Mnemonic = "v_cvt_f16_f32_t16";
                    return;
                  case 'p':	 // 1 string to match.
                    if (memcmp(Mnemonic.data()+12, "8_t16_dpp", 9) != 0)
                      break;
                    if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_f16_fp8_t16_dpp"
                      Mnemonic = "v_cvt_f16_fp8_t16";
                    return;
                  }
                  break;
                case 'i':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+11, "16_t16_dpp", 10) != 0)
                    break;
                  if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_f16_i16_t16_dpp"
                    Mnemonic = "v_cvt_f16_i16_t16";
                  return;
                case 'u':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+11, "16_t16_dpp", 10) != 0)
                    break;
                  if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_f16_u16_t16_dpp"
                    Mnemonic = "v_cvt_f16_u16_t16";
                  return;
                }
                break;
              case '3':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+8, "2_f16_t16_dpp", 13) != 0)
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_f32_f16_t16_dpp"
                  Mnemonic = "v_cvt_f32_f16_t16";
                return;
              case 'l':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+8, "r_i32_f32_dpp", 13) != 0)
                  break;
                Mnemonic = "v_cvt_flr_i32_f32";	 // "v_cvt_flr_i32_f32_dpp"
                return;
              }
              break;
            case 'i':	 // 2 strings to match.
              switch (Mnemonic[7]) {
              default: break;
              case '1':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+8, "6_f16_t16_dpp", 13) != 0)
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_i16_f16_t16_dpp"
                  Mnemonic = "v_cvt_i16_f16_t16";
                return;
              case '3':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+8, "2_i16_t16_dpp", 13) != 0)
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_i32_i16_t16_dpp"
                  Mnemonic = "v_cvt_i32_i16_t16";
                return;
              }
              break;
            case 'r':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "pi_i32_f32_dpp", 14) != 0)
                break;
              Mnemonic = "v_cvt_rpi_i32_f32";	 // "v_cvt_rpi_i32_f32_dpp"
              return;
            case 'u':	 // 2 strings to match.
              switch (Mnemonic[7]) {
              default: break;
              case '1':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+8, "6_f16_t16_dpp", 13) != 0)
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_u16_f16_t16_dpp"
                  Mnemonic = "v_cvt_u16_f16_t16";
                return;
              case '3':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+8, "2_u16_t16_dpp", 13) != 0)
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_u32_u16_t16_dpp"
                  Mnemonic = "v_cvt_u32_u16_t16";
                return;
              }
              break;
            }
            break;
          }
          break;
        case 'e':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "xp_bf16_fake16_dpp", 18) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_exp_bf16_fake16_dpp"
            Mnemonic = "v_exp_bf16_fake16";
          return;
        case 'l':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "og_bf16_fake16_dpp", 18) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_log_bf16_fake16_dpp"
            Mnemonic = "v_log_bf16_fake16";
          return;
        case 'r':	 // 2 strings to match.
          switch (Mnemonic[3]) {
          default: break;
          case 'c':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "p_bf16_fake16_dpp", 17) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rcp_bf16_fake16_dpp"
              Mnemonic = "v_rcp_bf16_fake16";
            return;
          case 's':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "q_bf16_fake16_dpp", 17) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rsq_bf16_fake16_dpp"
              Mnemonic = "v_rsq_bf16_fake16";
            return;
          }
          break;
        case 's':	 // 2 strings to match.
          switch (Mnemonic[3]) {
          default: break;
          case 'i':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "n_bf16_fake16_dpp", 17) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sin_bf16_fake16_dpp"
              Mnemonic = "v_sin_bf16_fake16";
            return;
          case 'q':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "rt_f16_fake16_dpp", 17) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_sqrt_f16_fake16_dpp"
              Mnemonic = "v_sqrt_f16_fake16";
            return;
          }
          break;
        case 't':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "anh_f16_fake16_dpp", 18) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasTanhInstsBit))	 // "v_tanh_f16_fake16_dpp"
            Mnemonic = "v_tanh_f16_fake16";
          return;
        }
        break;
      case 22:	 // 9 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_", 2) != 0)
          break;
        switch (Mnemonic[2]) {
        default: break;
        case 'c':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+3, "vt_", 3) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "32_bf16_t16_dpp", 15) != 0)
              break;
            if (Features.test(Feature_HasBF16ConversionInstsBit) && Features.test(Feature_HasGFX950InstsBit))	 // "v_cvt_f32_bf16_t16_dpp"
              Mnemonic = "v_cvt_f32_bf16_t16";
            return;
          case 'n':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "orm_", 4) != 0)
              break;
            switch (Mnemonic[11]) {
            default: break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+12, "16_f16_dpp", 10) != 0)
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_i16_f16_dpp"
                Mnemonic = "v_cvt_norm_i16_f16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+12, "16_f16_dpp", 10) != 0)
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_u16_f16_dpp"
                Mnemonic = "v_cvt_norm_u16_f16";
              return;
            }
            break;
          }
          break;
        case 'f':	 // 2 strings to match.
          switch (Mnemonic[3]) {
          default: break;
          case 'l':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "oor_f16_fake16_dpp", 18) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_floor_f16_fake16_dpp"
              Mnemonic = "v_floor_f16_fake16";
            return;
          case 'r':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "act_f16_fake16_dpp", 18) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_fract_f16_fake16_dpp"
              Mnemonic = "v_fract_f16_fake16";
            return;
          }
          break;
        case 'r':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "ndne_f16_fake16_dpp", 19) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_rndne_f16_fake16_dpp"
            Mnemonic = "v_rndne_f16_fake16";
          return;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "qrt_bf16_fake16_dpp", 19) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sqrt_bf16_fake16_dpp"
            Mnemonic = "v_sqrt_bf16_fake16";
          return;
        case 't':	 // 2 strings to match.
          switch (Mnemonic[3]) {
          default: break;
          case 'a':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "nh_bf16_fake16_dpp", 18) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_tanh_bf16_fake16_dpp"
              Mnemonic = "v_tanh_bf16_fake16";
            return;
          case 'r':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+4, "unc_f16_fake16_dpp", 18) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_trunc_f16_fake16_dpp"
              Mnemonic = "v_trunc_f16_fake16";
            return;
          }
          break;
        }
        break;
      case 23:	 // 6 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_", 2) != 0)
          break;
        switch (Mnemonic[2]) {
        default: break;
        case 'f':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+3, "rexp_exp_i", 10) != 0)
            break;
          switch (Mnemonic[13]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "6_f16_dpp", 9) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_frexp_exp_i16_f16_dpp"
              Mnemonic = "v_frexp_exp_i16_f16";
            return;
          case '3':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+14, "2_f", 3) != 0)
              break;
            switch (Mnemonic[17]) {
            default: break;
            case '3':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+18, "2_dpp", 5) != 0)
                break;
              Mnemonic = "v_frexp_exp_i32_f32";	 // "v_frexp_exp_i32_f32_dpp"
              return;
            case '6':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+18, "4_dpp", 5) != 0)
                break;
              Mnemonic = "v_frexp_exp_i32_f64";	 // "v_frexp_exp_i32_f64_dpp"
              return;
            }
            break;
          }
          break;
        case 's':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+3, "at_pk", 5) != 0)
            break;
          switch (Mnemonic[8]) {
          default: break;
          case '4':	 // 2 strings to match.
            if (Mnemonic[9] != '_')
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "4_i8_t16_dpp", 12) != 0)
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_i4_i8_t16_dpp"
                Mnemonic = "v_sat_pk4_i4_i8_t16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "4_u8_t16_dpp", 12) != 0)
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_u4_u8_t16_dpp"
                Mnemonic = "v_sat_pk4_u4_u8_t16";
              return;
            }
            break;
          case '_':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+9, "u8_i16_t16_dpp", 14) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX9PlusBit))	 // "v_sat_pk_u8_i16_t16_dpp"
              Mnemonic = "v_sat_pk_u8_i16_t16";
            return;
          }
          break;
        }
        break;
      case 24:	 // 15 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_", 2) != 0)
          break;
        switch (Mnemonic[2]) {
        default: break;
        case 'c':	 // 14 strings to match.
          if (memcmp(Mnemonic.data()+3, "vt_", 3) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'f':	 // 8 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 5 strings to match.
              if (memcmp(Mnemonic.data()+8, "6_", 2) != 0)
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'b':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "f8_fake16_dpp", 13) != 0)
                  break;
                if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_f16_bf8_fake16_dpp"
                  Mnemonic = "v_cvt_f16_bf8_fake16";
                return;
              case 'f':	 // 2 strings to match.
                switch (Mnemonic[11]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+12, "2_fake16_dpp", 12) != 0)
                    break;
                  if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_f16_f32_fake16_dpp"
                    Mnemonic = "v_cvt_f16_f32_fake16";
                  return;
                case 'p':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+12, "8_fake16_dpp", 12) != 0)
                    break;
                  if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_f16_fp8_fake16_dpp"
                    Mnemonic = "v_cvt_f16_fp8_fake16";
                  return;
                }
                break;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16_dpp", 13) != 0)
                  break;
                if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_f16_i16_fake16_dpp"
                  Mnemonic = "v_cvt_f16_i16_fake16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16_dpp", 13) != 0)
                  break;
                if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_f16_u16_fake16_dpp"
                  Mnemonic = "v_cvt_f16_u16_fake16";
                return;
              }
              break;
            case '3':	 // 3 strings to match.
              if (memcmp(Mnemonic.data()+8, "2_", 2) != 0)
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'b':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "f8_op_sel_dpp", 13) != 0)
                  break;
                if (Features.test(Feature_HasFP8ConversionInstsBit) && Features.test(Feature_isGFX12PlusBit))	 // "v_cvt_f32_bf8_op_sel_dpp"
                  Mnemonic = "v_cvt_f32_bf8_op_sel";
                return;
              case 'f':	 // 2 strings to match.
                switch (Mnemonic[11]) {
                default: break;
                case '1':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+12, "6_fake16_dpp", 12) != 0)
                    break;
                  if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_f32_f16_fake16_dpp"
                    Mnemonic = "v_cvt_f32_f16_fake16";
                  return;
                case 'p':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+12, "8_op_sel_dpp", 12) != 0)
                    break;
                  if (Features.test(Feature_HasFP8ConversionInstsBit) && Features.test(Feature_isGFX12PlusNot12_50Bit))	 // "v_cvt_f32_fp8_op_sel_dpp"
                    Mnemonic = "v_cvt_f32_fp8_op_sel";
                  return;
                }
                break;
              }
              break;
            }
            break;
          case 'i':	 // 2 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "6_f16_fake16_dpp", 16) != 0)
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_i16_f16_fake16_dpp"
                Mnemonic = "v_cvt_i16_f16_fake16";
              return;
            case '3':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "2_i16_fake16_dpp", 16) != 0)
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_i32_i16_fake16_dpp"
                Mnemonic = "v_cvt_i32_i16_fake16";
              return;
            }
            break;
          case 'p':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "k_f16_", 6) != 0)
              break;
            switch (Mnemonic[13]) {
            default: break;
            case 'b':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+14, "f8_t16_dpp", 10) != 0)
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_pk_f16_bf8_t16_dpp"
                Mnemonic = "v_cvt_pk_f16_bf8_t16";
              return;
            case 'f':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+14, "p8_t16_dpp", 10) != 0)
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_pk_f16_fp8_t16_dpp"
                Mnemonic = "v_cvt_pk_f16_fp8_t16";
              return;
            }
            break;
          case 'u':	 // 2 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "6_f16_fake16_dpp", 16) != 0)
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_u16_f16_fake16_dpp"
                Mnemonic = "v_cvt_u16_f16_fake16";
              return;
            case '3':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "2_u16_fake16_dpp", 16) != 0)
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_u32_u16_fake16_dpp"
                Mnemonic = "v_cvt_u32_u16_fake16";
              return;
            }
            break;
          }
          break;
        case 'f':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "rexp_mant_f16_t16_dpp", 21) != 0)
            break;
          if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_frexp_mant_f16_t16_dpp"
            Mnemonic = "v_frexp_mant_f16_t16";
          return;
        }
        break;
      case 25:	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_cvt_f32_", 10) != 0)
          break;
        switch (Mnemonic[10]) {
        default: break;
        case 'b':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+11, "f16_fake16_dpp", 14) != 0)
            break;
          if (Features.test(Feature_HasBF16ConversionInstsBit) && Features.test(Feature_HasGFX950InstsBit))	 // "v_cvt_f32_bf16_fake16_dpp"
            Mnemonic = "v_cvt_f32_bf16_fake16";
          return;
        case 'f':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+11, "p8_gfx1250_dpp", 14) != 0)
            break;
          if (Features.test(Feature_HasFP8ConversionInstsBit) && Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_f32_fp8_gfx1250_dpp"
            Mnemonic = "v_cvt_f32_fp8_gfx1250";
          return;
        }
        break;
      case 26:	 // 5 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_", 2) != 0)
          break;
        switch (Mnemonic[2]) {
        default: break;
        case 'c':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+3, "vt_norm_", 8) != 0)
            break;
          switch (Mnemonic[11]) {
          default: break;
          case 'i':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+12, "16_f16_t16_dpp", 14) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_i16_f16_t16_dpp"
              Mnemonic = "v_cvt_norm_i16_f16_t16";
            return;
          case 'u':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+12, "16_f16_t16_dpp", 14) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_u16_f16_t16_dpp"
              Mnemonic = "v_cvt_norm_u16_f16_t16";
            return;
          }
          break;
        case 's':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+3, "at_pk", 5) != 0)
            break;
          switch (Mnemonic[8]) {
          default: break;
          case '4':	 // 2 strings to match.
            if (Mnemonic[9] != '_')
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "4_i8_fake16_dpp", 15) != 0)
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_i4_i8_fake16_dpp"
                Mnemonic = "v_sat_pk4_i4_i8_fake16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "4_u8_fake16_dpp", 15) != 0)
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_u4_u8_fake16_dpp"
                Mnemonic = "v_sat_pk4_u4_u8_fake16";
              return;
            }
            break;
          case '_':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+9, "u8_i16_fake16_dpp", 17) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX9PlusBit))	 // "v_sat_pk_u8_i16_fake16_dpp"
              Mnemonic = "v_sat_pk_u8_i16_fake16";
            return;
          }
          break;
        }
        break;
      case 27:	 // 4 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_", 2) != 0)
          break;
        switch (Mnemonic[2]) {
        default: break;
        case 'c':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+3, "vt_pk_f16_", 10) != 0)
            break;
          switch (Mnemonic[13]) {
          default: break;
          case 'b':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "f8_fake16_dpp", 13) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_pk_f16_bf8_fake16_dpp"
              Mnemonic = "v_cvt_pk_f16_bf8_fake16";
            return;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "p8_fake16_dpp", 13) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_pk_f16_fp8_fake16_dpp"
              Mnemonic = "v_cvt_pk_f16_fp8_fake16";
            return;
          }
          break;
        case 'f':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+3, "rexp_", 5) != 0)
            break;
          switch (Mnemonic[8]) {
          default: break;
          case 'e':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+9, "xp_i16_f16_t16_dpp", 18) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_frexp_exp_i16_f16_t16_dpp"
              Mnemonic = "v_frexp_exp_i16_f16_t16";
            return;
          case 'm':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+9, "ant_f16_fake16_dpp", 18) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_frexp_mant_f16_fake16_dpp"
              Mnemonic = "v_frexp_mant_f16_fake16";
            return;
          }
          break;
        }
        break;
      case 29:	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_cvt_norm_", 11) != 0)
          break;
        switch (Mnemonic[11]) {
        default: break;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+12, "16_f16_fake16_dpp", 17) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_i16_f16_fake16_dpp"
            Mnemonic = "v_cvt_norm_i16_f16_fake16";
          return;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+12, "16_f16_fake16_dpp", 17) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_u16_f16_fake16_dpp"
            Mnemonic = "v_cvt_norm_u16_f16_fake16";
          return;
        }
        break;
      case 30:	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+0, "v_", 2) != 0)
          break;
        switch (Mnemonic[2]) {
        default: break;
        case 'c':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "vt_f32_bf16_gfx1250_t16_dpp", 27) != 0)
            break;
          if (Features.test(Feature_HasBF16ConversionInstsBit) && Features.test(Feature_isGFX1250PlusBit) && Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_f32_bf16_gfx1250_t16_dpp"
            Mnemonic = "v_cvt_f32_bf16_gfx1250_t16";
          return;
        case 'f':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "rexp_exp_i16_f16_fake16_dpp", 27) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_frexp_exp_i16_f16_fake16_dpp"
            Mnemonic = "v_frexp_exp_i16_f16_fake16";
          return;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "creen_partition_4se_b32_dpp", 27) != 0)
            break;
          if (Features.test(Feature_isGFX9OnlyBit))	 // "v_screen_partition_4se_b32_dpp"
            Mnemonic = "v_screen_partition_4se_b32";
          return;
        }
        break;
      case 33:	 // 1 string to match.
        if (memcmp(Mnemonic.data()+0, "v_cvt_f32_bf16_gfx1250_fake16_dpp", 33) != 0)
          break;
        if (Features.test(Feature_HasBF16ConversionInstsBit) && Features.test(Feature_isGFX1250PlusBit) && Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_f32_bf16_gfx1250_fake16_dpp"
          Mnemonic = "v_cvt_f32_bf16_gfx1250_fake16";
        return;
      }
    break;
  case 5:
    break;
  }
  switch (Mnemonic.size()) {
  default: break;
  case 3:	 // 1 string to match.
    if (memcmp(Mnemonic.data()+0, "exp", 3) != 0)
      break;
    if (Features.test(Feature_isGFX12PlusBit))	 // "exp"
      Mnemonic = "export";
    else if (Features.test(Feature_isGFX12PlusBit))
      Mnemonic = "export";
    else if (Features.test(Feature_isGFX12PlusBit))
      Mnemonic = "export";
    else if (Features.test(Feature_isGFX12PlusBit))
      Mnemonic = "export";
    return;
  case 9:	 // 23 strings to match.
    switch (Mnemonic[0]) {
    default: break;
    case 's':	 // 11 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'a':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+3, "dd_", 3) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "32", 2) != 0)
            break;
          if (Features.test(Feature_isGFX12PlusBit))	 // "s_add_i32"
            Mnemonic = "s_add_co_i32";
          return;
        case 'u':	 // 2 strings to match.
          switch (Mnemonic[7]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[8] != '2')
              break;
            if (Features.test(Feature_isGFX12PlusBit))	 // "s_add_u32"
              Mnemonic = "s_add_co_u32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[8] != '4')
              break;
            if (Features.test(Feature_isGFX12PlusBit))	 // "s_add_u64"
              Mnemonic = "s_add_nc_u64";
            return;
          }
          break;
        }
        break;
      case 'm':	 // 4 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "x_f", 3) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 1 string to match.
            if (Mnemonic[8] != '6')
              break;
            if (Features.test(Feature_isGFX12PlusBit))	 // "s_max_f16"
              Mnemonic = "s_max_num_f16";
            return;
          case '3':	 // 1 string to match.
            if (Mnemonic[8] != '2')
              break;
            if (Features.test(Feature_isGFX12PlusBit))	 // "s_max_f32"
              Mnemonic = "s_max_num_f32";
            return;
          }
          break;
        case 'i':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "n_f", 3) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 1 string to match.
            if (Mnemonic[8] != '6')
              break;
            if (Features.test(Feature_isGFX12PlusBit))	 // "s_min_f16"
              Mnemonic = "s_min_num_f16";
            return;
          case '3':	 // 1 string to match.
            if (Mnemonic[8] != '2')
              break;
            if (Features.test(Feature_isGFX12PlusBit))	 // "s_min_f32"
              Mnemonic = "s_min_num_f32";
            return;
          }
          break;
        }
        break;
      case 'r':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "fe_b64", 6) != 0)
          break;
        if (Features.test(Feature_isGFX1250PlusBit))	 // "s_rfe_b64"
          Mnemonic = "s_rfe_i64";
        return;
      case 's':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+3, "ub_", 3) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "32", 2) != 0)
            break;
          if (Features.test(Feature_isGFX12PlusBit))	 // "s_sub_i32"
            Mnemonic = "s_sub_co_i32";
          return;
        case 'u':	 // 2 strings to match.
          switch (Mnemonic[7]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[8] != '2')
              break;
            if (Features.test(Feature_isGFX12PlusBit))	 // "s_sub_u32"
              Mnemonic = "s_sub_co_u32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[8] != '4')
              break;
            if (Features.test(Feature_isGFX12PlusBit))	 // "s_sub_u64"
              Mnemonic = "s_sub_nc_u64";
            return;
          }
          break;
        }
        break;
      }
      break;
    case 'v':	 // 12 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'a':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+3, "dd_", 3) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "32", 2) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_add_i32"
            Mnemonic = "v_add_nc_i32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_add_nc_i32";
          return;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "32", 2) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_add_u32"
            Mnemonic = "v_add_nc_u32";
          else if (Features.test(Feature_isGFX11OnlyBit))
            Mnemonic = "v_add_nc_u32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_add_nc_u32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_add_nc_u32";
          return;
        }
        break;
      case 'm':	 // 6 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "x_f", 3) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 1 string to match.
            if (Mnemonic[8] != '6')
              break;
            if (Features.test(Feature_isGFX12OnlyBit))	 // "v_max_f16"
              Mnemonic = "v_max_num_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_max_num_f16";
            return;
          case '3':	 // 1 string to match.
            if (Mnemonic[8] != '2')
              break;
            if (Features.test(Feature_isGFX12OnlyBit))	 // "v_max_f32"
              Mnemonic = "v_max_num_f32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_max_num_f32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[8] != '4')
              break;
            if (Features.test(Feature_isGFX12OnlyBit))	 // "v_max_f64"
              Mnemonic = "v_max_num_f64";
            return;
          }
          break;
        case 'i':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "n_f", 3) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 1 string to match.
            if (Mnemonic[8] != '6')
              break;
            if (Features.test(Feature_isGFX12OnlyBit))	 // "v_min_f16"
              Mnemonic = "v_min_num_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_min_num_f16";
            return;
          case '3':	 // 1 string to match.
            if (Mnemonic[8] != '2')
              break;
            if (Features.test(Feature_isGFX12OnlyBit))	 // "v_min_f32"
              Mnemonic = "v_min_num_f32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_min_num_f32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[8] != '4')
              break;
            if (Features.test(Feature_isGFX12OnlyBit))	 // "v_min_f64"
              Mnemonic = "v_min_num_f64";
            return;
          }
          break;
        }
        break;
      case 'n':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+3, "op_e", 4) != 0)
          break;
        switch (Mnemonic[7]) {
        default: break;
        case '3':	 // 1 string to match.
          if (Mnemonic[8] != '2')
            break;
          Mnemonic = "v_nop";	 // "v_nop_e32"
          return;
        case '6':	 // 1 string to match.
          if (Mnemonic[8] != '4')
            break;
          Mnemonic = "v_nop";	 // "v_nop_e64"
          return;
        }
        break;
      case 's':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+3, "ub_", 3) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "32", 2) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_sub_i32"
            Mnemonic = "v_sub_nc_i32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_sub_nc_i32";
          return;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "32", 2) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_sub_u32"
            Mnemonic = "v_sub_nc_u32";
          else if (Features.test(Feature_isGFX11OnlyBit))
            Mnemonic = "v_sub_nc_u32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_sub_nc_u32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_sub_nc_u32";
          return;
        }
        break;
      }
      break;
    }
    break;
  case 10:	 // 22 strings to match.
    switch (Mnemonic[0]) {
    default: break;
    case 'd':	 // 6 strings to match.
      if (memcmp(Mnemonic.data()+1, "s_", 2) != 0)
        break;
      switch (Mnemonic[3]) {
      default: break;
      case 'm':	 // 4 strings to match.
        switch (Mnemonic[4]) {
        default: break;
        case 'a':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+5, "x_f", 3) != 0)
            break;
          switch (Mnemonic[8]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[9] != '2')
              break;
            if (Features.test(Feature_isGFX12PlusBit))	 // "ds_max_f32"
              Mnemonic = "ds_max_num_f32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[9] != '4')
              break;
            if (Features.test(Feature_isGFX12PlusBit))	 // "ds_max_f64"
              Mnemonic = "ds_max_num_f64";
            return;
          }
          break;
        case 'i':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+5, "n_f", 3) != 0)
            break;
          switch (Mnemonic[8]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[9] != '2')
              break;
            if (Features.test(Feature_isGFX12PlusBit))	 // "ds_min_f32"
              Mnemonic = "ds_min_num_f32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[9] != '4')
              break;
            if (Features.test(Feature_isGFX12PlusBit))	 // "ds_min_f64"
              Mnemonic = "ds_min_num_f64";
            return;
          }
          break;
        }
        break;
      case 'r':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+4, "ead_", 4) != 0)
          break;
        switch (Mnemonic[8]) {
        default: break;
        case 'i':	 // 1 string to match.
          if (Mnemonic[9] != '8')
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_read_i8"
            Mnemonic = "ds_load_i8";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "ds_load_i8";
          return;
        case 'u':	 // 1 string to match.
          if (Mnemonic[9] != '8')
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_read_u8"
            Mnemonic = "ds_load_u8";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "ds_load_u8";
          return;
        }
        break;
      }
      break;
    case 's':	 // 6 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'a':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+3, "dd", 2) != 0)
          break;
        switch (Mnemonic[5]) {
        default: break;
        case 'c':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+6, "_u32", 4) != 0)
            break;
          if (Features.test(Feature_isGFX12PlusBit))	 // "s_addc_u32"
            Mnemonic = "s_add_co_ci_u32";
          return;
        case 'k':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+6, "_i32", 4) != 0)
            break;
          if (Features.test(Feature_isGFX12PlusBit))	 // "s_addk_i32"
            Mnemonic = "s_addk_co_i32";
          return;
        }
        break;
      case 'c':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "all_b64", 7) != 0)
          break;
        if (Features.test(Feature_isGFX1250PlusBit))	 // "s_call_b64"
          Mnemonic = "s_call_i64";
        return;
      case 'o':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+3, "rn2_b", 5) != 0)
          break;
        switch (Mnemonic[8]) {
        default: break;
        case '3':	 // 1 string to match.
          if (Mnemonic[9] != '2')
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "s_orn2_b32"
            Mnemonic = "s_or_not1_b32";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "s_or_not1_b32";
          return;
        case '6':	 // 1 string to match.
          if (Mnemonic[9] != '4')
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "s_orn2_b64"
            Mnemonic = "s_or_not1_b64";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "s_or_not1_b64";
          return;
        }
        break;
      case 's':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "ubb_u32", 7) != 0)
          break;
        if (Features.test(Feature_isGFX12PlusBit))	 // "s_subb_u32"
          Mnemonic = "s_sub_co_ci_u32";
        return;
      }
      break;
    case 'v':	 // 10 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'f':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+3, "fb", 2) != 0)
          break;
        switch (Mnemonic[5]) {
        default: break;
        case 'h':	 // 2 strings to match.
          if (Mnemonic[6] != '_')
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'i':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "32", 2) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_ffbh_i32"
              Mnemonic = "v_cls_i32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cls_i32";
            return;
          case 'u':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "32", 2) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_ffbh_u32"
              Mnemonic = "v_clz_i32_u32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_clz_i32_u32";
            return;
          }
          break;
        case 'l':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+6, "_b32", 4) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_ffbl_b32"
            Mnemonic = "v_ctz_i32_b32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_ctz_i32_b32";
          return;
        }
        break;
      case 'm':	 // 6 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "x3_f", 4) != 0)
            break;
          switch (Mnemonic[8]) {
          default: break;
          case '1':	 // 1 string to match.
            if (Mnemonic[9] != '6')
              break;
            if (Features.test(Feature_isGFX12OnlyBit))	 // "v_max3_f16"
              Mnemonic = "v_max3_num_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_max3_num_f16";
            return;
          case '3':	 // 1 string to match.
            if (Mnemonic[9] != '2')
              break;
            if (Features.test(Feature_isGFX12OnlyBit))	 // "v_max3_f32"
              Mnemonic = "v_max3_num_f32";
            return;
          }
          break;
        case 'e':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "d3_f", 4) != 0)
            break;
          switch (Mnemonic[8]) {
          default: break;
          case '1':	 // 1 string to match.
            if (Mnemonic[9] != '6')
              break;
            if (Features.test(Feature_isGFX12OnlyBit))	 // "v_med3_f16"
              Mnemonic = "v_med3_num_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_med3_num_f16";
            return;
          case '3':	 // 1 string to match.
            if (Mnemonic[9] != '2')
              break;
            if (Features.test(Feature_isGFX12OnlyBit))	 // "v_med3_f32"
              Mnemonic = "v_med3_num_f32";
            return;
          }
          break;
        case 'i':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "n3_f", 4) != 0)
            break;
          switch (Mnemonic[8]) {
          default: break;
          case '1':	 // 1 string to match.
            if (Mnemonic[9] != '6')
              break;
            if (Features.test(Feature_isGFX12OnlyBit))	 // "v_min3_f16"
              Mnemonic = "v_min3_num_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_min3_num_f16";
            return;
          case '3':	 // 1 string to match.
            if (Mnemonic[9] != '2')
              break;
            if (Features.test(Feature_isGFX12OnlyBit))	 // "v_min3_f32"
              Mnemonic = "v_min3_num_f32";
            return;
          }
          break;
        }
        break;
      case 'n':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "op_sdwa", 7) != 0)
          break;
        Mnemonic = "v_nop";	 // "v_nop_sdwa"
        return;
      }
      break;
    }
    break;
  case 11:	 // 11 strings to match.
    switch (Mnemonic[0]) {
    default: break;
    case 'd':	 // 6 strings to match.
      if (memcmp(Mnemonic.data()+1, "s_", 2) != 0)
        break;
      switch (Mnemonic[3]) {
      default: break;
      case 'r':	 // 5 strings to match.
        if (memcmp(Mnemonic.data()+4, "ead_", 4) != 0)
          break;
        switch (Mnemonic[8]) {
        default: break;
        case 'b':	 // 3 strings to match.
          switch (Mnemonic[9]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[10] != '2')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_read_b32"
              Mnemonic = "ds_load_b32";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "ds_load_b32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[10] != '4')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_read_b64"
              Mnemonic = "ds_load_b64";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "ds_load_b64";
            return;
          case '9':	 // 1 string to match.
            if (Mnemonic[10] != '6')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_read_b96"
              Mnemonic = "ds_load_b96";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "ds_load_b96";
            return;
          }
          break;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+9, "16", 2) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_read_i16"
            Mnemonic = "ds_load_i16";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "ds_load_i16";
          return;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+9, "16", 2) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_read_u16"
            Mnemonic = "ds_load_u16";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "ds_load_u16";
          return;
        }
        break;
      case 'w':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+4, "rite_b8", 7) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_write_b8"
          Mnemonic = "ds_store_b8";
        else if (Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "ds_store_b8";
        return;
      }
      break;
    case 's':	 // 5 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'a':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+3, "ndn2_b", 6) != 0)
          break;
        switch (Mnemonic[9]) {
        default: break;
        case '3':	 // 1 string to match.
          if (Mnemonic[10] != '2')
            break;
          if (Features.test(Feature_isGFX12PlusBit))	 // "s_andn2_b32"
            Mnemonic = "s_and_not1_b32";
          else if (Features.test(Feature_isGFX11OnlyBit))
            Mnemonic = "s_and_not1_b32";
          return;
        case '6':	 // 1 string to match.
          if (Mnemonic[10] != '4')
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "s_andn2_b64"
            Mnemonic = "s_and_not1_b64";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "s_and_not1_b64";
          return;
        }
        break;
      case 'f':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "lbit_i32", 8) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "s_flbit_i32"
          Mnemonic = "s_cls_i32";
        else if (Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "s_cls_i32";
        return;
      case 'g':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "etpc_b64", 8) != 0)
          break;
        if (Features.test(Feature_isGFX1250PlusBit))	 // "s_getpc_b64"
          Mnemonic = "s_get_pc_i64";
        return;
      case 's':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "etpc_b64", 8) != 0)
          break;
        if (Features.test(Feature_isGFX1250PlusBit))	 // "s_setpc_b64"
          Mnemonic = "s_set_pc_i64";
        return;
      }
      break;
    }
    break;
  case 12:	 // 17 strings to match.
    switch (Mnemonic[0]) {
    default: break;
    case 'd':	 // 7 strings to match.
      if (memcmp(Mnemonic.data()+1, "s_", 2) != 0)
        break;
      switch (Mnemonic[3]) {
      default: break;
      case 'r':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+4, "ead", 3) != 0)
          break;
        switch (Mnemonic[7]) {
        default: break;
        case '2':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+8, "_b", 2) != 0)
            break;
          switch (Mnemonic[10]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[11] != '2')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_read2_b32"
              Mnemonic = "ds_load_2addr_b32";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "ds_load_2addr_b32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[11] != '4')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_read2_b64"
              Mnemonic = "ds_load_2addr_b64";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "ds_load_2addr_b64";
            return;
          }
          break;
        case '_':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+8, "b128", 4) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_read_b128"
            Mnemonic = "ds_load_b128";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "ds_load_b128";
          return;
        }
        break;
      case 'w':	 // 4 strings to match.
        if (memcmp(Mnemonic.data()+4, "rite_b", 6) != 0)
          break;
        switch (Mnemonic[10]) {
        default: break;
        case '1':	 // 1 string to match.
          if (Mnemonic[11] != '6')
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_write_b16"
            Mnemonic = "ds_store_b16";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "ds_store_b16";
          return;
        case '3':	 // 1 string to match.
          if (Mnemonic[11] != '2')
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_write_b32"
            Mnemonic = "ds_store_b32";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "ds_store_b32";
          return;
        case '6':	 // 1 string to match.
          if (Mnemonic[11] != '4')
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_write_b64"
            Mnemonic = "ds_store_b64";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "ds_store_b64";
          return;
        case '9':	 // 1 string to match.
          if (Mnemonic[11] != '6')
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_write_b96"
            Mnemonic = "ds_store_b96";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "ds_store_b96";
          return;
        }
        break;
      }
      break;
    case 's':	 // 2 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'l':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "oad_dword", 9) != 0)
          break;
        if (Features.test(Feature_isGFX11PlusBit))	 // "s_load_dword"
          Mnemonic = "s_load_b32";
        return;
      case 's':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "wappc_b64", 9) != 0)
          break;
        if (Features.test(Feature_isGFX1250PlusBit))	 // "s_swappc_b64"
          Mnemonic = "s_swap_pc_i64";
        return;
      }
      break;
    case 'v':	 // 8 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'm':	 // 4 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "xmin_f", 6) != 0)
            break;
          switch (Mnemonic[10]) {
          default: break;
          case '1':	 // 1 string to match.
            if (Mnemonic[11] != '6')
              break;
            if (Features.test(Feature_isGFX12OnlyBit))	 // "v_maxmin_f16"
              Mnemonic = "v_maxmin_num_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_maxmin_num_f16";
            return;
          case '3':	 // 1 string to match.
            if (Mnemonic[11] != '2')
              break;
            if (Features.test(Feature_isGFX12OnlyBit))	 // "v_maxmin_f32"
              Mnemonic = "v_maxmin_num_f32";
            return;
          }
          break;
        case 'i':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "nmax_f", 6) != 0)
            break;
          switch (Mnemonic[10]) {
          default: break;
          case '1':	 // 1 string to match.
            if (Mnemonic[11] != '6')
              break;
            if (Features.test(Feature_isGFX12OnlyBit))	 // "v_minmax_f16"
              Mnemonic = "v_minmax_num_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_minmax_num_f16";
            return;
          case '3':	 // 1 string to match.
            if (Mnemonic[11] != '2')
              break;
            if (Features.test(Feature_isGFX12OnlyBit))	 // "v_minmax_f32"
              Mnemonic = "v_minmax_num_f32";
            return;
          }
          break;
        }
        break;
      case 'o':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "r_b16_t16", 9) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_or_b16_t16"
          Mnemonic = "v_or_b16";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_or_b16";
        return;
      case 'p':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+3, "k_m", 3) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case 'a':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "x_f16", 5) != 0)
            break;
          if (Features.test(Feature_isGFX12OnlyBit))	 // "v_pk_max_f16"
            Mnemonic = "v_pk_max_num_f16";
          return;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "n_f16", 5) != 0)
            break;
          if (Features.test(Feature_isGFX12OnlyBit))	 // "v_pk_min_f16"
            Mnemonic = "v_pk_min_num_f16";
          return;
        }
        break;
      case 's':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "ubrev_u32", 9) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_subrev_u32"
          Mnemonic = "v_subrev_nc_u32";
        else if (Features.test(Feature_isGFX11OnlyBit))
          Mnemonic = "v_subrev_nc_u32";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_subrev_nc_u32";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_subrev_nc_u32";
        return;
      }
      break;
    }
    break;
  case 13:	 // 78 strings to match.
    switch (Mnemonic[0]) {
    default: break;
    case 'd':	 // 5 strings to match.
      if (memcmp(Mnemonic.data()+1, "s_", 2) != 0)
        break;
      switch (Mnemonic[3]) {
      default: break;
      case 's':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+4, "ubrev_u", 7) != 0)
          break;
        switch (Mnemonic[11]) {
        default: break;
        case '3':	 // 1 string to match.
          if (Mnemonic[12] != '2')
            break;
          if (Features.test(Feature_isGFX12PlusBit))	 // "ds_subrev_u32"
            Mnemonic = "ds_rsub_u32";
          return;
        case '6':	 // 1 string to match.
          if (Mnemonic[12] != '4')
            break;
          if (Features.test(Feature_isGFX12PlusBit))	 // "ds_subrev_u64"
            Mnemonic = "ds_rsub_u64";
          return;
        }
        break;
      case 'w':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+4, "rite", 4) != 0)
          break;
        switch (Mnemonic[8]) {
        default: break;
        case '2':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+9, "_b", 2) != 0)
            break;
          switch (Mnemonic[11]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[12] != '2')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_write2_b32"
              Mnemonic = "ds_store_2addr_b32";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "ds_store_2addr_b32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[12] != '4')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_write2_b64"
              Mnemonic = "ds_store_2addr_b64";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "ds_store_2addr_b64";
            return;
          }
          break;
        case '_':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+9, "b128", 4) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_write_b128"
            Mnemonic = "ds_store_b128";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "ds_store_b128";
          return;
        }
        break;
      }
      break;
    case 's':	 // 2 strings to match.
      if (memcmp(Mnemonic.data()+1, "_ff1_i32_b", 10) != 0)
        break;
      switch (Mnemonic[11]) {
      default: break;
      case '3':	 // 1 string to match.
        if (Mnemonic[12] != '2')
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "s_ff1_i32_b32"
          Mnemonic = "s_ctz_i32_b32";
        else if (Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "s_ctz_i32_b32";
        return;
      case '6':	 // 1 string to match.
        if (Mnemonic[12] != '4')
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "s_ff1_i32_b64"
          Mnemonic = "s_ctz_i32_b64";
        else if (Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "s_ctz_i32_b64";
        return;
      }
      break;
    case 'v':	 // 71 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'a':	 // 4 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'd':	 // 3 strings to match.
          if (Mnemonic[4] != 'd')
            break;
          switch (Mnemonic[5]) {
          default: break;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+6, "_nc_u32", 7) != 0)
              break;
            if (Features.test(Feature_isGFX11PlusBit))	 // "v_add3_nc_u32"
              Mnemonic = "v_add3_u32";
            return;
          case '_':	 // 2 strings to match.
            switch (Mnemonic[6]) {
            default: break;
            case 'f':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_add_f16_t16"
                Mnemonic = "v_add_f16";
              else if (Features.test(Feature_isGFX11OnlyBit))
                Mnemonic = "v_add_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_add_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_add_f16";
              return;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_add_i16_t16"
                Mnemonic = "v_add_nc_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_add_nc_i16";
              return;
            }
            break;
          }
          break;
        case 'n':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "d_b16_t16", 9) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_and_b16_t16"
            Mnemonic = "v_and_b16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_and_b16";
          return;
        }
        break;
      case 'c':	 // 11 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'l':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "rexcp_e", 7) != 0)
            break;
          switch (Mnemonic[11]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[12] != '2')
              break;
            Mnemonic = "v_clrexcp";	 // "v_clrexcp_e32"
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[12] != '4')
              break;
            Mnemonic = "v_clrexcp";	 // "v_clrexcp_e64"
            return;
          }
          break;
        case 'm':	 // 4 strings to match.
          if (memcmp(Mnemonic.data()+4, "p_tru_", 6) != 0)
            break;
          switch (Mnemonic[10]) {
          default: break;
          case 'i':	 // 2 strings to match.
            switch (Mnemonic[11]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[12] != '2')
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_tru_i32"
                Mnemonic = "v_cmp_t_i32";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[12] != '4')
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_tru_i64"
                Mnemonic = "v_cmp_t_i64";
              return;
            }
            break;
          case 'u':	 // 2 strings to match.
            switch (Mnemonic[11]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[12] != '2')
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_tru_u32"
                Mnemonic = "v_cmp_t_u32";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[12] != '4')
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmp_tru_u64"
                Mnemonic = "v_cmp_t_u64";
              return;
            }
            break;
          }
          break;
        case 'o':	 // 5 strings to match.
          if (memcmp(Mnemonic.data()+4, "s_f", 3) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+8, "6_", 2) != 0)
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'e':	 // 2 strings to match.
              switch (Mnemonic[11]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[12] != '2')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_cos_f16_e32"
                  Mnemonic = "v_cos_f16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[12] != '4')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_cos_f16_e64"
                  Mnemonic = "v_cos_f16";
                return;
              }
              break;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16", 2) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cos_f16_t16"
                Mnemonic = "v_cos_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cos_f16";
              return;
            }
            break;
          case '3':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+8, "2_e", 3) != 0)
              break;
            switch (Mnemonic[11]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[12] != '2')
                break;
              Mnemonic = "v_cos_f32";	 // "v_cos_f32_e32"
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[12] != '4')
                break;
              Mnemonic = "v_cos_f32";	 // "v_cos_f32_e64"
              return;
            }
            break;
          }
          break;
        }
        break;
      case 'd':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+3, "ot", 2) != 0)
          break;
        switch (Mnemonic[5]) {
        default: break;
        case '4':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+6, "_i32_i8", 7) != 0)
            break;
          if (Features.test(Feature_isGFX11PlusBit))	 // "v_dot4_i32_i8"
            Mnemonic = "v_dot4_i32_iu8";
          return;
        case '8':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+6, "_i32_i4", 7) != 0)
            break;
          if (Features.test(Feature_isGFX11PlusBit))	 // "v_dot8_i32_i4"
            Mnemonic = "v_dot8_i32_iu4";
          return;
        }
        break;
      case 'e':	 // 5 strings to match.
        if (memcmp(Mnemonic.data()+3, "xp_f", 4) != 0)
          break;
        switch (Mnemonic[7]) {
        default: break;
        case '1':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+8, "6_", 2) != 0)
            break;
          switch (Mnemonic[10]) {
          default: break;
          case 'e':	 // 2 strings to match.
            switch (Mnemonic[11]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[12] != '2')
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_exp_f16_e32"
                Mnemonic = "v_exp_f16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[12] != '4')
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_exp_f16_e64"
                Mnemonic = "v_exp_f16";
              return;
            }
            break;
          case 't':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+11, "16", 2) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_exp_f16_t16"
              Mnemonic = "v_exp_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_exp_f16";
            return;
          }
          break;
        case '3':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+8, "2_e", 3) != 0)
            break;
          switch (Mnemonic[11]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[12] != '2')
              break;
            Mnemonic = "v_exp_f32";	 // "v_exp_f32_e32"
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[12] != '4')
              break;
            Mnemonic = "v_exp_f32";	 // "v_exp_f32_e64"
            return;
          }
          break;
        }
        break;
      case 'l':	 // 5 strings to match.
        if (memcmp(Mnemonic.data()+3, "og_f", 4) != 0)
          break;
        switch (Mnemonic[7]) {
        default: break;
        case '1':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+8, "6_", 2) != 0)
            break;
          switch (Mnemonic[10]) {
          default: break;
          case 'e':	 // 2 strings to match.
            switch (Mnemonic[11]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[12] != '2')
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_log_f16_e32"
                Mnemonic = "v_log_f16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[12] != '4')
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_log_f16_e64"
                Mnemonic = "v_log_f16";
              return;
            }
            break;
          case 't':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+11, "16", 2) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_log_f16_t16"
              Mnemonic = "v_log_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_log_f16";
            return;
          }
          break;
        case '3':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+8, "2_e", 3) != 0)
            break;
          switch (Mnemonic[11]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[12] != '2')
              break;
            Mnemonic = "v_log_f32";	 // "v_log_f32_e32"
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[12] != '4')
              break;
            Mnemonic = "v_log_f32";	 // "v_log_f32_e64"
            return;
          }
          break;
        }
        break;
      case 'm':	 // 16 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 5 strings to match.
          switch (Mnemonic[4]) {
          default: break;
          case 'd':	 // 2 strings to match.
            if (Mnemonic[5] != '_')
              break;
            switch (Mnemonic[6]) {
            default: break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "64_i32", 6) != 0)
                break;
              if (Features.test(Feature_isGFX12OnlyBit))	 // "v_mad_i64_i32"
                Mnemonic = "v_mad_co_i64_i32";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "64_u32", 6) != 0)
                break;
              if (Features.test(Feature_isGFX12OnlyBit))	 // "v_mad_u64_u32"
                Mnemonic = "v_mad_co_u64_u32";
              return;
            }
            break;
          case 'x':	 // 3 strings to match.
            if (Mnemonic[5] != '_')
              break;
            switch (Mnemonic[6]) {
            default: break;
            case 'f':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_max_f16_t16"
                Mnemonic = "v_max_f16";
              else if (Features.test(Feature_isGFX11OnlyBit))
                Mnemonic = "v_max_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_max_num_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_max_num_f16";
              return;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_max_i16_t16"
                Mnemonic = "v_max_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_max_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "16_t16", 6) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_max_u16_t16"
                Mnemonic = "v_max_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_max_u16";
              return;
            }
            break;
          }
          break;
        case 'i':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "n_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "16_t16", 6) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_min_f16_t16"
              Mnemonic = "v_min_f16";
            else if (Features.test(Feature_isGFX11OnlyBit))
              Mnemonic = "v_min_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_min_num_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_min_num_f16";
            return;
          case 'i':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "16_t16", 6) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_min_i16_t16"
              Mnemonic = "v_min_i16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_min_i16";
            return;
          case 'u':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "16_t16", 6) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_min_u16_t16"
              Mnemonic = "v_min_u16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_min_u16";
            return;
          }
          break;
        case 'o':	 // 7 strings to match.
          if (memcmp(Mnemonic.data()+4, "v_b", 3) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+8, "6_", 2) != 0)
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'e':	 // 2 strings to match.
              switch (Mnemonic[11]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[12] != '2')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_mov_b16_e32"
                  Mnemonic = "v_mov_b16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[12] != '4')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_mov_b16_e64"
                  Mnemonic = "v_mov_b16";
                return;
              }
              break;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16", 2) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_mov_b16_t16"
                Mnemonic = "v_mov_b16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_mov_b16";
              return;
            }
            break;
          case '3':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+8, "2_e", 3) != 0)
              break;
            switch (Mnemonic[11]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[12] != '2')
                break;
              Mnemonic = "v_mov_b32";	 // "v_mov_b32_e32"
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[12] != '4')
                break;
              Mnemonic = "v_mov_b32";	 // "v_mov_b32_e64"
              return;
            }
            break;
          case '6':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+8, "4_e", 3) != 0)
              break;
            switch (Mnemonic[11]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[12] != '2')
                break;
              if (Features.test(Feature_isGFX940orGFX1250Bit))	 // "v_mov_b64_e32"
                Mnemonic = "v_mov_b64";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[12] != '4')
                break;
              if (Features.test(Feature_isGFX940orGFX1250Bit))	 // "v_mov_b64_e64"
                Mnemonic = "v_mov_b64";
              return;
            }
            break;
          }
          break;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "l_f16_t16", 9) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_mul_f16_t16"
            Mnemonic = "v_mul_f16";
          else if (Features.test(Feature_isGFX11OnlyBit))
            Mnemonic = "v_mul_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_mul_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_mul_f16";
          return;
        }
        break;
      case 'n':	 // 5 strings to match.
        if (memcmp(Mnemonic.data()+3, "ot_b", 4) != 0)
          break;
        switch (Mnemonic[7]) {
        default: break;
        case '1':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+8, "6_", 2) != 0)
            break;
          switch (Mnemonic[10]) {
          default: break;
          case 'e':	 // 2 strings to match.
            switch (Mnemonic[11]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[12] != '2')
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_not_b16_e32"
                Mnemonic = "v_not_b16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[12] != '4')
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_not_b16_e64"
                Mnemonic = "v_not_b16";
              return;
            }
            break;
          case 't':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+11, "16", 2) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_not_b16_t16"
              Mnemonic = "v_not_b16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_not_b16";
            return;
          }
          break;
        case '3':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+8, "2_e", 3) != 0)
            break;
          switch (Mnemonic[11]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[12] != '2')
              break;
            Mnemonic = "v_not_b32";	 // "v_not_b32_e32"
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[12] != '4')
              break;
            Mnemonic = "v_not_b32";	 // "v_not_b32_e64"
            return;
          }
          break;
        }
        break;
      case 'r':	 // 14 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'c':	 // 7 strings to match.
          if (memcmp(Mnemonic.data()+4, "p_f", 3) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+8, "6_", 2) != 0)
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'e':	 // 2 strings to match.
              switch (Mnemonic[11]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[12] != '2')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_rcp_f16_e32"
                  Mnemonic = "v_rcp_f16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[12] != '4')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_rcp_f16_e64"
                  Mnemonic = "v_rcp_f16";
                return;
              }
              break;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16", 2) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_rcp_f16_t16"
                Mnemonic = "v_rcp_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_rcp_f16";
              return;
            }
            break;
          case '3':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+8, "2_e", 3) != 0)
              break;
            switch (Mnemonic[11]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[12] != '2')
                break;
              Mnemonic = "v_rcp_f32";	 // "v_rcp_f32_e32"
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[12] != '4')
                break;
              Mnemonic = "v_rcp_f32";	 // "v_rcp_f32_e64"
              return;
            }
            break;
          case '6':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+8, "4_e", 3) != 0)
              break;
            switch (Mnemonic[11]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[12] != '2')
                break;
              Mnemonic = "v_rcp_f64";	 // "v_rcp_f64_e32"
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[12] != '4')
                break;
              Mnemonic = "v_rcp_f64";	 // "v_rcp_f64_e64"
              return;
            }
            break;
          }
          break;
        case 's':	 // 7 strings to match.
          if (memcmp(Mnemonic.data()+4, "q_f", 3) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+8, "6_", 2) != 0)
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'e':	 // 2 strings to match.
              switch (Mnemonic[11]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[12] != '2')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_rsq_f16_e32"
                  Mnemonic = "v_rsq_f16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[12] != '4')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_rsq_f16_e64"
                  Mnemonic = "v_rsq_f16";
                return;
              }
              break;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16", 2) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_rsq_f16_t16"
                Mnemonic = "v_rsq_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_rsq_f16";
              return;
            }
            break;
          case '3':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+8, "2_e", 3) != 0)
              break;
            switch (Mnemonic[11]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[12] != '2')
                break;
              Mnemonic = "v_rsq_f32";	 // "v_rsq_f32_e32"
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[12] != '4')
                break;
              Mnemonic = "v_rsq_f32";	 // "v_rsq_f32_e64"
              return;
            }
            break;
          case '6':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+8, "4_e", 3) != 0)
              break;
            switch (Mnemonic[11]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[12] != '2')
                break;
              Mnemonic = "v_rsq_f64";	 // "v_rsq_f64_e32"
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[12] != '4')
                break;
              Mnemonic = "v_rsq_f64";	 // "v_rsq_f64_e64"
              return;
            }
            break;
          }
          break;
        }
        break;
      case 's':	 // 7 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'i':	 // 5 strings to match.
          if (memcmp(Mnemonic.data()+4, "n_f", 3) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+8, "6_", 2) != 0)
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'e':	 // 2 strings to match.
              switch (Mnemonic[11]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[12] != '2')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_sin_f16_e32"
                  Mnemonic = "v_sin_f16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[12] != '4')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_sin_f16_e64"
                  Mnemonic = "v_sin_f16";
                return;
              }
              break;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16", 2) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_sin_f16_t16"
                Mnemonic = "v_sin_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_sin_f16";
              return;
            }
            break;
          case '3':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+8, "2_e", 3) != 0)
              break;
            switch (Mnemonic[11]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[12] != '2')
                break;
              Mnemonic = "v_sin_f32";	 // "v_sin_f32_e32"
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[12] != '4')
                break;
              Mnemonic = "v_sin_f32";	 // "v_sin_f32_e64"
              return;
            }
            break;
          }
          break;
        case 'u':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "b_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "16_t16", 6) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_sub_f16_t16"
              Mnemonic = "v_sub_f16";
            else if (Features.test(Feature_isGFX11OnlyBit))
              Mnemonic = "v_sub_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_sub_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_sub_f16";
            return;
          case 'i':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "16_t16", 6) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_sub_i16_t16"
              Mnemonic = "v_sub_nc_i16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_sub_nc_i16";
            return;
          }
          break;
        }
        break;
      case 'x':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+3, "or_", 3) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case 'a':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "dd_u32", 6) != 0)
            break;
          if (Features.test(Feature_isGFX11PlusBit))	 // "v_xor_add_u32"
            Mnemonic = "v_xad_u32";
          return;
        case 'b':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "16_t16", 6) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_xor_b16_t16"
            Mnemonic = "v_xor_b16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_xor_b16";
          return;
        }
        break;
      }
      break;
    }
    break;
  case 14:	 // 88 strings to match.
    switch (Mnemonic[0]) {
    default: break;
    case 'd':	 // 7 strings to match.
      if (memcmp(Mnemonic.data()+1, "s_", 2) != 0)
        break;
      switch (Mnemonic[3]) {
      default: break;
      case 'l':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+4, "oad_tr_b64", 10) != 0)
          break;
        if (Features.test(Feature_isGFX1250PlusBit))	 // "ds_load_tr_b64"
          Mnemonic = "ds_load_tr8_b64";
        return;
      case 'm':	 // 4 strings to match.
        switch (Mnemonic[4]) {
        default: break;
        case 'a':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+5, "x_rtn_f", 7) != 0)
            break;
          switch (Mnemonic[12]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[13] != '2')
              break;
            if (Features.test(Feature_isGFX12PlusBit))	 // "ds_max_rtn_f32"
              Mnemonic = "ds_max_num_rtn_f32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[13] != '4')
              break;
            if (Features.test(Feature_isGFX12PlusBit))	 // "ds_max_rtn_f64"
              Mnemonic = "ds_max_num_rtn_f64";
            return;
          }
          break;
        case 'i':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+5, "n_rtn_f", 7) != 0)
            break;
          switch (Mnemonic[12]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[13] != '2')
              break;
            if (Features.test(Feature_isGFX12PlusBit))	 // "ds_min_rtn_f32"
              Mnemonic = "ds_min_num_rtn_f32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[13] != '4')
              break;
            if (Features.test(Feature_isGFX12PlusBit))	 // "ds_min_rtn_f64"
              Mnemonic = "ds_min_num_rtn_f64";
            return;
          }
          break;
        }
        break;
      case 'r':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+4, "ead_", 4) != 0)
          break;
        switch (Mnemonic[8]) {
        default: break;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+9, "8_d16", 5) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_read_i8_d16"
            Mnemonic = "ds_load_i8_d16";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "ds_load_i8_d16";
          return;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+9, "8_d16", 5) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_read_u8_d16"
            Mnemonic = "ds_load_u8_d16";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "ds_load_u8_d16";
          return;
        }
        break;
      }
      break;
    case 'f':	 // 1 string to match.
      if (memcmp(Mnemonic.data()+1, "lat_atomic_or", 13) != 0)
        break;
      if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_or"
        Mnemonic = "flat_atomic_or_b32";
      else if (Features.test(Feature_isGFX12OnlyBit))
        Mnemonic = "flat_atomic_or_b32";
      return;
    case 'l':	 // 1 string to match.
      if (memcmp(Mnemonic.data()+1, "ds_param_load", 13) != 0)
        break;
      if (Features.test(Feature_isGFX12PlusBit))	 // "lds_param_load"
        Mnemonic = "ds_param_load";
      return;
    case 's':	 // 3 strings to match.
      if (memcmp(Mnemonic.data()+1, "_load_dwordx", 12) != 0)
        break;
      switch (Mnemonic[13]) {
      default: break;
      case '2':	 // 1 string to match.
        if (Features.test(Feature_isGFX11PlusBit))	 // "s_load_dwordx2"
          Mnemonic = "s_load_b64";
        return;
      case '4':	 // 1 string to match.
        if (Features.test(Feature_isGFX11PlusBit))	 // "s_load_dwordx4"
          Mnemonic = "s_load_b128";
        return;
      case '8':	 // 1 string to match.
        if (Features.test(Feature_isGFX11PlusBit))	 // "s_load_dwordx8"
          Mnemonic = "s_load_b256";
        return;
      }
      break;
    case 'v':	 // 76 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'a':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "ccvgpr_read", 11) != 0)
          break;
        Mnemonic = "v_accvgpr_read_b32";	 // "v_accvgpr_read"
        return;
      case 'c':	 // 16 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'e':	 // 7 strings to match.
          if (memcmp(Mnemonic.data()+4, "il_f", 4) != 0)
            break;
          switch (Mnemonic[8]) {
          default: break;
          case '1':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+9, "6_", 2) != 0)
              break;
            switch (Mnemonic[11]) {
            default: break;
            case 'e':	 // 2 strings to match.
              switch (Mnemonic[12]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[13] != '2')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_ceil_f16_e32"
                  Mnemonic = "v_ceil_f16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[13] != '4')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_ceil_f16_e64"
                  Mnemonic = "v_ceil_f16";
                return;
              }
              break;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+12, "16", 2) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_ceil_f16_t16"
                Mnemonic = "v_ceil_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_ceil_f16";
              return;
            }
            break;
          case '3':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+9, "2_e", 3) != 0)
              break;
            switch (Mnemonic[12]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[13] != '2')
                break;
              Mnemonic = "v_ceil_f32";	 // "v_ceil_f32_e32"
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[13] != '4')
                break;
              Mnemonic = "v_ceil_f32";	 // "v_ceil_f32_e64"
              return;
            }
            break;
          case '6':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+9, "4_e", 3) != 0)
              break;
            switch (Mnemonic[12]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[13] != '2')
                break;
              if (Features.test(Feature_isGFX7PlusBit))	 // "v_ceil_f64_e32"
                Mnemonic = "v_ceil_f64";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[13] != '4')
                break;
              if (Features.test(Feature_isGFX7PlusBit))	 // "v_ceil_f64_e64"
                Mnemonic = "v_ceil_f64";
              return;
            }
            break;
          }
          break;
        case 'm':	 // 4 strings to match.
          if (memcmp(Mnemonic.data()+4, "px_tru_", 7) != 0)
            break;
          switch (Mnemonic[11]) {
          default: break;
          case 'i':	 // 2 strings to match.
            switch (Mnemonic[12]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[13] != '2')
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_tru_i32"
                Mnemonic = "v_cmpx_t_i32";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[13] != '4')
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_tru_i64"
                Mnemonic = "v_cmpx_t_i64";
              return;
            }
            break;
          case 'u':	 // 2 strings to match.
            switch (Mnemonic[12]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[13] != '2')
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_tru_u32"
                Mnemonic = "v_cmpx_t_u32";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[13] != '4')
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cmpx_tru_u64"
                Mnemonic = "v_cmpx_t_u64";
              return;
            }
            break;
          }
          break;
        case 'o':	 // 5 strings to match.
          if (memcmp(Mnemonic.data()+4, "s_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'b':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+7, "f16_", 4) != 0)
              break;
            switch (Mnemonic[11]) {
            default: break;
            case 'e':	 // 2 strings to match.
              switch (Mnemonic[12]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[13] != '2')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_cos_bf16_e32"
                  Mnemonic = "v_cos_bf16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[13] != '4')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_cos_bf16_e64"
                  Mnemonic = "v_cos_bf16";
                return;
              }
              break;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+12, "16", 2) != 0)
                break;
              if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cos_bf16_t16"
                Mnemonic = "v_cos_bf16";
              return;
            }
            break;
          case 'f':	 // 2 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "6_sdwa", 6) != 0)
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_cos_f16_sdwa"
                Mnemonic = "v_cos_f16";
              return;
            case '3':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "2_sdwa", 6) != 0)
                break;
              Mnemonic = "v_cos_f32";	 // "v_cos_f32_sdwa"
              return;
            }
            break;
          }
          break;
        }
        break;
      case 'e':	 // 5 strings to match.
        if (memcmp(Mnemonic.data()+3, "xp_", 3) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case 'b':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+7, "f16_", 4) != 0)
            break;
          switch (Mnemonic[11]) {
          default: break;
          case 'e':	 // 2 strings to match.
            switch (Mnemonic[12]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[13] != '2')
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_exp_bf16_e32"
                Mnemonic = "v_exp_bf16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[13] != '4')
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_exp_bf16_e64"
                Mnemonic = "v_exp_bf16";
              return;
            }
            break;
          case 't':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+12, "16", 2) != 0)
              break;
            if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_exp_bf16_t16"
              Mnemonic = "v_exp_bf16";
            return;
          }
          break;
        case 'f':	 // 2 strings to match.
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "6_sdwa", 6) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_exp_f16_sdwa"
              Mnemonic = "v_exp_f16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "2_sdwa", 6) != 0)
              break;
            Mnemonic = "v_exp_f32";	 // "v_exp_f32_sdwa"
            return;
          }
          break;
        }
        break;
      case 'f':	 // 7 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'f':	 // 6 strings to match.
          if (Mnemonic[4] != 'b')
            break;
          switch (Mnemonic[5]) {
          default: break;
          case 'h':	 // 4 strings to match.
            if (Mnemonic[6] != '_')
              break;
            switch (Mnemonic[7]) {
            default: break;
            case 'i':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+8, "32_e", 4) != 0)
                break;
              switch (Mnemonic[12]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[13] != '2')
                  break;
                Mnemonic = "v_ffbh_i32";	 // "v_ffbh_i32_e32"
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[13] != '4')
                  break;
                Mnemonic = "v_ffbh_i32";	 // "v_ffbh_i32_e64"
                return;
              }
              break;
            case 'u':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+8, "32_e", 4) != 0)
                break;
              switch (Mnemonic[12]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[13] != '2')
                  break;
                Mnemonic = "v_ffbh_u32";	 // "v_ffbh_u32_e32"
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[13] != '4')
                  break;
                Mnemonic = "v_ffbh_u32";	 // "v_ffbh_u32_e64"
                return;
              }
              break;
            }
            break;
          case 'l':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+6, "_b32_e", 6) != 0)
              break;
            switch (Mnemonic[12]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[13] != '2')
                break;
              Mnemonic = "v_ffbl_b32";	 // "v_ffbl_b32_e32"
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[13] != '4')
                break;
              Mnemonic = "v_ffbl_b32";	 // "v_ffbl_b32_e64"
              return;
            }
            break;
          }
          break;
        case 'm':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "ac_f16_t16", 10) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_fmac_f16_t16"
            Mnemonic = "v_fmac_f16";
          else if (Features.test(Feature_isGFX11OnlyBit))
            Mnemonic = "v_fmac_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_fmac_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_fmac_f16";
          return;
        }
        break;
      case 'l':	 // 5 strings to match.
        if (memcmp(Mnemonic.data()+3, "og_", 3) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case 'b':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+7, "f16_", 4) != 0)
            break;
          switch (Mnemonic[11]) {
          default: break;
          case 'e':	 // 2 strings to match.
            switch (Mnemonic[12]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[13] != '2')
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_log_bf16_e32"
                Mnemonic = "v_log_bf16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[13] != '4')
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_log_bf16_e64"
                Mnemonic = "v_log_bf16";
              return;
            }
            break;
          case 't':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+12, "16", 2) != 0)
              break;
            if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_log_bf16_t16"
              Mnemonic = "v_log_bf16";
            return;
          }
          break;
        case 'f':	 // 2 strings to match.
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "6_sdwa", 6) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_log_f16_sdwa"
              Mnemonic = "v_log_f16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "2_sdwa", 6) != 0)
              break;
            Mnemonic = "v_log_f32";	 // "v_log_f32_sdwa"
            return;
          }
          break;
        }
        break;
      case 'm':	 // 11 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "x3_", 3) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "16_t16", 6) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_max3_f16_t16"
              Mnemonic = "v_max3_f16";
            return;
          case 'i':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "16_t16", 6) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_max3_i16_t16"
              Mnemonic = "v_max3_i16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_max3_i16";
            return;
          case 'u':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "16_t16", 6) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_max3_u16_t16"
              Mnemonic = "v_max3_u16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_max3_u16";
            return;
          }
          break;
        case 'e':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "d3_", 3) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "16_t16", 6) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_med3_f16_t16"
              Mnemonic = "v_med3_f16";
            return;
          case 'i':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "16_t16", 6) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_med3_i16_t16"
              Mnemonic = "v_med3_i16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_med3_i16";
            return;
          case 'u':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "16_t16", 6) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_med3_u16_t16"
              Mnemonic = "v_med3_u16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_med3_u16";
            return;
          }
          break;
        case 'i':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "n3_", 3) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "16_t16", 6) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_min3_f16_t16"
              Mnemonic = "v_min3_f16";
            return;
          case 'i':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "16_t16", 6) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_min3_i16_t16"
              Mnemonic = "v_min3_i16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_min3_i16";
            return;
          case 'u':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "16_t16", 6) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_min3_u16_t16"
              Mnemonic = "v_min3_u16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_min3_u16";
            return;
          }
          break;
        case 'o':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "v_b", 3) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "6_sdwa", 6) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_mov_b16_sdwa"
              Mnemonic = "v_mov_b16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "2_sdwa", 6) != 0)
              break;
            Mnemonic = "v_mov_b32";	 // "v_mov_b32_sdwa"
            return;
          }
          break;
        }
        break;
      case 'n':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+3, "ot_b", 4) != 0)
          break;
        switch (Mnemonic[7]) {
        default: break;
        case '1':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+8, "6_sdwa", 6) != 0)
            break;
          if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_not_b16_sdwa"
            Mnemonic = "v_not_b16";
          return;
        case '3':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+8, "2_sdwa", 6) != 0)
            break;
          Mnemonic = "v_not_b32";	 // "v_not_b32_sdwa"
          return;
        }
        break;
      case 'p':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+3, "rng_b32_e", 9) != 0)
          break;
        switch (Mnemonic[12]) {
        default: break;
        case '3':	 // 1 string to match.
          if (Mnemonic[13] != '2')
            break;
          if (Features.test(Feature_HasPrngInstBit))	 // "v_prng_b32_e32"
            Mnemonic = "v_prng_b32";
          return;
        case '6':	 // 1 string to match.
          if (Mnemonic[13] != '4')
            break;
          if (Features.test(Feature_HasPrngInstBit))	 // "v_prng_b32_e64"
            Mnemonic = "v_prng_b32";
          return;
        }
        break;
      case 'r':	 // 10 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'c':	 // 5 strings to match.
          if (memcmp(Mnemonic.data()+4, "p_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'b':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+7, "f16_", 4) != 0)
              break;
            switch (Mnemonic[11]) {
            default: break;
            case 'e':	 // 2 strings to match.
              switch (Mnemonic[12]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[13] != '2')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rcp_bf16_e32"
                  Mnemonic = "v_rcp_bf16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[13] != '4')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rcp_bf16_e64"
                  Mnemonic = "v_rcp_bf16";
                return;
              }
              break;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+12, "16", 2) != 0)
                break;
              if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_rcp_bf16_t16"
                Mnemonic = "v_rcp_bf16";
              return;
            }
            break;
          case 'f':	 // 2 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "6_sdwa", 6) != 0)
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_rcp_f16_sdwa"
                Mnemonic = "v_rcp_f16";
              return;
            case '3':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "2_sdwa", 6) != 0)
                break;
              Mnemonic = "v_rcp_f32";	 // "v_rcp_f32_sdwa"
              return;
            }
            break;
          }
          break;
        case 's':	 // 5 strings to match.
          if (memcmp(Mnemonic.data()+4, "q_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'b':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+7, "f16_", 4) != 0)
              break;
            switch (Mnemonic[11]) {
            default: break;
            case 'e':	 // 2 strings to match.
              switch (Mnemonic[12]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[13] != '2')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rsq_bf16_e32"
                  Mnemonic = "v_rsq_bf16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[13] != '4')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rsq_bf16_e64"
                  Mnemonic = "v_rsq_bf16";
                return;
              }
              break;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+12, "16", 2) != 0)
                break;
              if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_rsq_bf16_t16"
                Mnemonic = "v_rsq_bf16";
              return;
            }
            break;
          case 'f':	 // 2 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "6_sdwa", 6) != 0)
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_rsq_f16_sdwa"
                Mnemonic = "v_rsq_f16";
              return;
            case '3':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "2_sdwa", 6) != 0)
                break;
              Mnemonic = "v_rsq_f32";	 // "v_rsq_f32_sdwa"
              return;
            }
            break;
          }
          break;
        }
        break;
      case 's':	 // 12 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'i':	 // 5 strings to match.
          if (memcmp(Mnemonic.data()+4, "n_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'b':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+7, "f16_", 4) != 0)
              break;
            switch (Mnemonic[11]) {
            default: break;
            case 'e':	 // 2 strings to match.
              switch (Mnemonic[12]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[13] != '2')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sin_bf16_e32"
                  Mnemonic = "v_sin_bf16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[13] != '4')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sin_bf16_e64"
                  Mnemonic = "v_sin_bf16";
                return;
              }
              break;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+12, "16", 2) != 0)
                break;
              if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_sin_bf16_t16"
                Mnemonic = "v_sin_bf16";
              return;
            }
            break;
          case 'f':	 // 2 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "6_sdwa", 6) != 0)
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_sin_f16_sdwa"
                Mnemonic = "v_sin_f16";
              return;
            case '3':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "2_sdwa", 6) != 0)
                break;
              Mnemonic = "v_sin_f32";	 // "v_sin_f32_sdwa"
              return;
            }
            break;
          }
          break;
        case 'q':	 // 7 strings to match.
          if (memcmp(Mnemonic.data()+4, "rt_f", 4) != 0)
            break;
          switch (Mnemonic[8]) {
          default: break;
          case '1':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+9, "6_", 2) != 0)
              break;
            switch (Mnemonic[11]) {
            default: break;
            case 'e':	 // 2 strings to match.
              switch (Mnemonic[12]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[13] != '2')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_sqrt_f16_e32"
                  Mnemonic = "v_sqrt_f16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[13] != '4')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_sqrt_f16_e64"
                  Mnemonic = "v_sqrt_f16";
                return;
              }
              break;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+12, "16", 2) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_sqrt_f16_t16"
                Mnemonic = "v_sqrt_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_sqrt_f16";
              return;
            }
            break;
          case '3':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+9, "2_e", 3) != 0)
              break;
            switch (Mnemonic[12]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[13] != '2')
                break;
              Mnemonic = "v_sqrt_f32";	 // "v_sqrt_f32_e32"
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[13] != '4')
                break;
              Mnemonic = "v_sqrt_f32";	 // "v_sqrt_f32_e64"
              return;
            }
            break;
          case '6':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+9, "4_e", 3) != 0)
              break;
            switch (Mnemonic[12]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[13] != '2')
                break;
              Mnemonic = "v_sqrt_f64";	 // "v_sqrt_f64_e32"
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[13] != '4')
                break;
              Mnemonic = "v_sqrt_f64";	 // "v_sqrt_f64_e64"
              return;
            }
            break;
          }
          break;
        }
        break;
      case 't':	 // 5 strings to match.
        if (memcmp(Mnemonic.data()+3, "anh_f", 5) != 0)
          break;
        switch (Mnemonic[8]) {
        default: break;
        case '1':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+9, "6_", 2) != 0)
            break;
          switch (Mnemonic[11]) {
          default: break;
          case 'e':	 // 2 strings to match.
            switch (Mnemonic[12]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[13] != '2')
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasTanhInstsBit))	 // "v_tanh_f16_e32"
                Mnemonic = "v_tanh_f16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[13] != '4')
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasTanhInstsBit))	 // "v_tanh_f16_e64"
                Mnemonic = "v_tanh_f16";
              return;
            }
            break;
          case 't':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+12, "16", 2) != 0)
              break;
            if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_tanh_f16_t16"
              Mnemonic = "v_tanh_f16";
            return;
          }
          break;
        case '3':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+9, "2_e", 3) != 0)
            break;
          switch (Mnemonic[12]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[13] != '2')
              break;
            if (Features.test(Feature_HasTanhInstsBit))	 // "v_tanh_f32_e32"
              Mnemonic = "v_tanh_f32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[13] != '4')
              break;
            if (Features.test(Feature_HasTanhInstsBit))	 // "v_tanh_f32_e64"
              Mnemonic = "v_tanh_f32";
            return;
          }
          break;
        }
        break;
      }
      break;
    }
    break;
  case 15:	 // 76 strings to match.
    switch (Mnemonic[0]) {
    default: break;
    case 'd':	 // 2 strings to match.
      if (memcmp(Mnemonic.data()+1, "s_", 2) != 0)
        break;
      switch (Mnemonic[3]) {
      default: break;
      case 'l':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+4, "oad_tr_b128", 11) != 0)
          break;
        if (Features.test(Feature_isGFX1250PlusBit))	 // "ds_load_tr_b128"
          Mnemonic = "ds_load_tr16_b128";
        return;
      case 'r':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+4, "ead_u16_d16", 11) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_read_u16_d16"
          Mnemonic = "ds_load_u16_d16";
        else if (Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "ds_load_u16_d16";
        return;
      }
      break;
    case 'f':	 // 10 strings to match.
      if (memcmp(Mnemonic.data()+1, "lat_", 4) != 0)
        break;
      switch (Mnemonic[5]) {
      default: break;
      case 'a':	 // 6 strings to match.
        if (memcmp(Mnemonic.data()+6, "tomic_", 6) != 0)
          break;
        switch (Mnemonic[12]) {
        default: break;
        case 'a':	 // 2 strings to match.
          switch (Mnemonic[13]) {
          default: break;
          case 'd':	 // 1 string to match.
            if (Mnemonic[14] != 'd')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_add"
              Mnemonic = "flat_atomic_add_u32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "flat_atomic_add_u32";
            return;
          case 'n':	 // 1 string to match.
            if (Mnemonic[14] != 'd')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_and"
              Mnemonic = "flat_atomic_and_b32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "flat_atomic_and_b32";
            return;
          }
          break;
        case 'd':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "ec", 2) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_dec"
            Mnemonic = "flat_atomic_dec_u32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_atomic_dec_u32";
          return;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "nc", 2) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_inc"
            Mnemonic = "flat_atomic_inc_u32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_atomic_inc_u32";
          return;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "ub", 2) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_sub"
            Mnemonic = "flat_atomic_sub_u32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_atomic_sub_u32";
          return;
        case 'x':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "or", 2) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_xor"
            Mnemonic = "flat_atomic_xor_b32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_atomic_xor_b32";
          return;
        }
        break;
      case 'l':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+6, "oad_", 4) != 0)
          break;
        switch (Mnemonic[10]) {
        default: break;
        case 'd':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+11, "word", 4) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_load_dword"
            Mnemonic = "flat_load_b32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_load_b32";
          return;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+11, "byte", 4) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_load_sbyte"
            Mnemonic = "flat_load_i8";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_load_i8";
          return;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+11, "byte", 4) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_load_ubyte"
            Mnemonic = "flat_load_u8";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_load_u8";
          return;
        }
        break;
      case 's':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+6, "tore_byte", 9) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_store_byte"
          Mnemonic = "flat_store_b8";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "flat_store_b8";
        return;
      }
      break;
    case 'l':	 // 1 string to match.
      if (memcmp(Mnemonic.data()+1, "ds_direct_load", 14) != 0)
        break;
      if (Features.test(Feature_isGFX12PlusBit))	 // "lds_direct_load"
        Mnemonic = "ds_direct_load";
      return;
    case 's':	 // 5 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'f':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+3, "lbit_i32_", 9) != 0)
          break;
        switch (Mnemonic[12]) {
        default: break;
        case 'b':	 // 2 strings to match.
          switch (Mnemonic[13]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[14] != '2')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "s_flbit_i32_b32"
              Mnemonic = "s_clz_i32_u32";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "s_clz_i32_u32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[14] != '4')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "s_flbit_i32_b64"
              Mnemonic = "s_clz_i32_u64";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "s_clz_i32_u64";
            return;
          }
          break;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "64", 2) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "s_flbit_i32_i64"
            Mnemonic = "s_cls_i32_i64";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "s_cls_i32_i64";
          return;
        }
        break;
      case 'i':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "nst_prefetch", 12) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "s_inst_prefetch"
          Mnemonic = "s_set_inst_prefetch_distance";
        return;
      case 'l':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "oad_dwordx16", 12) != 0)
          break;
        if (Features.test(Feature_isGFX11PlusBit))	 // "s_load_dwordx16"
          Mnemonic = "s_load_b512";
        return;
      }
      break;
    case 'v':	 // 58 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'a':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "ccvgpr_write", 12) != 0)
          break;
        Mnemonic = "v_accvgpr_write_b32";	 // "v_accvgpr_write"
        return;
      case 'b':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+3, "frev_b32_e", 10) != 0)
          break;
        switch (Mnemonic[13]) {
        default: break;
        case '3':	 // 1 string to match.
          if (Mnemonic[14] != '2')
            break;
          Mnemonic = "v_bfrev_b32";	 // "v_bfrev_b32_e32"
          return;
        case '6':	 // 1 string to match.
          if (Mnemonic[14] != '4')
            break;
          Mnemonic = "v_bfrev_b32";	 // "v_bfrev_b32_e64"
          return;
        }
        break;
      case 'c':	 // 3 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'e':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "il_f", 4) != 0)
            break;
          switch (Mnemonic[8]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+9, "6_sdwa", 6) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_ceil_f16_sdwa"
              Mnemonic = "v_ceil_f16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+9, "2_sdwa", 6) != 0)
              break;
            Mnemonic = "v_ceil_f32";	 // "v_ceil_f32_sdwa"
            return;
          }
          break;
        case 'o':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "s_bf16_sdwa", 11) != 0)
            break;
          if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_cos_bf16_sdwa"
            Mnemonic = "v_cos_bf16";
          return;
        }
        break;
      case 'd':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "ot2c_f32_f16", 12) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_dot2c_f32_f16"
          Mnemonic = "v_dot2acc_f32_f16";
        return;
      case 'e':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "xp_bf16_sdwa", 12) != 0)
          break;
        if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_exp_bf16_sdwa"
          Mnemonic = "v_exp_bf16";
        return;
      case 'f':	 // 17 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'f':	 // 3 strings to match.
          if (Mnemonic[4] != 'b')
            break;
          switch (Mnemonic[5]) {
          default: break;
          case 'h':	 // 2 strings to match.
            if (Mnemonic[6] != '_')
              break;
            switch (Mnemonic[7]) {
            default: break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "32_sdwa", 7) != 0)
                break;
              Mnemonic = "v_ffbh_i32";	 // "v_ffbh_i32_sdwa"
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "32_sdwa", 7) != 0)
                break;
              Mnemonic = "v_ffbh_u32";	 // "v_ffbh_u32_sdwa"
              return;
            }
            break;
          case 'l':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+6, "_b32_sdwa", 9) != 0)
              break;
            Mnemonic = "v_ffbl_b32";	 // "v_ffbl_b32_sdwa"
            return;
          }
          break;
        case 'l':	 // 7 strings to match.
          if (memcmp(Mnemonic.data()+4, "oor_f", 5) != 0)
            break;
          switch (Mnemonic[9]) {
          default: break;
          case '1':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+10, "6_", 2) != 0)
              break;
            switch (Mnemonic[12]) {
            default: break;
            case 'e':	 // 2 strings to match.
              switch (Mnemonic[13]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[14] != '2')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_floor_f16_e32"
                  Mnemonic = "v_floor_f16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[14] != '4')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_floor_f16_e64"
                  Mnemonic = "v_floor_f16";
                return;
              }
              break;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+13, "16", 2) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_floor_f16_t16"
                Mnemonic = "v_floor_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_floor_f16";
              return;
            }
            break;
          case '3':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+10, "2_e", 3) != 0)
              break;
            switch (Mnemonic[13]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[14] != '2')
                break;
              Mnemonic = "v_floor_f32";	 // "v_floor_f32_e32"
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[14] != '4')
                break;
              Mnemonic = "v_floor_f32";	 // "v_floor_f32_e64"
              return;
            }
            break;
          case '6':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+10, "4_e", 3) != 0)
              break;
            switch (Mnemonic[13]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[14] != '2')
                break;
              if (Features.test(Feature_isGFX7PlusBit))	 // "v_floor_f64_e32"
                Mnemonic = "v_floor_f64";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[14] != '4')
                break;
              if (Features.test(Feature_isGFX7PlusBit))	 // "v_floor_f64_e64"
                Mnemonic = "v_floor_f64";
              return;
            }
            break;
          }
          break;
        case 'r':	 // 7 strings to match.
          if (memcmp(Mnemonic.data()+4, "act_f", 5) != 0)
            break;
          switch (Mnemonic[9]) {
          default: break;
          case '1':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+10, "6_", 2) != 0)
              break;
            switch (Mnemonic[12]) {
            default: break;
            case 'e':	 // 2 strings to match.
              switch (Mnemonic[13]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[14] != '2')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_fract_f16_e32"
                  Mnemonic = "v_fract_f16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[14] != '4')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_fract_f16_e64"
                  Mnemonic = "v_fract_f16";
                return;
              }
              break;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+13, "16", 2) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_fract_f16_t16"
                Mnemonic = "v_fract_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_fract_f16";
              return;
            }
            break;
          case '3':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+10, "2_e", 3) != 0)
              break;
            switch (Mnemonic[13]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[14] != '2')
                break;
              Mnemonic = "v_fract_f32";	 // "v_fract_f32_e32"
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[14] != '4')
                break;
              Mnemonic = "v_fract_f32";	 // "v_fract_f32_e64"
              return;
            }
            break;
          case '6':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+10, "4_e", 3) != 0)
              break;
            switch (Mnemonic[13]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[14] != '2')
                break;
              Mnemonic = "v_fract_f64";	 // "v_fract_f64_e32"
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[14] != '4')
                break;
              Mnemonic = "v_fract_f64";	 // "v_fract_f64_e64"
              return;
            }
            break;
          }
          break;
        }
        break;
      case 'l':	 // 2 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'd':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "exp_f16_t16", 11) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_ldexp_f16_t16"
            Mnemonic = "v_ldexp_f16";
          else if (Features.test(Feature_isGFX11OnlyBit))
            Mnemonic = "v_ldexp_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_ldexp_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_ldexp_f16";
          return;
        case 'o':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "g_bf16_sdwa", 11) != 0)
            break;
          if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_log_bf16_sdwa"
            Mnemonic = "v_log_bf16";
          return;
        }
        break;
      case 'o':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "r_b16_fake16", 12) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_or_b16_fake16"
          Mnemonic = "v_or_b16";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_or_b16";
        return;
      case 'p':	 // 3 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'i':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "peflush_e", 9) != 0)
            break;
          switch (Mnemonic[13]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[14] != '2')
              break;
            if (Features.test(Feature_isGFX10PlusBit))	 // "v_pipeflush_e32"
              Mnemonic = "v_pipeflush";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[14] != '4')
              break;
            if (Features.test(Feature_isGFX10PlusBit))	 // "v_pipeflush_e64"
              Mnemonic = "v_pipeflush";
            return;
          }
          break;
        case 'r':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "ng_b32_sdwa", 11) != 0)
            break;
          if (Features.test(Feature_HasPrngInstBit))	 // "v_prng_b32_sdwa"
            Mnemonic = "v_prng_b32";
          return;
        }
        break;
      case 'r':	 // 9 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'c':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "p_bf16_sdwa", 11) != 0)
            break;
          if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rcp_bf16_sdwa"
            Mnemonic = "v_rcp_bf16";
          return;
        case 'n':	 // 7 strings to match.
          if (memcmp(Mnemonic.data()+4, "dne_f", 5) != 0)
            break;
          switch (Mnemonic[9]) {
          default: break;
          case '1':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+10, "6_", 2) != 0)
              break;
            switch (Mnemonic[12]) {
            default: break;
            case 'e':	 // 2 strings to match.
              switch (Mnemonic[13]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[14] != '2')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_rndne_f16_e32"
                  Mnemonic = "v_rndne_f16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[14] != '4')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_rndne_f16_e64"
                  Mnemonic = "v_rndne_f16";
                return;
              }
              break;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+13, "16", 2) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_rndne_f16_t16"
                Mnemonic = "v_rndne_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_rndne_f16";
              return;
            }
            break;
          case '3':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+10, "2_e", 3) != 0)
              break;
            switch (Mnemonic[13]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[14] != '2')
                break;
              Mnemonic = "v_rndne_f32";	 // "v_rndne_f32_e32"
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[14] != '4')
                break;
              Mnemonic = "v_rndne_f32";	 // "v_rndne_f32_e64"
              return;
            }
            break;
          case '6':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+10, "4_e", 3) != 0)
              break;
            switch (Mnemonic[13]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[14] != '2')
                break;
              if (Features.test(Feature_isGFX7PlusBit))	 // "v_rndne_f64_e32"
                Mnemonic = "v_rndne_f64";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[14] != '4')
                break;
              if (Features.test(Feature_isGFX7PlusBit))	 // "v_rndne_f64_e64"
                Mnemonic = "v_rndne_f64";
              return;
            }
            break;
          }
          break;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "q_bf16_sdwa", 11) != 0)
            break;
          if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rsq_bf16_sdwa"
            Mnemonic = "v_rsq_bf16";
          return;
        }
        break;
      case 's':	 // 6 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "n_bf16_sdwa", 11) != 0)
            break;
          if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sin_bf16_sdwa"
            Mnemonic = "v_sin_bf16";
          return;
        case 'q':	 // 5 strings to match.
          if (memcmp(Mnemonic.data()+4, "rt_", 3) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'b':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+8, "f16_", 4) != 0)
              break;
            switch (Mnemonic[12]) {
            default: break;
            case 'e':	 // 2 strings to match.
              switch (Mnemonic[13]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[14] != '2')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sqrt_bf16_e32"
                  Mnemonic = "v_sqrt_bf16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[14] != '4')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sqrt_bf16_e64"
                  Mnemonic = "v_sqrt_bf16";
                return;
              }
              break;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+13, "16", 2) != 0)
                break;
              if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_sqrt_bf16_t16"
                Mnemonic = "v_sqrt_bf16";
              return;
            }
            break;
          case 'f':	 // 2 strings to match.
            switch (Mnemonic[8]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "6_sdwa", 6) != 0)
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_sqrt_f16_sdwa"
                Mnemonic = "v_sqrt_f16";
              return;
            case '3':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "2_sdwa", 6) != 0)
                break;
              Mnemonic = "v_sqrt_f32";	 // "v_sqrt_f32_sdwa"
              return;
            }
            break;
          }
          break;
        }
        break;
      case 't':	 // 12 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 5 strings to match.
          if (memcmp(Mnemonic.data()+4, "nh_", 3) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'b':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+8, "f16_", 4) != 0)
              break;
            switch (Mnemonic[12]) {
            default: break;
            case 'e':	 // 2 strings to match.
              switch (Mnemonic[13]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[14] != '2')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_tanh_bf16_e32"
                  Mnemonic = "v_tanh_bf16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[14] != '4')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_tanh_bf16_e64"
                  Mnemonic = "v_tanh_bf16";
                return;
              }
              break;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+13, "16", 2) != 0)
                break;
              if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_tanh_bf16_t16"
                Mnemonic = "v_tanh_bf16";
              return;
            }
            break;
          case 'f':	 // 2 strings to match.
            switch (Mnemonic[8]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "6_sdwa", 6) != 0)
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasTanhInstsBit))	 // "v_tanh_f16_sdwa"
                Mnemonic = "v_tanh_f16";
              return;
            case '3':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "2_sdwa", 6) != 0)
                break;
              if (Features.test(Feature_HasTanhInstsBit))	 // "v_tanh_f32_sdwa"
                Mnemonic = "v_tanh_f32";
              return;
            }
            break;
          }
          break;
        case 'r':	 // 7 strings to match.
          if (memcmp(Mnemonic.data()+4, "unc_f", 5) != 0)
            break;
          switch (Mnemonic[9]) {
          default: break;
          case '1':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+10, "6_", 2) != 0)
              break;
            switch (Mnemonic[12]) {
            default: break;
            case 'e':	 // 2 strings to match.
              switch (Mnemonic[13]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[14] != '2')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_trunc_f16_e32"
                  Mnemonic = "v_trunc_f16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[14] != '4')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_trunc_f16_e64"
                  Mnemonic = "v_trunc_f16";
                return;
              }
              break;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+13, "16", 2) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_trunc_f16_t16"
                Mnemonic = "v_trunc_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_trunc_f16";
              return;
            }
            break;
          case '3':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+10, "2_e", 3) != 0)
              break;
            switch (Mnemonic[13]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[14] != '2')
                break;
              Mnemonic = "v_trunc_f32";	 // "v_trunc_f32_e32"
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[14] != '4')
                break;
              Mnemonic = "v_trunc_f32";	 // "v_trunc_f32_e64"
              return;
            }
            break;
          case '6':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+10, "4_e", 3) != 0)
              break;
            switch (Mnemonic[13]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[14] != '2')
                break;
              if (Features.test(Feature_isGFX7PlusBit))	 // "v_trunc_f64_e32"
                Mnemonic = "v_trunc_f64";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[14] != '4')
                break;
              if (Features.test(Feature_isGFX7PlusBit))	 // "v_trunc_f64_e64"
                Mnemonic = "v_trunc_f64";
              return;
            }
            break;
          }
          break;
        }
        break;
      }
      break;
    }
    break;
  case 16:	 // 61 strings to match.
    switch (Mnemonic[0]) {
    default: break;
    case 'b':	 // 1 string to match.
      if (memcmp(Mnemonic.data()+1, "uffer_atomic_or", 15) != 0)
        break;
      if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_or"
        Mnemonic = "buffer_atomic_or_b32";
      else if (Features.test(Feature_isGFX12PlusBit))
        Mnemonic = "buffer_atomic_or_b32";
      return;
    case 'd':	 // 2 strings to match.
      if (memcmp(Mnemonic.data()+1, "s_read2st64_b", 13) != 0)
        break;
      switch (Mnemonic[14]) {
      default: break;
      case '3':	 // 1 string to match.
        if (Mnemonic[15] != '2')
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_read2st64_b32"
          Mnemonic = "ds_load_2addr_stride64_b32";
        else if (Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "ds_load_2addr_stride64_b32";
        return;
      case '6':	 // 1 string to match.
        if (Mnemonic[15] != '4')
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_read2st64_b64"
          Mnemonic = "ds_load_2addr_stride64_b64";
        else if (Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "ds_load_2addr_stride64_b64";
        return;
      }
      break;
    case 'f':	 // 11 strings to match.
      if (memcmp(Mnemonic.data()+1, "lat_", 4) != 0)
        break;
      switch (Mnemonic[5]) {
      default: break;
      case 'a':	 // 7 strings to match.
        if (memcmp(Mnemonic.data()+6, "tomic_", 6) != 0)
          break;
        switch (Mnemonic[12]) {
        default: break;
        case 'f':	 // 2 strings to match.
          if (Mnemonic[13] != 'm')
            break;
          switch (Mnemonic[14]) {
          default: break;
          case 'a':	 // 1 string to match.
            if (Mnemonic[15] != 'x')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_fmax"
              Mnemonic = "flat_atomic_max_f32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "flat_atomic_max_num_f32";
            return;
          case 'i':	 // 1 string to match.
            if (Mnemonic[15] != 'n')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_fmin"
              Mnemonic = "flat_atomic_min_f32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "flat_atomic_min_num_f32";
            return;
          }
          break;
        case 's':	 // 3 strings to match.
          switch (Mnemonic[13]) {
          default: break;
          case 'm':	 // 2 strings to match.
            switch (Mnemonic[14]) {
            default: break;
            case 'a':	 // 1 string to match.
              if (Mnemonic[15] != 'x')
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_smax"
                Mnemonic = "flat_atomic_max_i32";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "flat_atomic_max_i32";
              return;
            case 'i':	 // 1 string to match.
              if (Mnemonic[15] != 'n')
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_smin"
                Mnemonic = "flat_atomic_min_i32";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "flat_atomic_min_i32";
              return;
            }
            break;
          case 'w':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "ap", 2) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_swap"
              Mnemonic = "flat_atomic_swap_b32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "flat_atomic_swap_b32";
            return;
          }
          break;
        case 'u':	 // 2 strings to match.
          if (Mnemonic[13] != 'm')
            break;
          switch (Mnemonic[14]) {
          default: break;
          case 'a':	 // 1 string to match.
            if (Mnemonic[15] != 'x')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_umax"
              Mnemonic = "flat_atomic_max_u32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "flat_atomic_max_u32";
            return;
          case 'i':	 // 1 string to match.
            if (Mnemonic[15] != 'n')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_umin"
              Mnemonic = "flat_atomic_min_u32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "flat_atomic_min_u32";
            return;
          }
          break;
        }
        break;
      case 'l':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+6, "oad_", 4) != 0)
          break;
        switch (Mnemonic[10]) {
        default: break;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+11, "short", 5) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_load_sshort"
            Mnemonic = "flat_load_i16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_load_i16";
          return;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+11, "short", 5) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_load_ushort"
            Mnemonic = "flat_load_u16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_load_u16";
          return;
        }
        break;
      case 's':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+6, "tore_", 5) != 0)
          break;
        switch (Mnemonic[11]) {
        default: break;
        case 'd':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+12, "word", 4) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_store_dword"
            Mnemonic = "flat_store_b32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_store_b32";
          return;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+12, "hort", 4) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_store_short"
            Mnemonic = "flat_store_b16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_store_b16";
          return;
        }
        break;
      }
      break;
    case 'g':	 // 1 string to match.
      if (memcmp(Mnemonic.data()+1, "lobal_atomic_or", 15) != 0)
        break;
      if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_or"
        Mnemonic = "global_atomic_or_b32";
      else if (Features.test(Feature_isGFX12OnlyBit))
        Mnemonic = "global_atomic_or_b32";
      return;
    case 'i':	 // 4 strings to match.
      if (memcmp(Mnemonic.data()+1, "mage_atomic_", 12) != 0)
        break;
      switch (Mnemonic[13]) {
      default: break;
      case 'a':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+14, "dd", 2) != 0)
          break;
        if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))	 // "image_atomic_add"
          Mnemonic = "image_atomic_add_uint";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_add_uint";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_add_uint";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_add_uint";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_add_uint";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_add_uint";
        return;
      case 'd':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+14, "ec", 2) != 0)
          break;
        if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))	 // "image_atomic_dec"
          Mnemonic = "image_atomic_dec_uint";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_dec_uint";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_dec_uint";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_dec_uint";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_dec_uint";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_dec_uint";
        return;
      case 'i':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+14, "nc", 2) != 0)
          break;
        if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))	 // "image_atomic_inc"
          Mnemonic = "image_atomic_inc_uint";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_inc_uint";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_inc_uint";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_inc_uint";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_inc_uint";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_inc_uint";
        return;
      case 's':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+14, "ub", 2) != 0)
          break;
        if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))	 // "image_atomic_sub"
          Mnemonic = "image_atomic_sub_uint";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_sub_uint";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_sub_uint";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_sub_uint";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_sub_uint";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_sub_uint";
        return;
      }
      break;
    case 's':	 // 1 string to match.
      if (memcmp(Mnemonic.data()+1, "_waitcnt_depctr", 15) != 0)
        break;
      if (Features.test(Feature_isGFX12PlusBit))	 // "s_waitcnt_depctr"
        Mnemonic = "s_wait_alu";
      return;
    case 'v':	 // 41 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'a':	 // 5 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'd':	 // 4 strings to match.
          if (memcmp(Mnemonic.data()+4, "d_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'f':	 // 2 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "6_fake16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_add_f16_fake16"
                Mnemonic = "v_add_f16";
              else if (Features.test(Feature_isGFX11OnlyBit))
                Mnemonic = "v_add_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_add_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_add_f16";
              return;
            case '6':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "4_pseudo", 8) != 0)
                break;
              if (Features.test(Feature_isGFX12OnlyBit))	 // "v_add_f64_pseudo"
                Mnemonic = "v_add_f64";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_add_f64";
              return;
            }
            break;
          case 'i':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "16_fake16", 9) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_add_i16_fake16"
              Mnemonic = "v_add_nc_i16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_add_nc_i16";
            return;
          case 'n':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "c_u16_t16", 9) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_add_nc_u16_t16"
              Mnemonic = "v_add_nc_u16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_add_nc_u16";
            return;
          }
          break;
        case 'n':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "d_b16_fake16", 12) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_and_b16_fake16"
            Mnemonic = "v_and_b16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_and_b16";
          return;
        }
        break;
      case 'b':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "frev_b32_sdwa", 13) != 0)
          break;
        Mnemonic = "v_bfrev_b32";	 // "v_bfrev_b32_sdwa"
        return;
      case 'c':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "os_f16_fake16", 13) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cos_f16_fake16"
          Mnemonic = "v_cos_f16";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_cos_f16";
        return;
      case 'e':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "xp_f16_fake16", 13) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_exp_f16_fake16"
          Mnemonic = "v_exp_f16";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_exp_f16";
        return;
      case 'f':	 // 5 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'l':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "oor_f", 5) != 0)
            break;
          switch (Mnemonic[9]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "6_sdwa", 6) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_floor_f16_sdwa"
              Mnemonic = "v_floor_f16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "2_sdwa", 6) != 0)
              break;
            Mnemonic = "v_floor_f32";	 // "v_floor_f32_sdwa"
            return;
          }
          break;
        case 'm':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "a_legacy_f32", 12) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_fma_legacy_f32"
            Mnemonic = "v_fma_dx9_zero_f32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_fma_dx9_zero_f32";
          return;
        case 'r':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "act_f", 5) != 0)
            break;
          switch (Mnemonic[9]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "6_sdwa", 6) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_fract_f16_sdwa"
              Mnemonic = "v_fract_f16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "2_sdwa", 6) != 0)
              break;
            Mnemonic = "v_fract_f32";	 // "v_fract_f32_sdwa"
            return;
          }
          break;
        }
        break;
      case 'l':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "og_f16_fake16", 13) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_log_f16_fake16"
          Mnemonic = "v_log_f16";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_log_f16";
        return;
      case 'm':	 // 12 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 4 strings to match.
          if (Mnemonic[4] != 'x')
            break;
          switch (Mnemonic[5]) {
          default: break;
          case '_':	 // 3 strings to match.
            switch (Mnemonic[6]) {
            default: break;
            case 'f':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_max_f16_fake16"
                Mnemonic = "v_max_f16";
              else if (Features.test(Feature_isGFX11OnlyBit))
                Mnemonic = "v_max_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_max_num_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_max_num_f16";
              return;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_max_i16_fake16"
                Mnemonic = "v_max_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_max_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_max_u16_fake16"
                Mnemonic = "v_max_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_max_u16";
              return;
            }
            break;
          case 'm':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+6, "in_f16_t16", 10) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_maxmin_f16_t16"
              Mnemonic = "v_maxmin_f16";
            return;
          }
          break;
        case 'i':	 // 4 strings to match.
          if (Mnemonic[4] != 'n')
            break;
          switch (Mnemonic[5]) {
          default: break;
          case '_':	 // 3 strings to match.
            switch (Mnemonic[6]) {
            default: break;
            case 'f':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_min_f16_fake16"
                Mnemonic = "v_min_f16";
              else if (Features.test(Feature_isGFX11OnlyBit))
                Mnemonic = "v_min_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_min_num_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_min_num_f16";
              return;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_min_i16_fake16"
                Mnemonic = "v_min_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_min_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_min_u16_fake16"
                Mnemonic = "v_min_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_min_u16";
              return;
            }
            break;
          case 'm':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+6, "ax_f16_t16", 10) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_minmax_f16_t16"
              Mnemonic = "v_minmax_f16";
            return;
          }
          break;
        case 'u':	 // 4 strings to match.
          if (memcmp(Mnemonic.data()+4, "l_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'f':	 // 2 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "6_fake16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_mul_f16_fake16"
                Mnemonic = "v_mul_f16";
              else if (Features.test(Feature_isGFX11OnlyBit))
                Mnemonic = "v_mul_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_mul_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_mul_f16";
              return;
            case '6':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "4_pseudo", 8) != 0)
                break;
              if (Features.test(Feature_isGFX12OnlyBit))	 // "v_mul_f64_pseudo"
                Mnemonic = "v_mul_f64";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_mul_f64";
              return;
            }
            break;
          case 'l':	 // 2 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case 'e':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "gacy_f32", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_mul_legacy_f32"
                Mnemonic = "v_mul_dx9_zero_f32";
              else if (Features.test(Feature_isGFX11OnlyBit))
                Mnemonic = "v_mul_dx9_zero_f32";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_mul_dx9_zero_f32";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_mul_dx9_zero_f32";
              return;
            case 'o':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "_u16_t16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_mul_lo_u16_t16"
                Mnemonic = "v_mul_lo_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_mul_lo_u16";
              return;
            }
            break;
          }
          break;
        }
        break;
      case 'n':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "ot_b16_fake16", 13) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_not_b16_fake16"
          Mnemonic = "v_not_b16";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_not_b16";
        return;
      case 'r':	 // 4 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'c':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "p_f16_fake16", 12) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_rcp_f16_fake16"
            Mnemonic = "v_rcp_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_rcp_f16";
          return;
        case 'n':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "dne_f", 5) != 0)
            break;
          switch (Mnemonic[9]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "6_sdwa", 6) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_rndne_f16_sdwa"
              Mnemonic = "v_rndne_f16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "2_sdwa", 6) != 0)
              break;
            Mnemonic = "v_rndne_f32";	 // "v_rndne_f32_sdwa"
            return;
          }
          break;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "q_f16_fake16", 12) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_rsq_f16_fake16"
            Mnemonic = "v_rsq_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_rsq_f16";
          return;
        }
        break;
      case 's':	 // 6 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "n_f16_fake16", 12) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_sin_f16_fake16"
            Mnemonic = "v_sin_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_sin_f16";
          return;
        case 'q':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "rt_bf16_sdwa", 12) != 0)
            break;
          if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sqrt_bf16_sdwa"
            Mnemonic = "v_sqrt_bf16";
          return;
        case 'u':	 // 4 strings to match.
          if (Mnemonic[4] != 'b')
            break;
          switch (Mnemonic[5]) {
          default: break;
          case '_':	 // 3 strings to match.
            switch (Mnemonic[6]) {
            default: break;
            case 'f':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_sub_f16_fake16"
                Mnemonic = "v_sub_f16";
              else if (Features.test(Feature_isGFX11OnlyBit))
                Mnemonic = "v_sub_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_sub_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_sub_f16";
              return;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_sub_i16_fake16"
                Mnemonic = "v_sub_nc_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_sub_nc_i16";
              return;
            case 'n':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "c_u16_t16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_sub_nc_u16_t16"
                Mnemonic = "v_sub_nc_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_sub_nc_u16";
              return;
            }
            break;
          case 'r':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+6, "ev_f16_t16", 10) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_subrev_f16_t16"
              Mnemonic = "v_subrev_f16";
            else if (Features.test(Feature_isGFX11OnlyBit))
              Mnemonic = "v_subrev_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_subrev_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_subrev_f16";
            return;
          }
          break;
        }
        break;
      case 't':	 // 3 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "nh_bf16_sdwa", 12) != 0)
            break;
          if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_tanh_bf16_sdwa"
            Mnemonic = "v_tanh_bf16";
          return;
        case 'r':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "unc_f", 5) != 0)
            break;
          switch (Mnemonic[9]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "6_sdwa", 6) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_trunc_f16_sdwa"
              Mnemonic = "v_trunc_f16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "2_sdwa", 6) != 0)
              break;
            Mnemonic = "v_trunc_f32";	 // "v_trunc_f32_sdwa"
            return;
          }
          break;
        }
        break;
      case 'x':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "or_b16_fake16", 13) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_xor_b16_fake16"
          Mnemonic = "v_xor_b16";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_xor_b16";
        return;
      }
      break;
    }
    break;
  case 17:	 // 147 strings to match.
    switch (Mnemonic[0]) {
    default: break;
    case 'b':	 // 11 strings to match.
      switch (Mnemonic[1]) {
      default: break;
      case 'u':	 // 10 strings to match.
        if (memcmp(Mnemonic.data()+2, "ffer_", 5) != 0)
          break;
        switch (Mnemonic[7]) {
        default: break;
        case 'a':	 // 6 strings to match.
          if (memcmp(Mnemonic.data()+8, "tomic_", 6) != 0)
            break;
          switch (Mnemonic[14]) {
          default: break;
          case 'a':	 // 2 strings to match.
            switch (Mnemonic[15]) {
            default: break;
            case 'd':	 // 1 string to match.
              if (Mnemonic[16] != 'd')
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_add"
                Mnemonic = "buffer_atomic_add_u32";
              else if (Features.test(Feature_isGFX12PlusBit))
                Mnemonic = "buffer_atomic_add_u32";
              return;
            case 'n':	 // 1 string to match.
              if (Mnemonic[16] != 'd')
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_and"
                Mnemonic = "buffer_atomic_and_b32";
              else if (Features.test(Feature_isGFX12PlusBit))
                Mnemonic = "buffer_atomic_and_b32";
              return;
            }
            break;
          case 'd':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+15, "ec", 2) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_dec"
              Mnemonic = "buffer_atomic_dec_u32";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "buffer_atomic_dec_u32";
            return;
          case 'i':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+15, "nc", 2) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_inc"
              Mnemonic = "buffer_atomic_inc_u32";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "buffer_atomic_inc_u32";
            return;
          case 's':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+15, "ub", 2) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_sub"
              Mnemonic = "buffer_atomic_sub_u32";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "buffer_atomic_sub_u32";
            return;
          case 'x':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+15, "or", 2) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_xor"
              Mnemonic = "buffer_atomic_xor_b32";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "buffer_atomic_xor_b32";
            return;
          }
          break;
        case 'l':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+8, "oad_", 4) != 0)
            break;
          switch (Mnemonic[12]) {
          default: break;
          case 'd':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+13, "word", 4) != 0)
              break;
            if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_load_dword"
              Mnemonic = "buffer_load_b32";
            return;
          case 's':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+13, "byte", 4) != 0)
              break;
            if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_load_sbyte"
              Mnemonic = "buffer_load_i8";
            return;
          case 'u':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+13, "byte", 4) != 0)
              break;
            if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_load_ubyte"
              Mnemonic = "buffer_load_u8";
            return;
          }
          break;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+8, "tore_byte", 9) != 0)
            break;
          if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_store_byte"
            Mnemonic = "buffer_store_b8";
          return;
        }
        break;
      case 'v':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+2, "h_intersect_ray", 15) != 0)
          break;
        if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))	 // "bvh_intersect_ray"
          Mnemonic = "image_bvh_intersect_ray";
        return;
      }
      break;
    case 'd':	 // 11 strings to match.
      if (memcmp(Mnemonic.data()+1, "s_", 2) != 0)
        break;
      switch (Mnemonic[3]) {
      default: break;
      case 'l':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+4, "oad_b", 5) != 0)
          break;
        switch (Mnemonic[9]) {
        default: break;
        case '6':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+10, "4_tr_b", 6) != 0)
            break;
          switch (Mnemonic[16]) {
          default: break;
          case '4':	 // 1 string to match.
            if (Features.test(Feature_isGFX125xOnlyBit))	 // "ds_load_b64_tr_b4"
              Mnemonic = "ds_load_tr4_b64";
            return;
          case '8':	 // 1 string to match.
            if (Features.test(Feature_isGFX125xOnlyBit))	 // "ds_load_b64_tr_b8"
              Mnemonic = "ds_load_tr8_b64";
            return;
          }
          break;
        case '9':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+10, "6_tr_b6", 7) != 0)
            break;
          if (Features.test(Feature_isGFX125xOnlyBit))	 // "ds_load_b96_tr_b6"
            Mnemonic = "ds_load_tr6_b96";
          return;
        }
        break;
      case 'r':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+4, "ead_", 4) != 0)
          break;
        switch (Mnemonic[8]) {
        default: break;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+9, "8_d16_hi", 8) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_read_i8_d16_hi"
            Mnemonic = "ds_load_i8_d16_hi";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "ds_load_i8_d16_hi";
          return;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+9, "8_d16_hi", 8) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_read_u8_d16_hi"
            Mnemonic = "ds_load_u8_d16_hi";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "ds_load_u8_d16_hi";
          return;
        }
        break;
      case 's':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+4, "ubrev_rtn_u", 11) != 0)
          break;
        switch (Mnemonic[15]) {
        default: break;
        case '3':	 // 1 string to match.
          if (Mnemonic[16] != '2')
            break;
          if (Features.test(Feature_isGFX12PlusBit))	 // "ds_subrev_rtn_u32"
            Mnemonic = "ds_rsub_rtn_u32";
          return;
        case '6':	 // 1 string to match.
          if (Mnemonic[16] != '4')
            break;
          if (Features.test(Feature_isGFX12PlusBit))	 // "ds_subrev_rtn_u64"
            Mnemonic = "ds_rsub_rtn_u64";
          return;
        }
        break;
      case 'w':	 // 4 strings to match.
        if (Mnemonic[4] != 'r')
          break;
        switch (Mnemonic[5]) {
        default: break;
        case 'i':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+6, "te2st64_b", 9) != 0)
            break;
          switch (Mnemonic[15]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[16] != '2')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_write2st64_b32"
              Mnemonic = "ds_store_2addr_stride64_b32";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "ds_store_2addr_stride64_b32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[16] != '4')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_write2st64_b64"
              Mnemonic = "ds_store_2addr_stride64_b64";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "ds_store_2addr_stride64_b64";
            return;
          }
          break;
        case 'x':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+6, "chg_rtn_b", 9) != 0)
            break;
          switch (Mnemonic[15]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[16] != '2')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_wrxchg_rtn_b32"
              Mnemonic = "ds_storexchg_rtn_b32";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "ds_storexchg_rtn_b32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[16] != '4')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_wrxchg_rtn_b64"
              Mnemonic = "ds_storexchg_rtn_b64";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "ds_storexchg_rtn_b64";
            return;
          }
          break;
        }
        break;
      }
      break;
    case 'f':	 // 4 strings to match.
      if (memcmp(Mnemonic.data()+1, "lat_", 4) != 0)
        break;
      switch (Mnemonic[5]) {
      default: break;
      case 'a':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+6, "tomic_or_x2", 11) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_or_x2"
          Mnemonic = "flat_atomic_or_b64";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "flat_atomic_or_b64";
        return;
      case 'l':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+6, "oad_dwordx", 10) != 0)
          break;
        switch (Mnemonic[16]) {
        default: break;
        case '2':	 // 1 string to match.
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_load_dwordx2"
            Mnemonic = "flat_load_b64";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_load_b64";
          return;
        case '3':	 // 1 string to match.
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_load_dwordx3"
            Mnemonic = "flat_load_b96";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_load_b96";
          return;
        case '4':	 // 1 string to match.
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_load_dwordx4"
            Mnemonic = "flat_load_b128";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_load_b128";
          return;
        }
        break;
      }
      break;
    case 'g':	 // 10 strings to match.
      if (memcmp(Mnemonic.data()+1, "lobal_", 6) != 0)
        break;
      switch (Mnemonic[7]) {
      default: break;
      case 'a':	 // 6 strings to match.
        if (memcmp(Mnemonic.data()+8, "tomic_", 6) != 0)
          break;
        switch (Mnemonic[14]) {
        default: break;
        case 'a':	 // 2 strings to match.
          switch (Mnemonic[15]) {
          default: break;
          case 'd':	 // 1 string to match.
            if (Mnemonic[16] != 'd')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_add"
              Mnemonic = "global_atomic_add_u32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "global_atomic_add_u32";
            return;
          case 'n':	 // 1 string to match.
            if (Mnemonic[16] != 'd')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_and"
              Mnemonic = "global_atomic_and_b32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "global_atomic_and_b32";
            return;
          }
          break;
        case 'd':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+15, "ec", 2) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_dec"
            Mnemonic = "global_atomic_dec_u32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_atomic_dec_u32";
          return;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+15, "nc", 2) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_inc"
            Mnemonic = "global_atomic_inc_u32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_atomic_inc_u32";
          return;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+15, "ub", 2) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_sub"
            Mnemonic = "global_atomic_sub_u32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_atomic_sub_u32";
          return;
        case 'x':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+15, "or", 2) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_xor"
            Mnemonic = "global_atomic_xor_b32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_atomic_xor_b32";
          return;
        }
        break;
      case 'l':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+8, "oad_", 4) != 0)
          break;
        switch (Mnemonic[12]) {
        default: break;
        case 'd':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "word", 4) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_load_dword"
            Mnemonic = "global_load_b32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_load_b32";
          return;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "byte", 4) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_load_sbyte"
            Mnemonic = "global_load_i8";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_load_i8";
          return;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "byte", 4) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_load_ubyte"
            Mnemonic = "global_load_u8";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_load_u8";
          return;
        }
        break;
      case 's':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+8, "tore_byte", 9) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "global_store_byte"
          Mnemonic = "global_store_b8";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "global_store_b8";
        return;
      }
      break;
    case 'i':	 // 6 strings to match.
      if (memcmp(Mnemonic.data()+1, "mage_atomic_", 12) != 0)
        break;
      switch (Mnemonic[13]) {
      default: break;
      case 'f':	 // 2 strings to match.
        if (Mnemonic[14] != 'm')
          break;
        switch (Mnemonic[15]) {
        default: break;
        case 'a':	 // 1 string to match.
          if (Mnemonic[16] != 'x')
            break;
          if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))	 // "image_atomic_fmax"
            Mnemonic = "image_atomic_max_flt";
          return;
        case 'i':	 // 1 string to match.
          if (Mnemonic[16] != 'n')
            break;
          if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))	 // "image_atomic_fmin"
            Mnemonic = "image_atomic_min_flt";
          return;
        }
        break;
      case 's':	 // 2 strings to match.
        if (Mnemonic[14] != 'm')
          break;
        switch (Mnemonic[15]) {
        default: break;
        case 'a':	 // 1 string to match.
          if (Mnemonic[16] != 'x')
            break;
          if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))	 // "image_atomic_smax"
            Mnemonic = "image_atomic_max_int";
          else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "image_atomic_max_int";
          else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "image_atomic_max_int";
          else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "image_atomic_max_int";
          else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "image_atomic_max_int";
          else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "image_atomic_max_int";
          return;
        case 'i':	 // 1 string to match.
          if (Mnemonic[16] != 'n')
            break;
          if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))	 // "image_atomic_smin"
            Mnemonic = "image_atomic_min_int";
          else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "image_atomic_min_int";
          else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "image_atomic_min_int";
          else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "image_atomic_min_int";
          else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "image_atomic_min_int";
          else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "image_atomic_min_int";
          return;
        }
        break;
      case 'u':	 // 2 strings to match.
        if (Mnemonic[14] != 'm')
          break;
        switch (Mnemonic[15]) {
        default: break;
        case 'a':	 // 1 string to match.
          if (Mnemonic[16] != 'x')
            break;
          if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))	 // "image_atomic_umax"
            Mnemonic = "image_atomic_max_uint";
          else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "image_atomic_max_uint";
          else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "image_atomic_max_uint";
          else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "image_atomic_max_uint";
          else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "image_atomic_max_uint";
          else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "image_atomic_max_uint";
          return;
        case 'i':	 // 1 string to match.
          if (Mnemonic[16] != 'n')
            break;
          if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))	 // "image_atomic_umin"
            Mnemonic = "image_atomic_min_uint";
          else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "image_atomic_min_uint";
          else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "image_atomic_min_uint";
          else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "image_atomic_min_uint";
          else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "image_atomic_min_uint";
          else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "image_atomic_min_uint";
          return;
        }
        break;
      }
      break;
    case 'v':	 // 105 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'a':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "shrrev_i16_t16", 14) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_ashrrev_i16_t16"
          Mnemonic = "v_ashrrev_i16";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_ashrrev_i16";
        return;
      case 'c':	 // 61 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'e':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "il_f16_fake16", 13) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_ceil_f16_fake16"
            Mnemonic = "v_ceil_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_ceil_f16";
          return;
        case 'n':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "dmask_b16_t16", 13) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cndmask_b16_t16"
            Mnemonic = "v_cndmask_b16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_cndmask_b16";
          return;
        case 'o':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "s_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'b':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "f16_fake16", 10) != 0)
              break;
            if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cos_bf16_fake16"
              Mnemonic = "v_cos_bf16";
            return;
          case 'f':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "16_t16_e", 8) != 0)
              break;
            switch (Mnemonic[15]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[16] != '2')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cos_f16_t16_e32"
                Mnemonic = "v_cos_f16_t16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[16] != '4')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cos_f16_t16_e64"
                Mnemonic = "v_cos_f16_t16";
              return;
            }
            break;
          }
          break;
        case 'v':	 // 56 strings to match.
          if (memcmp(Mnemonic.data()+4, "t_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'f':	 // 35 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 15 strings to match.
              if (memcmp(Mnemonic.data()+8, "6_", 2) != 0)
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'b':	 // 3 strings to match.
                if (memcmp(Mnemonic.data()+11, "f8_", 3) != 0)
                  break;
                switch (Mnemonic[14]) {
                default: break;
                case 'e':	 // 2 strings to match.
                  switch (Mnemonic[15]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (Mnemonic[16] != '2')
                      break;
                    if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_f16_bf8_e32"
                      Mnemonic = "v_cvt_f16_bf8";
                    return;
                  case '6':	 // 1 string to match.
                    if (Mnemonic[16] != '4')
                      break;
                    if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_f16_bf8_e64"
                      Mnemonic = "v_cvt_f16_bf8";
                    return;
                  }
                  break;
                case 't':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+15, "16", 2) != 0)
                    break;
                  if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_f16_bf8_t16"
                    Mnemonic = "v_cvt_f16_bf8";
                  return;
                }
                break;
              case 'f':	 // 6 strings to match.
                switch (Mnemonic[11]) {
                default: break;
                case '3':	 // 3 strings to match.
                  if (memcmp(Mnemonic.data()+12, "2_", 2) != 0)
                    break;
                  switch (Mnemonic[14]) {
                  default: break;
                  case 'e':	 // 2 strings to match.
                    switch (Mnemonic[15]) {
                    default: break;
                    case '3':	 // 1 string to match.
                      if (Mnemonic[16] != '2')
                        break;
                      if (Features.test(Feature_NotHasTrue16BitInstsBit))	 // "v_cvt_f16_f32_e32"
                        Mnemonic = "v_cvt_f16_f32";
                      return;
                    case '6':	 // 1 string to match.
                      if (Mnemonic[16] != '4')
                        break;
                      if (Features.test(Feature_NotHasTrue16BitInstsBit))	 // "v_cvt_f16_f32_e64"
                        Mnemonic = "v_cvt_f16_f32";
                      return;
                    }
                    break;
                  case 't':	 // 1 string to match.
                    if (memcmp(Mnemonic.data()+15, "16", 2) != 0)
                      break;
                    if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_f16_f32_t16"
                      Mnemonic = "v_cvt_f16_f32";
                    else if (Features.test(Feature_isGFX12OnlyBit))
                      Mnemonic = "v_cvt_f16_f32";
                    return;
                  }
                  break;
                case 'p':	 // 3 strings to match.
                  if (memcmp(Mnemonic.data()+12, "8_", 2) != 0)
                    break;
                  switch (Mnemonic[14]) {
                  default: break;
                  case 'e':	 // 2 strings to match.
                    switch (Mnemonic[15]) {
                    default: break;
                    case '3':	 // 1 string to match.
                      if (Mnemonic[16] != '2')
                        break;
                      if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_f16_fp8_e32"
                        Mnemonic = "v_cvt_f16_fp8";
                      return;
                    case '6':	 // 1 string to match.
                      if (Mnemonic[16] != '4')
                        break;
                      if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_f16_fp8_e64"
                        Mnemonic = "v_cvt_f16_fp8";
                      return;
                    }
                    break;
                  case 't':	 // 1 string to match.
                    if (memcmp(Mnemonic.data()+15, "16", 2) != 0)
                      break;
                    if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_f16_fp8_t16"
                      Mnemonic = "v_cvt_f16_fp8";
                    return;
                  }
                  break;
                }
                break;
              case 'i':	 // 3 strings to match.
                if (memcmp(Mnemonic.data()+11, "16_", 3) != 0)
                  break;
                switch (Mnemonic[14]) {
                default: break;
                case 'e':	 // 2 strings to match.
                  switch (Mnemonic[15]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (Mnemonic[16] != '2')
                      break;
                    if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_cvt_f16_i16_e32"
                      Mnemonic = "v_cvt_f16_i16";
                    return;
                  case '6':	 // 1 string to match.
                    if (Mnemonic[16] != '4')
                      break;
                    if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_cvt_f16_i16_e64"
                      Mnemonic = "v_cvt_f16_i16";
                    return;
                  }
                  break;
                case 't':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+15, "16", 2) != 0)
                    break;
                  if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_f16_i16_t16"
                    Mnemonic = "v_cvt_f16_i16";
                  else if (Features.test(Feature_isGFX12OnlyBit))
                    Mnemonic = "v_cvt_f16_i16";
                  return;
                }
                break;
              case 'u':	 // 3 strings to match.
                if (memcmp(Mnemonic.data()+11, "16_", 3) != 0)
                  break;
                switch (Mnemonic[14]) {
                default: break;
                case 'e':	 // 2 strings to match.
                  switch (Mnemonic[15]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (Mnemonic[16] != '2')
                      break;
                    if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_cvt_f16_u16_e32"
                      Mnemonic = "v_cvt_f16_u16";
                    return;
                  case '6':	 // 1 string to match.
                    if (Mnemonic[16] != '4')
                      break;
                    if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_cvt_f16_u16_e64"
                      Mnemonic = "v_cvt_f16_u16";
                    return;
                  }
                  break;
                case 't':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+15, "16", 2) != 0)
                    break;
                  if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_f16_u16_t16"
                    Mnemonic = "v_cvt_f16_u16";
                  else if (Features.test(Feature_isGFX12OnlyBit))
                    Mnemonic = "v_cvt_f16_u16";
                  return;
                }
                break;
              }
              break;
            case '3':	 // 13 strings to match.
              if (memcmp(Mnemonic.data()+8, "2_", 2) != 0)
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'b':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+11, "f8_e", 4) != 0)
                  break;
                switch (Mnemonic[15]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[16] != '2')
                    break;
                  if (Features.test(Feature_HasFP8ConversionInstsBit))	 // "v_cvt_f32_bf8_e32"
                    Mnemonic = "v_cvt_f32_bf8";
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[16] != '4')
                    break;
                  if (Features.test(Feature_HasFP8ConversionInstsBit))	 // "v_cvt_f32_bf8_e64"
                    Mnemonic = "v_cvt_f32_bf8";
                  return;
                }
                break;
              case 'f':	 // 7 strings to match.
                switch (Mnemonic[11]) {
                default: break;
                case '1':	 // 3 strings to match.
                  if (memcmp(Mnemonic.data()+12, "6_", 2) != 0)
                    break;
                  switch (Mnemonic[14]) {
                  default: break;
                  case 'e':	 // 2 strings to match.
                    switch (Mnemonic[15]) {
                    default: break;
                    case '3':	 // 1 string to match.
                      if (Mnemonic[16] != '2')
                        break;
                      if (Features.test(Feature_NotHasTrue16BitInstsBit))	 // "v_cvt_f32_f16_e32"
                        Mnemonic = "v_cvt_f32_f16";
                      return;
                    case '6':	 // 1 string to match.
                      if (Mnemonic[16] != '4')
                        break;
                      if (Features.test(Feature_NotHasTrue16BitInstsBit))	 // "v_cvt_f32_f16_e64"
                        Mnemonic = "v_cvt_f32_f16";
                      return;
                    }
                    break;
                  case 't':	 // 1 string to match.
                    if (memcmp(Mnemonic.data()+15, "16", 2) != 0)
                      break;
                    if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_f32_f16_t16"
                      Mnemonic = "v_cvt_f32_f16";
                    else if (Features.test(Feature_isGFX12OnlyBit))
                      Mnemonic = "v_cvt_f32_f16";
                    return;
                  }
                  break;
                case '6':	 // 2 strings to match.
                  if (memcmp(Mnemonic.data()+12, "4_e", 3) != 0)
                    break;
                  switch (Mnemonic[15]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (Mnemonic[16] != '2')
                      break;
                    Mnemonic = "v_cvt_f32_f64";	 // "v_cvt_f32_f64_e32"
                    return;
                  case '6':	 // 1 string to match.
                    if (Mnemonic[16] != '4')
                      break;
                    Mnemonic = "v_cvt_f32_f64";	 // "v_cvt_f32_f64_e64"
                    return;
                  }
                  break;
                case 'p':	 // 2 strings to match.
                  if (memcmp(Mnemonic.data()+12, "8_e", 3) != 0)
                    break;
                  switch (Mnemonic[15]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (Mnemonic[16] != '2')
                      break;
                    if (Features.test(Feature_HasFP8ConversionInstsBit))	 // "v_cvt_f32_fp8_e32"
                      Mnemonic = "v_cvt_f32_fp8";
                    return;
                  case '6':	 // 1 string to match.
                    if (Mnemonic[16] != '4')
                      break;
                    if (Features.test(Feature_HasFP8ConversionInstsBit))	 // "v_cvt_f32_fp8_e64"
                      Mnemonic = "v_cvt_f32_fp8";
                    return;
                  }
                  break;
                }
                break;
              case 'i':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+11, "32_e", 4) != 0)
                  break;
                switch (Mnemonic[15]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[16] != '2')
                    break;
                  Mnemonic = "v_cvt_f32_i32";	 // "v_cvt_f32_i32_e32"
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[16] != '4')
                    break;
                  Mnemonic = "v_cvt_f32_i32";	 // "v_cvt_f32_i32_e64"
                  return;
                }
                break;
              case 'u':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+11, "32_e", 4) != 0)
                  break;
                switch (Mnemonic[15]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[16] != '2')
                    break;
                  Mnemonic = "v_cvt_f32_u32";	 // "v_cvt_f32_u32_e32"
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[16] != '4')
                    break;
                  Mnemonic = "v_cvt_f32_u32";	 // "v_cvt_f32_u32_e64"
                  return;
                }
                break;
              }
              break;
            case '6':	 // 6 strings to match.
              if (memcmp(Mnemonic.data()+8, "4_", 2) != 0)
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+11, "32_e", 4) != 0)
                  break;
                switch (Mnemonic[15]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[16] != '2')
                    break;
                  Mnemonic = "v_cvt_f64_f32";	 // "v_cvt_f64_f32_e32"
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[16] != '4')
                    break;
                  Mnemonic = "v_cvt_f64_f32";	 // "v_cvt_f64_f32_e64"
                  return;
                }
                break;
              case 'i':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+11, "32_e", 4) != 0)
                  break;
                switch (Mnemonic[15]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[16] != '2')
                    break;
                  Mnemonic = "v_cvt_f64_i32";	 // "v_cvt_f64_i32_e32"
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[16] != '4')
                    break;
                  Mnemonic = "v_cvt_f64_i32";	 // "v_cvt_f64_i32_e64"
                  return;
                }
                break;
              case 'u':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+11, "32_e", 4) != 0)
                  break;
                switch (Mnemonic[15]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[16] != '2')
                    break;
                  Mnemonic = "v_cvt_f64_u32";	 // "v_cvt_f64_u32_e32"
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[16] != '4')
                    break;
                  Mnemonic = "v_cvt_f64_u32";	 // "v_cvt_f64_u32_e64"
                  return;
                }
                break;
              }
              break;
            case 'l':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "r_i32_f32", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_flr_i32_f32"
                Mnemonic = "v_cvt_floor_i32_f32";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cvt_floor_i32_f32";
              return;
            }
            break;
          case 'i':	 // 10 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 3 strings to match.
              if (memcmp(Mnemonic.data()+8, "6_f16_", 6) != 0)
                break;
              switch (Mnemonic[14]) {
              default: break;
              case 'e':	 // 2 strings to match.
                switch (Mnemonic[15]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[16] != '2')
                    break;
                  if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_cvt_i16_f16_e32"
                    Mnemonic = "v_cvt_i16_f16";
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[16] != '4')
                    break;
                  if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_cvt_i16_f16_e64"
                    Mnemonic = "v_cvt_i16_f16";
                  return;
                }
                break;
              case 't':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+15, "16", 2) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_i16_f16_t16"
                  Mnemonic = "v_cvt_i16_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cvt_i16_f16";
                return;
              }
              break;
            case '3':	 // 7 strings to match.
              if (memcmp(Mnemonic.data()+8, "2_", 2) != 0)
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 4 strings to match.
                switch (Mnemonic[11]) {
                default: break;
                case '3':	 // 2 strings to match.
                  if (memcmp(Mnemonic.data()+12, "2_e", 3) != 0)
                    break;
                  switch (Mnemonic[15]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (Mnemonic[16] != '2')
                      break;
                    Mnemonic = "v_cvt_i32_f32";	 // "v_cvt_i32_f32_e32"
                    return;
                  case '6':	 // 1 string to match.
                    if (Mnemonic[16] != '4')
                      break;
                    Mnemonic = "v_cvt_i32_f32";	 // "v_cvt_i32_f32_e64"
                    return;
                  }
                  break;
                case '6':	 // 2 strings to match.
                  if (memcmp(Mnemonic.data()+12, "4_e", 3) != 0)
                    break;
                  switch (Mnemonic[15]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (Mnemonic[16] != '2')
                      break;
                    Mnemonic = "v_cvt_i32_f64";	 // "v_cvt_i32_f64_e32"
                    return;
                  case '6':	 // 1 string to match.
                    if (Mnemonic[16] != '4')
                      break;
                    Mnemonic = "v_cvt_i32_f64";	 // "v_cvt_i32_f64_e64"
                    return;
                  }
                  break;
                }
                break;
              case 'i':	 // 3 strings to match.
                if (memcmp(Mnemonic.data()+11, "16_", 3) != 0)
                  break;
                switch (Mnemonic[14]) {
                default: break;
                case 'e':	 // 2 strings to match.
                  switch (Mnemonic[15]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (Mnemonic[16] != '2')
                      break;
                    if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_i32_i16_e32"
                      Mnemonic = "v_cvt_i32_i16";
                    return;
                  case '6':	 // 1 string to match.
                    if (Mnemonic[16] != '4')
                      break;
                    if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_i32_i16_e64"
                      Mnemonic = "v_cvt_i32_i16";
                    return;
                  }
                  break;
                case 't':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+15, "16", 2) != 0)
                    break;
                  if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_i32_i16_t16"
                    Mnemonic = "v_cvt_i32_i16";
                  else if (Features.test(Feature_isGFX12OnlyBit))
                    Mnemonic = "v_cvt_i32_i16";
                  return;
                }
                break;
              }
              break;
            }
            break;
          case 'r':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "pi_i32_f32", 10) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_rpi_i32_f32"
              Mnemonic = "v_cvt_nearest_i32_f32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cvt_nearest_i32_f32";
            return;
          case 'u':	 // 10 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 3 strings to match.
              if (memcmp(Mnemonic.data()+8, "6_f16_", 6) != 0)
                break;
              switch (Mnemonic[14]) {
              default: break;
              case 'e':	 // 2 strings to match.
                switch (Mnemonic[15]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[16] != '2')
                    break;
                  if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_cvt_u16_f16_e32"
                    Mnemonic = "v_cvt_u16_f16";
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[16] != '4')
                    break;
                  if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_cvt_u16_f16_e64"
                    Mnemonic = "v_cvt_u16_f16";
                  return;
                }
                break;
              case 't':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+15, "16", 2) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_u16_f16_t16"
                  Mnemonic = "v_cvt_u16_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cvt_u16_f16";
                return;
              }
              break;
            case '3':	 // 7 strings to match.
              if (memcmp(Mnemonic.data()+8, "2_", 2) != 0)
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 4 strings to match.
                switch (Mnemonic[11]) {
                default: break;
                case '3':	 // 2 strings to match.
                  if (memcmp(Mnemonic.data()+12, "2_e", 3) != 0)
                    break;
                  switch (Mnemonic[15]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (Mnemonic[16] != '2')
                      break;
                    Mnemonic = "v_cvt_u32_f32";	 // "v_cvt_u32_f32_e32"
                    return;
                  case '6':	 // 1 string to match.
                    if (Mnemonic[16] != '4')
                      break;
                    Mnemonic = "v_cvt_u32_f32";	 // "v_cvt_u32_f32_e64"
                    return;
                  }
                  break;
                case '6':	 // 2 strings to match.
                  if (memcmp(Mnemonic.data()+12, "4_e", 3) != 0)
                    break;
                  switch (Mnemonic[15]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (Mnemonic[16] != '2')
                      break;
                    Mnemonic = "v_cvt_u32_f64";	 // "v_cvt_u32_f64_e32"
                    return;
                  case '6':	 // 1 string to match.
                    if (Mnemonic[16] != '4')
                      break;
                    Mnemonic = "v_cvt_u32_f64";	 // "v_cvt_u32_f64_e64"
                    return;
                  }
                  break;
                }
                break;
              case 'u':	 // 3 strings to match.
                if (memcmp(Mnemonic.data()+11, "16_", 3) != 0)
                  break;
                switch (Mnemonic[14]) {
                default: break;
                case 'e':	 // 2 strings to match.
                  switch (Mnemonic[15]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (Mnemonic[16] != '2')
                      break;
                    if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_u32_u16_e32"
                      Mnemonic = "v_cvt_u32_u16";
                    return;
                  case '6':	 // 1 string to match.
                    if (Mnemonic[16] != '4')
                      break;
                    if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_u32_u16_e64"
                      Mnemonic = "v_cvt_u32_u16";
                    return;
                  }
                  break;
                case 't':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+15, "16", 2) != 0)
                    break;
                  if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_u32_u16_t16"
                    Mnemonic = "v_cvt_u32_u16";
                  else if (Features.test(Feature_isGFX12OnlyBit))
                    Mnemonic = "v_cvt_u32_u16";
                  return;
                }
                break;
              }
              break;
            }
            break;
          }
          break;
        }
        break;
      case 'e':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+3, "xp_", 3) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case 'b':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "f16_fake16", 10) != 0)
            break;
          if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_exp_bf16_fake16"
            Mnemonic = "v_exp_bf16";
          return;
        case 'f':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+7, "16_t16_e", 8) != 0)
            break;
          switch (Mnemonic[15]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[16] != '2')
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_exp_f16_t16_e32"
              Mnemonic = "v_exp_f16_t16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[16] != '4')
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_exp_f16_t16_e64"
              Mnemonic = "v_exp_f16_t16";
            return;
          }
          break;
        }
        break;
      case 'f':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+3, "ma", 2) != 0)
          break;
        switch (Mnemonic[5]) {
        default: break;
        case '_':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+6, "mix_f32_f16", 11) != 0)
            break;
          if (Features.test(Feature_isGFX1250PlusBit))	 // "v_fma_mix_f32_f16"
            Mnemonic = "v_fma_mix_f32";
          return;
        case 'c':	 // 2 strings to match.
          if (Mnemonic[6] != '_')
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "16_fake16", 9) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_fmac_f16_fake16"
              Mnemonic = "v_fmac_f16";
            else if (Features.test(Feature_isGFX11OnlyBit))
              Mnemonic = "v_fmac_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_fmac_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_fmac_f16";
            return;
          case 'l':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "egacy_f32", 9) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_fmac_legacy_f32"
              Mnemonic = "v_fmac_dx9_zero_f32";
            return;
          }
          break;
        }
        break;
      case 'l':	 // 5 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'o':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "g_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'b':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "f16_fake16", 10) != 0)
              break;
            if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_log_bf16_fake16"
              Mnemonic = "v_log_bf16";
            return;
          case 'f':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "16_t16_e", 8) != 0)
              break;
            switch (Mnemonic[15]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[16] != '2')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_log_f16_t16_e32"
                Mnemonic = "v_log_f16_t16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[16] != '4')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_log_f16_t16_e64"
                Mnemonic = "v_log_f16_t16";
              return;
            }
            break;
          }
          break;
        case 's':	 // 2 strings to match.
          if (Mnemonic[4] != 'h')
            break;
          switch (Mnemonic[5]) {
          default: break;
          case 'l':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+6, "rev_b16_t16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_lshlrev_b16_t16"
              Mnemonic = "v_lshlrev_b16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_lshlrev_b16";
            return;
          case 'r':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+6, "rev_b16_t16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_lshrrev_b16_t16"
              Mnemonic = "v_lshrrev_b16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_lshrrev_b16";
            return;
          }
          break;
        }
        break;
      case 'm':	 // 19 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 6 strings to match.
          switch (Mnemonic[4]) {
          default: break;
          case 'd':	 // 2 strings to match.
            if (Mnemonic[5] != '_')
              break;
            switch (Mnemonic[6]) {
            default: break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "32_i16_t16", 10) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_mad_i32_i16_t16"
                Mnemonic = "v_mad_i32_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_mad_i32_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "32_u16_t16", 10) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_mad_u32_u16_t16"
                Mnemonic = "v_mad_u32_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_mad_u32_u16";
              return;
            }
            break;
          case 'x':	 // 4 strings to match.
            switch (Mnemonic[5]) {
            default: break;
            case '3':	 // 3 strings to match.
              if (Mnemonic[6] != '_')
                break;
              switch (Mnemonic[7]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+8, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_max3_f16_fake16"
                  Mnemonic = "v_max3_f16";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+8, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_max3_i16_fake16"
                  Mnemonic = "v_max3_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_max3_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+8, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_max3_u16_fake16"
                  Mnemonic = "v_max3_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_max3_u16";
                return;
              }
              break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+6, "mum_f16_t16", 11) != 0)
                break;
              if (Features.test(Feature_isGFX12OnlyBit))	 // "v_maximum_f16_t16"
                Mnemonic = "v_maximum_f16";
              return;
            }
            break;
          }
          break;
        case 'e':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "d3_", 3) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "16_fake16", 9) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_med3_f16_fake16"
              Mnemonic = "v_med3_f16";
            return;
          case 'i':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "16_fake16", 9) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_med3_i16_fake16"
              Mnemonic = "v_med3_i16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_med3_i16";
            return;
          case 'u':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "16_fake16", 9) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_med3_u16_fake16"
              Mnemonic = "v_med3_u16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_med3_u16";
            return;
          }
          break;
        case 'i':	 // 4 strings to match.
          if (Mnemonic[4] != 'n')
            break;
          switch (Mnemonic[5]) {
          default: break;
          case '3':	 // 3 strings to match.
            if (Mnemonic[6] != '_')
              break;
            switch (Mnemonic[7]) {
            default: break;
            case 'f':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_min3_f16_fake16"
                Mnemonic = "v_min3_f16";
              return;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_min3_i16_fake16"
                Mnemonic = "v_min3_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_min3_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "16_fake16", 9) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_min3_u16_fake16"
                Mnemonic = "v_min3_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_min3_u16";
              return;
            }
            break;
          case 'i':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+6, "mum_f16_t16", 11) != 0)
              break;
            if (Features.test(Feature_isGFX12OnlyBit))	 // "v_minimum_f16_t16"
              Mnemonic = "v_minimum_f16";
            return;
          }
          break;
        case 'o':	 // 6 strings to match.
          if (Mnemonic[4] != 'v')
            break;
          switch (Mnemonic[5]) {
          default: break;
          case '_':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+6, "b16_t16_e", 9) != 0)
              break;
            switch (Mnemonic[15]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[16] != '2')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_mov_b16_t16_e32"
                Mnemonic = "v_mov_b16_t16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[16] != '4')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_mov_b16_t16_e64"
                Mnemonic = "v_mov_b16_t16";
              return;
            }
            break;
          case 'r':	 // 4 strings to match.
            if (memcmp(Mnemonic.data()+6, "el", 2) != 0)
              break;
            switch (Mnemonic[8]) {
            default: break;
            case 'd':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+9, "_b32_e", 6) != 0)
                break;
              switch (Mnemonic[15]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[16] != '2')
                  break;
                if (Features.test(Feature_HasMovrelBit))	 // "v_movreld_b32_e32"
                  Mnemonic = "v_movreld_b32";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[16] != '4')
                  break;
                if (Features.test(Feature_HasMovrelBit))	 // "v_movreld_b32_e64"
                  Mnemonic = "v_movreld_b32";
                return;
              }
              break;
            case 's':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+9, "_b32_e", 6) != 0)
                break;
              switch (Mnemonic[15]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[16] != '2')
                  break;
                if (Features.test(Feature_HasMovrelBit))	 // "v_movrels_b32_e32"
                  Mnemonic = "v_movrels_b32";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[16] != '4')
                  break;
                if (Features.test(Feature_HasMovrelBit))	 // "v_movrels_b32_e64"
                  Mnemonic = "v_movrels_b32";
                return;
              }
              break;
            }
            break;
          }
          break;
        }
        break;
      case 'n':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+3, "ot_b16_t16_e", 12) != 0)
          break;
        switch (Mnemonic[15]) {
        default: break;
        case '3':	 // 1 string to match.
          if (Mnemonic[16] != '2')
            break;
          if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_not_b16_t16_e32"
            Mnemonic = "v_not_b16_t16";
          return;
        case '6':	 // 1 string to match.
          if (Mnemonic[16] != '4')
            break;
          if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_not_b16_t16_e64"
            Mnemonic = "v_not_b16_t16";
          return;
        }
        break;
      case 'r':	 // 6 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'c':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "p_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'b':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "f16_fake16", 10) != 0)
              break;
            if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_rcp_bf16_fake16"
              Mnemonic = "v_rcp_bf16";
            return;
          case 'f':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "16_t16_e", 8) != 0)
              break;
            switch (Mnemonic[15]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[16] != '2')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_rcp_f16_t16_e32"
                Mnemonic = "v_rcp_f16_t16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[16] != '4')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_rcp_f16_t16_e64"
                Mnemonic = "v_rcp_f16_t16";
              return;
            }
            break;
          }
          break;
        case 's':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "q_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'b':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "f16_fake16", 10) != 0)
              break;
            if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_rsq_bf16_fake16"
              Mnemonic = "v_rsq_bf16";
            return;
          case 'f':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "16_t16_e", 8) != 0)
              break;
            switch (Mnemonic[15]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[16] != '2')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_rsq_f16_t16_e32"
                Mnemonic = "v_rsq_f16_t16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[16] != '4')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_rsq_f16_t16_e64"
                Mnemonic = "v_rsq_f16_t16";
              return;
            }
            break;
          }
          break;
        }
        break;
      case 's':	 // 4 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'i':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "n_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'b':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "f16_fake16", 10) != 0)
              break;
            if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_sin_bf16_fake16"
              Mnemonic = "v_sin_bf16";
            return;
          case 'f':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "16_t16_e", 8) != 0)
              break;
            switch (Mnemonic[15]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[16] != '2')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_sin_f16_t16_e32"
                Mnemonic = "v_sin_f16_t16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[16] != '4')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_sin_f16_t16_e64"
                Mnemonic = "v_sin_f16_t16";
              return;
            }
            break;
          }
          break;
        case 'q':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "rt_f16_fake16", 13) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_sqrt_f16_fake16"
            Mnemonic = "v_sqrt_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_sqrt_f16";
          return;
        }
        break;
      case 't':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "anh_f16_fake16", 14) != 0)
          break;
        if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_tanh_f16_fake16"
          Mnemonic = "v_tanh_f16";
        return;
      }
      break;
    }
    break;
  case 18:	 // 108 strings to match.
    switch (Mnemonic[0]) {
    default: break;
    case 'b':	 // 13 strings to match.
      switch (Mnemonic[1]) {
      default: break;
      case 'u':	 // 12 strings to match.
        if (memcmp(Mnemonic.data()+2, "ffer_", 5) != 0)
          break;
        switch (Mnemonic[7]) {
        default: break;
        case 'a':	 // 8 strings to match.
          if (memcmp(Mnemonic.data()+8, "tomic_", 6) != 0)
            break;
          switch (Mnemonic[14]) {
          default: break;
          case 'c':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+15, "sub", 3) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_csub"
              Mnemonic = "buffer_atomic_csub_u32";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "buffer_atomic_sub_clamp_u32";
            return;
          case 'f':	 // 2 strings to match.
            if (Mnemonic[15] != 'm')
              break;
            switch (Mnemonic[16]) {
            default: break;
            case 'a':	 // 1 string to match.
              if (Mnemonic[17] != 'x')
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_fmax"
                Mnemonic = "buffer_atomic_max_f32";
              else if (Features.test(Feature_isGFX12PlusBit))
                Mnemonic = "buffer_atomic_max_num_f32";
              return;
            case 'i':	 // 1 string to match.
              if (Mnemonic[17] != 'n')
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_fmin"
                Mnemonic = "buffer_atomic_min_f32";
              else if (Features.test(Feature_isGFX12PlusBit))
                Mnemonic = "buffer_atomic_min_num_f32";
              return;
            }
            break;
          case 's':	 // 3 strings to match.
            switch (Mnemonic[15]) {
            default: break;
            case 'm':	 // 2 strings to match.
              switch (Mnemonic[16]) {
              default: break;
              case 'a':	 // 1 string to match.
                if (Mnemonic[17] != 'x')
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_smax"
                  Mnemonic = "buffer_atomic_max_i32";
                else if (Features.test(Feature_isGFX12PlusBit))
                  Mnemonic = "buffer_atomic_max_i32";
                return;
              case 'i':	 // 1 string to match.
                if (Mnemonic[17] != 'n')
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_smin"
                  Mnemonic = "buffer_atomic_min_i32";
                else if (Features.test(Feature_isGFX12PlusBit))
                  Mnemonic = "buffer_atomic_min_i32";
                return;
              }
              break;
            case 'w':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+16, "ap", 2) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_swap"
                Mnemonic = "buffer_atomic_swap_b32";
              else if (Features.test(Feature_isGFX12PlusBit))
                Mnemonic = "buffer_atomic_swap_b32";
              return;
            }
            break;
          case 'u':	 // 2 strings to match.
            if (Mnemonic[15] != 'm')
              break;
            switch (Mnemonic[16]) {
            default: break;
            case 'a':	 // 1 string to match.
              if (Mnemonic[17] != 'x')
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_umax"
                Mnemonic = "buffer_atomic_max_u32";
              else if (Features.test(Feature_isGFX12PlusBit))
                Mnemonic = "buffer_atomic_max_u32";
              return;
            case 'i':	 // 1 string to match.
              if (Mnemonic[17] != 'n')
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_umin"
                Mnemonic = "buffer_atomic_min_u32";
              else if (Features.test(Feature_isGFX12PlusBit))
                Mnemonic = "buffer_atomic_min_u32";
              return;
            }
            break;
          }
          break;
        case 'l':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+8, "oad_", 4) != 0)
            break;
          switch (Mnemonic[12]) {
          default: break;
          case 's':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+13, "short", 5) != 0)
              break;
            if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_load_sshort"
              Mnemonic = "buffer_load_i16";
            return;
          case 'u':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+13, "short", 5) != 0)
              break;
            if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_load_ushort"
              Mnemonic = "buffer_load_u16";
            return;
          }
          break;
        case 's':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+8, "tore_", 5) != 0)
            break;
          switch (Mnemonic[13]) {
          default: break;
          case 'd':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "word", 4) != 0)
              break;
            if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_store_dword"
              Mnemonic = "buffer_store_b32";
            return;
          case 's':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "hort", 4) != 0)
              break;
            if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_store_short"
              Mnemonic = "buffer_store_b16";
            return;
          }
          break;
        }
        break;
      case 'v':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+2, "h8_intersect_ray", 16) != 0)
          break;
        if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))	 // "bvh8_intersect_ray"
          Mnemonic = "image_bvh8_intersect_ray";
        return;
      }
      break;
    case 'd':	 // 5 strings to match.
      if (memcmp(Mnemonic.data()+1, "s_", 2) != 0)
        break;
      switch (Mnemonic[3]) {
      default: break;
      case 'r':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+4, "ead_", 4) != 0)
          break;
        switch (Mnemonic[8]) {
        default: break;
        case 'a':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+9, "ddtid_b32", 9) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_read_addtid_b32"
            Mnemonic = "ds_load_addtid_b32";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "ds_load_addtid_b32";
          return;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+9, "16_d16_hi", 9) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_read_u16_d16_hi"
            Mnemonic = "ds_load_u16_d16_hi";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "ds_load_u16_d16_hi";
          return;
        }
        break;
      case 'w':	 // 3 strings to match.
        if (Mnemonic[4] != 'r')
          break;
        switch (Mnemonic[5]) {
        default: break;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+6, "te_b8_d16_hi", 12) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_write_b8_d16_hi"
            Mnemonic = "ds_store_b8_d16_hi";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "ds_store_b8_d16_hi";
          return;
        case 'x':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+6, "chg2_rtn_b", 10) != 0)
            break;
          switch (Mnemonic[16]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[17] != '2')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_wrxchg2_rtn_b32"
              Mnemonic = "ds_storexchg_2addr_rtn_b32";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "ds_storexchg_2addr_rtn_b32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[17] != '4')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_wrxchg2_rtn_b64"
              Mnemonic = "ds_storexchg_2addr_rtn_b64";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "ds_storexchg_2addr_rtn_b64";
            return;
          }
          break;
        }
        break;
      }
      break;
    case 'f':	 // 9 strings to match.
      if (memcmp(Mnemonic.data()+1, "lat_", 4) != 0)
        break;
      switch (Mnemonic[5]) {
      default: break;
      case 'a':	 // 6 strings to match.
        if (memcmp(Mnemonic.data()+6, "tomic_", 6) != 0)
          break;
        switch (Mnemonic[12]) {
        default: break;
        case 'a':	 // 2 strings to match.
          switch (Mnemonic[13]) {
          default: break;
          case 'd':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "d_x2", 4) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_add_x2"
              Mnemonic = "flat_atomic_add_u64";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "flat_atomic_add_u64";
            return;
          case 'n':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "d_x2", 4) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_and_x2"
              Mnemonic = "flat_atomic_and_b64";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "flat_atomic_and_b64";
            return;
          }
          break;
        case 'd':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "ec_x2", 5) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_dec_x2"
            Mnemonic = "flat_atomic_dec_u64";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_atomic_dec_u64";
          return;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "nc_x2", 5) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_inc_x2"
            Mnemonic = "flat_atomic_inc_u64";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_atomic_inc_u64";
          return;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "ub_x2", 5) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_sub_x2"
            Mnemonic = "flat_atomic_sub_u64";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_atomic_sub_u64";
          return;
        case 'x':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "or_x2", 5) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_xor_x2"
            Mnemonic = "flat_atomic_xor_b64";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_atomic_xor_b64";
          return;
        }
        break;
      case 's':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+6, "tore_dwordx", 11) != 0)
          break;
        switch (Mnemonic[17]) {
        default: break;
        case '2':	 // 1 string to match.
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_store_dwordx2"
            Mnemonic = "flat_store_b64";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_store_b64";
          return;
        case '3':	 // 1 string to match.
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_store_dwordx3"
            Mnemonic = "flat_store_b96";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_store_b96";
          return;
        case '4':	 // 1 string to match.
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_store_dwordx4"
            Mnemonic = "flat_store_b128";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_store_b128";
          return;
        }
        break;
      }
      break;
    case 'g':	 // 13 strings to match.
      if (memcmp(Mnemonic.data()+1, "lobal_", 6) != 0)
        break;
      switch (Mnemonic[7]) {
      default: break;
      case 'a':	 // 8 strings to match.
        if (memcmp(Mnemonic.data()+8, "tomic_", 6) != 0)
          break;
        switch (Mnemonic[14]) {
        default: break;
        case 'c':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+15, "sub", 3) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_csub"
            Mnemonic = "global_atomic_csub_u32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_atomic_sub_clamp_u32";
          return;
        case 'f':	 // 2 strings to match.
          if (Mnemonic[15] != 'm')
            break;
          switch (Mnemonic[16]) {
          default: break;
          case 'a':	 // 1 string to match.
            if (Mnemonic[17] != 'x')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_fmax"
              Mnemonic = "global_atomic_max_f32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "global_atomic_max_num_f32";
            return;
          case 'i':	 // 1 string to match.
            if (Mnemonic[17] != 'n')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_fmin"
              Mnemonic = "global_atomic_min_f32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "global_atomic_min_num_f32";
            return;
          }
          break;
        case 's':	 // 3 strings to match.
          switch (Mnemonic[15]) {
          default: break;
          case 'm':	 // 2 strings to match.
            switch (Mnemonic[16]) {
            default: break;
            case 'a':	 // 1 string to match.
              if (Mnemonic[17] != 'x')
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_smax"
                Mnemonic = "global_atomic_max_i32";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "global_atomic_max_i32";
              return;
            case 'i':	 // 1 string to match.
              if (Mnemonic[17] != 'n')
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_smin"
                Mnemonic = "global_atomic_min_i32";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "global_atomic_min_i32";
              return;
            }
            break;
          case 'w':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+16, "ap", 2) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_swap"
              Mnemonic = "global_atomic_swap_b32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "global_atomic_swap_b32";
            return;
          }
          break;
        case 'u':	 // 2 strings to match.
          if (Mnemonic[15] != 'm')
            break;
          switch (Mnemonic[16]) {
          default: break;
          case 'a':	 // 1 string to match.
            if (Mnemonic[17] != 'x')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_umax"
              Mnemonic = "global_atomic_max_u32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "global_atomic_max_u32";
            return;
          case 'i':	 // 1 string to match.
            if (Mnemonic[17] != 'n')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_umin"
              Mnemonic = "global_atomic_min_u32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "global_atomic_min_u32";
            return;
          }
          break;
        }
        break;
      case 'l':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+8, "oad_", 4) != 0)
          break;
        switch (Mnemonic[12]) {
        default: break;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "short", 5) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_load_sshort"
            Mnemonic = "global_load_i16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_load_i16";
          return;
        case 't':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "r_b64", 5) != 0)
            break;
          if (Features.test(Feature_isGFX125xOnlyBit))	 // "global_load_tr_b64"
            Mnemonic = "global_load_tr8_b64";
          return;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "short", 5) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_load_ushort"
            Mnemonic = "global_load_u16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_load_u16";
          return;
        }
        break;
      case 's':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+8, "tore_", 5) != 0)
          break;
        switch (Mnemonic[13]) {
        default: break;
        case 'd':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+14, "word", 4) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_store_dword"
            Mnemonic = "global_store_b32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_store_b32";
          return;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+14, "hort", 4) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_store_short"
            Mnemonic = "global_store_b16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_store_b16";
          return;
        }
        break;
      }
      break;
    case 's':	 // 8 strings to match.
      switch (Mnemonic[1]) {
      default: break;
      case '_':	 // 4 strings to match.
        if (memcmp(Mnemonic.data()+2, "andn", 4) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case '1':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+7, "_wrexec_b", 9) != 0)
            break;
          switch (Mnemonic[16]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[17] != '2')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "s_andn1_wrexec_b32"
              Mnemonic = "s_and_not0_wrexec_b32";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "s_and_not0_wrexec_b32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[17] != '4')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "s_andn1_wrexec_b64"
              Mnemonic = "s_and_not0_wrexec_b64";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "s_and_not0_wrexec_b64";
            return;
          }
          break;
        case '2':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+7, "_wrexec_b", 9) != 0)
            break;
          switch (Mnemonic[16]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[17] != '2')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "s_andn2_wrexec_b32"
              Mnemonic = "s_and_not1_wrexec_b32";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "s_and_not1_wrexec_b32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[17] != '4')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "s_andn2_wrexec_b64"
              Mnemonic = "s_and_not1_wrexec_b64";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "s_and_not1_wrexec_b64";
            return;
          }
          break;
        }
        break;
      case 'c':	 // 4 strings to match.
        if (memcmp(Mnemonic.data()+2, "ratch_", 6) != 0)
          break;
        switch (Mnemonic[8]) {
        default: break;
        case 'l':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+9, "oad_", 4) != 0)
            break;
          switch (Mnemonic[13]) {
          default: break;
          case 'd':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "word", 4) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "scratch_load_dword"
              Mnemonic = "scratch_load_b32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "scratch_load_b32";
            return;
          case 's':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "byte", 4) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "scratch_load_sbyte"
              Mnemonic = "scratch_load_i8";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "scratch_load_i8";
            return;
          case 'u':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "byte", 4) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "scratch_load_ubyte"
              Mnemonic = "scratch_load_u8";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "scratch_load_u8";
            return;
          }
          break;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+9, "tore_byte", 9) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "scratch_store_byte"
            Mnemonic = "scratch_store_b8";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "scratch_store_b8";
          return;
        }
        break;
      }
      break;
    case 'v':	 // 60 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'a':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "lignbit_b32_t16", 15) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_alignbit_b32_t16"
          Mnemonic = "v_alignbit_b32";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_alignbit_b32";
        return;
      case 'c':	 // 21 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'e':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "il_f16_t16_e", 12) != 0)
            break;
          switch (Mnemonic[16]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[17] != '2')
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_ceil_f16_t16_e32"
              Mnemonic = "v_ceil_f16_t16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[17] != '4')
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_ceil_f16_t16_e64"
              Mnemonic = "v_ceil_f16_t16";
            return;
          }
          break;
        case 'o':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "s_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'b':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "f16_t16_e", 9) != 0)
              break;
            switch (Mnemonic[16]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[17] != '2')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_cos_bf16_t16_e32"
                Mnemonic = "v_cos_bf16_t16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[17] != '4')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_cos_bf16_t16_e64"
                Mnemonic = "v_cos_bf16_t16";
              return;
            }
            break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "16_t16_sdwa", 11) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cos_f16_t16_sdwa"
              Mnemonic = "v_cos_f16_t16";
            return;
          }
          break;
        case 'v':	 // 16 strings to match.
          if (memcmp(Mnemonic.data()+4, "t_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'f':	 // 10 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 3 strings to match.
              if (memcmp(Mnemonic.data()+8, "6_", 2) != 0)
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "32_sdwa", 7) != 0)
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit))	 // "v_cvt_f16_f32_sdwa"
                  Mnemonic = "v_cvt_f16_f32";
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_sdwa", 7) != 0)
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_cvt_f16_i16_sdwa"
                  Mnemonic = "v_cvt_f16_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_sdwa", 7) != 0)
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_cvt_f16_u16_sdwa"
                  Mnemonic = "v_cvt_f16_u16";
                return;
              }
              break;
            case '3':	 // 7 strings to match.
              if (memcmp(Mnemonic.data()+8, "2_", 2) != 0)
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'b':	 // 3 strings to match.
                if (Mnemonic[11] != 'f')
                  break;
                switch (Mnemonic[12]) {
                default: break;
                case '1':	 // 2 strings to match.
                  if (memcmp(Mnemonic.data()+13, "6_e", 3) != 0)
                    break;
                  switch (Mnemonic[16]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (Mnemonic[17] != '2')
                      break;
                    if (Features.test(Feature_HasBF16ConversionInstsBit) && Features.test(Feature_HasGFX950InstsBit))	 // "v_cvt_f32_bf16_e32"
                      Mnemonic = "v_cvt_f32_bf16";
                    return;
                  case '6':	 // 1 string to match.
                    if (Mnemonic[17] != '4')
                      break;
                    if (Features.test(Feature_HasBF16ConversionInstsBit) && Features.test(Feature_HasGFX950InstsBit))	 // "v_cvt_f32_bf16_e64"
                      Mnemonic = "v_cvt_f32_bf16";
                    return;
                  }
                  break;
                case '8':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+13, "_sdwa", 5) != 0)
                    break;
                  if (Features.test(Feature_HasFP8ConversionInstsBit))	 // "v_cvt_f32_bf8_sdwa"
                    Mnemonic = "v_cvt_f32_bf8";
                  return;
                }
                break;
              case 'f':	 // 2 strings to match.
                switch (Mnemonic[11]) {
                default: break;
                case '1':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+12, "6_sdwa", 6) != 0)
                    break;
                  if (Features.test(Feature_NotHasTrue16BitInstsBit))	 // "v_cvt_f32_f16_sdwa"
                    Mnemonic = "v_cvt_f32_f16";
                  return;
                case 'p':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+12, "8_sdwa", 6) != 0)
                    break;
                  if (Features.test(Feature_HasFP8ConversionInstsBit))	 // "v_cvt_f32_fp8_sdwa"
                    Mnemonic = "v_cvt_f32_fp8";
                  return;
                }
                break;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "32_sdwa", 7) != 0)
                  break;
                Mnemonic = "v_cvt_f32_i32";	 // "v_cvt_f32_i32_sdwa"
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "32_sdwa", 7) != 0)
                  break;
                Mnemonic = "v_cvt_f32_u32";	 // "v_cvt_f32_u32_sdwa"
                return;
              }
              break;
            }
            break;
          case 'i':	 // 3 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "6_f16_sdwa", 10) != 0)
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_cvt_i16_f16_sdwa"
                Mnemonic = "v_cvt_i16_f16";
              return;
            case '3':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+8, "2_", 2) != 0)
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "32_sdwa", 7) != 0)
                  break;
                Mnemonic = "v_cvt_i32_f32";	 // "v_cvt_i32_f32_sdwa"
                return;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_sdwa", 7) != 0)
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_i32_i16_sdwa"
                  Mnemonic = "v_cvt_i32_i16";
                return;
              }
              break;
            }
            break;
          case 'u':	 // 3 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "6_f16_sdwa", 10) != 0)
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_cvt_u16_f16_sdwa"
                Mnemonic = "v_cvt_u16_f16";
              return;
            case '3':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+8, "2_", 2) != 0)
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "32_sdwa", 7) != 0)
                  break;
                Mnemonic = "v_cvt_u32_f32";	 // "v_cvt_u32_f32_sdwa"
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_sdwa", 7) != 0)
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_u32_u16_sdwa"
                  Mnemonic = "v_cvt_u32_u16";
                return;
              }
              break;
            }
            break;
          }
          break;
        }
        break;
      case 'e':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+3, "xp_", 3) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case 'b':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+7, "f16_t16_e", 9) != 0)
            break;
          switch (Mnemonic[16]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[17] != '2')
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_exp_bf16_t16_e32"
              Mnemonic = "v_exp_bf16_t16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[17] != '4')
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_exp_bf16_t16_e64"
              Mnemonic = "v_exp_bf16_t16";
            return;
          }
          break;
        case 'f':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "16_t16_sdwa", 11) != 0)
            break;
          if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_exp_f16_t16_sdwa"
            Mnemonic = "v_exp_f16_t16";
          return;
        }
        break;
      case 'f':	 // 3 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'l':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "oor_f16_fake16", 14) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_floor_f16_fake16"
            Mnemonic = "v_floor_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_floor_f16";
          return;
        case 'm':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "a_f16_gfx9_t16", 14) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_fma_f16_gfx9_t16"
            Mnemonic = "v_fma_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_fma_f16";
          return;
        case 'r':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "act_f16_fake16", 14) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_fract_f16_fake16"
            Mnemonic = "v_fract_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_fract_f16";
          return;
        }
        break;
      case 'l':	 // 4 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'd':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "exp_f16_fake16", 14) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_ldexp_f16_fake16"
            Mnemonic = "v_ldexp_f16";
          else if (Features.test(Feature_isGFX11OnlyBit))
            Mnemonic = "v_ldexp_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_ldexp_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_ldexp_f16";
          return;
        case 'o':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "g_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'b':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "f16_t16_e", 9) != 0)
              break;
            switch (Mnemonic[16]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[17] != '2')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_log_bf16_t16_e32"
                Mnemonic = "v_log_bf16_t16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[17] != '4')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_log_bf16_t16_e64"
                Mnemonic = "v_log_bf16_t16";
              return;
            }
            break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "16_t16_sdwa", 11) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_log_f16_t16_sdwa"
              Mnemonic = "v_log_f16_t16";
            return;
          }
          break;
        }
        break;
      case 'm':	 // 9 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 3 strings to match.
          switch (Mnemonic[4]) {
          default: break;
          case 'd':	 // 2 strings to match.
            if (Mnemonic[5] != '_')
              break;
            switch (Mnemonic[6]) {
            default: break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "16_gfx9_t16", 11) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_mad_i16_gfx9_t16"
                Mnemonic = "v_mad_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_mad_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "16_gfx9_t16", 11) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_mad_u16_gfx9_t16"
                Mnemonic = "v_mad_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_mad_u16";
              return;
            }
            break;
          case 'x':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+5, "imum3_f16_t16", 13) != 0)
              break;
            if (Features.test(Feature_isGFX12OnlyBit))	 // "v_maximum3_f16_t16"
              Mnemonic = "v_maximum3_f16";
            return;
          }
          break;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "nimum3_f16_t16", 14) != 0)
            break;
          if (Features.test(Feature_isGFX12OnlyBit))	 // "v_minimum3_f16_t16"
            Mnemonic = "v_minimum3_f16";
          return;
        case 'o':	 // 5 strings to match.
          if (Mnemonic[4] != 'v')
            break;
          switch (Mnemonic[5]) {
          default: break;
          case '_':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+6, "b16_t16_sdwa", 12) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_mov_b16_t16_sdwa"
              Mnemonic = "v_mov_b16_t16";
            return;
          case 'r':	 // 4 strings to match.
            if (memcmp(Mnemonic.data()+6, "el", 2) != 0)
              break;
            switch (Mnemonic[8]) {
            default: break;
            case 'd':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "_b32_sdwa", 9) != 0)
                break;
              if (Features.test(Feature_HasMovrelBit))	 // "v_movreld_b32_sdwa"
                Mnemonic = "v_movreld_b32";
              return;
            case 's':	 // 3 strings to match.
              switch (Mnemonic[9]) {
              default: break;
              case '_':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "b32_sdwa", 8) != 0)
                  break;
                if (Features.test(Feature_HasMovrelBit))	 // "v_movrels_b32_sdwa"
                  Mnemonic = "v_movrels_b32";
                return;
              case 'd':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+10, "_b32_e", 6) != 0)
                  break;
                switch (Mnemonic[16]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[17] != '2')
                    break;
                  if (Features.test(Feature_HasMovrelBit))	 // "v_movrelsd_b32_e32"
                    Mnemonic = "v_movrelsd_b32";
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[17] != '4')
                    break;
                  if (Features.test(Feature_HasMovrelBit))	 // "v_movrelsd_b32_e64"
                    Mnemonic = "v_movrelsd_b32";
                  return;
                }
                break;
              }
              break;
            }
            break;
          }
          break;
        }
        break;
      case 'n':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "ot_b16_t16_sdwa", 15) != 0)
          break;
        if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_not_b16_t16_sdwa"
          Mnemonic = "v_not_b16_t16";
        return;
      case 'p':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "ack_b32_f16_t16", 15) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_pack_b32_f16_t16"
          Mnemonic = "v_pack_b32_f16";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_pack_b32_f16";
        return;
      case 'r':	 // 7 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'c':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "p_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'b':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "f16_t16_e", 9) != 0)
              break;
            switch (Mnemonic[16]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[17] != '2')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rcp_bf16_t16_e32"
                Mnemonic = "v_rcp_bf16_t16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[17] != '4')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rcp_bf16_t16_e64"
                Mnemonic = "v_rcp_bf16_t16";
              return;
            }
            break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "16_t16_sdwa", 11) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_rcp_f16_t16_sdwa"
              Mnemonic = "v_rcp_f16_t16";
            return;
          }
          break;
        case 'n':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "dne_f16_fake16", 14) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_rndne_f16_fake16"
            Mnemonic = "v_rndne_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_rndne_f16";
          return;
        case 's':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "q_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'b':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "f16_t16_e", 9) != 0)
              break;
            switch (Mnemonic[16]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[17] != '2')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rsq_bf16_t16_e32"
                Mnemonic = "v_rsq_bf16_t16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[17] != '4')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rsq_bf16_t16_e64"
                Mnemonic = "v_rsq_bf16_t16";
              return;
            }
            break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "16_t16_sdwa", 11) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_rsq_f16_t16_sdwa"
              Mnemonic = "v_rsq_f16_t16";
            return;
          }
          break;
        }
        break;
      case 's':	 // 6 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'i':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "n_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'b':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "f16_t16_e", 9) != 0)
              break;
            switch (Mnemonic[16]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[17] != '2')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sin_bf16_t16_e32"
                Mnemonic = "v_sin_bf16_t16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[17] != '4')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sin_bf16_t16_e64"
                Mnemonic = "v_sin_bf16_t16";
              return;
            }
            break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "16_t16_sdwa", 11) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_sin_f16_t16_sdwa"
              Mnemonic = "v_sin_f16_t16";
            return;
          }
          break;
        case 'q':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "rt_", 3) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'b':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "f16_fake16", 10) != 0)
              break;
            if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_sqrt_bf16_fake16"
              Mnemonic = "v_sqrt_bf16";
            return;
          case 'f':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+8, "16_t16_e", 8) != 0)
              break;
            switch (Mnemonic[16]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[17] != '2')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_sqrt_f16_t16_e32"
                Mnemonic = "v_sqrt_f16_t16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[17] != '4')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_sqrt_f16_t16_e64"
                Mnemonic = "v_sqrt_f16_t16";
              return;
            }
            break;
          }
          break;
        }
        break;
      case 't':	 // 4 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "nh_", 3) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'b':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "f16_fake16", 10) != 0)
              break;
            if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_tanh_bf16_fake16"
              Mnemonic = "v_tanh_bf16";
            return;
          case 'f':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+8, "16_t16_e", 8) != 0)
              break;
            switch (Mnemonic[16]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[17] != '2')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasTanhInstsBit))	 // "v_tanh_f16_t16_e32"
                Mnemonic = "v_tanh_f16_t16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[17] != '4')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasTanhInstsBit))	 // "v_tanh_f16_t16_e64"
                Mnemonic = "v_tanh_f16_t16";
              return;
            }
            break;
          }
          break;
        case 'r':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "unc_f16_fake16", 14) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_trunc_f16_fake16"
            Mnemonic = "v_trunc_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_trunc_f16";
          return;
        }
        break;
      }
      break;
    }
    break;
  case 19:	 // 88 strings to match.
    switch (Mnemonic[0]) {
    default: break;
    case 'b':	 // 5 strings to match.
      switch (Mnemonic[1]) {
      default: break;
      case 'u':	 // 4 strings to match.
        if (memcmp(Mnemonic.data()+2, "ffer_", 5) != 0)
          break;
        switch (Mnemonic[7]) {
        default: break;
        case 'a':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+8, "tomic_or_x2", 11) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_or_x2"
            Mnemonic = "buffer_atomic_or_b64";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "buffer_atomic_or_b64";
          return;
        case 'l':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+8, "oad_dwordx", 10) != 0)
            break;
          switch (Mnemonic[18]) {
          default: break;
          case '2':	 // 1 string to match.
            if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_load_dwordx2"
              Mnemonic = "buffer_load_b64";
            return;
          case '3':	 // 1 string to match.
            if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_load_dwordx3"
              Mnemonic = "buffer_load_b96";
            return;
          case '4':	 // 1 string to match.
            if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_load_dwordx4"
              Mnemonic = "buffer_load_b128";
            return;
          }
          break;
        }
        break;
      case 'v':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+2, "h64_intersect_ray", 17) != 0)
          break;
        if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))	 // "bvh64_intersect_ray"
          Mnemonic = "image_bvh64_intersect_ray";
        return;
      }
      break;
    case 'd':	 // 3 strings to match.
      if (memcmp(Mnemonic.data()+1, "s_", 2) != 0)
        break;
      switch (Mnemonic[3]) {
      default: break;
      case 'l':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+4, "oad_b128_tr_b16", 15) != 0)
          break;
        if (Features.test(Feature_isGFX125xOnlyBit))	 // "ds_load_b128_tr_b16"
          Mnemonic = "ds_load_tr16_b128";
        return;
      case 'w':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+4, "rite_", 5) != 0)
          break;
        switch (Mnemonic[9]) {
        default: break;
        case 'a':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+10, "ddtid_b32", 9) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_write_addtid_b32"
            Mnemonic = "ds_store_addtid_b32";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "ds_store_addtid_b32";
          return;
        case 'b':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+10, "16_d16_hi", 9) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_write_b16_d16_hi"
            Mnemonic = "ds_store_b16_d16_hi";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "ds_store_b16_d16_hi";
          return;
        }
        break;
      }
      break;
    case 'f':	 // 13 strings to match.
      if (memcmp(Mnemonic.data()+1, "lat_", 4) != 0)
        break;
      switch (Mnemonic[5]) {
      default: break;
      case 'a':	 // 10 strings to match.
        if (memcmp(Mnemonic.data()+6, "tomic_", 6) != 0)
          break;
        switch (Mnemonic[12]) {
        default: break;
        case 'c':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "mpswap", 6) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_cmpswap"
            Mnemonic = "flat_atomic_cmpswap_b32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_atomic_cmpswap_b32";
          return;
        case 'm':	 // 4 strings to match.
          switch (Mnemonic[13]) {
          default: break;
          case 'a':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+14, "x_f", 3) != 0)
              break;
            switch (Mnemonic[17]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[18] != '2')
                break;
              if (Features.test(Feature_isGFX12OnlyBit))	 // "flat_atomic_max_f32"
                Mnemonic = "flat_atomic_max_num_f32";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[18] != '4')
                break;
              if (Features.test(Feature_isGFX125xOnlyBit))	 // "flat_atomic_max_f64"
                Mnemonic = "flat_atomic_max_num_f64";
              return;
            }
            break;
          case 'i':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+14, "n_f", 3) != 0)
              break;
            switch (Mnemonic[17]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[18] != '2')
                break;
              if (Features.test(Feature_isGFX12OnlyBit))	 // "flat_atomic_min_f32"
                Mnemonic = "flat_atomic_min_num_f32";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[18] != '4')
                break;
              if (Features.test(Feature_isGFX125xOnlyBit))	 // "flat_atomic_min_f64"
                Mnemonic = "flat_atomic_min_num_f64";
              return;
            }
            break;
          }
          break;
        case 's':	 // 3 strings to match.
          switch (Mnemonic[13]) {
          default: break;
          case 'm':	 // 2 strings to match.
            switch (Mnemonic[14]) {
            default: break;
            case 'a':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+15, "x_x2", 4) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_smax_x2"
                Mnemonic = "flat_atomic_max_i64";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "flat_atomic_max_i64";
              return;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+15, "n_x2", 4) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_smin_x2"
                Mnemonic = "flat_atomic_min_i64";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "flat_atomic_min_i64";
              return;
            }
            break;
          case 'w':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "ap_x2", 5) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_swap_x2"
              Mnemonic = "flat_atomic_swap_b64";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "flat_atomic_swap_b64";
            return;
          }
          break;
        case 'u':	 // 2 strings to match.
          if (Mnemonic[13] != 'm')
            break;
          switch (Mnemonic[14]) {
          default: break;
          case 'a':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+15, "x_x2", 4) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_umax_x2"
              Mnemonic = "flat_atomic_max_u64";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "flat_atomic_max_u64";
            return;
          case 'i':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+15, "n_x2", 4) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_umin_x2"
              Mnemonic = "flat_atomic_min_u64";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "flat_atomic_min_u64";
            return;
          }
          break;
        }
        break;
      case 'l':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+6, "oad_", 4) != 0)
          break;
        switch (Mnemonic[10]) {
        default: break;
        case 's':	 // 2 strings to match.
          switch (Mnemonic[11]) {
          default: break;
          case 'b':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+12, "yte_d16", 7) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_load_sbyte_d16"
              Mnemonic = "flat_load_d16_i8";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "flat_load_d16_i8";
            return;
          case 'h':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+12, "ort_d16", 7) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_load_short_d16"
              Mnemonic = "flat_load_d16_b16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "flat_load_d16_b16";
            return;
          }
          break;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+11, "byte_d16", 8) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_load_ubyte_d16"
            Mnemonic = "flat_load_d16_u8";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_load_d16_u8";
          return;
        }
        break;
      }
      break;
    case 'g':	 // 5 strings to match.
      if (memcmp(Mnemonic.data()+1, "lobal_", 6) != 0)
        break;
      switch (Mnemonic[7]) {
      default: break;
      case 'a':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+8, "tomic_or_x2", 11) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_or_x2"
          Mnemonic = "global_atomic_or_b64";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "global_atomic_or_b64";
        return;
      case 'l':	 // 4 strings to match.
        if (memcmp(Mnemonic.data()+8, "oad_", 4) != 0)
          break;
        switch (Mnemonic[12]) {
        default: break;
        case 'd':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+13, "wordx", 5) != 0)
            break;
          switch (Mnemonic[18]) {
          default: break;
          case '2':	 // 1 string to match.
            if (Features.test(Feature_isGFX11OnlyBit))	 // "global_load_dwordx2"
              Mnemonic = "global_load_b64";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "global_load_b64";
            return;
          case '3':	 // 1 string to match.
            if (Features.test(Feature_isGFX11OnlyBit))	 // "global_load_dwordx3"
              Mnemonic = "global_load_b96";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "global_load_b96";
            return;
          case '4':	 // 1 string to match.
            if (Features.test(Feature_isGFX11OnlyBit))	 // "global_load_dwordx4"
              Mnemonic = "global_load_b128";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "global_load_b128";
            return;
          }
          break;
        case 't':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "r_b128", 6) != 0)
            break;
          if (Features.test(Feature_isGFX125xOnlyBit))	 // "global_load_tr_b128"
            Mnemonic = "global_load_tr16_b128";
          return;
        }
        break;
      }
      break;
    case 's':	 // 9 strings to match.
      switch (Mnemonic[1]) {
      default: break;
      case '_':	 // 5 strings to match.
        switch (Mnemonic[2]) {
        default: break;
        case 'b':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+3, "uffer_load_dword", 16) != 0)
            break;
          if (Features.test(Feature_isGFX11PlusBit))	 // "s_buffer_load_dword"
            Mnemonic = "s_buffer_load_b32";
          return;
        case 'o':	 // 4 strings to match.
          if (memcmp(Mnemonic.data()+3, "rn", 2) != 0)
            break;
          switch (Mnemonic[5]) {
          default: break;
          case '1':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+6, "_saveexec_b", 11) != 0)
              break;
            switch (Mnemonic[17]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[18] != '2')
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "s_orn1_saveexec_b32"
                Mnemonic = "s_or_not0_saveexec_b32";
              else if (Features.test(Feature_isGFX12PlusBit))
                Mnemonic = "s_or_not0_saveexec_b32";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[18] != '4')
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "s_orn1_saveexec_b64"
                Mnemonic = "s_or_not0_saveexec_b64";
              else if (Features.test(Feature_isGFX12PlusBit))
                Mnemonic = "s_or_not0_saveexec_b64";
              return;
            }
            break;
          case '2':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+6, "_saveexec_b", 11) != 0)
              break;
            switch (Mnemonic[17]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[18] != '2')
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "s_orn2_saveexec_b32"
                Mnemonic = "s_or_not1_saveexec_b32";
              else if (Features.test(Feature_isGFX12PlusBit))
                Mnemonic = "s_or_not1_saveexec_b32";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[18] != '4')
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "s_orn2_saveexec_b64"
                Mnemonic = "s_or_not1_saveexec_b64";
              else if (Features.test(Feature_isGFX12PlusBit))
                Mnemonic = "s_or_not1_saveexec_b64";
              return;
            }
            break;
          }
          break;
        }
        break;
      case 'c':	 // 4 strings to match.
        if (memcmp(Mnemonic.data()+2, "ratch_", 6) != 0)
          break;
        switch (Mnemonic[8]) {
        default: break;
        case 'l':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+9, "oad_", 4) != 0)
            break;
          switch (Mnemonic[13]) {
          default: break;
          case 's':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "short", 5) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "scratch_load_sshort"
              Mnemonic = "scratch_load_i16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "scratch_load_i16";
            return;
          case 'u':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "short", 5) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "scratch_load_ushort"
              Mnemonic = "scratch_load_u16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "scratch_load_u16";
            return;
          }
          break;
        case 's':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+9, "tore_", 5) != 0)
            break;
          switch (Mnemonic[14]) {
          default: break;
          case 'd':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+15, "word", 4) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "scratch_store_dword"
              Mnemonic = "scratch_store_b32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "scratch_store_b32";
            return;
          case 's':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+15, "hort", 4) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "scratch_store_short"
              Mnemonic = "scratch_store_b16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "scratch_store_b16";
            return;
          }
          break;
        }
        break;
      }
      break;
    case 'v':	 // 53 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'a':	 // 2 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'd':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "d_nc_u16_fake16", 15) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_add_nc_u16_fake16"
            Mnemonic = "v_add_nc_u16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_add_nc_u16";
          return;
        case 'l':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "ignbyte_b32_t16", 15) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_alignbyte_b32_t16"
            Mnemonic = "v_alignbyte_b32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_alignbyte_b32";
          return;
        }
        break;
      case 'c':	 // 4 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'e':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "il_f16_t16_sdwa", 15) != 0)
            break;
          if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_ceil_f16_t16_sdwa"
            Mnemonic = "v_ceil_f16_t16";
          return;
        case 'o':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "s_bf16_t16_sdwa", 15) != 0)
            break;
          if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_cos_bf16_t16_sdwa"
            Mnemonic = "v_cos_bf16_t16";
          return;
        case 'v':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "t_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "32_bf16_sdwa", 12) != 0)
              break;
            if (Features.test(Feature_HasBF16ConversionInstsBit) && Features.test(Feature_HasGFX950InstsBit))	 // "v_cvt_f32_bf16_sdwa"
              Mnemonic = "v_cvt_f32_bf16";
            return;
          case 'p':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "krtz_f16_f32", 12) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_pkrtz_f16_f32"
              Mnemonic = "v_cvt_pk_rtz_f16_f32";
            else if (Features.test(Feature_isGFX11OnlyBit))
              Mnemonic = "v_cvt_pk_rtz_f16_f32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cvt_pk_rtz_f16_f32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cvt_pk_rtz_f16_f32";
            return;
          }
          break;
        }
        break;
      case 'e':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "xp_bf16_t16_sdwa", 16) != 0)
          break;
        if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_exp_bf16_t16_sdwa"
          Mnemonic = "v_exp_bf16_t16";
        return;
      case 'f':	 // 4 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'l':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "oor_f16_t16_e", 13) != 0)
            break;
          switch (Mnemonic[17]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[18] != '2')
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_floor_f16_t16_e32"
              Mnemonic = "v_floor_f16_t16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[18] != '4')
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_floor_f16_t16_e64"
              Mnemonic = "v_floor_f16_t16";
            return;
          }
          break;
        case 'r':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "act_f16_t16_e", 13) != 0)
            break;
          switch (Mnemonic[17]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[18] != '2')
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_fract_f16_t16_e32"
              Mnemonic = "v_fract_f16_t16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[18] != '4')
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_fract_f16_t16_e64"
              Mnemonic = "v_fract_f16_t16";
            return;
          }
          break;
        }
        break;
      case 'i':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "nterp_p2_new_f32", 16) != 0)
          break;
        if (Features.test(Feature_isGFX11PlusBit))	 // "v_interp_p2_new_f32"
          Mnemonic = "v_interp_p2_f32";
        return;
      case 'l':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+3, "og_", 3) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case 'b':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "f16_t16_sdwa", 12) != 0)
            break;
          if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_log_bf16_t16_sdwa"
            Mnemonic = "v_log_bf16_t16";
          return;
        case 'c':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+7, "lamp_f32_e", 10) != 0)
            break;
          switch (Mnemonic[17]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[18] != '2')
              break;
            if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_log_clamp_f32_e32"
              Mnemonic = "v_log_clamp_f32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[18] != '4')
              break;
            if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_log_clamp_f32_e64"
              Mnemonic = "v_log_clamp_f32";
            return;
          }
          break;
        }
        break;
      case 'm':	 // 4 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "xmin_f16_fake16", 15) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_maxmin_f16_fake16"
            Mnemonic = "v_maxmin_f16";
          return;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "nmax_f16_fake16", 15) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_minmax_f16_fake16"
            Mnemonic = "v_minmax_f16";
          return;
        case 'o':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "vrelsd_b32_sdwa", 15) != 0)
            break;
          if (Features.test(Feature_HasMovrelBit))	 // "v_movrelsd_b32_sdwa"
            Mnemonic = "v_movrelsd_b32";
          return;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "l_lo_u16_fake16", 15) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_mul_lo_u16_fake16"
            Mnemonic = "v_mul_lo_u16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_mul_lo_u16";
          return;
        }
        break;
      case 'r':	 // 14 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'c':	 // 7 strings to match.
          if (memcmp(Mnemonic.data()+4, "p_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'b':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "f16_t16_sdwa", 12) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rcp_bf16_t16_sdwa"
              Mnemonic = "v_rcp_bf16_t16";
            return;
          case 'c':	 // 4 strings to match.
            if (memcmp(Mnemonic.data()+7, "lamp_f", 6) != 0)
              break;
            switch (Mnemonic[13]) {
            default: break;
            case '3':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+14, "2_e", 3) != 0)
                break;
              switch (Mnemonic[17]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[18] != '2')
                  break;
                if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_rcp_clamp_f32_e32"
                  Mnemonic = "v_rcp_clamp_f32";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[18] != '4')
                  break;
                if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_rcp_clamp_f32_e64"
                  Mnemonic = "v_rcp_clamp_f32";
                return;
              }
              break;
            case '6':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+14, "4_e", 3) != 0)
                break;
              switch (Mnemonic[17]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[18] != '2')
                  break;
                if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_rcp_clamp_f64_e32"
                  Mnemonic = "v_rcp_clamp_f64";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[18] != '4')
                  break;
                if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_rcp_clamp_f64_e64"
                  Mnemonic = "v_rcp_clamp_f64";
                return;
              }
              break;
            }
            break;
          case 'i':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "flag_f32_e", 10) != 0)
              break;
            switch (Mnemonic[17]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[18] != '2')
                break;
              Mnemonic = "v_rcp_iflag_f32";	 // "v_rcp_iflag_f32_e32"
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[18] != '4')
                break;
              Mnemonic = "v_rcp_iflag_f32";	 // "v_rcp_iflag_f32_e64"
              return;
            }
            break;
          }
          break;
        case 'n':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "dne_f16_t16_e", 13) != 0)
            break;
          switch (Mnemonic[17]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[18] != '2')
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_rndne_f16_t16_e32"
              Mnemonic = "v_rndne_f16_t16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[18] != '4')
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_rndne_f16_t16_e64"
              Mnemonic = "v_rndne_f16_t16";
            return;
          }
          break;
        case 's':	 // 5 strings to match.
          if (memcmp(Mnemonic.data()+4, "q_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'b':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "f16_t16_sdwa", 12) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rsq_bf16_t16_sdwa"
              Mnemonic = "v_rsq_bf16_t16";
            return;
          case 'c':	 // 4 strings to match.
            if (memcmp(Mnemonic.data()+7, "lamp_f", 6) != 0)
              break;
            switch (Mnemonic[13]) {
            default: break;
            case '3':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+14, "2_e", 3) != 0)
                break;
              switch (Mnemonic[17]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[18] != '2')
                  break;
                if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_rsq_clamp_f32_e32"
                  Mnemonic = "v_rsq_clamp_f32";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[18] != '4')
                  break;
                if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_rsq_clamp_f32_e64"
                  Mnemonic = "v_rsq_clamp_f32";
                return;
              }
              break;
            case '6':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+14, "4_e", 3) != 0)
                break;
              switch (Mnemonic[17]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[18] != '2')
                  break;
                if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_rsq_clamp_f64_e32"
                  Mnemonic = "v_rsq_clamp_f64";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[18] != '4')
                  break;
                if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_rsq_clamp_f64_e64"
                  Mnemonic = "v_rsq_clamp_f64";
                return;
              }
              break;
            }
            break;
          }
          break;
        }
        break;
      case 's':	 // 15 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 9 strings to match.
          if (memcmp(Mnemonic.data()+4, "t_pk", 4) != 0)
            break;
          switch (Mnemonic[8]) {
          default: break;
          case '4':	 // 6 strings to match.
            if (Mnemonic[9] != '_')
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'i':	 // 3 strings to match.
              if (memcmp(Mnemonic.data()+11, "4_i8_", 5) != 0)
                break;
              switch (Mnemonic[16]) {
              default: break;
              case 'e':	 // 2 strings to match.
                switch (Mnemonic[17]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[18] != '2')
                    break;
                  if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_i4_i8_e32"
                    Mnemonic = "v_sat_pk4_i4_i8";
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[18] != '4')
                    break;
                  if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_i4_i8_e64"
                    Mnemonic = "v_sat_pk4_i4_i8";
                  return;
                }
                break;
              case 't':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+17, "16", 2) != 0)
                  break;
                if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_sat_pk4_i4_i8_t16"
                  Mnemonic = "v_sat_pk4_i4_i8";
                return;
              }
              break;
            case 'u':	 // 3 strings to match.
              if (memcmp(Mnemonic.data()+11, "4_u8_", 5) != 0)
                break;
              switch (Mnemonic[16]) {
              default: break;
              case 'e':	 // 2 strings to match.
                switch (Mnemonic[17]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[18] != '2')
                    break;
                  if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_u4_u8_e32"
                    Mnemonic = "v_sat_pk4_u4_u8";
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[18] != '4')
                    break;
                  if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_u4_u8_e64"
                    Mnemonic = "v_sat_pk4_u4_u8";
                  return;
                }
                break;
              case 't':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+17, "16", 2) != 0)
                  break;
                if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_sat_pk4_u4_u8_t16"
                  Mnemonic = "v_sat_pk4_u4_u8";
                return;
              }
              break;
            }
            break;
          case '_':	 // 3 strings to match.
            if (memcmp(Mnemonic.data()+9, "u8_i16_", 7) != 0)
              break;
            switch (Mnemonic[16]) {
            default: break;
            case 'e':	 // 2 strings to match.
              switch (Mnemonic[17]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[18] != '2')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX9PlusBit))	 // "v_sat_pk_u8_i16_e32"
                  Mnemonic = "v_sat_pk_u8_i16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[18] != '4')
                  break;
                if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX9PlusBit))	 // "v_sat_pk_u8_i16_e64"
                  Mnemonic = "v_sat_pk_u8_i16";
                return;
              }
              break;
            case 't':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+17, "16", 2) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_sat_pk_u8_i16_t16"
                Mnemonic = "v_sat_pk_u8_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_sat_pk_u8_i16";
              return;
            }
            break;
          }
          break;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "n_bf16_t16_sdwa", 15) != 0)
            break;
          if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sin_bf16_t16_sdwa"
            Mnemonic = "v_sin_bf16_t16";
          return;
        case 'q':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "rt_", 3) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'b':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+8, "f16_t16_e", 9) != 0)
              break;
            switch (Mnemonic[17]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[18] != '2')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sqrt_bf16_t16_e32"
                Mnemonic = "v_sqrt_bf16_t16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[18] != '4')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sqrt_bf16_t16_e64"
                Mnemonic = "v_sqrt_bf16_t16";
              return;
            }
            break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "16_t16_sdwa", 11) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_sqrt_f16_t16_sdwa"
              Mnemonic = "v_sqrt_f16_t16";
            return;
          }
          break;
        case 'u':	 // 2 strings to match.
          if (Mnemonic[4] != 'b')
            break;
          switch (Mnemonic[5]) {
          default: break;
          case '_':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+6, "nc_u16_fake16", 13) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_sub_nc_u16_fake16"
              Mnemonic = "v_sub_nc_u16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_sub_nc_u16";
            return;
          case 'r':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+6, "ev_f16_fake16", 13) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_subrev_f16_fake16"
              Mnemonic = "v_subrev_f16";
            else if (Features.test(Feature_isGFX11OnlyBit))
              Mnemonic = "v_subrev_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_subrev_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_subrev_f16";
            return;
          }
          break;
        }
        break;
      case 't':	 // 5 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "nh_", 3) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'b':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+8, "f16_t16_e", 9) != 0)
              break;
            switch (Mnemonic[17]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[18] != '2')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_tanh_bf16_t16_e32"
                Mnemonic = "v_tanh_bf16_t16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[18] != '4')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_tanh_bf16_t16_e64"
                Mnemonic = "v_tanh_bf16_t16";
              return;
            }
            break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "16_t16_sdwa", 11) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasTanhInstsBit))	 // "v_tanh_f16_t16_sdwa"
              Mnemonic = "v_tanh_f16_t16";
            return;
          }
          break;
        case 'r':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "unc_f16_t16_e", 13) != 0)
            break;
          switch (Mnemonic[17]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[18] != '2')
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_trunc_f16_t16_e32"
              Mnemonic = "v_trunc_f16_t16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[18] != '4')
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_trunc_f16_t16_e64"
              Mnemonic = "v_trunc_f16_t16";
            return;
          }
          break;
        }
        break;
      }
      break;
    }
    break;
  case 20:	 // 125 strings to match.
    switch (Mnemonic[0]) {
    default: break;
    case 'b':	 // 9 strings to match.
      if (memcmp(Mnemonic.data()+1, "uffer_", 6) != 0)
        break;
      switch (Mnemonic[7]) {
      default: break;
      case 'a':	 // 6 strings to match.
        if (memcmp(Mnemonic.data()+8, "tomic_", 6) != 0)
          break;
        switch (Mnemonic[14]) {
        default: break;
        case 'a':	 // 2 strings to match.
          switch (Mnemonic[15]) {
          default: break;
          case 'd':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+16, "d_x2", 4) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_add_x2"
              Mnemonic = "buffer_atomic_add_u64";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "buffer_atomic_add_u64";
            return;
          case 'n':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+16, "d_x2", 4) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_and_x2"
              Mnemonic = "buffer_atomic_and_b64";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "buffer_atomic_and_b64";
            return;
          }
          break;
        case 'd':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+15, "ec_x2", 5) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_dec_x2"
            Mnemonic = "buffer_atomic_dec_u64";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "buffer_atomic_dec_u64";
          return;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+15, "nc_x2", 5) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_inc_x2"
            Mnemonic = "buffer_atomic_inc_u64";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "buffer_atomic_inc_u64";
          return;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+15, "ub_x2", 5) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_sub_x2"
            Mnemonic = "buffer_atomic_sub_u64";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "buffer_atomic_sub_u64";
          return;
        case 'x':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+15, "or_x2", 5) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_xor_x2"
            Mnemonic = "buffer_atomic_xor_b64";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "buffer_atomic_xor_b64";
          return;
        }
        break;
      case 's':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+8, "tore_dwordx", 11) != 0)
          break;
        switch (Mnemonic[19]) {
        default: break;
        case '2':	 // 1 string to match.
          if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_store_dwordx2"
            Mnemonic = "buffer_store_b64";
          return;
        case '3':	 // 1 string to match.
          if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_store_dwordx3"
            Mnemonic = "buffer_store_b96";
          return;
        case '4':	 // 1 string to match.
          if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_store_dwordx4"
            Mnemonic = "buffer_store_b128";
          return;
        }
        break;
      }
      break;
    case 'd':	 // 1 string to match.
      if (memcmp(Mnemonic.data()+1, "s_bvh_stack_rtn_b32", 19) != 0)
        break;
      if (Features.test(Feature_isGFX12PlusBit))	 // "ds_bvh_stack_rtn_b32"
        Mnemonic = "ds_bvh_stack_push4_pop1_rtn_b32";
      return;
    case 'f':	 // 2 strings to match.
      if (memcmp(Mnemonic.data()+1, "lat_atomic_", 11) != 0)
        break;
      switch (Mnemonic[12]) {
      default: break;
      case 'c':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+13, "sub_u32", 7) != 0)
          break;
        if (Features.test(Feature_isGFX12OnlyBit))	 // "flat_atomic_csub_u32"
          Mnemonic = "flat_atomic_sub_clamp_u32";
        return;
      case 'f':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+13, "cmpswap", 7) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_fcmpswap"
          Mnemonic = "flat_atomic_cmpswap_f32";
        return;
      }
      break;
    case 'g':	 // 9 strings to match.
      if (memcmp(Mnemonic.data()+1, "lobal_", 6) != 0)
        break;
      switch (Mnemonic[7]) {
      default: break;
      case 'a':	 // 6 strings to match.
        if (memcmp(Mnemonic.data()+8, "tomic_", 6) != 0)
          break;
        switch (Mnemonic[14]) {
        default: break;
        case 'a':	 // 2 strings to match.
          switch (Mnemonic[15]) {
          default: break;
          case 'd':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+16, "d_x2", 4) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_add_x2"
              Mnemonic = "global_atomic_add_u64";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "global_atomic_add_u64";
            return;
          case 'n':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+16, "d_x2", 4) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_and_x2"
              Mnemonic = "global_atomic_and_b64";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "global_atomic_and_b64";
            return;
          }
          break;
        case 'd':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+15, "ec_x2", 5) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_dec_x2"
            Mnemonic = "global_atomic_dec_u64";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_atomic_dec_u64";
          return;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+15, "nc_x2", 5) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_inc_x2"
            Mnemonic = "global_atomic_inc_u64";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_atomic_inc_u64";
          return;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+15, "ub_x2", 5) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_sub_x2"
            Mnemonic = "global_atomic_sub_u64";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_atomic_sub_u64";
          return;
        case 'x':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+15, "or_x2", 5) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_xor_x2"
            Mnemonic = "global_atomic_xor_b64";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_atomic_xor_b64";
          return;
        }
        break;
      case 's':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+8, "tore_dwordx", 11) != 0)
          break;
        switch (Mnemonic[19]) {
        default: break;
        case '2':	 // 1 string to match.
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_store_dwordx2"
            Mnemonic = "global_store_b64";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_store_b64";
          return;
        case '3':	 // 1 string to match.
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_store_dwordx3"
            Mnemonic = "global_store_b96";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_store_b96";
          return;
        case '4':	 // 1 string to match.
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_store_dwordx4"
            Mnemonic = "global_store_b128";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_store_b128";
          return;
        }
        break;
      }
      break;
    case 's':	 // 7 strings to match.
      switch (Mnemonic[1]) {
      default: break;
      case '_':	 // 4 strings to match.
        if (memcmp(Mnemonic.data()+2, "andn", 4) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case '1':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+7, "_saveexec_b", 11) != 0)
            break;
          switch (Mnemonic[18]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[19] != '2')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "s_andn1_saveexec_b32"
              Mnemonic = "s_and_not0_saveexec_b32";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "s_and_not0_saveexec_b32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[19] != '4')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "s_andn1_saveexec_b64"
              Mnemonic = "s_and_not0_saveexec_b64";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "s_and_not0_saveexec_b64";
            return;
          }
          break;
        case '2':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+7, "_saveexec_b", 11) != 0)
            break;
          switch (Mnemonic[18]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[19] != '2')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "s_andn2_saveexec_b32"
              Mnemonic = "s_and_not1_saveexec_b32";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "s_and_not1_saveexec_b32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[19] != '4')
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "s_andn2_saveexec_b64"
              Mnemonic = "s_and_not1_saveexec_b64";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "s_and_not1_saveexec_b64";
            return;
          }
          break;
        }
        break;
      case 'c':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+2, "ratch_load_dwordx", 17) != 0)
          break;
        switch (Mnemonic[19]) {
        default: break;
        case '2':	 // 1 string to match.
          if (Features.test(Feature_isGFX11OnlyBit))	 // "scratch_load_dwordx2"
            Mnemonic = "scratch_load_b64";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "scratch_load_b64";
          return;
        case '3':	 // 1 string to match.
          if (Features.test(Feature_isGFX11OnlyBit))	 // "scratch_load_dwordx3"
            Mnemonic = "scratch_load_b96";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "scratch_load_b96";
          return;
        case '4':	 // 1 string to match.
          if (Features.test(Feature_isGFX11OnlyBit))	 // "scratch_load_dwordx4"
            Mnemonic = "scratch_load_b128";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "scratch_load_b128";
          return;
        }
        break;
      }
      break;
    case 'v':	 // 97 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'a':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "shrrev_i16_fake16", 17) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_ashrrev_i16_fake16"
          Mnemonic = "v_ashrrev_i16";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_ashrrev_i16";
        return;
      case 'c':	 // 45 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'n':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "dmask_b16_fake16", 16) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cndmask_b16_fake16"
            Mnemonic = "v_cndmask_b16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_cndmask_b16";
          return;
        case 'o':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "s_f16_fake16_e", 14) != 0)
            break;
          switch (Mnemonic[18]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[19] != '2')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cos_f16_fake16_e32"
              Mnemonic = "v_cos_f16_fake16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[19] != '4')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cos_f16_fake16_e64"
              Mnemonic = "v_cos_f16_fake16";
            return;
          }
          break;
        case 'v':	 // 42 strings to match.
          if (memcmp(Mnemonic.data()+4, "t_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'f':	 // 16 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 5 strings to match.
              if (memcmp(Mnemonic.data()+8, "6_", 2) != 0)
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'b':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "f8_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_f16_bf8_fake16"
                  Mnemonic = "v_cvt_f16_bf8";
                return;
              case 'f':	 // 2 strings to match.
                switch (Mnemonic[11]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+12, "2_fake16", 8) != 0)
                    break;
                  if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_f16_f32_fake16"
                    Mnemonic = "v_cvt_f16_f32";
                  else if (Features.test(Feature_isGFX12OnlyBit))
                    Mnemonic = "v_cvt_f16_f32";
                  return;
                case 'p':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+12, "8_fake16", 8) != 0)
                    break;
                  if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_f16_fp8_fake16"
                    Mnemonic = "v_cvt_f16_fp8";
                  return;
                }
                break;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_f16_i16_fake16"
                  Mnemonic = "v_cvt_f16_i16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cvt_f16_i16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_f16_u16_fake16"
                  Mnemonic = "v_cvt_f16_u16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cvt_f16_u16";
                return;
              }
              break;
            case '3':	 // 11 strings to match.
              if (memcmp(Mnemonic.data()+8, "2_", 2) != 0)
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'b':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "f8_op_sel", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX12OnlyBit))	 // "v_cvt_f32_bf8_op_sel"
                  Mnemonic = "v_cvt_f32_bf8";
                return;
              case 'f':	 // 2 strings to match.
                switch (Mnemonic[11]) {
                default: break;
                case '1':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+12, "6_fake16", 8) != 0)
                    break;
                  if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_f32_f16_fake16"
                    Mnemonic = "v_cvt_f32_f16";
                  else if (Features.test(Feature_isGFX12OnlyBit))
                    Mnemonic = "v_cvt_f32_f16";
                  return;
                case 'p':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+12, "8_op_sel", 8) != 0)
                    break;
                  if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_f32_fp8_op_sel"
                    Mnemonic = "v_cvt_f32_fp8";
                  else if (Features.test(Feature_isGFX12Not12_50Bit))
                    Mnemonic = "v_cvt_f32_fp8";
                  return;
                }
                break;
              case 'u':	 // 8 strings to match.
                if (memcmp(Mnemonic.data()+11, "byte", 4) != 0)
                  break;
                switch (Mnemonic[15]) {
                default: break;
                case '0':	 // 2 strings to match.
                  if (memcmp(Mnemonic.data()+16, "_e", 2) != 0)
                    break;
                  switch (Mnemonic[18]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (Mnemonic[19] != '2')
                      break;
                    Mnemonic = "v_cvt_f32_ubyte0";	 // "v_cvt_f32_ubyte0_e32"
                    return;
                  case '6':	 // 1 string to match.
                    if (Mnemonic[19] != '4')
                      break;
                    Mnemonic = "v_cvt_f32_ubyte0";	 // "v_cvt_f32_ubyte0_e64"
                    return;
                  }
                  break;
                case '1':	 // 2 strings to match.
                  if (memcmp(Mnemonic.data()+16, "_e", 2) != 0)
                    break;
                  switch (Mnemonic[18]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (Mnemonic[19] != '2')
                      break;
                    Mnemonic = "v_cvt_f32_ubyte1";	 // "v_cvt_f32_ubyte1_e32"
                    return;
                  case '6':	 // 1 string to match.
                    if (Mnemonic[19] != '4')
                      break;
                    Mnemonic = "v_cvt_f32_ubyte1";	 // "v_cvt_f32_ubyte1_e64"
                    return;
                  }
                  break;
                case '2':	 // 2 strings to match.
                  if (memcmp(Mnemonic.data()+16, "_e", 2) != 0)
                    break;
                  switch (Mnemonic[18]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (Mnemonic[19] != '2')
                      break;
                    Mnemonic = "v_cvt_f32_ubyte2";	 // "v_cvt_f32_ubyte2_e32"
                    return;
                  case '6':	 // 1 string to match.
                    if (Mnemonic[19] != '4')
                      break;
                    Mnemonic = "v_cvt_f32_ubyte2";	 // "v_cvt_f32_ubyte2_e64"
                    return;
                  }
                  break;
                case '3':	 // 2 strings to match.
                  if (memcmp(Mnemonic.data()+16, "_e", 2) != 0)
                    break;
                  switch (Mnemonic[18]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (Mnemonic[19] != '2')
                      break;
                    Mnemonic = "v_cvt_f32_ubyte3";	 // "v_cvt_f32_ubyte3_e32"
                    return;
                  case '6':	 // 1 string to match.
                    if (Mnemonic[19] != '4')
                      break;
                    Mnemonic = "v_cvt_f32_ubyte3";	 // "v_cvt_f32_ubyte3_e64"
                    return;
                  }
                  break;
                }
                break;
              }
              break;
            }
            break;
          case 'i':	 // 2 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "6_f16_fake16", 12) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_i16_f16_fake16"
                Mnemonic = "v_cvt_i16_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cvt_i16_f16";
              return;
            case '3':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "2_i16_fake16", 12) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_i32_i16_fake16"
                Mnemonic = "v_cvt_i32_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cvt_i32_i16";
              return;
            }
            break;
          case 'o':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "ff_f32_i4_e", 11) != 0)
              break;
            switch (Mnemonic[18]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[19] != '2')
                break;
              Mnemonic = "v_cvt_off_f32_i4";	 // "v_cvt_off_f32_i4_e32"
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[19] != '4')
                break;
              Mnemonic = "v_cvt_off_f32_i4";	 // "v_cvt_off_f32_i4_e64"
              return;
            }
            break;
          case 'p':	 // 18 strings to match.
            if (Mnemonic[7] != 'k')
              break;
            switch (Mnemonic[8]) {
            default: break;
            case '_':	 // 14 strings to match.
              switch (Mnemonic[9]) {
              default: break;
              case 'b':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+10, "f8_f32_t16", 10) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_pk_bf8_f32_t16"
                  Mnemonic = "v_cvt_pk_bf8_f32";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cvt_pk_bf8_f32";
                return;
              case 'f':	 // 13 strings to match.
                switch (Mnemonic[10]) {
                default: break;
                case '1':	 // 6 strings to match.
                  if (memcmp(Mnemonic.data()+11, "6_", 2) != 0)
                    break;
                  switch (Mnemonic[13]) {
                  default: break;
                  case 'b':	 // 3 strings to match.
                    if (memcmp(Mnemonic.data()+14, "f8_", 3) != 0)
                      break;
                    switch (Mnemonic[17]) {
                    default: break;
                    case 'e':	 // 2 strings to match.
                      switch (Mnemonic[18]) {
                      default: break;
                      case '3':	 // 1 string to match.
                        if (Mnemonic[19] != '2')
                          break;
                        if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_pk_f16_bf8_e32"
                          Mnemonic = "v_cvt_pk_f16_bf8";
                        return;
                      case '6':	 // 1 string to match.
                        if (Mnemonic[19] != '4')
                          break;
                        if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_pk_f16_bf8_e64"
                          Mnemonic = "v_cvt_pk_f16_bf8";
                        return;
                      }
                      break;
                    case 't':	 // 1 string to match.
                      if (memcmp(Mnemonic.data()+18, "16", 2) != 0)
                        break;
                      if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_pk_f16_bf8_t16"
                        Mnemonic = "v_cvt_pk_f16_bf8";
                      return;
                    }
                    break;
                  case 'f':	 // 3 strings to match.
                    if (memcmp(Mnemonic.data()+14, "p8_", 3) != 0)
                      break;
                    switch (Mnemonic[17]) {
                    default: break;
                    case 'e':	 // 2 strings to match.
                      switch (Mnemonic[18]) {
                      default: break;
                      case '3':	 // 1 string to match.
                        if (Mnemonic[19] != '2')
                          break;
                        if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_pk_f16_fp8_e32"
                          Mnemonic = "v_cvt_pk_f16_fp8";
                        return;
                      case '6':	 // 1 string to match.
                        if (Mnemonic[19] != '4')
                          break;
                        if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_pk_f16_fp8_e64"
                          Mnemonic = "v_cvt_pk_f16_fp8";
                        return;
                      }
                      break;
                    case 't':	 // 1 string to match.
                      if (memcmp(Mnemonic.data()+18, "16", 2) != 0)
                        break;
                      if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_pk_f16_fp8_t16"
                        Mnemonic = "v_cvt_pk_f16_fp8";
                      return;
                    }
                    break;
                  }
                  break;
                case '3':	 // 6 strings to match.
                  if (memcmp(Mnemonic.data()+11, "2_", 2) != 0)
                    break;
                  switch (Mnemonic[13]) {
                  default: break;
                  case 'b':	 // 3 strings to match.
                    if (memcmp(Mnemonic.data()+14, "f8_", 3) != 0)
                      break;
                    switch (Mnemonic[17]) {
                    default: break;
                    case 'e':	 // 2 strings to match.
                      switch (Mnemonic[18]) {
                      default: break;
                      case '3':	 // 1 string to match.
                        if (Mnemonic[19] != '2')
                          break;
                        if (Features.test(Feature_HasFP8ConversionInstsBit))	 // "v_cvt_pk_f32_bf8_e32"
                          Mnemonic = "v_cvt_pk_f32_bf8";
                        return;
                      case '6':	 // 1 string to match.
                        if (Mnemonic[19] != '4')
                          break;
                        if (Features.test(Feature_HasFP8ConversionInstsBit))	 // "v_cvt_pk_f32_bf8_e64"
                          Mnemonic = "v_cvt_pk_f32_bf8";
                        return;
                      }
                      break;
                    case 't':	 // 1 string to match.
                      if (memcmp(Mnemonic.data()+18, "16", 2) != 0)
                        break;
                      if (Features.test(Feature_isGFX12OnlyBit))	 // "v_cvt_pk_f32_bf8_t16"
                        Mnemonic = "v_cvt_pk_f32_bf8";
                      return;
                    }
                    break;
                  case 'f':	 // 3 strings to match.
                    if (memcmp(Mnemonic.data()+14, "p8_", 3) != 0)
                      break;
                    switch (Mnemonic[17]) {
                    default: break;
                    case 'e':	 // 2 strings to match.
                      switch (Mnemonic[18]) {
                      default: break;
                      case '3':	 // 1 string to match.
                        if (Mnemonic[19] != '2')
                          break;
                        if (Features.test(Feature_HasFP8ConversionInstsBit))	 // "v_cvt_pk_f32_fp8_e32"
                          Mnemonic = "v_cvt_pk_f32_fp8";
                        return;
                      case '6':	 // 1 string to match.
                        if (Mnemonic[19] != '4')
                          break;
                        if (Features.test(Feature_HasFP8ConversionInstsBit))	 // "v_cvt_pk_f32_fp8_e64"
                          Mnemonic = "v_cvt_pk_f32_fp8";
                        return;
                      }
                      break;
                    case 't':	 // 1 string to match.
                      if (memcmp(Mnemonic.data()+18, "16", 2) != 0)
                        break;
                      if (Features.test(Feature_isGFX12OnlyBit))	 // "v_cvt_pk_f32_fp8_t16"
                        Mnemonic = "v_cvt_pk_f32_fp8";
                      return;
                    }
                    break;
                  }
                  break;
                case 'p':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+11, "8_f32_t16", 9) != 0)
                    break;
                  if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_pk_fp8_f32_t16"
                    Mnemonic = "v_cvt_pk_fp8_f32";
                  else if (Features.test(Feature_isGFX12Not12_50Bit))
                    Mnemonic = "v_cvt_pk_fp8_f32";
                  return;
                }
                break;
              }
              break;
            case 'n':	 // 4 strings to match.
              if (memcmp(Mnemonic.data()+9, "orm_", 4) != 0)
                break;
              switch (Mnemonic[13]) {
              default: break;
              case 'i':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+14, "16_f", 4) != 0)
                  break;
                switch (Mnemonic[18]) {
                default: break;
                case '1':	 // 1 string to match.
                  if (Mnemonic[19] != '6')
                    break;
                  if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_pknorm_i16_f16"
                    Mnemonic = "v_cvt_pk_norm_i16_f16";
                  else if (Features.test(Feature_isGFX12OnlyBit))
                    Mnemonic = "v_cvt_pk_norm_i16_f16";
                  else if (Features.test(Feature_isGFX11OnlyBit))
                    Mnemonic = "v_cvt_pk_norm_i16_f16";
                  else if (Features.test(Feature_isGFX12OnlyBit))
                    Mnemonic = "v_cvt_pk_norm_i16_f16";
                  return;
                case '3':	 // 1 string to match.
                  if (Mnemonic[19] != '2')
                    break;
                  if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_pknorm_i16_f32"
                    Mnemonic = "v_cvt_pk_norm_i16_f32";
                  else if (Features.test(Feature_isGFX12OnlyBit))
                    Mnemonic = "v_cvt_pk_norm_i16_f32";
                  return;
                }
                break;
              case 'u':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+14, "16_f", 4) != 0)
                  break;
                switch (Mnemonic[18]) {
                default: break;
                case '1':	 // 1 string to match.
                  if (Mnemonic[19] != '6')
                    break;
                  if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_pknorm_u16_f16"
                    Mnemonic = "v_cvt_pk_norm_u16_f16";
                  else if (Features.test(Feature_isGFX12OnlyBit))
                    Mnemonic = "v_cvt_pk_norm_u16_f16";
                  else if (Features.test(Feature_isGFX11OnlyBit))
                    Mnemonic = "v_cvt_pk_norm_u16_f16";
                  else if (Features.test(Feature_isGFX12OnlyBit))
                    Mnemonic = "v_cvt_pk_norm_u16_f16";
                  return;
                case '3':	 // 1 string to match.
                  if (Mnemonic[19] != '2')
                    break;
                  if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_pknorm_u16_f32"
                    Mnemonic = "v_cvt_pk_norm_u16_f32";
                  else if (Features.test(Feature_isGFX12OnlyBit))
                    Mnemonic = "v_cvt_pk_norm_u16_f32";
                  return;
                }
                break;
              }
              break;
            }
            break;
          case 's':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "r_", 2) != 0)
              break;
            switch (Mnemonic[9]) {
            default: break;
            case 'b':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "f8_f16_t16", 10) != 0)
                break;
              if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_sr_bf8_f16_t16"
                Mnemonic = "v_cvt_sr_bf8_f16";
              return;
            case 'f':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "p8_f16_t16", 10) != 0)
                break;
              if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_sr_fp8_f16_t16"
                Mnemonic = "v_cvt_sr_fp8_f16";
              return;
            }
            break;
          case 'u':	 // 2 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "6_f16_fake16", 12) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_u16_f16_fake16"
                Mnemonic = "v_cvt_u16_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cvt_u16_f16";
              return;
            case '3':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "2_u16_fake16", 12) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_u32_u16_fake16"
                Mnemonic = "v_cvt_u32_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cvt_u32_u16";
              return;
            }
            break;
          }
          break;
        }
        break;
      case 'e':	 // 4 strings to match.
        if (memcmp(Mnemonic.data()+3, "xp_", 3) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case 'f':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+7, "16_fake16_e", 11) != 0)
            break;
          switch (Mnemonic[18]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[19] != '2')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_exp_f16_fake16_e32"
              Mnemonic = "v_exp_f16_fake16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[19] != '4')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_exp_f16_fake16_e64"
              Mnemonic = "v_exp_f16_fake16";
            return;
          }
          break;
        case 'l':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+7, "egacy_f32_e", 11) != 0)
            break;
          switch (Mnemonic[18]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[19] != '2')
              break;
            if (Features.test(Feature_isGFX7GFX8GFX9Bit))	 // "v_exp_legacy_f32_e32"
              Mnemonic = "v_exp_legacy_f32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[19] != '4')
              break;
            if (Features.test(Feature_isGFX7GFX8GFX9Bit))	 // "v_exp_legacy_f32_e64"
              Mnemonic = "v_exp_legacy_f32";
            return;
          }
          break;
        }
        break;
      case 'f':	 // 9 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'l':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "oor_f16_t16_sdwa", 16) != 0)
            break;
          if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_floor_f16_t16_sdwa"
            Mnemonic = "v_floor_f16_t16";
          return;
        case 'r':	 // 8 strings to match.
          switch (Mnemonic[4]) {
          default: break;
          case 'a':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+5, "ct_f16_t16_sdwa", 15) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_fract_f16_t16_sdwa"
              Mnemonic = "v_fract_f16_t16";
            return;
          case 'e':	 // 7 strings to match.
            if (memcmp(Mnemonic.data()+5, "xp_mant_f", 9) != 0)
              break;
            switch (Mnemonic[14]) {
            default: break;
            case '1':	 // 3 strings to match.
              if (memcmp(Mnemonic.data()+15, "6_", 2) != 0)
                break;
              switch (Mnemonic[17]) {
              default: break;
              case 'e':	 // 2 strings to match.
                switch (Mnemonic[18]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[19] != '2')
                    break;
                  if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_frexp_mant_f16_e32"
                    Mnemonic = "v_frexp_mant_f16";
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[19] != '4')
                    break;
                  if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_frexp_mant_f16_e64"
                    Mnemonic = "v_frexp_mant_f16";
                  return;
                }
                break;
              case 't':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+18, "16", 2) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_frexp_mant_f16_t16"
                  Mnemonic = "v_frexp_mant_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_frexp_mant_f16";
                return;
              }
              break;
            case '3':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+15, "2_e", 3) != 0)
                break;
              switch (Mnemonic[18]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[19] != '2')
                  break;
                Mnemonic = "v_frexp_mant_f32";	 // "v_frexp_mant_f32_e32"
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[19] != '4')
                  break;
                Mnemonic = "v_frexp_mant_f32";	 // "v_frexp_mant_f32_e64"
                return;
              }
              break;
            case '6':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+15, "4_e", 3) != 0)
                break;
              switch (Mnemonic[18]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[19] != '2')
                  break;
                Mnemonic = "v_frexp_mant_f64";	 // "v_frexp_mant_f64_e32"
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[19] != '4')
                  break;
                Mnemonic = "v_frexp_mant_f64";	 // "v_frexp_mant_f64_e64"
                return;
              }
              break;
            }
            break;
          }
          break;
        }
        break;
      case 'l':	 // 8 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'o':	 // 5 strings to match.
          if (memcmp(Mnemonic.data()+4, "g_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'c':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "lamp_f32_sdwa", 13) != 0)
              break;
            if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_log_clamp_f32_sdwa"
              Mnemonic = "v_log_clamp_f32";
            return;
          case 'f':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "16_fake16_e", 11) != 0)
              break;
            switch (Mnemonic[18]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[19] != '2')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_log_f16_fake16_e32"
                Mnemonic = "v_log_f16_fake16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[19] != '4')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_log_f16_fake16_e64"
                Mnemonic = "v_log_f16_fake16";
              return;
            }
            break;
          case 'l':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "egacy_f32_e", 11) != 0)
              break;
            switch (Mnemonic[18]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[19] != '2')
                break;
              if (Features.test(Feature_isGFX7GFX8GFX9Bit))	 // "v_log_legacy_f32_e32"
                Mnemonic = "v_log_legacy_f32";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[19] != '4')
                break;
              if (Features.test(Feature_isGFX7GFX8GFX9Bit))	 // "v_log_legacy_f32_e64"
                Mnemonic = "v_log_legacy_f32";
              return;
            }
            break;
          }
          break;
        case 's':	 // 3 strings to match.
          if (Mnemonic[4] != 'h')
            break;
          switch (Mnemonic[5]) {
          default: break;
          case 'l':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+6, "rev_b", 5) != 0)
              break;
            switch (Mnemonic[11]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+12, "6_fake16", 8) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_lshlrev_b16_fake16"
                Mnemonic = "v_lshlrev_b16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_lshlrev_b16";
              return;
            case '6':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+12, "4_pseudo", 8) != 0)
                break;
              if (Features.test(Feature_isGFX12OnlyBit))	 // "v_lshlrev_b64_pseudo"
                Mnemonic = "v_lshlrev_b64";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_lshlrev_b64";
              return;
            }
            break;
          case 'r':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+6, "rev_b16_fake16", 14) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_lshrrev_b16_fake16"
              Mnemonic = "v_lshrrev_b16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_lshrrev_b16";
            return;
          }
          break;
        }
        break;
      case 'm':	 // 8 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 3 strings to match.
          switch (Mnemonic[4]) {
          default: break;
          case 'd':	 // 2 strings to match.
            if (Mnemonic[5] != '_')
              break;
            switch (Mnemonic[6]) {
            default: break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "32_i16_fake16", 13) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_mad_i32_i16_fake16"
                Mnemonic = "v_mad_i32_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_mad_i32_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "32_u16_fake16", 13) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_mad_u32_u16_fake16"
                Mnemonic = "v_mad_u32_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_mad_u32_u16";
              return;
            }
            break;
          case 'x':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+5, "imum_f16_fake16", 15) != 0)
              break;
            if (Features.test(Feature_isGFX12OnlyBit))	 // "v_maximum_f16_fake16"
              Mnemonic = "v_maximum_f16";
            return;
          }
          break;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "nimum_f16_fake16", 16) != 0)
            break;
          if (Features.test(Feature_isGFX12OnlyBit))	 // "v_minimum_f16_fake16"
            Mnemonic = "v_minimum_f16";
          return;
        case 'o':	 // 4 strings to match.
          if (Mnemonic[4] != 'v')
            break;
          switch (Mnemonic[5]) {
          default: break;
          case '_':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+6, "b16_fake16_e", 12) != 0)
              break;
            switch (Mnemonic[18]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[19] != '2')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_mov_b16_fake16_e32"
                Mnemonic = "v_mov_b16_fake16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[19] != '4')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_mov_b16_fake16_e64"
                Mnemonic = "v_mov_b16_fake16";
              return;
            }
            break;
          case 'r':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+6, "elsd_2_b32_e", 12) != 0)
              break;
            switch (Mnemonic[18]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[19] != '2')
                break;
              if (Features.test(Feature_isGFX10PlusBit))	 // "v_movrelsd_2_b32_e32"
                Mnemonic = "v_movrelsd_2_b32";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[19] != '4')
                break;
              if (Features.test(Feature_isGFX10PlusBit))	 // "v_movrelsd_2_b32_e64"
                Mnemonic = "v_movrelsd_2_b32";
              return;
            }
            break;
          }
          break;
        }
        break;
      case 'n':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+3, "ot_b16_fake16_e", 15) != 0)
          break;
        switch (Mnemonic[18]) {
        default: break;
        case '3':	 // 1 string to match.
          if (Mnemonic[19] != '2')
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_not_b16_fake16_e32"
            Mnemonic = "v_not_b16_fake16";
          return;
        case '6':	 // 1 string to match.
          if (Mnemonic[19] != '4')
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_not_b16_fake16_e64"
            Mnemonic = "v_not_b16_fake16";
          return;
        }
        break;
      case 'r':	 // 12 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'c':	 // 6 strings to match.
          if (memcmp(Mnemonic.data()+4, "p_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'c':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "lamp_f32_sdwa", 13) != 0)
              break;
            if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_rcp_clamp_f32_sdwa"
              Mnemonic = "v_rcp_clamp_f32";
            return;
          case 'f':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "16_fake16_e", 11) != 0)
              break;
            switch (Mnemonic[18]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[19] != '2')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_rcp_f16_fake16_e32"
                Mnemonic = "v_rcp_f16_fake16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[19] != '4')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_rcp_f16_fake16_e64"
                Mnemonic = "v_rcp_f16_fake16";
              return;
            }
            break;
          case 'i':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "flag_f32_sdwa", 13) != 0)
              break;
            Mnemonic = "v_rcp_iflag_f32";	 // "v_rcp_iflag_f32_sdwa"
            return;
          case 'l':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "egacy_f32_e", 11) != 0)
              break;
            switch (Mnemonic[18]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[19] != '2')
                break;
              if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_rcp_legacy_f32_e32"
                Mnemonic = "v_rcp_legacy_f32";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[19] != '4')
                break;
              if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_rcp_legacy_f32_e64"
                Mnemonic = "v_rcp_legacy_f32";
              return;
            }
            break;
          }
          break;
        case 'n':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "dne_f16_t16_sdwa", 16) != 0)
            break;
          if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_rndne_f16_t16_sdwa"
            Mnemonic = "v_rndne_f16_t16";
          return;
        case 's':	 // 5 strings to match.
          if (memcmp(Mnemonic.data()+4, "q_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'c':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "lamp_f32_sdwa", 13) != 0)
              break;
            if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_rsq_clamp_f32_sdwa"
              Mnemonic = "v_rsq_clamp_f32";
            return;
          case 'f':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "16_fake16_e", 11) != 0)
              break;
            switch (Mnemonic[18]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[19] != '2')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_rsq_f16_fake16_e32"
                Mnemonic = "v_rsq_f16_fake16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[19] != '4')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_rsq_f16_fake16_e64"
                Mnemonic = "v_rsq_f16_fake16";
              return;
            }
            break;
          case 'l':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "egacy_f32_e", 11) != 0)
              break;
            switch (Mnemonic[18]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[19] != '2')
                break;
              if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_rsq_legacy_f32_e32"
                Mnemonic = "v_rsq_legacy_f32";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[19] != '4')
                break;
              if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_rsq_legacy_f32_e64"
                Mnemonic = "v_rsq_legacy_f32";
              return;
            }
            break;
          }
          break;
        }
        break;
      case 's':	 // 6 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "t_pk", 4) != 0)
            break;
          switch (Mnemonic[8]) {
          default: break;
          case '4':	 // 2 strings to match.
            if (Mnemonic[9] != '_')
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "4_i8_sdwa", 9) != 0)
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_i4_i8_sdwa"
                Mnemonic = "v_sat_pk4_i4_i8";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "4_u8_sdwa", 9) != 0)
                break;
              if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_u4_u8_sdwa"
                Mnemonic = "v_sat_pk4_u4_u8";
              return;
            }
            break;
          case '_':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+9, "u8_i16_sdwa", 11) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_isGFX9PlusBit))	 // "v_sat_pk_u8_i16_sdwa"
              Mnemonic = "v_sat_pk_u8_i16";
            return;
          }
          break;
        case 'i':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "n_f16_fake16_e", 14) != 0)
            break;
          switch (Mnemonic[18]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[19] != '2')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_sin_f16_fake16_e32"
              Mnemonic = "v_sin_f16_fake16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[19] != '4')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_sin_f16_fake16_e64"
              Mnemonic = "v_sin_f16_fake16";
            return;
          }
          break;
        case 'q':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "rt_bf16_t16_sdwa", 16) != 0)
            break;
          if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sqrt_bf16_t16_sdwa"
            Mnemonic = "v_sqrt_bf16_t16";
          return;
        }
        break;
      case 't':	 // 2 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "nh_bf16_t16_sdwa", 16) != 0)
            break;
          if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_tanh_bf16_t16_sdwa"
            Mnemonic = "v_tanh_bf16_t16";
          return;
        case 'r':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "unc_f16_t16_sdwa", 16) != 0)
            break;
          if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_trunc_f16_t16_sdwa"
            Mnemonic = "v_trunc_f16_t16";
          return;
        }
        break;
      }
      break;
    }
    break;
  case 21:	 // 107 strings to match.
    switch (Mnemonic[0]) {
    default: break;
    case 'b':	 // 13 strings to match.
      if (memcmp(Mnemonic.data()+1, "uffer_", 6) != 0)
        break;
      switch (Mnemonic[7]) {
      default: break;
      case 'a':	 // 10 strings to match.
        if (memcmp(Mnemonic.data()+8, "tomic_", 6) != 0)
          break;
        switch (Mnemonic[14]) {
        default: break;
        case 'c':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+15, "mpswap", 6) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_cmpswap"
            Mnemonic = "buffer_atomic_cmpswap_b32";
          else if (Features.test(Feature_isGFX12PlusBit))
            Mnemonic = "buffer_atomic_cmpswap_b32";
          return;
        case 'm':	 // 4 strings to match.
          switch (Mnemonic[15]) {
          default: break;
          case 'a':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+16, "x_f", 3) != 0)
              break;
            switch (Mnemonic[19]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[20] != '2')
                break;
              if (Features.test(Feature_isGFX12PlusBit))	 // "buffer_atomic_max_f32"
                Mnemonic = "buffer_atomic_max_num_f32";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[20] != '4')
                break;
              if (Features.test(Feature_isGFX12PlusBit))	 // "buffer_atomic_max_f64"
                Mnemonic = "buffer_atomic_max_num_f64";
              return;
            }
            break;
          case 'i':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+16, "n_f", 3) != 0)
              break;
            switch (Mnemonic[19]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[20] != '2')
                break;
              if (Features.test(Feature_isGFX12PlusBit))	 // "buffer_atomic_min_f32"
                Mnemonic = "buffer_atomic_min_num_f32";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[20] != '4')
                break;
              if (Features.test(Feature_isGFX12PlusBit))	 // "buffer_atomic_min_f64"
                Mnemonic = "buffer_atomic_min_num_f64";
              return;
            }
            break;
          }
          break;
        case 's':	 // 3 strings to match.
          switch (Mnemonic[15]) {
          default: break;
          case 'm':	 // 2 strings to match.
            switch (Mnemonic[16]) {
            default: break;
            case 'a':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+17, "x_x2", 4) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_smax_x2"
                Mnemonic = "buffer_atomic_max_i64";
              else if (Features.test(Feature_isGFX12PlusBit))
                Mnemonic = "buffer_atomic_max_i64";
              return;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+17, "n_x2", 4) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_smin_x2"
                Mnemonic = "buffer_atomic_min_i64";
              else if (Features.test(Feature_isGFX12PlusBit))
                Mnemonic = "buffer_atomic_min_i64";
              return;
            }
            break;
          case 'w':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+16, "ap_x2", 5) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_swap_x2"
              Mnemonic = "buffer_atomic_swap_b64";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "buffer_atomic_swap_b64";
            return;
          }
          break;
        case 'u':	 // 2 strings to match.
          if (Mnemonic[15] != 'm')
            break;
          switch (Mnemonic[16]) {
          default: break;
          case 'a':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+17, "x_x2", 4) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_umax_x2"
              Mnemonic = "buffer_atomic_max_u64";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "buffer_atomic_max_u64";
            return;
          case 'i':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+17, "n_x2", 4) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_umin_x2"
              Mnemonic = "buffer_atomic_min_u64";
            else if (Features.test(Feature_isGFX12PlusBit))
              Mnemonic = "buffer_atomic_min_u64";
            return;
          }
          break;
        }
        break;
      case 'l':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+8, "oad_", 4) != 0)
          break;
        switch (Mnemonic[12]) {
        default: break;
        case 's':	 // 2 strings to match.
          switch (Mnemonic[13]) {
          default: break;
          case 'b':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "yte_d16", 7) != 0)
              break;
            if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_load_sbyte_d16"
              Mnemonic = "buffer_load_d16_i8";
            return;
          case 'h':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "ort_d16", 7) != 0)
              break;
            if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_load_short_d16"
              Mnemonic = "buffer_load_d16_b16";
            return;
          }
          break;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "byte_d16", 8) != 0)
            break;
          if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_load_ubyte_d16"
            Mnemonic = "buffer_load_d16_u8";
          return;
        }
        break;
      }
      break;
    case 'g':	 // 16 strings to match.
      if (memcmp(Mnemonic.data()+1, "lobal_", 6) != 0)
        break;
      switch (Mnemonic[7]) {
      default: break;
      case 'a':	 // 10 strings to match.
        if (memcmp(Mnemonic.data()+8, "tomic_", 6) != 0)
          break;
        switch (Mnemonic[14]) {
        default: break;
        case 'c':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+15, "mpswap", 6) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_cmpswap"
            Mnemonic = "global_atomic_cmpswap_b32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_atomic_cmpswap_b32";
          return;
        case 'm':	 // 4 strings to match.
          switch (Mnemonic[15]) {
          default: break;
          case 'a':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+16, "x_f", 3) != 0)
              break;
            switch (Mnemonic[19]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[20] != '2')
                break;
              if (Features.test(Feature_isGFX12OnlyBit))	 // "global_atomic_max_f32"
                Mnemonic = "global_atomic_max_num_f32";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[20] != '4')
                break;
              if (Features.test(Feature_isGFX125xOnlyBit))	 // "global_atomic_max_f64"
                Mnemonic = "global_atomic_max_num_f64";
              return;
            }
            break;
          case 'i':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+16, "n_f", 3) != 0)
              break;
            switch (Mnemonic[19]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[20] != '2')
                break;
              if (Features.test(Feature_isGFX12OnlyBit))	 // "global_atomic_min_f32"
                Mnemonic = "global_atomic_min_num_f32";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[20] != '4')
                break;
              if (Features.test(Feature_isGFX125xOnlyBit))	 // "global_atomic_min_f64"
                Mnemonic = "global_atomic_min_num_f64";
              return;
            }
            break;
          }
          break;
        case 's':	 // 3 strings to match.
          switch (Mnemonic[15]) {
          default: break;
          case 'm':	 // 2 strings to match.
            switch (Mnemonic[16]) {
            default: break;
            case 'a':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+17, "x_x2", 4) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_smax_x2"
                Mnemonic = "global_atomic_max_i64";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "global_atomic_max_i64";
              return;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+17, "n_x2", 4) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_smin_x2"
                Mnemonic = "global_atomic_min_i64";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "global_atomic_min_i64";
              return;
            }
            break;
          case 'w':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+16, "ap_x2", 5) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_swap_x2"
              Mnemonic = "global_atomic_swap_b64";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "global_atomic_swap_b64";
            return;
          }
          break;
        case 'u':	 // 2 strings to match.
          if (Mnemonic[15] != 'm')
            break;
          switch (Mnemonic[16]) {
          default: break;
          case 'a':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+17, "x_x2", 4) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_umax_x2"
              Mnemonic = "global_atomic_max_u64";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "global_atomic_max_u64";
            return;
          case 'i':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+17, "n_x2", 4) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_umin_x2"
              Mnemonic = "global_atomic_min_u64";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "global_atomic_min_u64";
            return;
          }
          break;
        }
        break;
      case 'l':	 // 6 strings to match.
        if (memcmp(Mnemonic.data()+8, "oad_", 4) != 0)
          break;
        switch (Mnemonic[12]) {
        default: break;
        case 'b':	 // 3 strings to match.
          switch (Mnemonic[13]) {
          default: break;
          case '6':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+14, "4_tr_b", 6) != 0)
              break;
            switch (Mnemonic[20]) {
            default: break;
            case '4':	 // 1 string to match.
              if (Features.test(Feature_isGFX125xOnlyBit))	 // "global_load_b64_tr_b4"
                Mnemonic = "global_load_tr4_b64";
              return;
            case '8':	 // 1 string to match.
              if (Features.test(Feature_isGFX125xOnlyBit))	 // "global_load_b64_tr_b8"
                Mnemonic = "global_load_tr8_b64";
              return;
            }
            break;
          case '9':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "6_tr_b6", 7) != 0)
              break;
            if (Features.test(Feature_isGFX125xOnlyBit))	 // "global_load_b96_tr_b6"
              Mnemonic = "global_load_tr6_b96";
            return;
          }
          break;
        case 's':	 // 2 strings to match.
          switch (Mnemonic[13]) {
          default: break;
          case 'b':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "yte_d16", 7) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "global_load_sbyte_d16"
              Mnemonic = "global_load_d16_i8";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "global_load_d16_i8";
            return;
          case 'h':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "ort_d16", 7) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "global_load_short_d16"
              Mnemonic = "global_load_d16_b16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "global_load_d16_b16";
            return;
          }
          break;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "byte_d16", 8) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_load_ubyte_d16"
            Mnemonic = "global_load_d16_u8";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_load_d16_u8";
          return;
        }
        break;
      }
      break;
    case 's':	 // 6 strings to match.
      switch (Mnemonic[1]) {
      default: break;
      case '_':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+2, "buffer_load_dwordx", 18) != 0)
          break;
        switch (Mnemonic[20]) {
        default: break;
        case '2':	 // 1 string to match.
          if (Features.test(Feature_isGFX11PlusBit))	 // "s_buffer_load_dwordx2"
            Mnemonic = "s_buffer_load_b64";
          return;
        case '4':	 // 1 string to match.
          if (Features.test(Feature_isGFX11PlusBit))	 // "s_buffer_load_dwordx4"
            Mnemonic = "s_buffer_load_b128";
          return;
        case '8':	 // 1 string to match.
          if (Features.test(Feature_isGFX11PlusBit))	 // "s_buffer_load_dwordx8"
            Mnemonic = "s_buffer_load_b256";
          return;
        }
        break;
      case 'c':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+2, "ratch_store_dwordx", 18) != 0)
          break;
        switch (Mnemonic[20]) {
        default: break;
        case '2':	 // 1 string to match.
          if (Features.test(Feature_isGFX11OnlyBit))	 // "scratch_store_dwordx2"
            Mnemonic = "scratch_store_b64";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "scratch_store_b64";
          return;
        case '3':	 // 1 string to match.
          if (Features.test(Feature_isGFX11OnlyBit))	 // "scratch_store_dwordx3"
            Mnemonic = "scratch_store_b96";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "scratch_store_b96";
          return;
        case '4':	 // 1 string to match.
          if (Features.test(Feature_isGFX11OnlyBit))	 // "scratch_store_dwordx4"
            Mnemonic = "scratch_store_b128";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "scratch_store_b128";
          return;
        }
        break;
      }
      break;
    case 'v':	 // 72 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'a':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "lignbit_b32_fake16", 18) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_alignbit_b32_fake16"
          Mnemonic = "v_alignbit_b32";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_alignbit_b32";
        return;
      case 'c':	 // 37 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'e':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "il_f16_fake16_e", 15) != 0)
            break;
          switch (Mnemonic[19]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[20] != '2')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_ceil_f16_fake16_e32"
              Mnemonic = "v_ceil_f16_fake16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[20] != '4')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_ceil_f16_fake16_e64"
              Mnemonic = "v_ceil_f16_fake16";
            return;
          }
          break;
        case 'o':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "s_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'b':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "f16_fake16_e", 12) != 0)
              break;
            switch (Mnemonic[19]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[20] != '2')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_cos_bf16_fake16_e32"
                Mnemonic = "v_cos_bf16_fake16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[20] != '4')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_cos_bf16_fake16_e64"
                Mnemonic = "v_cos_bf16_fake16";
              return;
            }
            break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "16_fake16_sdwa", 14) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cos_f16_fake16_sdwa"
              Mnemonic = "v_cos_f16_fake16";
            return;
          }
          break;
        case 'v':	 // 32 strings to match.
          if (memcmp(Mnemonic.data()+4, "t_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'f':	 // 19 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 10 strings to match.
              if (memcmp(Mnemonic.data()+8, "6_", 2) != 0)
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'b':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+11, "f8_t16_e", 8) != 0)
                  break;
                switch (Mnemonic[19]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[20] != '2')
                    break;
                  if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_f16_bf8_t16_e32"
                    Mnemonic = "v_cvt_f16_bf8_t16";
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[20] != '4')
                    break;
                  if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_f16_bf8_t16_e64"
                    Mnemonic = "v_cvt_f16_bf8_t16";
                  return;
                }
                break;
              case 'f':	 // 4 strings to match.
                switch (Mnemonic[11]) {
                default: break;
                case '3':	 // 2 strings to match.
                  if (memcmp(Mnemonic.data()+12, "2_t16_e", 7) != 0)
                    break;
                  switch (Mnemonic[19]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (Mnemonic[20] != '2')
                      break;
                    if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_f16_f32_t16_e32"
                      Mnemonic = "v_cvt_f16_f32_t16";
                    return;
                  case '6':	 // 1 string to match.
                    if (Mnemonic[20] != '4')
                      break;
                    if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_f16_f32_t16_e64"
                      Mnemonic = "v_cvt_f16_f32_t16";
                    return;
                  }
                  break;
                case 'p':	 // 2 strings to match.
                  if (memcmp(Mnemonic.data()+12, "8_t16_e", 7) != 0)
                    break;
                  switch (Mnemonic[19]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (Mnemonic[20] != '2')
                      break;
                    if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_f16_fp8_t16_e32"
                      Mnemonic = "v_cvt_f16_fp8_t16";
                    return;
                  case '6':	 // 1 string to match.
                    if (Mnemonic[20] != '4')
                      break;
                    if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_f16_fp8_t16_e64"
                      Mnemonic = "v_cvt_f16_fp8_t16";
                    return;
                  }
                  break;
                }
                break;
              case 'i':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+11, "16_t16_e", 8) != 0)
                  break;
                switch (Mnemonic[19]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[20] != '2')
                    break;
                  if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_f16_i16_t16_e32"
                    Mnemonic = "v_cvt_f16_i16_t16";
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[20] != '4')
                    break;
                  if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_f16_i16_t16_e64"
                    Mnemonic = "v_cvt_f16_i16_t16";
                  return;
                }
                break;
              case 'u':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+11, "16_t16_e", 8) != 0)
                  break;
                switch (Mnemonic[19]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[20] != '2')
                    break;
                  if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_f16_u16_t16_e32"
                    Mnemonic = "v_cvt_f16_u16_t16";
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[20] != '4')
                    break;
                  if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_f16_u16_t16_e64"
                    Mnemonic = "v_cvt_f16_u16_t16";
                  return;
                }
                break;
              }
              break;
            case '3':	 // 7 strings to match.
              if (memcmp(Mnemonic.data()+8, "2_", 2) != 0)
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'f':	 // 3 strings to match.
                switch (Mnemonic[11]) {
                default: break;
                case '1':	 // 2 strings to match.
                  if (memcmp(Mnemonic.data()+12, "6_t16_e", 7) != 0)
                    break;
                  switch (Mnemonic[19]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (Mnemonic[20] != '2')
                      break;
                    if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_f32_f16_t16_e32"
                      Mnemonic = "v_cvt_f32_f16_t16";
                    return;
                  case '6':	 // 1 string to match.
                    if (Mnemonic[20] != '4')
                      break;
                    if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_f32_f16_t16_e64"
                      Mnemonic = "v_cvt_f32_f16_t16";
                    return;
                  }
                  break;
                case 'p':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+12, "8_gfx1250", 9) != 0)
                    break;
                  if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_f32_fp8_gfx1250"
                    Mnemonic = "v_cvt_f32_fp8";
                  return;
                }
                break;
              case 'u':	 // 4 strings to match.
                if (memcmp(Mnemonic.data()+11, "byte", 4) != 0)
                  break;
                switch (Mnemonic[15]) {
                default: break;
                case '0':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+16, "_sdwa", 5) != 0)
                    break;
                  Mnemonic = "v_cvt_f32_ubyte0";	 // "v_cvt_f32_ubyte0_sdwa"
                  return;
                case '1':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+16, "_sdwa", 5) != 0)
                    break;
                  Mnemonic = "v_cvt_f32_ubyte1";	 // "v_cvt_f32_ubyte1_sdwa"
                  return;
                case '2':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+16, "_sdwa", 5) != 0)
                    break;
                  Mnemonic = "v_cvt_f32_ubyte2";	 // "v_cvt_f32_ubyte2_sdwa"
                  return;
                case '3':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+16, "_sdwa", 5) != 0)
                    break;
                  Mnemonic = "v_cvt_f32_ubyte3";	 // "v_cvt_f32_ubyte3_sdwa"
                  return;
                }
                break;
              }
              break;
            case 'l':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+8, "r_i32_f32_e", 11) != 0)
                break;
              switch (Mnemonic[19]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[20] != '2')
                  break;
                Mnemonic = "v_cvt_flr_i32_f32";	 // "v_cvt_flr_i32_f32_e32"
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[20] != '4')
                  break;
                Mnemonic = "v_cvt_flr_i32_f32";	 // "v_cvt_flr_i32_f32_e64"
                return;
              }
              break;
            }
            break;
          case 'i':	 // 4 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+8, "6_f16_t16_e", 11) != 0)
                break;
              switch (Mnemonic[19]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[20] != '2')
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_i16_f16_t16_e32"
                  Mnemonic = "v_cvt_i16_f16_t16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[20] != '4')
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_i16_f16_t16_e64"
                  Mnemonic = "v_cvt_i16_f16_t16";
                return;
              }
              break;
            case '3':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+8, "2_i16_t16_e", 11) != 0)
                break;
              switch (Mnemonic[19]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[20] != '2')
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_i32_i16_t16_e32"
                  Mnemonic = "v_cvt_i32_i16_t16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[20] != '4')
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_i32_i16_t16_e64"
                  Mnemonic = "v_cvt_i32_i16_t16";
                return;
              }
              break;
            }
            break;
          case 'o':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "ff_f32_i4_sdwa", 14) != 0)
              break;
            Mnemonic = "v_cvt_off_f32_i4";	 // "v_cvt_off_f32_i4_sdwa"
            return;
          case 'p':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "k_f32_", 6) != 0)
              break;
            switch (Mnemonic[13]) {
            default: break;
            case 'b':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+14, "f8_sdwa", 7) != 0)
                break;
              if (Features.test(Feature_HasFP8ConversionInstsBit))	 // "v_cvt_pk_f32_bf8_sdwa"
                Mnemonic = "v_cvt_pk_f32_bf8";
              return;
            case 'f':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+14, "p8_sdwa", 7) != 0)
                break;
              if (Features.test(Feature_HasFP8ConversionInstsBit))	 // "v_cvt_pk_f32_fp8_sdwa"
                Mnemonic = "v_cvt_pk_f32_fp8";
              return;
            }
            break;
          case 'r':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "pi_i32_f32_e", 12) != 0)
              break;
            switch (Mnemonic[19]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[20] != '2')
                break;
              Mnemonic = "v_cvt_rpi_i32_f32";	 // "v_cvt_rpi_i32_f32_e32"
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[20] != '4')
                break;
              Mnemonic = "v_cvt_rpi_i32_f32";	 // "v_cvt_rpi_i32_f32_e64"
              return;
            }
            break;
          case 'u':	 // 4 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+8, "6_f16_t16_e", 11) != 0)
                break;
              switch (Mnemonic[19]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[20] != '2')
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_u16_f16_t16_e32"
                  Mnemonic = "v_cvt_u16_f16_t16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[20] != '4')
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_u16_f16_t16_e64"
                  Mnemonic = "v_cvt_u16_f16_t16";
                return;
              }
              break;
            case '3':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+8, "2_u16_t16_e", 11) != 0)
                break;
              switch (Mnemonic[19]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[20] != '2')
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_u32_u16_t16_e32"
                  Mnemonic = "v_cvt_u32_u16_t16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[20] != '4')
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_u32_u16_t16_e64"
                  Mnemonic = "v_cvt_u32_u16_t16";
                return;
              }
              break;
            }
            break;
          }
          break;
        }
        break;
      case 'e':	 // 4 strings to match.
        if (memcmp(Mnemonic.data()+3, "xp_", 3) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case 'b':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+7, "f16_fake16_e", 12) != 0)
            break;
          switch (Mnemonic[19]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[20] != '2')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_exp_bf16_fake16_e32"
              Mnemonic = "v_exp_bf16_fake16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[20] != '4')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_exp_bf16_fake16_e64"
              Mnemonic = "v_exp_bf16_fake16";
            return;
          }
          break;
        case 'f':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "16_fake16_sdwa", 14) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_exp_f16_fake16_sdwa"
            Mnemonic = "v_exp_f16_fake16";
          return;
        case 'l':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "egacy_f32_sdwa", 14) != 0)
            break;
          if (Features.test(Feature_isGFX7GFX8GFX9Bit))	 // "v_exp_legacy_f32_sdwa"
            Mnemonic = "v_exp_legacy_f32";
          return;
        }
        break;
      case 'f':	 // 3 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'm':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "a_f16_gfx9_fake16", 17) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "v_fma_f16_gfx9_fake16"
            Mnemonic = "v_fma_f16";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "v_fma_f16";
          return;
        case 'r':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "exp_mant_f", 10) != 0)
            break;
          switch (Mnemonic[14]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+15, "6_sdwa", 6) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_frexp_mant_f16_sdwa"
              Mnemonic = "v_frexp_mant_f16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+15, "2_sdwa", 6) != 0)
              break;
            Mnemonic = "v_frexp_mant_f32";	 // "v_frexp_mant_f32_sdwa"
            return;
          }
          break;
        }
        break;
      case 'l':	 // 4 strings to match.
        if (memcmp(Mnemonic.data()+3, "og_", 3) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case 'b':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+7, "f16_fake16_e", 12) != 0)
            break;
          switch (Mnemonic[19]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[20] != '2')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_log_bf16_fake16_e32"
              Mnemonic = "v_log_bf16_fake16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[20] != '4')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_log_bf16_fake16_e64"
              Mnemonic = "v_log_bf16_fake16";
            return;
          }
          break;
        case 'f':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "16_fake16_sdwa", 14) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_log_f16_fake16_sdwa"
            Mnemonic = "v_log_f16_fake16";
          return;
        case 'l':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "egacy_f32_sdwa", 14) != 0)
            break;
          if (Features.test(Feature_isGFX7GFX8GFX9Bit))	 // "v_log_legacy_f32_sdwa"
            Mnemonic = "v_log_legacy_f32";
          return;
        }
        break;
      case 'm':	 // 6 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 3 strings to match.
          switch (Mnemonic[4]) {
          default: break;
          case 'd':	 // 2 strings to match.
            if (Mnemonic[5] != '_')
              break;
            switch (Mnemonic[6]) {
            default: break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "16_gfx9_fake16", 14) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_mad_i16_gfx9_fake16"
                Mnemonic = "v_mad_i16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_mad_i16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+7, "16_gfx9_fake16", 14) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_mad_u16_gfx9_fake16"
                Mnemonic = "v_mad_u16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_mad_u16";
              return;
            }
            break;
          case 'x':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+5, "imum3_f16_fake16", 16) != 0)
              break;
            if (Features.test(Feature_isGFX12OnlyBit))	 // "v_maximum3_f16_fake16"
              Mnemonic = "v_maximum3_f16";
            return;
          }
          break;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "nimum3_f16_fake16", 17) != 0)
            break;
          if (Features.test(Feature_isGFX12OnlyBit))	 // "v_minimum3_f16_fake16"
            Mnemonic = "v_minimum3_f16";
          return;
        case 'o':	 // 2 strings to match.
          if (Mnemonic[4] != 'v')
            break;
          switch (Mnemonic[5]) {
          default: break;
          case '_':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+6, "b16_fake16_sdwa", 15) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_mov_b16_fake16_sdwa"
              Mnemonic = "v_mov_b16_fake16";
            return;
          case 'r':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+6, "elsd_2_b32_sdwa", 15) != 0)
              break;
            if (Features.test(Feature_isGFX10PlusBit))	 // "v_movrelsd_2_b32_sdwa"
              Mnemonic = "v_movrelsd_2_b32";
            return;
          }
          break;
        }
        break;
      case 'n':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "ot_b16_fake16_sdwa", 18) != 0)
          break;
        if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_not_b16_fake16_sdwa"
          Mnemonic = "v_not_b16_fake16";
        return;
      case 'p':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "ack_b32_f16_fake16", 18) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_pack_b32_f16_fake16"
          Mnemonic = "v_pack_b32_f16";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_pack_b32_f16";
        return;
      case 'r':	 // 8 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'c':	 // 4 strings to match.
          if (memcmp(Mnemonic.data()+4, "p_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'b':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "f16_fake16_e", 12) != 0)
              break;
            switch (Mnemonic[19]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[20] != '2')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rcp_bf16_fake16_e32"
                Mnemonic = "v_rcp_bf16_fake16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[20] != '4')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rcp_bf16_fake16_e64"
                Mnemonic = "v_rcp_bf16_fake16";
              return;
            }
            break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "16_fake16_sdwa", 14) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_rcp_f16_fake16_sdwa"
              Mnemonic = "v_rcp_f16_fake16";
            return;
          case 'l':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "egacy_f32_sdwa", 14) != 0)
              break;
            if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_rcp_legacy_f32_sdwa"
              Mnemonic = "v_rcp_legacy_f32";
            return;
          }
          break;
        case 's':	 // 4 strings to match.
          if (memcmp(Mnemonic.data()+4, "q_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'b':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "f16_fake16_e", 12) != 0)
              break;
            switch (Mnemonic[19]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[20] != '2')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rsq_bf16_fake16_e32"
                Mnemonic = "v_rsq_bf16_fake16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[20] != '4')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rsq_bf16_fake16_e64"
                Mnemonic = "v_rsq_bf16_fake16";
              return;
            }
            break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "16_fake16_sdwa", 14) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_rsq_f16_fake16_sdwa"
              Mnemonic = "v_rsq_f16_fake16";
            return;
          case 'l':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "egacy_f32_sdwa", 14) != 0)
              break;
            if (Features.test(Feature_isGFX6GFX7Bit))	 // "v_rsq_legacy_f32_sdwa"
              Mnemonic = "v_rsq_legacy_f32";
            return;
          }
          break;
        }
        break;
      case 's':	 // 5 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'i':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "n_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'b':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "f16_fake16_e", 12) != 0)
              break;
            switch (Mnemonic[19]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[20] != '2')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sin_bf16_fake16_e32"
                Mnemonic = "v_sin_bf16_fake16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[20] != '4')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sin_bf16_fake16_e64"
                Mnemonic = "v_sin_bf16_fake16";
              return;
            }
            break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "16_fake16_sdwa", 14) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_sin_f16_fake16_sdwa"
              Mnemonic = "v_sin_f16_fake16";
            return;
          }
          break;
        case 'q':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "rt_f16_fake16_e", 15) != 0)
            break;
          switch (Mnemonic[19]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[20] != '2')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_sqrt_f16_fake16_e32"
              Mnemonic = "v_sqrt_f16_fake16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[20] != '4')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_sqrt_f16_fake16_e64"
              Mnemonic = "v_sqrt_f16_fake16";
            return;
          }
          break;
        }
        break;
      case 't':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+3, "anh_f16_fake16_e", 16) != 0)
          break;
        switch (Mnemonic[19]) {
        default: break;
        case '3':	 // 1 string to match.
          if (Mnemonic[20] != '2')
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasTanhInstsBit))	 // "v_tanh_f16_fake16_e32"
            Mnemonic = "v_tanh_f16_fake16";
          return;
        case '6':	 // 1 string to match.
          if (Mnemonic[20] != '4')
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasTanhInstsBit))	 // "v_tanh_f16_fake16_e64"
            Mnemonic = "v_tanh_f16_fake16";
          return;
        }
        break;
      }
      break;
    }
    break;
  case 22:	 // 63 strings to match.
    switch (Mnemonic[0]) {
    default: break;
    case 'b':	 // 3 strings to match.
      switch (Mnemonic[1]) {
      default: break;
      case 'u':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+2, "ffer_atomic_", 12) != 0)
          break;
        switch (Mnemonic[14]) {
        default: break;
        case 'c':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+15, "sub_u32", 7) != 0)
            break;
          if (Features.test(Feature_isGFX12PlusBit))	 // "buffer_atomic_csub_u32"
            Mnemonic = "buffer_atomic_sub_clamp_u32";
          return;
        case 'f':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+15, "cmpswap", 7) != 0)
            break;
          if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_atomic_fcmpswap"
            Mnemonic = "buffer_atomic_cmpswap_f32";
          return;
        }
        break;
      case 'v':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+2, "h_dual_intersect_ray", 20) != 0)
          break;
        if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))	 // "bvh_dual_intersect_ray"
          Mnemonic = "image_bvh_dual_intersect_ray";
        return;
      }
      break;
    case 'd':	 // 2 strings to match.
      if (memcmp(Mnemonic.data()+1, "s_wrxchg2st64_rtn_b", 19) != 0)
        break;
      switch (Mnemonic[20]) {
      default: break;
      case '3':	 // 1 string to match.
        if (Mnemonic[21] != '2')
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_wrxchg2st64_rtn_b32"
          Mnemonic = "ds_storexchg_2addr_stride64_rtn_b32";
        else if (Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "ds_storexchg_2addr_stride64_rtn_b32";
        return;
      case '6':	 // 1 string to match.
        if (Mnemonic[21] != '4')
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "ds_wrxchg2st64_rtn_b64"
          Mnemonic = "ds_storexchg_2addr_stride64_rtn_b64";
        else if (Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "ds_storexchg_2addr_stride64_rtn_b64";
        return;
      }
      break;
    case 'f':	 // 5 strings to match.
      if (memcmp(Mnemonic.data()+1, "lat_", 4) != 0)
        break;
      switch (Mnemonic[5]) {
      default: break;
      case 'a':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+6, "tomic_cmpswap_x2", 16) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_atomic_cmpswap_x2"
          Mnemonic = "flat_atomic_cmpswap_b64";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "flat_atomic_cmpswap_b64";
        return;
      case 'l':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+6, "oad_", 4) != 0)
          break;
        switch (Mnemonic[10]) {
        default: break;
        case 's':	 // 2 strings to match.
          switch (Mnemonic[11]) {
          default: break;
          case 'b':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+12, "yte_d16_hi", 10) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_load_sbyte_d16_hi"
              Mnemonic = "flat_load_d16_hi_i8";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "flat_load_d16_hi_i8";
            return;
          case 'h':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+12, "ort_d16_hi", 10) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_load_short_d16_hi"
              Mnemonic = "flat_load_d16_hi_b16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "flat_load_d16_hi_b16";
            return;
          }
          break;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+11, "byte_d16_hi", 11) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_load_ubyte_d16_hi"
            Mnemonic = "flat_load_d16_hi_u8";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "flat_load_d16_hi_u8";
          return;
        }
        break;
      case 's':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+6, "tore_byte_d16_hi", 16) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_store_byte_d16_hi"
          Mnemonic = "flat_store_d16_hi_b8";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "flat_store_d16_hi_b8";
        return;
      }
      break;
    case 'g':	 // 2 strings to match.
      if (memcmp(Mnemonic.data()+1, "lobal_atomic_", 13) != 0)
        break;
      switch (Mnemonic[14]) {
      default: break;
      case 'c':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+15, "sub_u32", 7) != 0)
          break;
        if (Features.test(Feature_isGFX12OnlyBit))	 // "global_atomic_csub_u32"
          Mnemonic = "global_atomic_sub_clamp_u32";
        return;
      case 'f':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+15, "cmpswap", 7) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_fcmpswap"
          Mnemonic = "global_atomic_cmpswap_f32";
        return;
      }
      break;
    case 's':	 // 4 strings to match.
      switch (Mnemonic[1]) {
      default: break;
      case '_':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+2, "buffer_load_dwordx16", 20) != 0)
          break;
        if (Features.test(Feature_isGFX11PlusBit))	 // "s_buffer_load_dwordx16"
          Mnemonic = "s_buffer_load_b512";
        return;
      case 'c':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+2, "ratch_load_", 11) != 0)
          break;
        switch (Mnemonic[13]) {
        default: break;
        case 's':	 // 2 strings to match.
          switch (Mnemonic[14]) {
          default: break;
          case 'b':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+15, "yte_d16", 7) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "scratch_load_sbyte_d16"
              Mnemonic = "scratch_load_d16_i8";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "scratch_load_d16_i8";
            return;
          case 'h':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+15, "ort_d16", 7) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "scratch_load_short_d16"
              Mnemonic = "scratch_load_d16_b16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "scratch_load_d16_b16";
            return;
          }
          break;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+14, "byte_d16", 8) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "scratch_load_ubyte_d16"
            Mnemonic = "scratch_load_d16_u8";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "scratch_load_d16_u8";
          return;
        }
        break;
      }
      break;
    case 'v':	 // 47 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'a':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "lignbyte_b32_fake16", 19) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_alignbyte_b32_fake16"
          Mnemonic = "v_alignbyte_b32";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_alignbyte_b32";
        return;
      case 'c':	 // 24 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'e':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "il_f16_fake16_sdwa", 18) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_ceil_f16_fake16_sdwa"
            Mnemonic = "v_ceil_f16_fake16";
          return;
        case 'o':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "s_bf16_fake16_sdwa", 18) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_cos_bf16_fake16_sdwa"
            Mnemonic = "v_cos_bf16_fake16";
          return;
        case 'v':	 // 22 strings to match.
          if (memcmp(Mnemonic.data()+4, "t_", 2) != 0)
            break;
          switch (Mnemonic[6]) {
          default: break;
          case 'f':	 // 9 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 5 strings to match.
              if (memcmp(Mnemonic.data()+8, "6_", 2) != 0)
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'b':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "f8_t16_sdwa", 11) != 0)
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_f16_bf8_t16_sdwa"
                  Mnemonic = "v_cvt_f16_bf8_t16";
                return;
              case 'f':	 // 2 strings to match.
                switch (Mnemonic[11]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+12, "2_t16_sdwa", 10) != 0)
                    break;
                  if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_f16_f32_t16_sdwa"
                    Mnemonic = "v_cvt_f16_f32_t16";
                  return;
                case 'p':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+12, "8_t16_sdwa", 10) != 0)
                    break;
                  if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_f16_fp8_t16_sdwa"
                    Mnemonic = "v_cvt_f16_fp8_t16";
                  return;
                }
                break;
              case 'i':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16_sdwa", 11) != 0)
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_f16_i16_t16_sdwa"
                  Mnemonic = "v_cvt_f16_i16_t16";
                return;
              case 'u':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16_sdwa", 11) != 0)
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_f16_u16_t16_sdwa"
                  Mnemonic = "v_cvt_f16_u16_t16";
                return;
              }
              break;
            case '3':	 // 3 strings to match.
              if (memcmp(Mnemonic.data()+8, "2_", 2) != 0)
                break;
              switch (Mnemonic[10]) {
              default: break;
              case 'b':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+11, "f16_t16_e", 9) != 0)
                  break;
                switch (Mnemonic[20]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[21] != '2')
                    break;
                  if (Features.test(Feature_HasBF16ConversionInstsBit) && Features.test(Feature_HasGFX950InstsBit))	 // "v_cvt_f32_bf16_t16_e32"
                    Mnemonic = "v_cvt_f32_bf16_t16";
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[21] != '4')
                    break;
                  if (Features.test(Feature_HasBF16ConversionInstsBit) && Features.test(Feature_HasGFX950InstsBit))	 // "v_cvt_f32_bf16_t16_e64"
                    Mnemonic = "v_cvt_f32_bf16_t16";
                  return;
                }
                break;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+11, "16_t16_sdwa", 11) != 0)
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_f32_f16_t16_sdwa"
                  Mnemonic = "v_cvt_f32_f16_t16";
                return;
              }
              break;
            case 'l':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "r_i32_f32_sdwa", 14) != 0)
                break;
              Mnemonic = "v_cvt_flr_i32_f32";	 // "v_cvt_flr_i32_f32_sdwa"
              return;
            }
            break;
          case 'i':	 // 2 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "6_f16_t16_sdwa", 14) != 0)
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_i16_f16_t16_sdwa"
                Mnemonic = "v_cvt_i16_f16_t16";
              return;
            case '3':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "2_i16_t16_sdwa", 14) != 0)
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_i32_i16_t16_sdwa"
                Mnemonic = "v_cvt_i32_i16_t16";
              return;
            }
            break;
          case 'n':	 // 6 strings to match.
            if (memcmp(Mnemonic.data()+7, "orm_", 4) != 0)
              break;
            switch (Mnemonic[11]) {
            default: break;
            case 'i':	 // 3 strings to match.
              if (memcmp(Mnemonic.data()+12, "16_f16_", 7) != 0)
                break;
              switch (Mnemonic[19]) {
              default: break;
              case 'e':	 // 2 strings to match.
                switch (Mnemonic[20]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[21] != '2')
                    break;
                  if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_i16_f16_e32"
                    Mnemonic = "v_cvt_norm_i16_f16";
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[21] != '4')
                    break;
                  if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_i16_f16_e64"
                    Mnemonic = "v_cvt_norm_i16_f16";
                  return;
                }
                break;
              case 't':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+20, "16", 2) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_norm_i16_f16_t16"
                  Mnemonic = "v_cvt_norm_i16_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cvt_norm_i16_f16";
                return;
              }
              break;
            case 'u':	 // 3 strings to match.
              if (memcmp(Mnemonic.data()+12, "16_f16_", 7) != 0)
                break;
              switch (Mnemonic[19]) {
              default: break;
              case 'e':	 // 2 strings to match.
                switch (Mnemonic[20]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[21] != '2')
                    break;
                  if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_u16_f16_e32"
                    Mnemonic = "v_cvt_norm_u16_f16";
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[21] != '4')
                    break;
                  if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_u16_f16_e64"
                    Mnemonic = "v_cvt_norm_u16_f16";
                  return;
                }
                break;
              case 't':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+20, "16", 2) != 0)
                  break;
                if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_norm_u16_f16_t16"
                  Mnemonic = "v_cvt_norm_u16_f16";
                else if (Features.test(Feature_isGFX12OnlyBit))
                  Mnemonic = "v_cvt_norm_u16_f16";
                return;
              }
              break;
            }
            break;
          case 'r':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+7, "pi_i32_f32_sdwa", 15) != 0)
              break;
            Mnemonic = "v_cvt_rpi_i32_f32";	 // "v_cvt_rpi_i32_f32_sdwa"
            return;
          case 's':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+7, "r_", 2) != 0)
              break;
            switch (Mnemonic[9]) {
            default: break;
            case 'b':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "f8_f32_gfx12", 12) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_sr_bf8_f32_gfx12"
                Mnemonic = "v_cvt_sr_bf8_f32";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_cvt_sr_bf8_f32";
              return;
            case 'f':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+10, "p8_f32_gfx12", 12) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_sr_fp8_f32_gfx12"
                Mnemonic = "v_cvt_sr_fp8_f32";
              else if (Features.test(Feature_isGFX12Not12_50Bit))
                Mnemonic = "v_cvt_sr_fp8_f32";
              return;
            }
            break;
          case 'u':	 // 2 strings to match.
            switch (Mnemonic[7]) {
            default: break;
            case '1':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "6_f16_t16_sdwa", 14) != 0)
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_u16_f16_t16_sdwa"
                Mnemonic = "v_cvt_u16_f16_t16";
              return;
            case '3':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+8, "2_u16_t16_sdwa", 14) != 0)
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_u32_u16_t16_sdwa"
                Mnemonic = "v_cvt_u32_u16_t16";
              return;
            }
            break;
          }
          break;
        }
        break;
      case 'e':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "xp_bf16_fake16_sdwa", 19) != 0)
          break;
        if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_exp_bf16_fake16_sdwa"
          Mnemonic = "v_exp_bf16_fake16";
        return;
      case 'f':	 // 4 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'l':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "oor_f16_fake16_e", 16) != 0)
            break;
          switch (Mnemonic[20]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[21] != '2')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_floor_f16_fake16_e32"
              Mnemonic = "v_floor_f16_fake16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[21] != '4')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_floor_f16_fake16_e64"
              Mnemonic = "v_floor_f16_fake16";
            return;
          }
          break;
        case 'r':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "act_f16_fake16_e", 16) != 0)
            break;
          switch (Mnemonic[20]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[21] != '2')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_fract_f16_fake16_e32"
              Mnemonic = "v_fract_f16_fake16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[21] != '4')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_fract_f16_fake16_e64"
              Mnemonic = "v_fract_f16_fake16";
            return;
          }
          break;
        }
        break;
      case 'l':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "og_bf16_fake16_sdwa", 19) != 0)
          break;
        if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_log_bf16_fake16_sdwa"
          Mnemonic = "v_log_bf16_fake16";
        return;
      case 'r':	 // 4 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'c':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "p_bf16_fake16_sdwa", 18) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rcp_bf16_fake16_sdwa"
            Mnemonic = "v_rcp_bf16_fake16";
          return;
        case 'n':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "dne_f16_fake16_e", 16) != 0)
            break;
          switch (Mnemonic[20]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[21] != '2')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_rndne_f16_fake16_e32"
              Mnemonic = "v_rndne_f16_fake16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[21] != '4')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_rndne_f16_fake16_e64"
              Mnemonic = "v_rndne_f16_fake16";
            return;
          }
          break;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "q_bf16_fake16_sdwa", 18) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_rsq_bf16_fake16_sdwa"
            Mnemonic = "v_rsq_bf16_fake16";
          return;
        }
        break;
      case 's':	 // 7 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "t_pk", 4) != 0)
            break;
          switch (Mnemonic[8]) {
          default: break;
          case '4':	 // 2 strings to match.
            if (Mnemonic[9] != '_')
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "4_i8_fake16", 11) != 0)
                break;
              if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_sat_pk4_i4_i8_fake16"
                Mnemonic = "v_sat_pk4_i4_i8";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "4_u8_fake16", 11) != 0)
                break;
              if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_sat_pk4_u4_u8_fake16"
                Mnemonic = "v_sat_pk4_u4_u8";
              return;
            }
            break;
          case '_':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+9, "u8_i16_fake16", 13) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_sat_pk_u8_i16_fake16"
              Mnemonic = "v_sat_pk_u8_i16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_sat_pk_u8_i16";
            return;
          }
          break;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "n_bf16_fake16_sdwa", 18) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sin_bf16_fake16_sdwa"
            Mnemonic = "v_sin_bf16_fake16";
          return;
        case 'q':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "rt_", 3) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'b':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+8, "f16_fake16_e", 12) != 0)
              break;
            switch (Mnemonic[20]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[21] != '2')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sqrt_bf16_fake16_e32"
                Mnemonic = "v_sqrt_bf16_fake16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[21] != '4')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sqrt_bf16_fake16_e64"
                Mnemonic = "v_sqrt_bf16_fake16";
              return;
            }
            break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "16_fake16_sdwa", 14) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_sqrt_f16_fake16_sdwa"
              Mnemonic = "v_sqrt_f16_fake16";
            return;
          }
          break;
        }
        break;
      case 't':	 // 5 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "nh_", 3) != 0)
            break;
          switch (Mnemonic[7]) {
          default: break;
          case 'b':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+8, "f16_fake16_e", 12) != 0)
              break;
            switch (Mnemonic[20]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[21] != '2')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_tanh_bf16_fake16_e32"
                Mnemonic = "v_tanh_bf16_fake16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[21] != '4')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_tanh_bf16_fake16_e64"
                Mnemonic = "v_tanh_bf16_fake16";
              return;
            }
            break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "16_fake16_sdwa", 14) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasTanhInstsBit))	 // "v_tanh_f16_fake16_sdwa"
              Mnemonic = "v_tanh_f16_fake16";
            return;
          }
          break;
        case 'r':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+4, "unc_f16_fake16_e", 16) != 0)
            break;
          switch (Mnemonic[20]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[21] != '2')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_trunc_f16_fake16_e32"
              Mnemonic = "v_trunc_f16_fake16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[21] != '4')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_trunc_f16_fake16_e64"
              Mnemonic = "v_trunc_f16_fake16";
            return;
          }
          break;
        }
        break;
      }
      break;
    }
    break;
  case 23:	 // 36 strings to match.
    switch (Mnemonic[0]) {
    default: break;
    case 'f':	 // 1 string to match.
      if (memcmp(Mnemonic.data()+1, "lat_store_short_d16_hi", 22) != 0)
        break;
      if (Features.test(Feature_isGFX11OnlyBit))	 // "flat_store_short_d16_hi"
        Mnemonic = "flat_store_d16_hi_b16";
      else if (Features.test(Feature_isGFX12OnlyBit))
        Mnemonic = "flat_store_d16_hi_b16";
      return;
    case 'g':	 // 1 string to match.
      if (memcmp(Mnemonic.data()+1, "lobal_load_b128_tr_b16", 22) != 0)
        break;
      if (Features.test(Feature_isGFX125xOnlyBit))	 // "global_load_b128_tr_b16"
        Mnemonic = "global_load_tr16_b128";
      return;
    case 'v':	 // 34 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'c':	 // 11 strings to match.
        if (memcmp(Mnemonic.data()+3, "vt_", 3) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case 'f':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "32_bf16_t16_sdwa", 16) != 0)
            break;
          if (Features.test(Feature_HasBF16ConversionInstsBit) && Features.test(Feature_HasGFX950InstsBit))	 // "v_cvt_f32_bf16_t16_sdwa"
            Mnemonic = "v_cvt_f32_bf16_t16";
          return;
        case 'n':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+7, "orm_", 4) != 0)
            break;
          switch (Mnemonic[11]) {
          default: break;
          case 'i':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+12, "16_f16_sdwa", 11) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_i16_f16_sdwa"
              Mnemonic = "v_cvt_norm_i16_f16";
            return;
          case 'u':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+12, "16_f16_sdwa", 11) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_u16_f16_sdwa"
              Mnemonic = "v_cvt_norm_u16_f16";
            return;
          }
          break;
        case 'p':	 // 6 strings to match.
          if (memcmp(Mnemonic.data()+7, "k_", 2) != 0)
            break;
          switch (Mnemonic[9]) {
          default: break;
          case 'b':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "f8_f32_fake16", 13) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_pk_bf8_f32_fake16"
              Mnemonic = "v_cvt_pk_bf8_f32";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cvt_pk_bf8_f32";
            return;
          case 'f':	 // 5 strings to match.
            switch (Mnemonic[10]) {
            default: break;
            case '1':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+11, "6_", 2) != 0)
                break;
              switch (Mnemonic[13]) {
              default: break;
              case 'b':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+14, "f8_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_pk_f16_bf8_fake16"
                  Mnemonic = "v_cvt_pk_f16_bf8";
                return;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+14, "p8_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_pk_f16_fp8_fake16"
                  Mnemonic = "v_cvt_pk_f16_fp8";
                return;
              }
              break;
            case '3':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+11, "2_", 2) != 0)
                break;
              switch (Mnemonic[13]) {
              default: break;
              case 'b':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+14, "f8_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX12OnlyBit))	 // "v_cvt_pk_f32_bf8_fake16"
                  Mnemonic = "v_cvt_pk_f32_bf8";
                return;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+14, "p8_fake16", 9) != 0)
                  break;
                if (Features.test(Feature_isGFX12OnlyBit))	 // "v_cvt_pk_f32_fp8_fake16"
                  Mnemonic = "v_cvt_pk_f32_fp8";
                return;
              }
              break;
            case 'p':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "8_f32_fake16", 12) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_pk_fp8_f32_fake16"
                Mnemonic = "v_cvt_pk_fp8_f32";
              else if (Features.test(Feature_isGFX12Not12_50Bit))
                Mnemonic = "v_cvt_pk_fp8_f32";
              return;
            }
            break;
          }
          break;
        case 's':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+7, "r_", 2) != 0)
            break;
          switch (Mnemonic[9]) {
          default: break;
          case 'b':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "f8_f16_fake16", 13) != 0)
              break;
            if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_sr_bf8_f16_fake16"
              Mnemonic = "v_cvt_sr_bf8_f16";
            return;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "p8_f16_fake16", 13) != 0)
              break;
            if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_sr_fp8_f16_fake16"
              Mnemonic = "v_cvt_sr_fp8_f16";
            return;
          }
          break;
        }
        break;
      case 'f':	 // 10 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'l':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "oor_f16_fake16_sdwa", 19) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_floor_f16_fake16_sdwa"
            Mnemonic = "v_floor_f16_fake16";
          return;
        case 'r':	 // 9 strings to match.
          switch (Mnemonic[4]) {
          default: break;
          case 'a':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+5, "ct_f16_fake16_sdwa", 18) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_fract_f16_fake16_sdwa"
              Mnemonic = "v_fract_f16_fake16";
            return;
          case 'e':	 // 8 strings to match.
            if (memcmp(Mnemonic.data()+5, "xp_", 3) != 0)
              break;
            switch (Mnemonic[8]) {
            default: break;
            case 'e':	 // 7 strings to match.
              if (memcmp(Mnemonic.data()+9, "xp_i", 4) != 0)
                break;
              switch (Mnemonic[13]) {
              default: break;
              case '1':	 // 3 strings to match.
                if (memcmp(Mnemonic.data()+14, "6_f16_", 6) != 0)
                  break;
                switch (Mnemonic[20]) {
                default: break;
                case 'e':	 // 2 strings to match.
                  switch (Mnemonic[21]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (Mnemonic[22] != '2')
                      break;
                    if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_frexp_exp_i16_f16_e32"
                      Mnemonic = "v_frexp_exp_i16_f16";
                    return;
                  case '6':	 // 1 string to match.
                    if (Mnemonic[22] != '4')
                      break;
                    if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_frexp_exp_i16_f16_e64"
                      Mnemonic = "v_frexp_exp_i16_f16";
                    return;
                  }
                  break;
                case 't':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+21, "16", 2) != 0)
                    break;
                  if (Features.test(Feature_isGFX11OnlyBit))	 // "v_frexp_exp_i16_f16_t16"
                    Mnemonic = "v_frexp_exp_i16_f16";
                  else if (Features.test(Feature_isGFX12OnlyBit))
                    Mnemonic = "v_frexp_exp_i16_f16";
                  return;
                }
                break;
              case '3':	 // 4 strings to match.
                if (memcmp(Mnemonic.data()+14, "2_f", 3) != 0)
                  break;
                switch (Mnemonic[17]) {
                default: break;
                case '3':	 // 2 strings to match.
                  if (memcmp(Mnemonic.data()+18, "2_e", 3) != 0)
                    break;
                  switch (Mnemonic[21]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (Mnemonic[22] != '2')
                      break;
                    Mnemonic = "v_frexp_exp_i32_f32";	 // "v_frexp_exp_i32_f32_e32"
                    return;
                  case '6':	 // 1 string to match.
                    if (Mnemonic[22] != '4')
                      break;
                    Mnemonic = "v_frexp_exp_i32_f32";	 // "v_frexp_exp_i32_f32_e64"
                    return;
                  }
                  break;
                case '6':	 // 2 strings to match.
                  if (memcmp(Mnemonic.data()+18, "4_e", 3) != 0)
                    break;
                  switch (Mnemonic[21]) {
                  default: break;
                  case '3':	 // 1 string to match.
                    if (Mnemonic[22] != '2')
                      break;
                    Mnemonic = "v_frexp_exp_i32_f64";	 // "v_frexp_exp_i32_f64_e32"
                    return;
                  case '6':	 // 1 string to match.
                    if (Mnemonic[22] != '4')
                      break;
                    Mnemonic = "v_frexp_exp_i32_f64";	 // "v_frexp_exp_i32_f64_e64"
                    return;
                  }
                  break;
                }
                break;
              }
              break;
            case 'm':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+9, "ant_f16_fake16", 14) != 0)
                break;
              if (Features.test(Feature_isGFX11OnlyBit))	 // "v_frexp_mant_f16_fake16"
                Mnemonic = "v_frexp_mant_f16";
              else if (Features.test(Feature_isGFX12OnlyBit))
                Mnemonic = "v_frexp_mant_f16";
              return;
            }
            break;
          }
          break;
        }
        break;
      case 'r':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "ndne_f16_fake16_sdwa", 20) != 0)
          break;
        if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_rndne_f16_fake16_sdwa"
          Mnemonic = "v_rndne_f16_fake16";
        return;
      case 's':	 // 10 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 6 strings to match.
          if (memcmp(Mnemonic.data()+4, "t_pk", 4) != 0)
            break;
          switch (Mnemonic[8]) {
          default: break;
          case '4':	 // 4 strings to match.
            if (Mnemonic[9] != '_')
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'i':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+11, "4_i8_t16_e", 10) != 0)
                break;
              switch (Mnemonic[21]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[22] != '2')
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_i4_i8_t16_e32"
                  Mnemonic = "v_sat_pk4_i4_i8_t16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[22] != '4')
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_i4_i8_t16_e64"
                  Mnemonic = "v_sat_pk4_i4_i8_t16";
                return;
              }
              break;
            case 'u':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+11, "4_u8_t16_e", 10) != 0)
                break;
              switch (Mnemonic[21]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[22] != '2')
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_u4_u8_t16_e32"
                  Mnemonic = "v_sat_pk4_u4_u8_t16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[22] != '4')
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_u4_u8_t16_e64"
                  Mnemonic = "v_sat_pk4_u4_u8_t16";
                return;
              }
              break;
            }
            break;
          case '_':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+9, "u8_i16_t16_e", 12) != 0)
              break;
            switch (Mnemonic[21]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[22] != '2')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX9PlusBit))	 // "v_sat_pk_u8_i16_t16_e32"
                Mnemonic = "v_sat_pk_u8_i16_t16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[22] != '4')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX9PlusBit))	 // "v_sat_pk_u8_i16_t16_e64"
                Mnemonic = "v_sat_pk_u8_i16_t16";
              return;
            }
            break;
          }
          break;
        case 'm':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "fmac_i32_", 9) != 0)
            break;
          switch (Mnemonic[13]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "6x16x64i8", 9) != 0)
              break;
            if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_i32_16x16x64i8"
              Mnemonic = "v_smfmac_i32_16x16x64_i8";
            return;
          case '3':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+14, "2x32x", 5) != 0)
              break;
            switch (Mnemonic[19]) {
            default: break;
            case '3':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+20, "2i8", 3) != 0)
                break;
              if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_i32_32x32x32i8"
                Mnemonic = "v_smfmac_i32_32x32x32_i8";
              return;
            case '6':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+20, "4i8", 3) != 0)
                break;
              if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_i32_32x32x64i8"
                Mnemonic = "v_smfmac_i32_32x32x64_i8";
              return;
            }
            break;
          }
          break;
        case 'q':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "rt_bf16_fake16_sdwa", 19) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_sqrt_bf16_fake16_sdwa"
            Mnemonic = "v_sqrt_bf16_fake16";
          return;
        }
        break;
      case 't':	 // 2 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "nh_bf16_fake16_sdwa", 19) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasBF16TransInstsBit))	 // "v_tanh_bf16_fake16_sdwa"
            Mnemonic = "v_tanh_bf16_fake16";
          return;
        case 'r':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "unc_f16_fake16_sdwa", 19) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_trunc_f16_fake16_sdwa"
            Mnemonic = "v_trunc_f16_fake16";
          return;
        }
        break;
      }
      break;
    }
    break;
  case 24:	 // 62 strings to match.
    switch (Mnemonic[0]) {
    default: break;
    case 'b':	 // 6 strings to match.
      if (memcmp(Mnemonic.data()+1, "uffer_", 6) != 0)
        break;
      switch (Mnemonic[7]) {
      default: break;
      case 'a':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+8, "tomic_cmpswap_x2", 16) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "buffer_atomic_cmpswap_x2"
          Mnemonic = "buffer_atomic_cmpswap_b64";
        else if (Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "buffer_atomic_cmpswap_b64";
        return;
      case 'l':	 // 4 strings to match.
        if (memcmp(Mnemonic.data()+8, "oad_", 4) != 0)
          break;
        switch (Mnemonic[12]) {
        default: break;
        case 'f':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "ormat_d16_x", 11) != 0)
            break;
          if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_load_format_d16_x"
            Mnemonic = "buffer_load_d16_format_x";
          return;
        case 's':	 // 2 strings to match.
          switch (Mnemonic[13]) {
          default: break;
          case 'b':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "yte_d16_hi", 10) != 0)
              break;
            if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_load_sbyte_d16_hi"
              Mnemonic = "buffer_load_d16_hi_i8";
            return;
          case 'h':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "ort_d16_hi", 10) != 0)
              break;
            if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_load_short_d16_hi"
              Mnemonic = "buffer_load_d16_hi_b16";
            return;
          }
          break;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "byte_d16_hi", 11) != 0)
            break;
          if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_load_ubyte_d16_hi"
            Mnemonic = "buffer_load_d16_hi_u8";
          return;
        }
        break;
      case 's':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+8, "tore_byte_d16_hi", 16) != 0)
          break;
        if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_store_byte_d16_hi"
          Mnemonic = "buffer_store_d16_hi_b8";
        return;
      }
      break;
    case 'g':	 // 6 strings to match.
      if (memcmp(Mnemonic.data()+1, "lobal_", 6) != 0)
        break;
      switch (Mnemonic[7]) {
      default: break;
      case 'a':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+8, "tomic_cmpswap_x2", 16) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "global_atomic_cmpswap_x2"
          Mnemonic = "global_atomic_cmpswap_b64";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "global_atomic_cmpswap_b64";
        return;
      case 'l':	 // 4 strings to match.
        if (memcmp(Mnemonic.data()+8, "oad_", 4) != 0)
          break;
        switch (Mnemonic[12]) {
        default: break;
        case 'd':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "word_addtid", 11) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_load_dword_addtid"
            Mnemonic = "global_load_addtid_b32";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_load_addtid_b32";
          return;
        case 's':	 // 2 strings to match.
          switch (Mnemonic[13]) {
          default: break;
          case 'b':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "yte_d16_hi", 10) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "global_load_sbyte_d16_hi"
              Mnemonic = "global_load_d16_hi_i8";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "global_load_d16_hi_i8";
            return;
          case 'h':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "ort_d16_hi", 10) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "global_load_short_d16_hi"
              Mnemonic = "global_load_d16_hi_b16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "global_load_d16_hi_b16";
            return;
          }
          break;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+13, "byte_d16_hi", 11) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "global_load_ubyte_d16_hi"
            Mnemonic = "global_load_d16_hi_u8";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "global_load_d16_hi_u8";
          return;
        }
        break;
      case 's':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+8, "tore_byte_d16_hi", 16) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "global_store_byte_d16_hi"
          Mnemonic = "global_store_d16_hi_b8";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "global_store_d16_hi_b8";
        return;
      }
      break;
    case 'i':	 // 2 strings to match.
      if (memcmp(Mnemonic.data()+1, "mage_atomic_m", 13) != 0)
        break;
      switch (Mnemonic[14]) {
      default: break;
      case 'a':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+15, "x_num_flt", 9) != 0)
          break;
        if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))	 // "image_atomic_max_num_flt"
          Mnemonic = "image_atomic_max_flt";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_max_flt";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_max_flt";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_max_flt";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_max_flt";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_max_flt";
        return;
      case 'i':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+15, "n_num_flt", 9) != 0)
          break;
        if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))	 // "image_atomic_min_num_flt"
          Mnemonic = "image_atomic_min_flt";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_min_flt";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_min_flt";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_min_flt";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_min_flt";
        else if (Features.test(Feature_HasImageInstsBit) && Features.test(Feature_isGFX12PlusBit))
          Mnemonic = "image_atomic_min_flt";
        return;
      }
      break;
    case 'v':	 // 48 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'c':	 // 33 strings to match.
        if (memcmp(Mnemonic.data()+3, "vt_", 3) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case 'f':	 // 16 strings to match.
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 10 strings to match.
            if (memcmp(Mnemonic.data()+8, "6_", 2) != 0)
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'b':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+11, "f8_fake16_e", 11) != 0)
                break;
              switch (Mnemonic[22]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[23] != '2')
                  break;
                if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_f16_bf8_fake16_e32"
                  Mnemonic = "v_cvt_f16_bf8_fake16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[23] != '4')
                  break;
                if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_f16_bf8_fake16_e64"
                  Mnemonic = "v_cvt_f16_bf8_fake16";
                return;
              }
              break;
            case 'f':	 // 4 strings to match.
              switch (Mnemonic[11]) {
              default: break;
              case '3':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+12, "2_fake16_e", 10) != 0)
                  break;
                switch (Mnemonic[22]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[23] != '2')
                    break;
                  if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_f16_f32_fake16_e32"
                    Mnemonic = "v_cvt_f16_f32_fake16";
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[23] != '4')
                    break;
                  if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_f16_f32_fake16_e64"
                    Mnemonic = "v_cvt_f16_f32_fake16";
                  return;
                }
                break;
              case 'p':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+12, "8_fake16_e", 10) != 0)
                  break;
                switch (Mnemonic[22]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[23] != '2')
                    break;
                  if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_f16_fp8_fake16_e32"
                    Mnemonic = "v_cvt_f16_fp8_fake16";
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[23] != '4')
                    break;
                  if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_f16_fp8_fake16_e64"
                    Mnemonic = "v_cvt_f16_fp8_fake16";
                  return;
                }
                break;
              }
              break;
            case 'i':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+11, "16_fake16_e", 11) != 0)
                break;
              switch (Mnemonic[22]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[23] != '2')
                  break;
                if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_f16_i16_fake16_e32"
                  Mnemonic = "v_cvt_f16_i16_fake16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[23] != '4')
                  break;
                if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_f16_i16_fake16_e64"
                  Mnemonic = "v_cvt_f16_i16_fake16";
                return;
              }
              break;
            case 'u':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+11, "16_fake16_e", 11) != 0)
                break;
              switch (Mnemonic[22]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[23] != '2')
                  break;
                if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_f16_u16_fake16_e32"
                  Mnemonic = "v_cvt_f16_u16_fake16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[23] != '4')
                  break;
                if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_f16_u16_fake16_e64"
                  Mnemonic = "v_cvt_f16_u16_fake16";
                return;
              }
              break;
            }
            break;
          case '3':	 // 6 strings to match.
            if (memcmp(Mnemonic.data()+8, "2_", 2) != 0)
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'b':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+11, "f8_op_sel_e", 11) != 0)
                break;
              switch (Mnemonic[22]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[23] != '2')
                  break;
                if (Features.test(Feature_HasFP8ConversionInstsBit) && Features.test(Feature_isGFX12PlusBit))	 // "v_cvt_f32_bf8_op_sel_e32"
                  Mnemonic = "v_cvt_f32_bf8_op_sel";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[23] != '4')
                  break;
                if (Features.test(Feature_HasFP8ConversionInstsBit) && Features.test(Feature_isGFX12PlusBit))	 // "v_cvt_f32_bf8_op_sel_e64"
                  Mnemonic = "v_cvt_f32_bf8_op_sel";
                return;
              }
              break;
            case 'f':	 // 4 strings to match.
              switch (Mnemonic[11]) {
              default: break;
              case '1':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+12, "6_fake16_e", 10) != 0)
                  break;
                switch (Mnemonic[22]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[23] != '2')
                    break;
                  if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_f32_f16_fake16_e32"
                    Mnemonic = "v_cvt_f32_f16_fake16";
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[23] != '4')
                    break;
                  if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_f32_f16_fake16_e64"
                    Mnemonic = "v_cvt_f32_f16_fake16";
                  return;
                }
                break;
              case 'p':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+12, "8_op_sel_e", 10) != 0)
                  break;
                switch (Mnemonic[22]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[23] != '2')
                    break;
                  if (Features.test(Feature_HasFP8ConversionInstsBit) && Features.test(Feature_isGFX12PlusNot12_50Bit))	 // "v_cvt_f32_fp8_op_sel_e32"
                    Mnemonic = "v_cvt_f32_fp8_op_sel";
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[23] != '4')
                    break;
                  if (Features.test(Feature_HasFP8ConversionInstsBit) && Features.test(Feature_isGFX12PlusNot12_50Bit))	 // "v_cvt_f32_fp8_op_sel_e64"
                    Mnemonic = "v_cvt_f32_fp8_op_sel";
                  return;
                }
                break;
              }
              break;
            }
            break;
          }
          break;
        case 'i':	 // 4 strings to match.
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+8, "6_f16_fake16_e", 14) != 0)
              break;
            switch (Mnemonic[22]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[23] != '2')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_i16_f16_fake16_e32"
                Mnemonic = "v_cvt_i16_f16_fake16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[23] != '4')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_i16_f16_fake16_e64"
                Mnemonic = "v_cvt_i16_f16_fake16";
              return;
            }
            break;
          case '3':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+8, "2_i16_fake16_e", 14) != 0)
              break;
            switch (Mnemonic[22]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[23] != '2')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_i32_i16_fake16_e32"
                Mnemonic = "v_cvt_i32_i16_fake16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[23] != '4')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_i32_i16_fake16_e64"
                Mnemonic = "v_cvt_i32_i16_fake16";
              return;
            }
            break;
          }
          break;
        case 'p':	 // 8 strings to match.
          if (memcmp(Mnemonic.data()+7, "k_f", 3) != 0)
            break;
          switch (Mnemonic[10]) {
          default: break;
          case '1':	 // 4 strings to match.
            if (memcmp(Mnemonic.data()+11, "6_", 2) != 0)
              break;
            switch (Mnemonic[13]) {
            default: break;
            case 'b':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+14, "f8_t16_e", 8) != 0)
                break;
              switch (Mnemonic[22]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[23] != '2')
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_pk_f16_bf8_t16_e32"
                  Mnemonic = "v_cvt_pk_f16_bf8_t16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[23] != '4')
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_pk_f16_bf8_t16_e64"
                  Mnemonic = "v_cvt_pk_f16_bf8_t16";
                return;
              }
              break;
            case 'f':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+14, "p8_t16_e", 8) != 0)
                break;
              switch (Mnemonic[22]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[23] != '2')
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_pk_f16_fp8_t16_e32"
                  Mnemonic = "v_cvt_pk_f16_fp8_t16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[23] != '4')
                  break;
                if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_pk_f16_fp8_t16_e64"
                  Mnemonic = "v_cvt_pk_f16_fp8_t16";
                return;
              }
              break;
            }
            break;
          case '3':	 // 4 strings to match.
            if (memcmp(Mnemonic.data()+11, "2_", 2) != 0)
              break;
            switch (Mnemonic[13]) {
            default: break;
            case 'b':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+14, "f8_t16_e", 8) != 0)
                break;
              switch (Mnemonic[22]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[23] != '2')
                  break;
                if (Features.test(Feature_HasFP8ConversionInstsBit) && Features.test(Feature_isGFX12PlusBit) && Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_pk_f32_bf8_t16_e32"
                  Mnemonic = "v_cvt_pk_f32_bf8_t16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[23] != '4')
                  break;
                if (Features.test(Feature_HasFP8ConversionInstsBit) && Features.test(Feature_isGFX12PlusBit) && Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_pk_f32_bf8_t16_e64"
                  Mnemonic = "v_cvt_pk_f32_bf8_t16";
                return;
              }
              break;
            case 'f':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+14, "p8_t16_e", 8) != 0)
                break;
              switch (Mnemonic[22]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[23] != '2')
                  break;
                if (Features.test(Feature_HasFP8ConversionInstsBit) && Features.test(Feature_isGFX12PlusBit) && Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_pk_f32_fp8_t16_e32"
                  Mnemonic = "v_cvt_pk_f32_fp8_t16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[23] != '4')
                  break;
                if (Features.test(Feature_HasFP8ConversionInstsBit) && Features.test(Feature_isGFX12PlusBit) && Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_pk_f32_fp8_t16_e64"
                  Mnemonic = "v_cvt_pk_f32_fp8_t16";
                return;
              }
              break;
            }
            break;
          }
          break;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+7, "r_fp8_f32_gfx1250", 17) != 0)
            break;
          if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_sr_fp8_f32_gfx1250"
            Mnemonic = "v_cvt_sr_fp8_f32";
          return;
        case 'u':	 // 4 strings to match.
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+8, "6_f16_fake16_e", 14) != 0)
              break;
            switch (Mnemonic[22]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[23] != '2')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_u16_f16_fake16_e32"
                Mnemonic = "v_cvt_u16_f16_fake16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[23] != '4')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_u16_f16_fake16_e64"
                Mnemonic = "v_cvt_u16_f16_fake16";
              return;
            }
            break;
          case '3':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+8, "2_u16_fake16_e", 14) != 0)
              break;
            switch (Mnemonic[22]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[23] != '2')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_u32_u16_fake16_e32"
                Mnemonic = "v_cvt_u32_u16_fake16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[23] != '4')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_u32_u16_fake16_e64"
                Mnemonic = "v_cvt_u32_u16_fake16";
              return;
            }
            break;
          }
          break;
        }
        break;
      case 'd':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "iv_fixup_f16_gfx9_t16", 21) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_div_fixup_f16_gfx9_t16"
          Mnemonic = "v_div_fixup_f16";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_div_fixup_f16";
        return;
      case 'f':	 // 4 strings to match.
        if (memcmp(Mnemonic.data()+3, "rexp_", 5) != 0)
          break;
        switch (Mnemonic[8]) {
        default: break;
        case 'e':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+9, "xp_i", 4) != 0)
            break;
          switch (Mnemonic[13]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "6_f16_sdwa", 10) != 0)
              break;
            if (Features.test(Feature_NotHasTrue16BitInstsBit) && Features.test(Feature_Has16BitInstsBit))	 // "v_frexp_exp_i16_f16_sdwa"
              Mnemonic = "v_frexp_exp_i16_f16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+14, "2_f32_sdwa", 10) != 0)
              break;
            Mnemonic = "v_frexp_exp_i32_f32";	 // "v_frexp_exp_i32_f32_sdwa"
            return;
          }
          break;
        case 'm':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+9, "ant_f16_t16_e", 13) != 0)
            break;
          switch (Mnemonic[22]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[23] != '2')
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_frexp_mant_f16_t16_e32"
              Mnemonic = "v_frexp_mant_f16_t16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[23] != '4')
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_frexp_mant_f16_t16_e64"
              Mnemonic = "v_frexp_mant_f16_t16";
            return;
          }
          break;
        }
        break;
      case 'm':	 // 2 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "ximumminimum_f16_t16", 20) != 0)
            break;
          if (Features.test(Feature_isGFX12OnlyBit))	 // "v_maximumminimum_f16_t16"
            Mnemonic = "v_maximumminimum_f16";
          return;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "nimummaximum_f16_t16", 20) != 0)
            break;
          if (Features.test(Feature_isGFX12OnlyBit))	 // "v_minimummaximum_f16_t16"
            Mnemonic = "v_minimummaximum_f16";
          return;
        }
        break;
      case 's':	 // 8 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "t_pk", 4) != 0)
            break;
          switch (Mnemonic[8]) {
          default: break;
          case '4':	 // 2 strings to match.
            if (Mnemonic[9] != '_')
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "4_i8_t16_sdwa", 13) != 0)
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_i4_i8_t16_sdwa"
                Mnemonic = "v_sat_pk4_i4_i8_t16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "4_u8_t16_sdwa", 13) != 0)
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_u4_u8_t16_sdwa"
                Mnemonic = "v_sat_pk4_u4_u8_t16";
              return;
            }
            break;
          case '_':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+9, "u8_i16_t16_sdwa", 15) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_isGFX9PlusBit))	 // "v_sat_pk_u8_i16_t16_sdwa"
              Mnemonic = "v_sat_pk_u8_i16_t16";
            return;
          }
          break;
        case 'm':	 // 5 strings to match.
          if (memcmp(Mnemonic.data()+4, "fmac_", 5) != 0)
            break;
          switch (Mnemonic[9]) {
          default: break;
          case 'f':	 // 4 strings to match.
            if (memcmp(Mnemonic.data()+10, "32_", 3) != 0)
              break;
            switch (Mnemonic[13]) {
            default: break;
            case '1':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+14, "6x16x", 5) != 0)
                break;
              switch (Mnemonic[19]) {
              default: break;
              case '3':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+20, "2f16", 4) != 0)
                  break;
                if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_16x16x32f16"
                  Mnemonic = "v_smfmac_f32_16x16x32_f16";
                return;
              case '6':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+20, "4f16", 4) != 0)
                  break;
                if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_16x16x64f16"
                  Mnemonic = "v_smfmac_f32_16x16x64_f16";
                return;
              }
              break;
            case '3':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+14, "2x32x", 5) != 0)
                break;
              switch (Mnemonic[19]) {
              default: break;
              case '1':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+20, "6f16", 4) != 0)
                  break;
                if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_32x32x16f16"
                  Mnemonic = "v_smfmac_f32_32x32x16_f16";
                return;
              case '3':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+20, "2f16", 4) != 0)
                  break;
                if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_32x32x32f16"
                  Mnemonic = "v_smfmac_f32_32x32x32_f16";
                return;
              }
              break;
            }
            break;
          case 'i':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+10, "32_16x16x128i8", 14) != 0)
              break;
            if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_i32_16x16x128i8"
              Mnemonic = "v_smfmac_i32_16x16x128_i8";
            return;
          }
          break;
        }
        break;
      }
      break;
    }
    break;
  case 25:	 // 35 strings to match.
    switch (Mnemonic[0]) {
    default: break;
    case 'b':	 // 3 strings to match.
      if (memcmp(Mnemonic.data()+1, "uffer_", 6) != 0)
        break;
      switch (Mnemonic[7]) {
      default: break;
      case 'l':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+8, "oad_format_d16_xy", 17) != 0)
          break;
        if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_load_format_d16_xy"
          Mnemonic = "buffer_load_d16_format_xy";
        return;
      case 's':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+8, "tore_", 5) != 0)
          break;
        switch (Mnemonic[13]) {
        default: break;
        case 'f':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+14, "ormat_d16_x", 11) != 0)
            break;
          if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_store_format_d16_x"
            Mnemonic = "buffer_store_d16_format_x";
          return;
        case 's':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+14, "hort_d16_hi", 11) != 0)
            break;
          if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_store_short_d16_hi"
            Mnemonic = "buffer_store_d16_hi_b16";
          return;
        }
        break;
      }
      break;
    case 'g':	 // 2 strings to match.
      if (memcmp(Mnemonic.data()+1, "lobal_store_", 12) != 0)
        break;
      switch (Mnemonic[13]) {
      default: break;
      case 'd':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+14, "word_addtid", 11) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "global_store_dword_addtid"
          Mnemonic = "global_store_addtid_b32";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "global_store_addtid_b32";
        return;
      case 's':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+14, "hort_d16_hi", 11) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "global_store_short_d16_hi"
          Mnemonic = "global_store_d16_hi_b16";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "global_store_d16_hi_b16";
        return;
      }
      break;
    case 's':	 // 4 strings to match.
      if (memcmp(Mnemonic.data()+1, "cratch_", 7) != 0)
        break;
      switch (Mnemonic[8]) {
      default: break;
      case 'l':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+9, "oad_", 4) != 0)
          break;
        switch (Mnemonic[13]) {
        default: break;
        case 's':	 // 2 strings to match.
          switch (Mnemonic[14]) {
          default: break;
          case 'b':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+15, "yte_d16_hi", 10) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "scratch_load_sbyte_d16_hi"
              Mnemonic = "scratch_load_d16_hi_i8";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "scratch_load_d16_hi_i8";
            return;
          case 'h':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+15, "ort_d16_hi", 10) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "scratch_load_short_d16_hi"
              Mnemonic = "scratch_load_d16_hi_b16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "scratch_load_d16_hi_b16";
            return;
          }
          break;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+14, "byte_d16_hi", 11) != 0)
            break;
          if (Features.test(Feature_isGFX11OnlyBit))	 // "scratch_load_ubyte_d16_hi"
            Mnemonic = "scratch_load_d16_hi_u8";
          else if (Features.test(Feature_isGFX12OnlyBit))
            Mnemonic = "scratch_load_d16_hi_u8";
          return;
        }
        break;
      case 's':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+9, "tore_byte_d16_hi", 16) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "scratch_store_byte_d16_hi"
          Mnemonic = "scratch_store_d16_hi_b8";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "scratch_store_d16_hi_b8";
        return;
      }
      break;
    case 't':	 // 1 string to match.
      if (memcmp(Mnemonic.data()+1, "buffer_load_format_d16_x", 24) != 0)
        break;
      if (Features.test(Feature_isGFX11PlusBit))	 // "tbuffer_load_format_d16_x"
        Mnemonic = "tbuffer_load_d16_format_x";
      return;
    case 'v':	 // 25 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'c':	 // 16 strings to match.
        if (memcmp(Mnemonic.data()+3, "vt_", 3) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case 'f':	 // 10 strings to match.
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 5 strings to match.
            if (memcmp(Mnemonic.data()+8, "6_", 2) != 0)
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'b':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "f8_fake16_sdwa", 14) != 0)
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_f16_bf8_fake16_sdwa"
                Mnemonic = "v_cvt_f16_bf8_fake16";
              return;
            case 'f':	 // 2 strings to match.
              switch (Mnemonic[11]) {
              default: break;
              case '3':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+12, "2_fake16_sdwa", 13) != 0)
                  break;
                if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_f16_f32_fake16_sdwa"
                  Mnemonic = "v_cvt_f16_f32_fake16";
                return;
              case 'p':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+12, "8_fake16_sdwa", 13) != 0)
                  break;
                if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_f16_fp8_fake16_sdwa"
                  Mnemonic = "v_cvt_f16_fp8_fake16";
                return;
              }
              break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16_fake16_sdwa", 14) != 0)
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_f16_i16_fake16_sdwa"
                Mnemonic = "v_cvt_f16_i16_fake16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "16_fake16_sdwa", 14) != 0)
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_f16_u16_fake16_sdwa"
                Mnemonic = "v_cvt_f16_u16_fake16";
              return;
            }
            break;
          case '3':	 // 5 strings to match.
            if (memcmp(Mnemonic.data()+8, "2_", 2) != 0)
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'b':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+11, "f16_fake16_e", 12) != 0)
                break;
              switch (Mnemonic[23]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[24] != '2')
                  break;
                if (Features.test(Feature_HasBF16ConversionInstsBit) && Features.test(Feature_HasGFX950InstsBit))	 // "v_cvt_f32_bf16_fake16_e32"
                  Mnemonic = "v_cvt_f32_bf16_fake16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[24] != '4')
                  break;
                if (Features.test(Feature_HasBF16ConversionInstsBit) && Features.test(Feature_HasGFX950InstsBit))	 // "v_cvt_f32_bf16_fake16_e64"
                  Mnemonic = "v_cvt_f32_bf16_fake16";
                return;
              }
              break;
            case 'f':	 // 3 strings to match.
              switch (Mnemonic[11]) {
              default: break;
              case '1':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+12, "6_fake16_sdwa", 13) != 0)
                  break;
                if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_f32_f16_fake16_sdwa"
                  Mnemonic = "v_cvt_f32_f16_fake16";
                return;
              case 'p':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+12, "8_gfx1250_e", 11) != 0)
                  break;
                switch (Mnemonic[23]) {
                default: break;
                case '3':	 // 1 string to match.
                  if (Mnemonic[24] != '2')
                    break;
                  if (Features.test(Feature_HasFP8ConversionInstsBit) && Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_f32_fp8_gfx1250_e32"
                    Mnemonic = "v_cvt_f32_fp8_gfx1250";
                  return;
                case '6':	 // 1 string to match.
                  if (Mnemonic[24] != '4')
                    break;
                  if (Features.test(Feature_HasFP8ConversionInstsBit) && Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_f32_fp8_gfx1250_e64"
                    Mnemonic = "v_cvt_f32_fp8_gfx1250";
                  return;
                }
                break;
              }
              break;
            }
            break;
          }
          break;
        case 'i':	 // 2 strings to match.
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "6_f16_fake16_sdwa", 17) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_i16_f16_fake16_sdwa"
              Mnemonic = "v_cvt_i16_f16_fake16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "2_i16_fake16_sdwa", 17) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_i32_i16_fake16_sdwa"
              Mnemonic = "v_cvt_i32_i16_fake16";
            return;
          }
          break;
        case 'n':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+7, "orm_", 4) != 0)
            break;
          switch (Mnemonic[11]) {
          default: break;
          case 'i':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+12, "16_f16_fake16", 13) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_norm_i16_f16_fake16"
              Mnemonic = "v_cvt_norm_i16_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cvt_norm_i16_f16";
            return;
          case 'u':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+12, "16_f16_fake16", 13) != 0)
              break;
            if (Features.test(Feature_isGFX11OnlyBit))	 // "v_cvt_norm_u16_f16_fake16"
              Mnemonic = "v_cvt_norm_u16_f16";
            else if (Features.test(Feature_isGFX12OnlyBit))
              Mnemonic = "v_cvt_norm_u16_f16";
            return;
          }
          break;
        case 'u':	 // 2 strings to match.
          switch (Mnemonic[7]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "6_f16_fake16_sdwa", 17) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_u16_f16_fake16_sdwa"
              Mnemonic = "v_cvt_u16_f16_fake16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+8, "2_u16_fake16_sdwa", 17) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX11PlusBit))	 // "v_cvt_u32_u16_fake16_sdwa"
              Mnemonic = "v_cvt_u32_u16_fake16";
            return;
          }
          break;
        }
        break;
      case 'f':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "rexp_mant_f16_t16_sdwa", 22) != 0)
          break;
        if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_frexp_mant_f16_t16_sdwa"
          Mnemonic = "v_frexp_mant_f16_t16";
        return;
      case 'p':	 // 4 strings to match.
        if (memcmp(Mnemonic.data()+3, "ermlane", 7) != 0)
          break;
        switch (Mnemonic[10]) {
        default: break;
        case '1':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+11, "6_swap_b32_e", 12) != 0)
            break;
          switch (Mnemonic[23]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[24] != '2')
              break;
            if (Features.test(Feature_HasPermlane16SwapBit))	 // "v_permlane16_swap_b32_e32"
              Mnemonic = "v_permlane16_swap_b32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[24] != '4')
              break;
            if (Features.test(Feature_HasPermlane16SwapBit))	 // "v_permlane16_swap_b32_e64"
              Mnemonic = "v_permlane16_swap_b32";
            return;
          }
          break;
        case '3':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+11, "2_swap_b32_e", 12) != 0)
            break;
          switch (Mnemonic[23]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[24] != '2')
              break;
            if (Features.test(Feature_HasPermlane32SwapBit))	 // "v_permlane32_swap_b32_e32"
              Mnemonic = "v_permlane32_swap_b32";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[24] != '4')
              break;
            if (Features.test(Feature_HasPermlane32SwapBit))	 // "v_permlane32_swap_b32_e64"
              Mnemonic = "v_permlane32_swap_b32";
            return;
          }
          break;
        }
        break;
      case 's':	 // 4 strings to match.
        if (memcmp(Mnemonic.data()+3, "mfmac_f32_", 10) != 0)
          break;
        switch (Mnemonic[13]) {
        default: break;
        case '1':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+14, "6x16x", 5) != 0)
            break;
          switch (Mnemonic[19]) {
          default: break;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+20, "2bf16", 5) != 0)
              break;
            if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_16x16x32bf16"
              Mnemonic = "v_smfmac_f32_16x16x32_bf16";
            return;
          case '6':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+20, "4bf16", 5) != 0)
              break;
            if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_16x16x64bf16"
              Mnemonic = "v_smfmac_f32_16x16x64_bf16";
            return;
          }
          break;
        case '3':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+14, "2x32x", 5) != 0)
            break;
          switch (Mnemonic[19]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+20, "6bf16", 5) != 0)
              break;
            if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_32x32x16bf16"
              Mnemonic = "v_smfmac_f32_32x32x16_bf16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+20, "2bf16", 5) != 0)
              break;
            if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_32x32x32bf16"
              Mnemonic = "v_smfmac_f32_32x32x32_bf16";
            return;
          }
          break;
        }
        break;
      }
      break;
    }
    break;
  case 26:	 // 18 strings to match.
    switch (Mnemonic[0]) {
    default: break;
    case 'b':	 // 2 strings to match.
      if (memcmp(Mnemonic.data()+1, "uffer_", 6) != 0)
        break;
      switch (Mnemonic[7]) {
      default: break;
      case 'l':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+8, "oad_format_d16_xyz", 18) != 0)
          break;
        if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_load_format_d16_xyz"
          Mnemonic = "buffer_load_d16_format_xyz";
        return;
      case 's':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+8, "tore_format_d16_xy", 18) != 0)
          break;
        if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_store_format_d16_xy"
          Mnemonic = "buffer_store_d16_format_xy";
        return;
      }
      break;
    case 's':	 // 1 string to match.
      if (memcmp(Mnemonic.data()+1, "cratch_store_short_d16_hi", 25) != 0)
        break;
      if (Features.test(Feature_isGFX11OnlyBit))	 // "scratch_store_short_d16_hi"
        Mnemonic = "scratch_store_d16_hi_b16";
      else if (Features.test(Feature_isGFX12OnlyBit))
        Mnemonic = "scratch_store_d16_hi_b16";
      return;
    case 't':	 // 2 strings to match.
      if (memcmp(Mnemonic.data()+1, "buffer_", 7) != 0)
        break;
      switch (Mnemonic[8]) {
      default: break;
      case 'l':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+9, "oad_format_d16_xy", 17) != 0)
          break;
        if (Features.test(Feature_isGFX11PlusBit))	 // "tbuffer_load_format_d16_xy"
          Mnemonic = "tbuffer_load_d16_format_xy";
        return;
      case 's':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+9, "tore_format_d16_x", 17) != 0)
          break;
        if (Features.test(Feature_isGFX11PlusBit))	 // "tbuffer_store_format_d16_x"
          Mnemonic = "tbuffer_store_d16_format_x";
        return;
      }
      break;
    case 'v':	 // 13 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'c':	 // 6 strings to match.
        if (memcmp(Mnemonic.data()+3, "vt_", 3) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case 'f':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+7, "32_bf16_", 8) != 0)
            break;
          switch (Mnemonic[15]) {
          default: break;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+16, "ake16_sdwa", 10) != 0)
              break;
            if (Features.test(Feature_HasBF16ConversionInstsBit) && Features.test(Feature_HasGFX950InstsBit))	 // "v_cvt_f32_bf16_fake16_sdwa"
              Mnemonic = "v_cvt_f32_bf16_fake16";
            return;
          case 'g':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+16, "fx1250_t16", 10) != 0)
              break;
            if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_f32_bf16_gfx1250_t16"
              Mnemonic = "v_cvt_f32_bf16";
            return;
          }
          break;
        case 'n':	 // 4 strings to match.
          if (memcmp(Mnemonic.data()+7, "orm_", 4) != 0)
            break;
          switch (Mnemonic[11]) {
          default: break;
          case 'i':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+12, "16_f16_t16_e", 12) != 0)
              break;
            switch (Mnemonic[24]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[25] != '2')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_i16_f16_t16_e32"
                Mnemonic = "v_cvt_norm_i16_f16_t16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[25] != '4')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_i16_f16_t16_e64"
                Mnemonic = "v_cvt_norm_i16_f16_t16";
              return;
            }
            break;
          case 'u':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+12, "16_f16_t16_e", 12) != 0)
              break;
            switch (Mnemonic[24]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[25] != '2')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_u16_f16_t16_e32"
                Mnemonic = "v_cvt_norm_u16_f16_t16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[25] != '4')
                break;
              if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_u16_f16_t16_e64"
                Mnemonic = "v_cvt_norm_u16_f16_t16";
              return;
            }
            break;
          }
          break;
        }
        break;
      case 'f':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "rexp_exp_i16_f16_fake16", 23) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_frexp_exp_i16_f16_fake16"
          Mnemonic = "v_frexp_exp_i16_f16";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_frexp_exp_i16_f16";
        return;
      case 's':	 // 6 strings to match.
        if (memcmp(Mnemonic.data()+3, "at_pk", 5) != 0)
          break;
        switch (Mnemonic[8]) {
        default: break;
        case '4':	 // 4 strings to match.
          if (Mnemonic[9] != '_')
            break;
          switch (Mnemonic[10]) {
          default: break;
          case 'i':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+11, "4_i8_fake16_e", 13) != 0)
              break;
            switch (Mnemonic[24]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[25] != '2')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_i4_i8_fake16_e32"
                Mnemonic = "v_sat_pk4_i4_i8_fake16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[25] != '4')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_i4_i8_fake16_e64"
                Mnemonic = "v_sat_pk4_i4_i8_fake16";
              return;
            }
            break;
          case 'u':	 // 2 strings to match.
            if (memcmp(Mnemonic.data()+11, "4_u8_fake16_e", 13) != 0)
              break;
            switch (Mnemonic[24]) {
            default: break;
            case '3':	 // 1 string to match.
              if (Mnemonic[25] != '2')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_u4_u8_fake16_e32"
                Mnemonic = "v_sat_pk4_u4_u8_fake16";
              return;
            case '6':	 // 1 string to match.
              if (Mnemonic[25] != '4')
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_u4_u8_fake16_e64"
                Mnemonic = "v_sat_pk4_u4_u8_fake16";
              return;
            }
            break;
          }
          break;
        case '_':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+9, "u8_i16_fake16_e", 15) != 0)
            break;
          switch (Mnemonic[24]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[25] != '2')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX9PlusBit))	 // "v_sat_pk_u8_i16_fake16_e32"
              Mnemonic = "v_sat_pk_u8_i16_fake16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[25] != '4')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX9PlusBit))	 // "v_sat_pk_u8_i16_fake16_e64"
              Mnemonic = "v_sat_pk_u8_i16_fake16";
            return;
          }
          break;
        }
        break;
      }
      break;
    }
    break;
  case 27:	 // 37 strings to match.
    switch (Mnemonic[0]) {
    default: break;
    case 'b':	 // 3 strings to match.
      if (memcmp(Mnemonic.data()+1, "uffer_", 6) != 0)
        break;
      switch (Mnemonic[7]) {
      default: break;
      case 'l':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+8, "oad_format_d16_", 15) != 0)
          break;
        switch (Mnemonic[23]) {
        default: break;
        case 'h':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+24, "i_x", 3) != 0)
            break;
          if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_load_format_d16_hi_x"
            Mnemonic = "buffer_load_d16_hi_format_x";
          return;
        case 'x':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+24, "yzw", 3) != 0)
            break;
          if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_load_format_d16_xyzw"
            Mnemonic = "buffer_load_d16_format_xyzw";
          return;
        }
        break;
      case 's':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+8, "tore_format_d16_xyz", 19) != 0)
          break;
        if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_store_format_d16_xyz"
          Mnemonic = "buffer_store_d16_format_xyz";
        return;
      }
      break;
    case 't':	 // 2 strings to match.
      if (memcmp(Mnemonic.data()+1, "buffer_", 7) != 0)
        break;
      switch (Mnemonic[8]) {
      default: break;
      case 'l':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+9, "oad_format_d16_xyz", 18) != 0)
          break;
        if (Features.test(Feature_isGFX11PlusBit))	 // "tbuffer_load_format_d16_xyz"
          Mnemonic = "tbuffer_load_d16_format_xyz";
        return;
      case 's':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+9, "tore_format_d16_xy", 18) != 0)
          break;
        if (Features.test(Feature_isGFX11PlusBit))	 // "tbuffer_store_format_d16_xy"
          Mnemonic = "tbuffer_store_d16_format_xy";
        return;
      }
      break;
    case 'v':	 // 32 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'c':	 // 10 strings to match.
        if (memcmp(Mnemonic.data()+3, "vt_", 3) != 0)
          break;
        switch (Mnemonic[6]) {
        default: break;
        case 'n':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+7, "orm_", 4) != 0)
            break;
          switch (Mnemonic[11]) {
          default: break;
          case 'i':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+12, "16_f16_t16_sdwa", 15) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_i16_f16_t16_sdwa"
              Mnemonic = "v_cvt_norm_i16_f16_t16";
            return;
          case 'u':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+12, "16_f16_t16_sdwa", 15) != 0)
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_u16_f16_t16_sdwa"
              Mnemonic = "v_cvt_norm_u16_f16_t16";
            return;
          }
          break;
        case 'p':	 // 8 strings to match.
          if (memcmp(Mnemonic.data()+7, "k_f", 3) != 0)
            break;
          switch (Mnemonic[10]) {
          default: break;
          case '1':	 // 4 strings to match.
            if (memcmp(Mnemonic.data()+11, "6_", 2) != 0)
              break;
            switch (Mnemonic[13]) {
            default: break;
            case 'b':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+14, "f8_fake16_e", 11) != 0)
                break;
              switch (Mnemonic[25]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[26] != '2')
                  break;
                if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_pk_f16_bf8_fake16_e32"
                  Mnemonic = "v_cvt_pk_f16_bf8_fake16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[26] != '4')
                  break;
                if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_pk_f16_bf8_fake16_e64"
                  Mnemonic = "v_cvt_pk_f16_bf8_fake16";
                return;
              }
              break;
            case 'f':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+14, "p8_fake16_e", 11) != 0)
                break;
              switch (Mnemonic[25]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[26] != '2')
                  break;
                if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_pk_f16_fp8_fake16_e32"
                  Mnemonic = "v_cvt_pk_f16_fp8_fake16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[26] != '4')
                  break;
                if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_cvt_pk_f16_fp8_fake16_e64"
                  Mnemonic = "v_cvt_pk_f16_fp8_fake16";
                return;
              }
              break;
            }
            break;
          case '3':	 // 4 strings to match.
            if (memcmp(Mnemonic.data()+11, "2_", 2) != 0)
              break;
            switch (Mnemonic[13]) {
            default: break;
            case 'b':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+14, "f8_fake16_e", 11) != 0)
                break;
              switch (Mnemonic[25]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[26] != '2')
                  break;
                if (Features.test(Feature_HasFP8ConversionInstsBit) && Features.test(Feature_isGFX12PlusBit) && Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_pk_f32_bf8_fake16_e32"
                  Mnemonic = "v_cvt_pk_f32_bf8_fake16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[26] != '4')
                  break;
                if (Features.test(Feature_HasFP8ConversionInstsBit) && Features.test(Feature_isGFX12PlusBit) && Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_pk_f32_bf8_fake16_e64"
                  Mnemonic = "v_cvt_pk_f32_bf8_fake16";
                return;
              }
              break;
            case 'f':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+14, "p8_fake16_e", 11) != 0)
                break;
              switch (Mnemonic[25]) {
              default: break;
              case '3':	 // 1 string to match.
                if (Mnemonic[26] != '2')
                  break;
                if (Features.test(Feature_HasFP8ConversionInstsBit) && Features.test(Feature_isGFX12PlusBit) && Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_pk_f32_fp8_fake16_e32"
                  Mnemonic = "v_cvt_pk_f32_fp8_fake16";
                return;
              case '6':	 // 1 string to match.
                if (Mnemonic[26] != '4')
                  break;
                if (Features.test(Feature_HasFP8ConversionInstsBit) && Features.test(Feature_isGFX12PlusBit) && Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_pk_f32_fp8_fake16_e64"
                  Mnemonic = "v_cvt_pk_f32_fp8_fake16";
                return;
              }
              break;
            }
            break;
          }
          break;
        }
        break;
      case 'd':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+3, "iv_fixup_f16_gfx9_fake16", 24) != 0)
          break;
        if (Features.test(Feature_isGFX11OnlyBit))	 // "v_div_fixup_f16_gfx9_fake16"
          Mnemonic = "v_div_fixup_f16";
        else if (Features.test(Feature_isGFX12OnlyBit))
          Mnemonic = "v_div_fixup_f16";
        return;
      case 'f':	 // 4 strings to match.
        if (memcmp(Mnemonic.data()+3, "rexp_", 5) != 0)
          break;
        switch (Mnemonic[8]) {
        default: break;
        case 'e':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+9, "xp_i16_f16_t16_e", 16) != 0)
            break;
          switch (Mnemonic[25]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[26] != '2')
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_frexp_exp_i16_f16_t16_e32"
              Mnemonic = "v_frexp_exp_i16_f16_t16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[26] != '4')
              break;
            if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_frexp_exp_i16_f16_t16_e64"
              Mnemonic = "v_frexp_exp_i16_f16_t16";
            return;
          }
          break;
        case 'm':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+9, "ant_f16_fake16_e", 16) != 0)
            break;
          switch (Mnemonic[25]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[26] != '2')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_frexp_mant_f16_fake16_e32"
              Mnemonic = "v_frexp_mant_f16_fake16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[26] != '4')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_frexp_mant_f16_fake16_e64"
              Mnemonic = "v_frexp_mant_f16_fake16";
            return;
          }
          break;
        }
        break;
      case 'm':	 // 2 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "ximumminimum_f16_fake16", 23) != 0)
            break;
          if (Features.test(Feature_isGFX12OnlyBit))	 // "v_maximumminimum_f16_fake16"
            Mnemonic = "v_maximumminimum_f16";
          return;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+4, "nimummaximum_f16_fake16", 23) != 0)
            break;
          if (Features.test(Feature_isGFX12OnlyBit))	 // "v_minimummaximum_f16_fake16"
            Mnemonic = "v_minimummaximum_f16";
          return;
        }
        break;
      case 's':	 // 15 strings to match.
        switch (Mnemonic[3]) {
        default: break;
        case 'a':	 // 3 strings to match.
          if (memcmp(Mnemonic.data()+4, "t_pk", 4) != 0)
            break;
          switch (Mnemonic[8]) {
          default: break;
          case '4':	 // 2 strings to match.
            if (Mnemonic[9] != '_')
              break;
            switch (Mnemonic[10]) {
            default: break;
            case 'i':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "4_i8_fake16_sdwa", 16) != 0)
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_i4_i8_fake16_sdwa"
                Mnemonic = "v_sat_pk4_i4_i8_fake16";
              return;
            case 'u':	 // 1 string to match.
              if (memcmp(Mnemonic.data()+11, "4_u8_fake16_sdwa", 16) != 0)
                break;
              if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX1250PlusBit))	 // "v_sat_pk4_u4_u8_fake16_sdwa"
                Mnemonic = "v_sat_pk4_u4_u8_fake16";
              return;
            }
            break;
          case '_':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+9, "u8_i16_fake16_sdwa", 18) != 0)
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_isGFX9PlusBit))	 // "v_sat_pk_u8_i16_fake16_sdwa"
              Mnemonic = "v_sat_pk_u8_i16_fake16";
            return;
          }
          break;
        case 'm':	 // 12 strings to match.
          if (memcmp(Mnemonic.data()+4, "fmac_f32_", 9) != 0)
            break;
          switch (Mnemonic[13]) {
          default: break;
          case '1':	 // 4 strings to match.
            if (memcmp(Mnemonic.data()+14, "6x16x64", 7) != 0)
              break;
            switch (Mnemonic[21]) {
            default: break;
            case 'b':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+22, "f8", 2) != 0)
                break;
              switch (Mnemonic[24]) {
              default: break;
              case 'b':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+25, "f8", 2) != 0)
                  break;
                if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_16x16x64bf8bf8"
                  Mnemonic = "v_smfmac_f32_16x16x64_bf8_bf8";
                return;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+25, "p8", 2) != 0)
                  break;
                if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_16x16x64bf8fp8"
                  Mnemonic = "v_smfmac_f32_16x16x64_bf8_fp8";
                return;
              }
              break;
            case 'f':	 // 2 strings to match.
              if (memcmp(Mnemonic.data()+22, "p8", 2) != 0)
                break;
              switch (Mnemonic[24]) {
              default: break;
              case 'b':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+25, "f8", 2) != 0)
                  break;
                if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_16x16x64fp8bf8"
                  Mnemonic = "v_smfmac_f32_16x16x64_fp8_bf8";
                return;
              case 'f':	 // 1 string to match.
                if (memcmp(Mnemonic.data()+25, "p8", 2) != 0)
                  break;
                if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_16x16x64fp8fp8"
                  Mnemonic = "v_smfmac_f32_16x16x64_fp8_fp8";
                return;
              }
              break;
            }
            break;
          case '3':	 // 8 strings to match.
            if (memcmp(Mnemonic.data()+14, "2x32x", 5) != 0)
              break;
            switch (Mnemonic[19]) {
            default: break;
            case '3':	 // 4 strings to match.
              if (Mnemonic[20] != '2')
                break;
              switch (Mnemonic[21]) {
              default: break;
              case 'b':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+22, "f8", 2) != 0)
                  break;
                switch (Mnemonic[24]) {
                default: break;
                case 'b':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+25, "f8", 2) != 0)
                    break;
                  if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_32x32x32bf8bf8"
                    Mnemonic = "v_smfmac_f32_32x32x32_bf8_bf8";
                  return;
                case 'f':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+25, "p8", 2) != 0)
                    break;
                  if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_32x32x32bf8fp8"
                    Mnemonic = "v_smfmac_f32_32x32x32_bf8_fp8";
                  return;
                }
                break;
              case 'f':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+22, "p8", 2) != 0)
                  break;
                switch (Mnemonic[24]) {
                default: break;
                case 'b':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+25, "f8", 2) != 0)
                    break;
                  if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_32x32x32fp8bf8"
                    Mnemonic = "v_smfmac_f32_32x32x32_fp8_bf8";
                  return;
                case 'f':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+25, "p8", 2) != 0)
                    break;
                  if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_32x32x32fp8fp8"
                    Mnemonic = "v_smfmac_f32_32x32x32_fp8_fp8";
                  return;
                }
                break;
              }
              break;
            case '6':	 // 4 strings to match.
              if (Mnemonic[20] != '4')
                break;
              switch (Mnemonic[21]) {
              default: break;
              case 'b':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+22, "f8", 2) != 0)
                  break;
                switch (Mnemonic[24]) {
                default: break;
                case 'b':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+25, "f8", 2) != 0)
                    break;
                  if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_32x32x64bf8bf8"
                    Mnemonic = "v_smfmac_f32_32x32x64_bf8_bf8";
                  return;
                case 'f':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+25, "p8", 2) != 0)
                    break;
                  if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_32x32x64bf8fp8"
                    Mnemonic = "v_smfmac_f32_32x32x64_bf8_fp8";
                  return;
                }
                break;
              case 'f':	 // 2 strings to match.
                if (memcmp(Mnemonic.data()+22, "p8", 2) != 0)
                  break;
                switch (Mnemonic[24]) {
                default: break;
                case 'b':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+25, "f8", 2) != 0)
                    break;
                  if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_32x32x64fp8bf8"
                    Mnemonic = "v_smfmac_f32_32x32x64_fp8_bf8";
                  return;
                case 'f':	 // 1 string to match.
                  if (memcmp(Mnemonic.data()+25, "p8", 2) != 0)
                    break;
                  if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_32x32x64fp8fp8"
                    Mnemonic = "v_smfmac_f32_32x32x64_fp8_fp8";
                  return;
                }
                break;
              }
              break;
            }
            break;
          }
          break;
        }
        break;
      }
      break;
    }
    break;
  case 28:	 // 13 strings to match.
    switch (Mnemonic[0]) {
    default: break;
    case 'b':	 // 2 strings to match.
      if (memcmp(Mnemonic.data()+1, "uffer_store_format_d16_", 23) != 0)
        break;
      switch (Mnemonic[24]) {
      default: break;
      case 'h':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+25, "i_x", 3) != 0)
          break;
        if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_store_format_d16_hi_x"
          Mnemonic = "buffer_store_d16_hi_format_x";
        return;
      case 'x':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+25, "yzw", 3) != 0)
          break;
        if (Features.test(Feature_isGFX11PlusBit))	 // "buffer_store_format_d16_xyzw"
          Mnemonic = "buffer_store_d16_format_xyzw";
        return;
      }
      break;
    case 't':	 // 2 strings to match.
      if (memcmp(Mnemonic.data()+1, "buffer_", 7) != 0)
        break;
      switch (Mnemonic[8]) {
      default: break;
      case 'l':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+9, "oad_format_d16_xyzw", 19) != 0)
          break;
        if (Features.test(Feature_isGFX11PlusBit))	 // "tbuffer_load_format_d16_xyzw"
          Mnemonic = "tbuffer_load_d16_format_xyzw";
        return;
      case 's':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+9, "tore_format_d16_xyz", 19) != 0)
          break;
        if (Features.test(Feature_isGFX11PlusBit))	 // "tbuffer_store_format_d16_xyz"
          Mnemonic = "tbuffer_store_d16_format_xyz";
        return;
      }
      break;
    case 'v':	 // 9 strings to match.
      if (Mnemonic[1] != '_')
        break;
      switch (Mnemonic[2]) {
      default: break;
      case 'c':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+3, "vt_pk_", 6) != 0)
          break;
        switch (Mnemonic[9]) {
        default: break;
        case 'b':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+10, "f8_f16_gfx1250_t16", 18) != 0)
            break;
          if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_pk_bf8_f16_gfx1250_t16"
            Mnemonic = "v_cvt_pk_bf8_f16";
          return;
        case 'f':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+10, "p8_f", 4) != 0)
            break;
          switch (Mnemonic[14]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+15, "6_gfx1250_t16", 13) != 0)
              break;
            if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_pk_fp8_f16_gfx1250_t16"
              Mnemonic = "v_cvt_pk_fp8_f16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+15, "2_gfx1250_t16", 13) != 0)
              break;
            if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_pk_fp8_f32_gfx1250_t16"
              Mnemonic = "v_cvt_pk_fp8_f32";
            return;
          }
          break;
        }
        break;
      case 'f':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+3, "rexp_", 5) != 0)
          break;
        switch (Mnemonic[8]) {
        default: break;
        case 'e':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+9, "xp_i16_f16_t16_sdwa", 19) != 0)
            break;
          if (Features.test(Feature_UseRealTrue16InstsBit))	 // "v_frexp_exp_i16_f16_t16_sdwa"
            Mnemonic = "v_frexp_exp_i16_f16_t16";
          return;
        case 'm':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+9, "ant_f16_fake16_sdwa", 19) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_frexp_mant_f16_fake16_sdwa"
            Mnemonic = "v_frexp_mant_f16_fake16";
          return;
        }
        break;
      case 's':	 // 4 strings to match.
        if (memcmp(Mnemonic.data()+3, "mfmac_f32_16x16x128", 19) != 0)
          break;
        switch (Mnemonic[22]) {
        default: break;
        case 'b':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+23, "f8", 2) != 0)
            break;
          switch (Mnemonic[25]) {
          default: break;
          case 'b':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+26, "f8", 2) != 0)
              break;
            if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_16x16x128bf8bf8"
              Mnemonic = "v_smfmac_f32_16x16x128_bf8_bf8";
            return;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+26, "p8", 2) != 0)
              break;
            if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_16x16x128bf8fp8"
              Mnemonic = "v_smfmac_f32_16x16x128_bf8_fp8";
            return;
          }
          break;
        case 'f':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+23, "p8", 2) != 0)
            break;
          switch (Mnemonic[25]) {
          default: break;
          case 'b':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+26, "f8", 2) != 0)
              break;
            if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_16x16x128fp8bf8"
              Mnemonic = "v_smfmac_f32_16x16x128_fp8_bf8";
            return;
          case 'f':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+26, "p8", 2) != 0)
              break;
            if (Features.test(Feature_isGFX940PlusBit))	 // "v_smfmac_f32_16x16x128fp8fp8"
              Mnemonic = "v_smfmac_f32_16x16x128_fp8_fp8";
            return;
          }
          break;
        }
        break;
      }
      break;
    }
    break;
  case 29:	 // 6 strings to match.
    switch (Mnemonic[0]) {
    default: break;
    case 't':	 // 1 string to match.
      if (memcmp(Mnemonic.data()+1, "buffer_store_format_d16_xyzw", 28) != 0)
        break;
      if (Features.test(Feature_isGFX11PlusBit))	 // "tbuffer_store_format_d16_xyzw"
        Mnemonic = "tbuffer_store_d16_format_xyzw";
      return;
    case 'v':	 // 5 strings to match.
      if (memcmp(Mnemonic.data()+1, "_cvt_", 5) != 0)
        break;
      switch (Mnemonic[6]) {
      default: break;
      case 'f':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+7, "32_bf16_gfx1250_fake16", 22) != 0)
          break;
        if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_f32_bf16_gfx1250_fake16"
          Mnemonic = "v_cvt_f32_bf16";
        return;
      case 'n':	 // 4 strings to match.
        if (memcmp(Mnemonic.data()+7, "orm_", 4) != 0)
          break;
        switch (Mnemonic[11]) {
        default: break;
        case 'i':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+12, "16_f16_fake16_e", 15) != 0)
            break;
          switch (Mnemonic[27]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[28] != '2')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_i16_f16_fake16_e32"
              Mnemonic = "v_cvt_norm_i16_f16_fake16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[28] != '4')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_i16_f16_fake16_e64"
              Mnemonic = "v_cvt_norm_i16_f16_fake16";
            return;
          }
          break;
        case 'u':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+12, "16_f16_fake16_e", 15) != 0)
            break;
          switch (Mnemonic[27]) {
          default: break;
          case '3':	 // 1 string to match.
            if (Mnemonic[28] != '2')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_u16_f16_fake16_e32"
              Mnemonic = "v_cvt_norm_u16_f16_fake16";
            return;
          case '6':	 // 1 string to match.
            if (Mnemonic[28] != '4')
              break;
            if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_u16_f16_fake16_e64"
              Mnemonic = "v_cvt_norm_u16_f16_fake16";
            return;
          }
          break;
        }
        break;
      }
      break;
    }
    break;
  case 30:	 // 8 strings to match.
    if (memcmp(Mnemonic.data()+0, "v_", 2) != 0)
      break;
    switch (Mnemonic[2]) {
    default: break;
    case 'c':	 // 4 strings to match.
      if (memcmp(Mnemonic.data()+3, "vt_", 3) != 0)
        break;
      switch (Mnemonic[6]) {
      default: break;
      case 'f':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+7, "32_bf16_gfx1250_t16_e", 21) != 0)
          break;
        switch (Mnemonic[28]) {
        default: break;
        case '3':	 // 1 string to match.
          if (Mnemonic[29] != '2')
            break;
          if (Features.test(Feature_HasBF16ConversionInstsBit) && Features.test(Feature_isGFX1250PlusBit) && Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_f32_bf16_gfx1250_t16_e32"
            Mnemonic = "v_cvt_f32_bf16_gfx1250_t16";
          return;
        case '6':	 // 1 string to match.
          if (Mnemonic[29] != '4')
            break;
          if (Features.test(Feature_HasBF16ConversionInstsBit) && Features.test(Feature_isGFX1250PlusBit) && Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_f32_bf16_gfx1250_t16_e64"
            Mnemonic = "v_cvt_f32_bf16_gfx1250_t16";
          return;
        }
        break;
      case 'n':	 // 2 strings to match.
        if (memcmp(Mnemonic.data()+7, "orm_", 4) != 0)
          break;
        switch (Mnemonic[11]) {
        default: break;
        case 'i':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+12, "16_f16_fake16_sdwa", 18) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_i16_f16_fake16_sdwa"
            Mnemonic = "v_cvt_norm_i16_f16_fake16";
          return;
        case 'u':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+12, "16_f16_fake16_sdwa", 18) != 0)
            break;
          if (Features.test(Feature_UseFakeTrue16InstsBit) && Features.test(Feature_HasCvtNormInstsBit))	 // "v_cvt_norm_u16_f16_fake16_sdwa"
            Mnemonic = "v_cvt_norm_u16_f16_fake16";
          return;
        }
        break;
      }
      break;
    case 'f':	 // 2 strings to match.
      if (memcmp(Mnemonic.data()+3, "rexp_exp_i16_f16_fake16_e", 25) != 0)
        break;
      switch (Mnemonic[28]) {
      default: break;
      case '3':	 // 1 string to match.
        if (Mnemonic[29] != '2')
          break;
        if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_frexp_exp_i16_f16_fake16_e32"
          Mnemonic = "v_frexp_exp_i16_f16_fake16";
        return;
      case '6':	 // 1 string to match.
        if (Mnemonic[29] != '4')
          break;
        if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_frexp_exp_i16_f16_fake16_e64"
          Mnemonic = "v_frexp_exp_i16_f16_fake16";
        return;
      }
      break;
    case 's':	 // 2 strings to match.
      if (memcmp(Mnemonic.data()+3, "creen_partition_4se_b32_e", 25) != 0)
        break;
      switch (Mnemonic[28]) {
      default: break;
      case '3':	 // 1 string to match.
        if (Mnemonic[29] != '2')
          break;
        if (Features.test(Feature_isGFX9OnlyBit))	 // "v_screen_partition_4se_b32_e32"
          Mnemonic = "v_screen_partition_4se_b32";
        return;
      case '6':	 // 1 string to match.
        if (Mnemonic[29] != '4')
          break;
        if (Features.test(Feature_isGFX9OnlyBit))	 // "v_screen_partition_4se_b32_e64"
          Mnemonic = "v_screen_partition_4se_b32";
        return;
      }
      break;
    }
    break;
  case 31:	 // 6 strings to match.
    if (memcmp(Mnemonic.data()+0, "v_", 2) != 0)
      break;
    switch (Mnemonic[2]) {
    default: break;
    case 'c':	 // 4 strings to match.
      if (memcmp(Mnemonic.data()+3, "vt_", 3) != 0)
        break;
      switch (Mnemonic[6]) {
      default: break;
      case 'f':	 // 1 string to match.
        if (memcmp(Mnemonic.data()+7, "32_bf16_gfx1250_t16_sdwa", 24) != 0)
          break;
        if (Features.test(Feature_HasBF16ConversionInstsBit) && Features.test(Feature_isGFX1250PlusBit) && Features.test(Feature_UseRealTrue16InstsBit))	 // "v_cvt_f32_bf16_gfx1250_t16_sdwa"
          Mnemonic = "v_cvt_f32_bf16_gfx1250_t16";
        return;
      case 'p':	 // 3 strings to match.
        if (memcmp(Mnemonic.data()+7, "k_", 2) != 0)
          break;
        switch (Mnemonic[9]) {
        default: break;
        case 'b':	 // 1 string to match.
          if (memcmp(Mnemonic.data()+10, "f8_f16_gfx1250_fake16", 21) != 0)
            break;
          if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_pk_bf8_f16_gfx1250_fake16"
            Mnemonic = "v_cvt_pk_bf8_f16";
          return;
        case 'f':	 // 2 strings to match.
          if (memcmp(Mnemonic.data()+10, "p8_f", 4) != 0)
            break;
          switch (Mnemonic[14]) {
          default: break;
          case '1':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+15, "6_gfx1250_fake16", 16) != 0)
              break;
            if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_pk_fp8_f16_gfx1250_fake16"
              Mnemonic = "v_cvt_pk_fp8_f16";
            return;
          case '3':	 // 1 string to match.
            if (memcmp(Mnemonic.data()+15, "2_gfx1250_fake16", 16) != 0)
              break;
            if (Features.test(Feature_isGFX125xOnlyBit))	 // "v_cvt_pk_fp8_f32_gfx1250_fake16"
              Mnemonic = "v_cvt_pk_fp8_f32";
            return;
          }
          break;
        }
        break;
      }
      break;
    case 'f':	 // 1 string to match.
      if (memcmp(Mnemonic.data()+3, "rexp_exp_i16_f16_fake16_sdwa", 28) != 0)
        break;
      if (Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_frexp_exp_i16_f16_fake16_sdwa"
        Mnemonic = "v_frexp_exp_i16_f16_fake16";
      return;
    case 's':	 // 1 string to match.
      if (memcmp(Mnemonic.data()+3, "creen_partition_4se_b32_sdwa", 28) != 0)
        break;
      if (Features.test(Feature_isGFX9OnlyBit))	 // "v_screen_partition_4se_b32_sdwa"
        Mnemonic = "v_screen_partition_4se_b32";
      return;
    }
    break;
  case 33:	 // 2 strings to match.
    if (memcmp(Mnemonic.data()+0, "v_cvt_f32_bf16_gfx1250_fake16_e", 31) != 0)
      break;
    switch (Mnemonic[31]) {
    default: break;
    case '3':	 // 1 string to match.
      if (Mnemonic[32] != '2')
        break;
      if (Features.test(Feature_HasBF16ConversionInstsBit) && Features.test(Feature_isGFX1250PlusBit) && Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_f32_bf16_gfx1250_fake16_e32"
        Mnemonic = "v_cvt_f32_bf16_gfx1250_fake16";
      return;
    case '6':	 // 1 string to match.
      if (Mnemonic[32] != '4')
        break;
      if (Features.test(Feature_HasBF16ConversionInstsBit) && Features.test(Feature_isGFX1250PlusBit) && Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_f32_bf16_gfx1250_fake16_e64"
        Mnemonic = "v_cvt_f32_bf16_gfx1250_fake16";
      return;
    }
    break;
  case 34:	 // 1 string to match.
    if (memcmp(Mnemonic.data()+0, "v_cvt_f32_bf16_gfx1250_fake16_sdwa", 34) != 0)
      break;
    if (Features.test(Feature_HasBF16ConversionInstsBit) && Features.test(Feature_isGFX1250PlusBit) && Features.test(Feature_UseFakeTrue16InstsBit))	 // "v_cvt_f32_bf16_gfx1250_fake16_sdwa"
      Mnemonic = "v_cvt_f32_bf16_gfx1250_fake16";
    return;
  }
}

enum {
  Tie0_1_1,
  Tie1_1_1,
  Tie1_2_2,
  Tie1_5_5,
  Tie2_6_6,
};

static const uint8_t TiedAsmOperandTable[][3] = {
  /* Tie0_1_1 */ { 0, 1, 1 },
  /* Tie1_1_1 */ { 1, 1, 1 },
  /* Tie1_2_2 */ { 1, 2, 2 },
  /* Tie1_5_5 */ { 1, 5, 5 },
  /* Tie2_6_6 */ { 2, 6, 6 },
};

namespace {
enum OperatorConversionKind {
  CVT_Done,
  CVT_Reg,
  CVT_Tied,
  CVT_cvtMubufAtomic,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_,
  CVT_cvtMubuf,
  CVT_imm_95_0,
  CVT_95_Reg,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_,
  CVT_95_addRegOperands,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyWaitVAVDst_41__59__32__125_,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyWaitVMVSrc_41__59__32__125_,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset0_41__59__32__125_,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset1_41__59__32__125_,
  CVT_95_addImmOperands,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTySwizzle_41__59__32__125_,
  CVT_cvtExp,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyWaitVDST_41__59__32__125_,
  CVT_95_addRegOrImmOperands,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyNone_41__59__32__125_,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTySMEMOffsetMod_41__59__32__125_,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyEndpgm_41__59__32__125_,
  CVT_cvtVOP3DPP8,
  CVT_cvtVOP3DPP,
  CVT_cvtDPP8,
  CVT_cvtVOP3,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppRowMask_41__59__32__125_,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBankMask_41__59__32__125_,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBoundCtrl_41__59__32__125_,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppFI_41__59__32__125_,
  CVT_cvtSdwaVOP2b,
  CVT_cvtVOP3OpSel,
  CVT_cvtDPP,
  CVT_cvtSdwaVOP2,
  CVT_cvtSdwaVOP1,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBitOp3_41__59__32__125_,
  CVT_cvtSdwaVOPC,
  CVT_cvtSdwaVOP2e,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyByteSel_41__59__32__125_,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyClamp_41__59__32__125_,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyScaleSel_41__59__32__125_,
  CVT_cvtVOP3P,
  CVT_cvtVOPD,
  CVT_cvtVOP3Interp,
  CVT_cvtVINTERP,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_,
  CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_,
  CVT_cvtScaledMFMA,
  CVT_cvtSWMMAC,
  CVT_NUM_CONVERTERS
};

enum InstructionConversionKind {
  ConvertCustom_cvtMubufAtomic,
  Convert_NoOperands,
  Convert__CPol1_0,
  ConvertCustom_cvtMubuf,
  Convert__imm_95_0,
  Convert__Reg1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4,
  Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4,
  Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3,
  Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Offset1_2,
  Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4,
  Convert__Reg1_0__Offset1_1__GDS1_2,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Offset1_1__GDS1_2,
  Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__RegByHwMode_AV_LdSt_32_Target1_2__Offset1_3,
  Convert__Reg1_0__Reg1_1__Tie1_1_1__Reg1_2__RegByHwMode_VReg_128_AlignTarget1_3__Offset1_4,
  Convert__Reg1_0__Reg1_1__Tie1_1_1__Reg1_2__RegByHwMode_VReg_256_AlignTarget1_3__Offset1_4,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Tie1_1_1__Reg1_2__RegByHwMode_VReg_256_AlignTarget1_3__Offset1_4,
  Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4,
  Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset1_4__GDS1_5,
  Convert__Reg1_0__WaitVAVDst1_1__WaitVMVSrc1_2,
  Convert__AV_LdSt_32_Align2_RegOp1_0__Offset1_1,
  Convert__Offset1_0,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1,
  Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3,
  Convert__Reg1_0__Reg1_1__Offset1_2__GDS1_3,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2,
  Convert__Reg1_0__InterpAttr1_1__InterpAttrChan1_2__WaitVAVDst1_3__WaitVMVSrc1_4,
  Convert__RegByHwMode_AV_LdSt_96_Align11_0__Reg1_1__Offset1_2__GDS1_3,
  Convert__Reg1_0__Reg1_1__Reg1_2__Offset01_3__Offset11_4__GDS1_5,
  Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset01_3__Offset11_4__GDS1_5,
  Convert__Reg1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Offset1_2__GDS1_3,
  Convert__Reg1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Offset1_2__GDS1_3,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__Offset01_4__Offset11_5__GDS1_6,
  Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset01_4__Offset11_5__GDS1_6,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Swizzle1_2__GDS1_3,
  Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset01_4__Offset11_5__GDS1_6,
  ConvertCustom_cvtExp,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3,
  Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3,
  Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5,
  Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4,
  Convert__Reg1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_2__CPol1_3,
  Convert__Reg1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_128_AlignTarget1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_128_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__FlatOffset1_2__CPol1_3,
  Convert__Reg1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0,
  Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3,
  Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_1__CPol1_2,
  Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__FlatOffset1_2__CPol1_3,
  Convert__Reg1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4,
  Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5,
  Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_128_AlignTarget1_2__FlatOffset1_4__CPol1_5,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4,
  Convert__Reg1_0__FlatOffset1_2__CPol1_3,
  Convert__Reg1_0__Reg1_1__FlatOffset1_2__CPol1_3,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_2__CPol1_3,
  Convert__Reg1_2__Reg1_0__Reg1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__FlatOffset1_3__CPol1_4,
  Convert__Reg1_0__RegByHwMode_VReg_1024_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_1024_AlignTarget1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8,
  Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8,
  Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13,
  Convert__RegByHwMode_AV_LdSt_128_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8,
  Convert__RegByHwMode_AV_LdSt_160_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15,
  Convert__Reg1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__A161_3,
  Convert__Reg1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__A161_3,
  Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__RegByHwMode_VReg_96_AlignTarget1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__A161_8,
  Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__RegByHwMode_VReg_96_AlignTarget1_4__RegByHwMode_VReg_96_AlignTarget1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__A161_9,
  Convert__Reg1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__A161_13,
  Convert__Reg1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__A161_16,
  Convert__Reg1_0__RegByHwMode_VReg_96_AlignTarget1_4__RegByHwMode_VReg_96_AlignTarget1_5__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Tie1_5_5__Tie2_6_6__Reg1_6__Reg1_8,
  Convert__Reg1_0__RegByHwMode_VReg_96_AlignTarget1_4__RegByHwMode_VReg_96_AlignTarget1_5__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Tie1_5_5__Tie2_6_6__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8,
  Convert__Reg1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__A161_3,
  Convert__Reg1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__A161_3,
  Convert__Reg1_0__Reg1_2__Reg1_3__RegByHwMode_VReg_96_AlignTarget1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__A161_8,
  Convert__Reg1_0__Reg1_2__Reg1_3__RegByHwMode_VReg_96_AlignTarget1_4__RegByHwMode_VReg_96_AlignTarget1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__A161_9,
  Convert__Reg1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__A161_12,
  Convert__Reg1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__A161_15,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8,
  Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8,
  Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8,
  Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8,
  Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9,
  Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9,
  Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9,
  Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9,
  Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15,
  Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16,
  Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21,
  Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22,
  Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11,
  Convert__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12,
  Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25,
  Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_288_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_288_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_288_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_288_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_288_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_288_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17,
  Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_256_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_256_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_256_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_256_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_256_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_256_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18,
  Convert__Reg1_0__WaitVDST1_1,
  Convert__Reg1_0__InterpAttr1_1__InterpAttrChan1_2__WaitVDST1_3,
  Convert__Reg1_0__SSrc_b321_1,
  Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2,
  Convert__Reg1_0__SSrc_f161_1__SSrc_f161_2,
  Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2,
  Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2,
  Convert__SSrc_b641_0,
  Convert__Reg1_0__Tie0_1_1__S16Imm1_1,
  Convert__SSrc_b321_0,
  Convert__Reg1_0__SSrc_b641_1,
  Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2,
  Convert__Imm1_0__Reg1_1__Reg1_2,
  Convert__Imm1_0__Reg1_1__SMEMOffset1_2,
  Convert__Imm1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3,
  Convert__Imm1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3,
  Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3,
  Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3,
  Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3,
  Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3,
  Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4,
  Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4,
  Convert__SplitBarrier1_0,
  Convert__Imm1_0,
  Convert__SSrc_b321_0__SSrc_b321_1,
  Convert__SSrc_b641_0__SSrc_b321_1,
  Convert__Reg1_0__SSrc_b321_1__imm_95_0,
  Convert__SOPPBrTarget1_0,
  Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3,
  Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3,
  Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4,
  Convert__Reg1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3__CPol1_4,
  Convert__Reg1_0__Reg1_1__SMRDOffset81_2__CPol1_3,
  Convert__Reg1_0__Reg1_1__SMRDLiteralOffset1_2__CPol1_3,
  Convert__Reg1_0__SMEMOffset1_1__Reg1_2__Imm1_3,
  Convert__Reg1_0__SOPPBrTarget1_1,
  Convert__SCSrc_b641_0__SCSrc_b641_1,
  Convert__Reg1_0,
  Convert__S16Imm1_0,
  Convert__Reg1_0__S16Imm1_1,
  Convert__SSrc_b161_0__SSrc_b161_1,
  Convert__SSrc_b641_0__SSrc_b641_1,
  Convert__Reg1_0__U16Imm1_1,
  Convert__Reg1_0__Reg1_1,
  Convert__Reg1_0__SMEMOffset1_1,
  Convert__Reg1_0__Reg1_1__SMEMOffsetMod1_2,
  Convert__SDelayALU1_0,
  Convert__Endpgm1_0,
  Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2__KImmFP321_3,
  Convert__Reg1_0__SSrc_f161_1__SSrc_f161_2__Tie0_1_1,
  Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2__Tie0_1_1,
  Convert__Reg1_0__SSrc_f321_1__KImmFP321_2__SSrc_f321_3,
  Convert__SSrc_b321_0__SplitBarrier1_1,
  Convert__Reg1_0__Hwreg1_1,
  Convert__SMEMOffset1_0__Reg1_1__Imm1_2,
  Convert__SendMsg1_0,
  Convert__Reg1_0__SendMsg1_1,
  Convert__GPRIdxMode1_0,
  Convert__SSrc_b321_0__GPRIdxMode1_1,
  Convert__Reg1_1__Hwreg1_0,
  Convert__Imm1_1__Hwreg1_0,
  Convert__SOPPBrTarget1_1__Reg1_0,
  Convert__DepCtr1_0,
  Convert__SWaitCnt1_0,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_1024_AlignTarget1_0__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0,
  Convert__FlatOffset1_2__CPol1_3,
  Convert__Reg1_1__FlatOffset1_2__CPol1_3,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_1024_AlignTarget1_1__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_1024_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_1024_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_VReg_1024_AlignTarget1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0,
  Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0,
  Convert__Reg1_0__Reg1_1__R128A161_2__CPol1_3,
  Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__R128A161_4__CPol1_5,
  Convert__Reg1_0__FlatOffset1_1__CPol1_2,
  Convert__Reg1_0__VCSrc_b321_1,
  Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3,
  ConvertCustom_cvtVOP3DPP8,
  ConvertCustom_cvtVOP3DPP,
  Convert__Reg1_0__VSrc_b321_1__Reg1_2,
  Convert__Reg1_0__VSrc_b321_2__Reg1_3,
  ConvertCustom_cvtDPP8,
  ConvertCustom_cvtVOP3,
  Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7,
  ConvertCustom_cvtSdwaVOP2b,
  Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8__DppFI1_9,
  Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_4__DppRowMask1_5__DppBankMask1_6__DppBoundCtrl1_7,
  Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2,
  Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2,
  Convert__Reg1_0__VSrc_f161_1__Reg1_2,
  ConvertCustom_cvtVOP3OpSel,
  ConvertCustom_cvtDPP,
  ConvertCustom_cvtSdwaVOP2,
  Convert__Reg1_0__VSrc_f321_1__Reg1_2,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7,
  Convert__Reg1_0__VSrc_b161_1__Reg1_2,
  Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6,
  Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8,
  Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2,
  Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1__VSrc_b321_2,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1__VSrc_b641_2,
  Convert__Reg1_0__VSrc_b321_1,
  Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5,
  ConvertCustom_cvtSdwaVOP1,
  Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6,
  Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3__BitOp31_4,
  Convert__Reg1_0__VSrcFake16_f16_Lo1281_1,
  Convert__Reg1_0__VSrcT_f16_Lo1281_1,
  Convert__Reg1_0__VSrc_f161_1,
  Convert__Reg1_0__VSrc_f321_1,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1,
  Convert__VSrc_f161_0__Reg1_1,
  Convert__VSrcT_f16_Lo1281_0__Reg1_1,
  Convert__VSrcFake16_f16_Lo1281_0__Reg1_1,
  Convert__VSrc_f161_1__Reg1_2,
  Convert__VSrcT_f16_Lo1281_1__Reg1_2,
  Convert__VSrcFake16_f16_Lo1281_1__Reg1_2,
  ConvertCustom_cvtSdwaVOPC,
  Convert__VSrc_f321_0__Reg1_1,
  Convert__VSrc_f321_1__Reg1_2,
  Convert__VSrc_f641_0__Reg1_1,
  Convert__VSrc_f641_1__Reg1_2,
  Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1,
  Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2,
  Convert__VSrc_b161_0__Reg1_1,
  Convert__VSrcT_b16_Lo1281_0__Reg1_1,
  Convert__VSrcFake16_b16_Lo1281_0__Reg1_1,
  Convert__VSrc_b161_1__Reg1_2,
  Convert__VSrcT_b16_Lo1281_1__Reg1_2,
  Convert__VSrcFake16_b16_Lo1281_1__Reg1_2,
  Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2,
  Convert__VSrc_b321_0__Reg1_1,
  Convert__VSrc_b321_1__Reg1_2,
  Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2,
  Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1,
  Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2,
  Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2,
  Convert__VSrc_b161_0__VSrc_b161_1,
  Convert__VSrc_b321_0__VSrc_b321_1,
  Convert__VSrc_b641_0__VSrc_b641_1,
  ConvertCustom_cvtSdwaVOP2e,
  Convert__Reg1_0__VSrcFake16_bf16_Lo1281_1,
  Convert__Reg1_0__VSrcT_bf16_Lo1281_1,
  Convert__Reg1_0__VSrcFake16_b16_Lo1281_1,
  Convert__Reg1_0__VSrcT_b16_Lo1281_1,
  Convert__Reg1_0__VSrc_b161_1,
  Convert__Reg1_0__VSrc_bf161_1,
  Convert__Reg1_0__VSrc_b321_1__ByteSel1_2,
  Convert__Reg1_0__VSrc_f641_1,
  Convert__Reg1_0__VSrc_b321_1__Clamp1_3__ByteSel1_2,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f321_1,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrcT_f16_Lo1281_1,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrcFake16_f16_Lo1281_1,
  Convert__Reg1_0__imm_95_0__VCSrc_f321_1__imm_95_0__VCSrc_f321_2__imm_95_0,
  Convert__Reg1_0__imm_95_0__VCSrc_f321_1__imm_95_0__VCSrc_f321_2__imm_95_0__imm_95_0,
  Convert__RegByHwMode_VReg_256_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__VSrc_b321_2__ScaleSel1_3,
  Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__VSrc_b321_2__ScaleSel1_3,
  Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__VSrc_b321_2__ScaleSel1_3,
  Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__VSrc_b321_2__ScaleSel1_3,
  Convert__RegByHwMode_VReg_256_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__VSrc_b321_2__ScaleSel1_3,
  Convert__RegByHwMode_VReg_256_AlignTarget1_0__Reg1_1__VSrc_b321_2__ScaleSel1_3,
  Convert__RegByHwMode_VReg_192_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__RegByHwMode_VReg_512_AlignTarget1_2__VSrc_f321_3,
  Convert__RegByHwMode_VReg_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_f321_2,
  Convert__RegByHwMode_VReg_96_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__VSrc_f321_2,
  Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__VSrc_f321_2,
  Convert__RegByHwMode_VReg_192_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__VSrc_f321_2,
  Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__VSrc_f321_2,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__VSrc_f321_2,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_f321_2,
  Convert__Reg1_0__RegByHwMode_VReg_128_AlignTarget1_1__VSrc_f321_2,
  Convert__Reg1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_f321_2,
  Convert__RegByHwMode_VReg_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3,
  Convert__RegByHwMode_VReg_96_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3,
  Convert__RegByHwMode_VReg_192_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3,
  Convert__RegByHwMode_VReg_192_AlignTarget1_0__RegByHwMode_VReg_1024_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3,
  Convert__Reg1_0__RegByHwMode_VReg_128_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3,
  Convert__Reg1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3,
  ConvertCustom_cvtVOP3P,
  Convert__Reg1_0__VSrc_v2f161_1__Reg1_2__Tie0_1_1,
  Convert__Reg1_0__VSrc_v2bf161_1__Reg1_2__Tie0_1_1,
  Convert__Reg1_0__VSrc_b321_1__Reg1_2__Tie0_1_1,
  Convert__Reg1_0__imm_95_0__Reg1_1__imm_95_0__Reg1_2__Tie0_1_1__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6,
  Convert__Reg1_0__imm_95_0__Reg1_1__imm_95_0__Reg1_2__Tie0_1_1__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7,
  ConvertCustom_cvtVOPD,
  Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2__KImmFP161_3,
  Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2__KImmFP161_3,
  Convert__Reg1_0__VSrc_f161_1__Reg1_2__KImmFP161_3,
  Convert__Reg1_0__VSrc_f321_1__Reg1_2__KImmFP321_3,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2__KImmFP641_3,
  Convert__Reg1_0__VSrc_f321_1__Reg1_2__Tie0_1_1,
  Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2__Tie0_1_1,
  Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2__Tie0_1_1,
  Convert__Reg1_0__VSrc_f161_1__Reg1_2__Tie0_1_1,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2__Tie0_1_1,
  Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__KImmFP161_2__Reg1_3,
  Convert__Reg1_0__VSrcT_f16_Lo1281_1__KImmFP161_2__Reg1_3,
  Convert__Reg1_0__VSrc_f161_1__KImmFP161_2__Reg1_3,
  Convert__Reg1_0__VSrc_f321_1__KImmFP321_2__Reg1_3,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1__KImmFP641_2__Reg1_3,
  Convert__Reg1_0__InterpSlot1_1__InterpAttr1_2__InterpAttrChan1_3,
  ConvertCustom_cvtVOP3Interp,
  ConvertCustom_cvtVINTERP,
  Convert__Reg1_0__Reg1_1__InterpAttr1_2__InterpAttrChan1_3,
  Convert__Reg1_0__Tie0_1_1__Reg1_1__InterpAttr1_2__InterpAttrChan1_3,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1__VSrc_b321_2__VSrc_b641_3,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1__RegByHwMode_VReg_64_AlignTarget1_2,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1__VSrc_b641_2,
  Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_f321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_1024_f321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5,
  Convert__RegByHwMode_AReg_256_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_256_f641_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_VReg_256_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_256_f641_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_AReg_64_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_64_f641_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_64_f641_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6,
  ConvertCustom_cvtScaledMFMA,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__RegByHwMode_VReg_64_AlignTarget1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__RegByHwMode_VReg_64_AlignTarget1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6,
  Convert__DPPCtrl1_0__DppRowMask1_1__DppBankMask1_2__DppBoundCtrl1_3,
  Convert__DPPCtrl1_0__DppRowMask1_1__DppBankMask1_2__DppBoundCtrl1_3__DppFI1_4,
  Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1__VSrc_b321_2__VSrc_v2b321_3,
  Convert__RegByHwMode_VReg_96_AlignTarget1_0__VSrc_b321_1__VSrc_b641_2__VSrc_v2b321_3,
  Convert__RegByHwMode_VReg_128_AlignTarget1_0__VSrc_b641_1__VSrc_b641_2__VSrc_v2b321_3,
  Convert__Reg1_0__Reg1_1__Tie0_1_1__Tie1_2_2,
  Convert__Reg1_0__Reg1_1__Tie0_1_1__Tie1_2_2__DppFI1_3__DppBoundCtrl1_2,
  Convert__Reg1_0__Reg1_1__SSrc_b321_2__SSrc_b321_3,
  Convert__Reg1_0__Reg1_1__SSrc_b321_2,
  Convert__Reg1_0__VSrc_v2f16_splat1_1__Reg1_2,
  Convert__Reg1_0__Reg1_1__SCSrc_b321_2,
  Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1,
  Convert__Reg1_0__Reg1_1__Tie1_2_2__Tie0_1_1,
  ConvertCustom_cvtSWMMAC,
  Convert__Reg1_0__SSrcOrLds_b321_1__SCSrc_b321_2__Tie0_1_1,
  Convert__Reg1_0__SCSrc_b321_1__SCSrc_b321_2__Tie0_1_1,
  CVT_NUM_SIGNATURES
};

} // end anonymous namespace

static const uint8_t ConversionTable[CVT_NUM_SIGNATURES][49] = {
  // ConvertCustom_cvtMubufAtomic
  { CVT_cvtMubufAtomic, 0, CVT_Done },
  // Convert_NoOperands
  { CVT_Done },
  // Convert__CPol1_0
  { CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 1, CVT_Done },
  // ConvertCustom_cvtMubuf
  { CVT_cvtMubuf, 0, CVT_Done },
  // Convert__imm_95_0
  { CVT_imm_95_0, 0, CVT_Done },
  // Convert__Reg1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4
  { CVT_95_Reg, 1, CVT_95_Reg, 3, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Offset1_2
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_Done },
  // Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addRegOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 5, CVT_Done },
  // Convert__Reg1_0__Offset1_1__GDS1_2
  { CVT_95_Reg, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 3, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Offset1_1__GDS1_2
  { CVT_95_addRegOperands, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 3, CVT_Done },
  // Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__RegByHwMode_AV_LdSt_32_Target1_2__Offset1_3
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addRegOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__Reg1_1__Tie1_1_1__Reg1_2__RegByHwMode_VReg_128_AlignTarget1_3__Offset1_4
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_Tied, Tie1_1_1, CVT_95_Reg, 3, CVT_95_addRegOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 5, CVT_Done },
  // Convert__Reg1_0__Reg1_1__Tie1_1_1__Reg1_2__RegByHwMode_VReg_256_AlignTarget1_3__Offset1_4
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_Tied, Tie1_1_1, CVT_95_Reg, 3, CVT_95_addRegOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Tie1_1_1__Reg1_2__RegByHwMode_VReg_256_AlignTarget1_3__Offset1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_Tied, Tie1_1_1, CVT_95_Reg, 3, CVT_95_addRegOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 5, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 5, CVT_Done },
  // Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset1_4__GDS1_5
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 6, CVT_Done },
  // Convert__Reg1_0__WaitVAVDst1_1__WaitVMVSrc1_2
  { CVT_95_Reg, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyWaitVAVDst_41__59__32__125_, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyWaitVMVSrc_41__59__32__125_, 3, CVT_Done },
  // Convert__AV_LdSt_32_Align2_RegOp1_0__Offset1_1
  { CVT_95_addRegOperands, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 2, CVT_Done },
  // Convert__Offset1_0
  { CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 1, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset0_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset1_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset0_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset1_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 4, CVT_Tied, Tie0_1_1, CVT_Done },
  // Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__Reg1_1__Offset1_2__GDS1_3
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_Done },
  // Convert__Reg1_0__InterpAttr1_1__InterpAttrChan1_2__WaitVAVDst1_3__WaitVMVSrc1_4
  { CVT_95_Reg, 1, CVT_95_addImmOperands, 2, CVT_95_addImmOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyWaitVAVDst_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyWaitVMVSrc_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_Align11_0__Reg1_1__Offset1_2__GDS1_3
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__Reg1_1__Reg1_2__Offset01_3__Offset11_4__GDS1_5
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset0_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset1_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 6, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset01_3__Offset11_4__GDS1_5
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset0_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset1_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 6, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Offset1_2__GDS1_3
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Offset1_2__GDS1_3
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__Offset01_4__Offset11_5__GDS1_6
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset0_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset1_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset01_4__Offset11_5__GDS1_6
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset0_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset1_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Swizzle1_2__GDS1_3
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTySwizzle_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset01_4__Offset11_5__GDS1_6
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset0_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset1_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_, 7, CVT_Done },
  // ConvertCustom_cvtExp
  { CVT_cvtExp, 0, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addRegOperands, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__Reg1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_addRegOperands, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_2__CPol1_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_128_AlignTarget1_2__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_128_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addRegOperands, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__FlatOffset1_2__CPol1_3
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_1__CPol1_2
  { CVT_95_addRegOperands, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 3, CVT_Done },
  // Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3
  { CVT_95_Reg, 2, CVT_95_Reg, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__FlatOffset1_2__CPol1_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_128_AlignTarget1_2__FlatOffset1_4__CPol1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__Reg1_0__FlatOffset1_2__CPol1_3
  { CVT_95_Reg, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__Reg1_1__FlatOffset1_2__CPol1_3
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_2__CPol1_3
  { CVT_95_addRegOperands, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_2__Reg1_0__Reg1_1__FlatOffset1_3__CPol1_4
  { CVT_95_Reg, 3, CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_VReg_1024_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_1024_AlignTarget1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 9, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 9, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 9, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 9, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 9, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__A161_3
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__A161_3
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__RegByHwMode_VReg_96_AlignTarget1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__A161_8
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 3, CVT_95_Reg, 4, CVT_95_addRegOperands, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__RegByHwMode_VReg_96_AlignTarget1_4__RegByHwMode_VReg_96_AlignTarget1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__A161_9
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 3, CVT_95_Reg, 4, CVT_95_addRegOperands, 5, CVT_95_addRegOperands, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_Done },
  // Convert__Reg1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__A161_13
  { CVT_95_Reg, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_Done },
  // Convert__Reg1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__A161_16
  { CVT_95_Reg, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_Reg, 13, CVT_95_Reg, 14, CVT_95_Reg, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 17, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_VReg_96_AlignTarget1_4__RegByHwMode_VReg_96_AlignTarget1_5__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Tie1_5_5__Tie2_6_6__Reg1_6__Reg1_8
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 5, CVT_95_addRegOperands, 6, CVT_95_addRegOperands, 3, CVT_95_addRegOperands, 4, CVT_Tied, Tie1_5_5, CVT_Tied, Tie2_6_6, CVT_95_Reg, 7, CVT_95_Reg, 9, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_VReg_96_AlignTarget1_4__RegByHwMode_VReg_96_AlignTarget1_5__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Tie1_5_5__Tie2_6_6__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 5, CVT_95_addRegOperands, 6, CVT_95_addRegOperands, 3, CVT_95_addRegOperands, 4, CVT_Tied, Tie1_5_5, CVT_Tied, Tie2_6_6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__A161_3
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__A161_3
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__Reg1_2__Reg1_3__RegByHwMode_VReg_96_AlignTarget1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__A161_8
  { CVT_95_Reg, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addRegOperands, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_Done },
  // Convert__Reg1_0__Reg1_2__Reg1_3__RegByHwMode_VReg_96_AlignTarget1_4__RegByHwMode_VReg_96_AlignTarget1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__A161_9
  { CVT_95_Reg, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addRegOperands, 5, CVT_95_addRegOperands, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_Done },
  // Convert__Reg1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__A161_12
  { CVT_95_Reg, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_Done },
  // Convert__Reg1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__A161_15
  { CVT_95_Reg, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_Reg, 13, CVT_95_Reg, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 17, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 17, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 17, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 20, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 20, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 20, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 21, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 21, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 21, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 9, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 9, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 9, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 9, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 9, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 10, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 14, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 15, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 17, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 17, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 17, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 17, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 17, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 11, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 16, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 16, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 17, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 17, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 17, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 20, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 20, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 20, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 21, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 21, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 21, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 12, CVT_95_Reg, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 22, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 12, CVT_95_Reg, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 22, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 12, CVT_95_Reg, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 22, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 12, CVT_95_Reg, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 22, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 12, CVT_95_Reg, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 22, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 12, CVT_95_Reg, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 22, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 13, CVT_95_Reg, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 23, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 13, CVT_95_Reg, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 23, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 13, CVT_95_Reg, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 23, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 13, CVT_95_Reg, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 23, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 13, CVT_95_Reg, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 23, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 13, CVT_95_Reg, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 23, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_Reg, 14, CVT_95_Reg, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 23, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 24, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_Reg, 14, CVT_95_Reg, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 23, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 24, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_Reg, 14, CVT_95_Reg, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 23, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 24, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_Reg, 14, CVT_95_Reg, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 23, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 24, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_Reg, 14, CVT_95_Reg, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 23, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 24, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_Reg, 14, CVT_95_Reg, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 23, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 24, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_Reg, 13, CVT_95_Reg, 15, CVT_95_Reg, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 23, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 24, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 25, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_Reg, 13, CVT_95_Reg, 15, CVT_95_Reg, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 23, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 24, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 25, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_Reg, 13, CVT_95_Reg, 15, CVT_95_Reg, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 23, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 24, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 25, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_Reg, 13, CVT_95_Reg, 15, CVT_95_Reg, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 23, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 24, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 25, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_Reg, 13, CVT_95_Reg, 15, CVT_95_Reg, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 23, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 24, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 25, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_Reg, 13, CVT_95_Reg, 15, CVT_95_Reg, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 23, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 24, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 25, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 12, CVT_Done },
  // Convert__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 13, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_Reg, 13, CVT_95_Reg, 14, CVT_95_Reg, 16, CVT_95_Reg, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 23, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 24, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 25, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 26, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_Reg, 13, CVT_95_Reg, 14, CVT_95_Reg, 16, CVT_95_Reg, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 23, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 24, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 25, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 26, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_Reg, 13, CVT_95_Reg, 14, CVT_95_Reg, 16, CVT_95_Reg, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 23, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 24, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 25, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 26, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_Reg, 13, CVT_95_Reg, 14, CVT_95_Reg, 16, CVT_95_Reg, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 23, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 24, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 25, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 26, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_Reg, 13, CVT_95_Reg, 14, CVT_95_Reg, 16, CVT_95_Reg, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 23, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 24, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 25, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 26, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_Reg, 7, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_Reg, 11, CVT_95_Reg, 12, CVT_95_Reg, 13, CVT_95_Reg, 14, CVT_95_Reg, 16, CVT_95_Reg, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 19, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 20, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 21, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 22, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 23, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 24, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 25, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 26, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_288_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_288_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_288_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_288_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_288_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_288_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_addRegOperands, 6, CVT_95_Reg, 8, CVT_95_Reg, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 18, CVT_Done },
  // Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_256_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_256_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_256_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_256_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_256_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_256_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_Reg, 5, CVT_95_Reg, 6, CVT_95_addRegOperands, 7, CVT_95_Reg, 9, CVT_95_Reg, 10, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_, 11, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_, 12, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_, 13, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 14, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 15, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_, 16, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_, 17, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_, 18, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_, 19, CVT_Done },
  // Convert__Reg1_0__WaitVDST1_1
  { CVT_95_Reg, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyWaitVDST_41__59__32__125_, 2, CVT_Done },
  // Convert__Reg1_0__InterpAttr1_1__InterpAttrChan1_2__WaitVDST1_3
  { CVT_95_Reg, 1, CVT_95_addImmOperands, 2, CVT_95_addImmOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyWaitVDST_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__SSrc_b321_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__Reg1_0__SSrc_f161_1__SSrc_f161_2
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__SSrc_b641_0
  { CVT_95_addRegOrImmOperands, 1, CVT_Done },
  // Convert__Reg1_0__Tie0_1_1__S16Imm1_1
  { CVT_95_Reg, 1, CVT_Tied, Tie0_1_1, CVT_95_addImmOperands, 2, CVT_Done },
  // Convert__SSrc_b321_0
  { CVT_95_addRegOrImmOperands, 1, CVT_Done },
  // Convert__Reg1_0__SSrc_b641_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__Imm1_0__Reg1_1__Reg1_2
  { CVT_95_addImmOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_Done },
  // Convert__Imm1_0__Reg1_1__SMEMOffset1_2
  { CVT_95_addImmOperands, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyNone_41__59__32__125_, 3, CVT_Done },
  // Convert__Imm1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3
  { CVT_95_addImmOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands, 4, CVT_Done },
  // Convert__Imm1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3
  { CVT_95_addImmOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTySMEMOffsetMod_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3
  { CVT_95_Reg, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands, 4, CVT_Done },
  // Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3
  { CVT_95_Reg, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyNone_41__59__32__125_, 3, CVT_95_addImmOperands, 4, CVT_Done },
  // Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyNone_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4
  { CVT_95_Reg, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands, 4, CVT_95_addImmOperands, 5, CVT_Done },
  // Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__SplitBarrier1_0
  { CVT_95_addImmOperands, 1, CVT_Done },
  // Convert__Imm1_0
  { CVT_95_addImmOperands, 1, CVT_Done },
  // Convert__SSrc_b321_0__SSrc_b321_1
  { CVT_95_addRegOrImmOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__SSrc_b641_0__SSrc_b321_1
  { CVT_95_addRegOrImmOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__Reg1_0__SSrc_b321_1__imm_95_0
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_imm_95_0, 0, CVT_Done },
  // Convert__SOPPBrTarget1_0
  { CVT_95_addImmOperands, 1, CVT_Done },
  // Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyNone_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__Reg1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3__CPol1_4
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTySMEMOffsetMod_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__Reg1_0__Reg1_1__SMRDOffset81_2__CPol1_3
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyNone_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__Reg1_1__SMRDLiteralOffset1_2__CPol1_3
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_addImmOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__SMEMOffset1_1__Reg1_2__Imm1_3
  { CVT_95_Reg, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyNone_41__59__32__125_, 2, CVT_95_Reg, 3, CVT_95_addImmOperands, 4, CVT_Done },
  // Convert__Reg1_0__SOPPBrTarget1_1
  { CVT_95_Reg, 1, CVT_95_addImmOperands, 2, CVT_Done },
  // Convert__SCSrc_b641_0__SCSrc_b641_1
  { CVT_95_addRegOrImmOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__Reg1_0
  { CVT_95_Reg, 1, CVT_Done },
  // Convert__S16Imm1_0
  { CVT_95_addImmOperands, 1, CVT_Done },
  // Convert__Reg1_0__S16Imm1_1
  { CVT_95_Reg, 1, CVT_95_addImmOperands, 2, CVT_Done },
  // Convert__SSrc_b161_0__SSrc_b161_1
  { CVT_95_addRegOrImmOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__SSrc_b641_0__SSrc_b641_1
  { CVT_95_addRegOrImmOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__Reg1_0__U16Imm1_1
  { CVT_95_Reg, 1, CVT_95_addImmOperands, 2, CVT_Done },
  // Convert__Reg1_0__Reg1_1
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_Done },
  // Convert__Reg1_0__SMEMOffset1_1
  { CVT_95_Reg, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyNone_41__59__32__125_, 2, CVT_Done },
  // Convert__Reg1_0__Reg1_1__SMEMOffsetMod1_2
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_addImmOperands, 3, CVT_Done },
  // Convert__SDelayALU1_0
  { CVT_95_addImmOperands, 1, CVT_Done },
  // Convert__Endpgm1_0
  { CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyEndpgm_41__59__32__125_, 1, CVT_Done },
  // Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2__KImmFP321_3
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_95_addImmOperands, 4, CVT_Done },
  // Convert__Reg1_0__SSrc_f161_1__SSrc_f161_2__Tie0_1_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Tied, Tie0_1_1, CVT_Done },
  // Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2__Tie0_1_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Tied, Tie0_1_1, CVT_Done },
  // Convert__Reg1_0__SSrc_f321_1__KImmFP321_2__SSrc_f321_3
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addImmOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_Done },
  // Convert__SSrc_b321_0__SplitBarrier1_1
  { CVT_95_addRegOrImmOperands, 1, CVT_95_addImmOperands, 2, CVT_Done },
  // Convert__Reg1_0__Hwreg1_1
  { CVT_95_Reg, 1, CVT_95_addImmOperands, 2, CVT_Done },
  // Convert__SMEMOffset1_0__Reg1_1__Imm1_2
  { CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyNone_41__59__32__125_, 1, CVT_95_Reg, 2, CVT_95_addImmOperands, 3, CVT_Done },
  // Convert__SendMsg1_0
  { CVT_95_addImmOperands, 1, CVT_Done },
  // Convert__Reg1_0__SendMsg1_1
  { CVT_95_Reg, 1, CVT_95_addImmOperands, 2, CVT_Done },
  // Convert__GPRIdxMode1_0
  { CVT_95_addImmOperands, 1, CVT_Done },
  // Convert__SSrc_b321_0__GPRIdxMode1_1
  { CVT_95_addRegOrImmOperands, 1, CVT_95_addImmOperands, 2, CVT_Done },
  // Convert__Reg1_1__Hwreg1_0
  { CVT_95_Reg, 2, CVT_95_addImmOperands, 1, CVT_Done },
  // Convert__Imm1_1__Hwreg1_0
  { CVT_95_addImmOperands, 2, CVT_95_addImmOperands, 1, CVT_Done },
  // Convert__SOPPBrTarget1_1__Reg1_0
  { CVT_95_addImmOperands, 2, CVT_95_Reg, 1, CVT_Done },
  // Convert__DepCtr1_0
  { CVT_95_addImmOperands, 1, CVT_Done },
  // Convert__SWaitCnt1_0
  { CVT_95_addImmOperands, 1, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_1024_AlignTarget1_0__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_imm_95_0, 0, CVT_Done },
  // Convert__FlatOffset1_2__CPol1_3
  { CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_1__FlatOffset1_2__CPol1_3
  { CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 1, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 1, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 1, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 1, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_1024_AlignTarget1_1__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_1024_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_1024_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_1024_AlignTarget1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4
  { CVT_95_addRegOperands, 2, CVT_95_Reg, 1, CVT_95_Reg, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 6, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 6, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 7, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 7, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 8, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 8, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 6, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 6, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 7, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 7, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 8, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 8, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 6, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 7, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 8, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 6, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 7, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 8, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 6, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 7, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 8, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 3, CVT_95_Reg, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 6, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 7, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 7, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 8, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 8, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 9, CVT_imm_95_0, 0, CVT_Done },
  // Convert__Reg1_0__Reg1_1__R128A161_2__CPol1_3
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 4, CVT_Done },
  // Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__R128A161_4__CPol1_5
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 6, CVT_Done },
  // Convert__Reg1_0__FlatOffset1_1__CPol1_2
  { CVT_95_Reg, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_, 3, CVT_Done },
  // Convert__Reg1_0__VCSrc_b321_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_Done },
  // ConvertCustom_cvtVOP3DPP8
  { CVT_cvtVOP3DPP8, 0, CVT_Done },
  // ConvertCustom_cvtVOP3DPP
  { CVT_cvtVOP3DPP, 0, CVT_Done },
  // Convert__Reg1_0__VSrc_b321_1__Reg1_2
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Done },
  // Convert__Reg1_0__VSrc_b321_2__Reg1_3
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 3, CVT_95_Reg, 4, CVT_Done },
  // ConvertCustom_cvtDPP8
  { CVT_cvtDPP8, 0, CVT_Done },
  // ConvertCustom_cvtVOP3
  { CVT_cvtVOP3, 0, CVT_Done },
  // Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7
  { CVT_95_Reg, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppRowMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBankMask_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBoundCtrl_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppFI_41__59__32__125_, 8, CVT_Done },
  // ConvertCustom_cvtSdwaVOP2b
  { CVT_cvtSdwaVOP2b, 0, CVT_Done },
  // Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8__DppFI1_9
  { CVT_95_Reg, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppRowMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBankMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBoundCtrl_41__59__32__125_, 9, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppFI_41__59__32__125_, 10, CVT_Done },
  // Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_4__DppRowMask1_5__DppBankMask1_6__DppBoundCtrl1_7
  { CVT_95_Reg, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppRowMask_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBankMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBoundCtrl_41__59__32__125_, 8, CVT_Done },
  // Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Done },
  // Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Done },
  // Convert__Reg1_0__VSrc_f161_1__Reg1_2
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Done },
  // ConvertCustom_cvtVOP3OpSel
  { CVT_cvtVOP3OpSel, 0, CVT_Done },
  // ConvertCustom_cvtDPP
  { CVT_cvtDPP, 0, CVT_Done },
  // ConvertCustom_cvtSdwaVOP2
  { CVT_cvtSdwaVOP2, 0, CVT_Done },
  // Convert__Reg1_0__VSrc_f321_1__Reg1_2
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2
  { CVT_95_addRegOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOperands, 3, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2
  { CVT_95_addRegOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOperands, 3, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppRowMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBankMask_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBoundCtrl_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppFI_41__59__32__125_, 8, CVT_Done },
  // Convert__Reg1_0__VSrc_b161_1__Reg1_2
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Done },
  // Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6
  { CVT_95_Reg, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppRowMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBankMask_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBoundCtrl_41__59__32__125_, 7, CVT_Done },
  // Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8
  { CVT_95_Reg, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppRowMask_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBankMask_41__59__32__125_, 8, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBoundCtrl_41__59__32__125_, 9, CVT_Done },
  // Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1__VSrc_b321_2
  { CVT_95_addRegOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1__VSrc_b641_2
  { CVT_95_addRegOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__Reg1_0__VSrc_b321_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5
  { CVT_95_Reg, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_addImmOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppRowMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBankMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBoundCtrl_41__59__32__125_, 6, CVT_Done },
  // ConvertCustom_cvtSdwaVOP1
  { CVT_cvtSdwaVOP1, 0, CVT_Done },
  // Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6
  { CVT_95_Reg, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_addImmOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppRowMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBankMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBoundCtrl_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppFI_41__59__32__125_, 7, CVT_Done },
  // Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3__BitOp31_4
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBitOp3_41__59__32__125_, 5, CVT_Done },
  // Convert__Reg1_0__VSrcFake16_f16_Lo1281_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__Reg1_0__VSrcT_f16_Lo1281_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__Reg1_0__VSrc_f161_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__Reg1_0__VSrc_f321_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1
  { CVT_95_addRegOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__VSrc_f161_0__Reg1_1
  { CVT_95_addRegOrImmOperands, 1, CVT_95_Reg, 2, CVT_Done },
  // Convert__VSrcT_f16_Lo1281_0__Reg1_1
  { CVT_95_addRegOrImmOperands, 1, CVT_95_Reg, 2, CVT_Done },
  // Convert__VSrcFake16_f16_Lo1281_0__Reg1_1
  { CVT_95_addRegOrImmOperands, 1, CVT_95_Reg, 2, CVT_Done },
  // Convert__VSrc_f161_1__Reg1_2
  { CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Done },
  // Convert__VSrcT_f16_Lo1281_1__Reg1_2
  { CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Done },
  // Convert__VSrcFake16_f16_Lo1281_1__Reg1_2
  { CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Done },
  // ConvertCustom_cvtSdwaVOPC
  { CVT_cvtSdwaVOPC, 0, CVT_Done },
  // Convert__VSrc_f321_0__Reg1_1
  { CVT_95_addRegOrImmOperands, 1, CVT_95_Reg, 2, CVT_Done },
  // Convert__VSrc_f321_1__Reg1_2
  { CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Done },
  // Convert__VSrc_f641_0__Reg1_1
  { CVT_95_addRegOrImmOperands, 1, CVT_95_Reg, 2, CVT_Done },
  // Convert__VSrc_f641_1__Reg1_2
  { CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Done },
  // Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1
  { CVT_95_addRegOrImmOperands, 1, CVT_95_addRegOperands, 2, CVT_Done },
  // Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2
  { CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOperands, 3, CVT_Done },
  // Convert__VSrc_b161_0__Reg1_1
  { CVT_95_addRegOrImmOperands, 1, CVT_95_Reg, 2, CVT_Done },
  // Convert__VSrcT_b16_Lo1281_0__Reg1_1
  { CVT_95_addRegOrImmOperands, 1, CVT_95_Reg, 2, CVT_Done },
  // Convert__VSrcFake16_b16_Lo1281_0__Reg1_1
  { CVT_95_addRegOrImmOperands, 1, CVT_95_Reg, 2, CVT_Done },
  // Convert__VSrc_b161_1__Reg1_2
  { CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Done },
  // Convert__VSrcT_b16_Lo1281_1__Reg1_2
  { CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Done },
  // Convert__VSrcFake16_b16_Lo1281_1__Reg1_2
  { CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Done },
  // Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2
  { CVT_95_addRegOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__VSrc_b321_0__Reg1_1
  { CVT_95_addRegOrImmOperands, 1, CVT_95_Reg, 2, CVT_Done },
  // Convert__VSrc_b321_1__Reg1_2
  { CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Done },
  // Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2
  { CVT_95_addRegOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1
  { CVT_95_addRegOrImmOperands, 1, CVT_95_addRegOperands, 2, CVT_Done },
  // Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2
  { CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOperands, 3, CVT_Done },
  // Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2
  { CVT_95_addRegOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__VSrc_b161_0__VSrc_b161_1
  { CVT_95_addRegOrImmOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__VSrc_b321_0__VSrc_b321_1
  { CVT_95_addRegOrImmOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__VSrc_b641_0__VSrc_b641_1
  { CVT_95_addRegOrImmOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // ConvertCustom_cvtSdwaVOP2e
  { CVT_cvtSdwaVOP2e, 0, CVT_Done },
  // Convert__Reg1_0__VSrcFake16_bf16_Lo1281_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__Reg1_0__VSrcT_bf16_Lo1281_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__Reg1_0__VSrcFake16_b16_Lo1281_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__Reg1_0__VSrcT_b16_Lo1281_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__Reg1_0__VSrc_b161_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__Reg1_0__VSrc_bf161_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__Reg1_0__VSrc_b321_1__ByteSel1_2
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyByteSel_41__59__32__125_, 3, CVT_Done },
  // Convert__Reg1_0__VSrc_f641_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__Reg1_0__VSrc_b321_1__Clamp1_3__ByteSel1_2
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyClamp_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyByteSel_41__59__32__125_, 3, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f321_1
  { CVT_95_addRegOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1
  { CVT_95_addRegOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_addImmOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppRowMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBankMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBoundCtrl_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_addImmOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppRowMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBankMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBoundCtrl_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppFI_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrcT_f16_Lo1281_1
  { CVT_95_addRegOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrcFake16_f16_Lo1281_1
  { CVT_95_addRegOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__Reg1_0__imm_95_0__VCSrc_f321_1__imm_95_0__VCSrc_f321_2__imm_95_0
  { CVT_95_Reg, 1, CVT_imm_95_0, 0, CVT_95_addRegOrImmOperands, 2, CVT_imm_95_0, 0, CVT_95_addRegOrImmOperands, 3, CVT_imm_95_0, 0, CVT_Done },
  // Convert__Reg1_0__imm_95_0__VCSrc_f321_1__imm_95_0__VCSrc_f321_2__imm_95_0__imm_95_0
  { CVT_95_Reg, 1, CVT_imm_95_0, 0, CVT_95_addRegOrImmOperands, 2, CVT_imm_95_0, 0, CVT_95_addRegOrImmOperands, 3, CVT_imm_95_0, 0, CVT_imm_95_0, 0, CVT_Done },
  // Convert__RegByHwMode_VReg_256_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__VSrc_b321_2__ScaleSel1_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyScaleSel_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__VSrc_b321_2__ScaleSel1_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyScaleSel_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__VSrc_b321_2__ScaleSel1_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyScaleSel_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__VSrc_b321_2__ScaleSel1_3
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addRegOrImmOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyScaleSel_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_256_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__VSrc_b321_2__ScaleSel1_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyScaleSel_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_256_AlignTarget1_0__Reg1_1__VSrc_b321_2__ScaleSel1_3
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_addRegOrImmOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyScaleSel_41__59__32__125_, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_192_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__RegByHwMode_VReg_512_AlignTarget1_2__VSrc_f321_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_f321_2
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__RegByHwMode_VReg_96_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__VSrc_f321_2
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__VSrc_f321_2
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__RegByHwMode_VReg_192_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__VSrc_f321_2
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__VSrc_f321_2
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__VSrc_f321_2
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_f321_2
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_VReg_128_AlignTarget1_1__VSrc_f321_2
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_f321_2
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__RegByHwMode_VReg_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_96_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_192_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_192_AlignTarget1_0__RegByHwMode_VReg_1024_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_VReg_128_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_Done },
  // Convert__Reg1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3
  { CVT_95_Reg, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_Done },
  // ConvertCustom_cvtVOP3P
  { CVT_cvtVOP3P, 0, CVT_Done },
  // Convert__Reg1_0__VSrc_v2f161_1__Reg1_2__Tie0_1_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Tied, Tie0_1_1, CVT_Done },
  // Convert__Reg1_0__VSrc_v2bf161_1__Reg1_2__Tie0_1_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Tied, Tie0_1_1, CVT_Done },
  // Convert__Reg1_0__VSrc_b321_1__Reg1_2__Tie0_1_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Tied, Tie0_1_1, CVT_Done },
  // Convert__Reg1_0__imm_95_0__Reg1_1__imm_95_0__Reg1_2__Tie0_1_1__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6
  { CVT_95_Reg, 1, CVT_imm_95_0, 0, CVT_95_Reg, 2, CVT_imm_95_0, 0, CVT_95_Reg, 3, CVT_Tied, Tie0_1_1, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppRowMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBankMask_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBoundCtrl_41__59__32__125_, 7, CVT_Done },
  // Convert__Reg1_0__imm_95_0__Reg1_1__imm_95_0__Reg1_2__Tie0_1_1__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7
  { CVT_95_Reg, 1, CVT_imm_95_0, 0, CVT_95_Reg, 2, CVT_imm_95_0, 0, CVT_95_Reg, 3, CVT_Tied, Tie0_1_1, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppRowMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBankMask_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBoundCtrl_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppFI_41__59__32__125_, 8, CVT_Done },
  // ConvertCustom_cvtVOPD
  { CVT_cvtVOPD, 0, CVT_Done },
  // Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2__KImmFP161_3
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands, 4, CVT_Done },
  // Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2__KImmFP161_3
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands, 4, CVT_Done },
  // Convert__Reg1_0__VSrc_f161_1__Reg1_2__KImmFP161_3
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands, 4, CVT_Done },
  // Convert__Reg1_0__VSrc_f321_1__Reg1_2__KImmFP321_3
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_95_addImmOperands, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2__KImmFP641_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addImmOperands, 4, CVT_Done },
  // Convert__Reg1_0__VSrc_f321_1__Reg1_2__Tie0_1_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Tied, Tie0_1_1, CVT_Done },
  // Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2__Tie0_1_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Tied, Tie0_1_1, CVT_Done },
  // Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2__Tie0_1_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Tied, Tie0_1_1, CVT_Done },
  // Convert__Reg1_0__VSrc_f161_1__Reg1_2__Tie0_1_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Tied, Tie0_1_1, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2__Tie0_1_1
  { CVT_95_addRegOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOperands, 3, CVT_Tied, Tie0_1_1, CVT_Done },
  // Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__KImmFP161_2__Reg1_3
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addImmOperands, 3, CVT_95_Reg, 4, CVT_Done },
  // Convert__Reg1_0__VSrcT_f16_Lo1281_1__KImmFP161_2__Reg1_3
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addImmOperands, 3, CVT_95_Reg, 4, CVT_Done },
  // Convert__Reg1_0__VSrc_f161_1__KImmFP161_2__Reg1_3
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addImmOperands, 3, CVT_95_Reg, 4, CVT_Done },
  // Convert__Reg1_0__VSrc_f321_1__KImmFP321_2__Reg1_3
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addImmOperands, 3, CVT_95_Reg, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1__KImmFP641_2__Reg1_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addImmOperands, 3, CVT_95_Reg, 4, CVT_Done },
  // Convert__Reg1_0__InterpSlot1_1__InterpAttr1_2__InterpAttrChan1_3
  { CVT_95_Reg, 1, CVT_95_addImmOperands, 2, CVT_95_addImmOperands, 3, CVT_95_addImmOperands, 4, CVT_Done },
  // ConvertCustom_cvtVOP3Interp
  { CVT_cvtVOP3Interp, 0, CVT_Done },
  // ConvertCustom_cvtVINTERP
  { CVT_cvtVINTERP, 0, CVT_Done },
  // Convert__Reg1_0__Reg1_1__InterpAttr1_2__InterpAttrChan1_3
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_addImmOperands, 3, CVT_95_addImmOperands, 4, CVT_Done },
  // Convert__Reg1_0__Tie0_1_1__Reg1_1__InterpAttr1_2__InterpAttrChan1_3
  { CVT_95_Reg, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_addImmOperands, 3, CVT_95_addImmOperands, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1__VSrc_b321_2__VSrc_b641_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1__RegByHwMode_VReg_64_AlignTarget1_2
  { CVT_95_addRegOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOperands, 3, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_Reg, 2, CVT_95_addRegOperands, 3, CVT_95_addImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppRowMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBankMask_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBoundCtrl_41__59__32__125_, 7, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppFI_41__59__32__125_, 8, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1__VSrc_b641_2
  { CVT_95_addRegOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_f321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_1024_f321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_AReg_256_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_256_f641_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_VReg_256_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_256_f641_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_AReg_64_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_64_f641_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_64_f641_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6
  { CVT_95_addRegOperands, 1, CVT_95_addRegOperands, 2, CVT_95_addRegOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_, 7, CVT_Done },
  // ConvertCustom_cvtScaledMFMA
  { CVT_cvtScaledMFMA, 0, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1
  { CVT_95_addRegOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__RegByHwMode_VReg_64_AlignTarget1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppRowMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBankMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBoundCtrl_41__59__32__125_, 6, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__RegByHwMode_VReg_64_AlignTarget1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6
  { CVT_95_addRegOperands, 1, CVT_Tied, Tie0_1_1, CVT_95_addRegOperands, 2, CVT_95_addImmOperands, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppRowMask_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBankMask_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBoundCtrl_41__59__32__125_, 6, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppFI_41__59__32__125_, 7, CVT_Done },
  // Convert__DPPCtrl1_0__DppRowMask1_1__DppBankMask1_2__DppBoundCtrl1_3
  { CVT_95_addImmOperands, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppRowMask_41__59__32__125_, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBankMask_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBoundCtrl_41__59__32__125_, 4, CVT_Done },
  // Convert__DPPCtrl1_0__DppRowMask1_1__DppBankMask1_2__DppBoundCtrl1_3__DppFI1_4
  { CVT_95_addImmOperands, 1, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppRowMask_41__59__32__125_, 2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBankMask_41__59__32__125_, 3, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBoundCtrl_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppFI_41__59__32__125_, 5, CVT_Done },
  // Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1__VSrc_b321_2__VSrc_v2b321_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_96_AlignTarget1_0__VSrc_b321_1__VSrc_b641_2__VSrc_v2b321_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_Done },
  // Convert__RegByHwMode_VReg_128_AlignTarget1_0__VSrc_b641_1__VSrc_b641_2__VSrc_v2b321_3
  { CVT_95_addRegOperands, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_Done },
  // Convert__Reg1_0__Reg1_1__Tie0_1_1__Tie1_2_2
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_Tied, Tie0_1_1, CVT_Tied, Tie1_2_2, CVT_Done },
  // Convert__Reg1_0__Reg1_1__Tie0_1_1__Tie1_2_2__DppFI1_3__DppBoundCtrl1_2
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_Tied, Tie0_1_1, CVT_Tied, Tie1_2_2, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppFI_41__59__32__125_, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBoundCtrl_41__59__32__125_, 3, CVT_Done },
  // Convert__Reg1_0__Reg1_1__SSrc_b321_2__SSrc_b321_3
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_addRegOrImmOperands, 3, CVT_95_addRegOrImmOperands, 4, CVT_Done },
  // Convert__Reg1_0__Reg1_1__SSrc_b321_2
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__Reg1_0__VSrc_v2f16_splat1_1__Reg1_2
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_Reg, 3, CVT_Done },
  // Convert__Reg1_0__Reg1_1__SCSrc_b321_2
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_addRegOrImmOperands, 3, CVT_Done },
  // Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_95_Reg, 3, CVT_95_Reg, 4, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_, 5, CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_, 6, CVT_Tied, Tie0_1_1, CVT_Done },
  // Convert__Reg1_0__Reg1_1__Tie1_2_2__Tie0_1_1
  { CVT_95_Reg, 1, CVT_95_Reg, 2, CVT_Tied, Tie1_2_2, CVT_Tied, Tie0_1_1, CVT_Done },
  // ConvertCustom_cvtSWMMAC
  { CVT_cvtSWMMAC, 0, CVT_Done },
  // Convert__Reg1_0__SSrcOrLds_b321_1__SCSrc_b321_2__Tie0_1_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Tied, Tie0_1_1, CVT_Done },
  // Convert__Reg1_0__SCSrc_b321_1__SCSrc_b321_2__Tie0_1_1
  { CVT_95_Reg, 1, CVT_95_addRegOrImmOperands, 2, CVT_95_addRegOrImmOperands, 3, CVT_Tied, Tie0_1_1, CVT_Done },
};

void AMDGPUAsmParser::
convertToMCInst(unsigned Kind, MCInst &Inst, unsigned Opcode,
                const OperandVector &Operands,
                const SmallBitVector &OptionalOperandsMask,
                ArrayRef<unsigned> DefaultsOffset) {
  assert(Kind < CVT_NUM_SIGNATURES && "Invalid signature!");
  const uint8_t *Converter = ConversionTable[Kind];
  Inst.setOpcode(Opcode);
  for (const uint8_t *p = Converter; *p; p += 2) {
    unsigned OpIdx = *(p + 1) - DefaultsOffset[*(p + 1)];
    switch (*p) {
    default: llvm_unreachable("invalid conversion entry!");
    case CVT_Reg:
      static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addRegOperands(Inst, 1);
      break;
    case CVT_Tied: {
      assert(*(p + 1) < (size_t)(std::end(TiedAsmOperandTable) -
                              std::begin(TiedAsmOperandTable)) &&
             "Tied operand not found");
      unsigned TiedResOpnd = TiedAsmOperandTable[*(p + 1)][0];
      if (TiedResOpnd != (uint8_t)-1)
        Inst.addOperand(Inst.getOperand(TiedResOpnd));
      break;
    }
    case CVT_cvtMubufAtomic:
      cvtMubufAtomic(Inst, Operands);
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyCPol); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_cvtMubuf:
      cvtMubuf(Inst, Operands);
      break;
    case CVT_imm_95_0:
      Inst.addOperand(MCOperand::createImm(0));
      break;
    case CVT_95_Reg:
      static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addRegOperands(Inst, 1);
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyOffset); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addRegOperands:
      static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addRegOperands(Inst, 1);
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyGDS); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyWaitVAVDst_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyWaitVAVDst); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyWaitVMVSrc_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyWaitVMVSrc); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset0_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyOffset0); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset1_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyOffset1); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands:
      static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTySwizzle_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTySwizzle); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_cvtExp:
      cvtExp(Inst, Operands);
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyDMask); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyUNorm); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyR128A16); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyLWE); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyDA); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyTFE); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyDim); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyA16); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyD16); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyWaitVDST_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyWaitVDST); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addRegOrImmOperands:
      static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addRegOrImmOperands(Inst, 1);
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyNone_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyNone); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTySMEMOffsetMod_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTySMEMOffsetMod); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyEndpgm_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyEndpgm); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_cvtVOP3DPP8:
      cvtVOP3DPP8(Inst, Operands);
      break;
    case CVT_cvtVOP3DPP:
      cvtVOP3DPP(Inst, Operands);
      break;
    case CVT_cvtDPP8:
      cvtDPP8(Inst, Operands);
      break;
    case CVT_cvtVOP3:
      cvtVOP3(Inst, Operands);
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppRowMask_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0xf, SMLoc(), AMDGPUOperand::ImmTyDppRowMask); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBankMask_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0xf, SMLoc(), AMDGPUOperand::ImmTyDppBankMask); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBoundCtrl_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyDppBoundCtrl); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppFI_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyDppFI); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_cvtSdwaVOP2b:
      cvtSdwaVOP2b(Inst, Operands);
      break;
    case CVT_cvtVOP3OpSel:
      cvtVOP3OpSel(Inst, Operands);
      break;
    case CVT_cvtDPP:
      cvtDPP(Inst, Operands);
      break;
    case CVT_cvtSdwaVOP2:
      cvtSdwaVOP2(Inst, Operands);
      break;
    case CVT_cvtSdwaVOP1:
      cvtSdwaVOP1(Inst, Operands);
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBitOp3_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyBitOp3); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_cvtSdwaVOPC:
      cvtSdwaVOPC(Inst, Operands);
      break;
    case CVT_cvtSdwaVOP2e:
      cvtSdwaVOP2e(Inst, Operands);
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyByteSel_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyByteSel); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyClamp_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyClamp); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyScaleSel_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyScaleSel); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_cvtVOP3P:
      cvtVOP3P(Inst, Operands);
      break;
    case CVT_cvtVOPD:
      cvtVOPD(Inst, Operands);
      break;
    case CVT_cvtVOP3Interp:
      cvtVOP3Interp(Inst, Operands);
      break;
    case CVT_cvtVINTERP:
      cvtVINTERP(Inst, Operands);
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyCBSZ); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyBLGP); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_:
      if (OptionalOperandsMask[*(p + 1) - 1]) {
        [this]() { return AMDGPUOperand::CreateImm(this, 0, SMLoc(), AMDGPUOperand::ImmTyABID); }()->addImmOperands(Inst, 1);
      } else {
        static_cast<AMDGPUOperand &>(*Operands[OpIdx]).addImmOperands(Inst, 1);
      }
      break;
    case CVT_cvtScaledMFMA:
      cvtScaledMFMA(Inst, Operands);
      break;
    case CVT_cvtSWMMAC:
      cvtSWMMAC(Inst, Operands);
      break;
    }
  }
}

void AMDGPUAsmParser::
convertToMapAndConstraints(unsigned Kind,
                           const OperandVector &Operands) {
  assert(Kind < CVT_NUM_SIGNATURES && "Invalid signature!");
  unsigned NumMCOperands = 0;
  const uint8_t *Converter = ConversionTable[Kind];
  for (const uint8_t *p = Converter; *p; p += 2) {
    switch (*p) {
    default: llvm_unreachable("invalid conversion entry!");
    case CVT_Reg:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("r");
      ++NumMCOperands;
      break;
    case CVT_Tied:
      ++NumMCOperands;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCPol_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_imm_95_0:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("");
      ++NumMCOperands;
      break;
    case CVT_95_Reg:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("r");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addRegOperands:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyGDS_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyWaitVAVDst_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyWaitVMVSrc_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset0_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyOffset1_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTySwizzle_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDMask_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyUNorm_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyR128A16_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyLWE_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDA_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyTFE_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDim_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyA16_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyD16_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyWaitVDST_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addRegOrImmOperands:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyNone_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTySMEMOffsetMod_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyEndpgm_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppRowMask_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0xf_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBankMask_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppBoundCtrl_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyDppFI_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBitOp3_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyByteSel_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyClamp_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyScaleSel_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyCBSZ_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyBLGP_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    case CVT_95_addImmOperands_95__91_this_93__40__41__32__123__32_return_32_AMDGPUOperand_COLON__COLON_CreateImm_40_this_44__32_0_44__32_SMLoc_40__41__44__32_AMDGPUOperand_COLON__COLON_ImmTyABID_41__59__32__125_:
      Operands[*(p + 1)]->setMCOperandNum(NumMCOperands);
      Operands[*(p + 1)]->setConstraint("m");
      NumMCOperands += 1;
      break;
    }
  }
}

namespace {

/// MatchClassKind - The kinds of classes which participate in
/// instruction matching.
enum MatchClassKind {
  InvalidMatchClass = 0,
  OptionalMatchClass = 1,
  MCK__COLON__COLON_, // '::'
  MCK__91_, // '['
  MCK__93_, // ']'
  MCK_addr64, // 'addr64'
  MCK_done, // 'done'
  MCK_gds, // 'gds'
  MCK_idxen, // 'idxen'
  MCK_lds, // 'lds'
  MCK_off, // 'off'
  MCK_offen, // 'offen'
  MCK_row_95_en, // 'row_en'
  MCK_tfe, // 'tfe'
  MCK_v_95_dual_95_add_95_f32, // 'v_dual_add_f32'
  MCK_v_95_dual_95_add_95_nc_95_u32, // 'v_dual_add_nc_u32'
  MCK_v_95_dual_95_and_95_b32, // 'v_dual_and_b32'
  MCK_v_95_dual_95_ashrrev_95_i32, // 'v_dual_ashrrev_i32'
  MCK_v_95_dual_95_bitop2_95_b32, // 'v_dual_bitop2_b32'
  MCK_v_95_dual_95_cndmask_95_b32, // 'v_dual_cndmask_b32'
  MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, // 'v_dual_dot2acc_f32_bf16'
  MCK_v_95_dual_95_dot2acc_95_f32_95_f16, // 'v_dual_dot2acc_f32_f16'
  MCK_v_95_dual_95_fma_95_f32, // 'v_dual_fma_f32'
  MCK_v_95_dual_95_fmaak_95_f32, // 'v_dual_fmaak_f32'
  MCK_v_95_dual_95_fmac_95_f32, // 'v_dual_fmac_f32'
  MCK_v_95_dual_95_fmamk_95_f32, // 'v_dual_fmamk_f32'
  MCK_v_95_dual_95_lshlrev_95_b32, // 'v_dual_lshlrev_b32'
  MCK_v_95_dual_95_lshrrev_95_b32, // 'v_dual_lshrrev_b32'
  MCK_v_95_dual_95_max_95_f32, // 'v_dual_max_f32'
  MCK_v_95_dual_95_max_95_i32, // 'v_dual_max_i32'
  MCK_v_95_dual_95_max_95_num_95_f32, // 'v_dual_max_num_f32'
  MCK_v_95_dual_95_min_95_f32, // 'v_dual_min_f32'
  MCK_v_95_dual_95_min_95_i32, // 'v_dual_min_i32'
  MCK_v_95_dual_95_min_95_num_95_f32, // 'v_dual_min_num_f32'
  MCK_v_95_dual_95_mov_95_b32, // 'v_dual_mov_b32'
  MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, // 'v_dual_mul_dx9_zero_f32'
  MCK_v_95_dual_95_mul_95_f32, // 'v_dual_mul_f32'
  MCK_v_95_dual_95_sub_95_f32, // 'v_dual_sub_f32'
  MCK_v_95_dual_95_sub_95_nc_95_u32, // 'v_dual_sub_nc_u32'
  MCK_v_95_dual_95_subrev_95_f32, // 'v_dual_subrev_f32'
  MCK_LAST_TOKEN = MCK_v_95_dual_95_subrev_95_f32,
  MCK_VReg_1, // register class 'VReg_1'
  MCK_Reg316, // derived register class
  MCK_Reg309, // derived register class
  MCK_Reg302, // derived register class
  MCK_Reg295, // derived register class
  MCK_Reg288, // derived register class
  MCK_Reg281, // derived register class
  MCK_Reg274, // derived register class
  MCK_Reg267, // derived register class
  MCK_Reg258, // derived register class
  MCK_Reg248, // derived register class
  MCK_Reg245, // derived register class
  MCK_Reg231, // derived register class
  MCK_Reg218, // derived register class
  MCK_Reg206, // derived register class
  MCK_Reg43, // derived register class
  MCK_M0, // register class 'M0'
  MCK_Pseudo_SReg_128, // register class 'Pseudo_SReg_128'
  MCK_SCC_CLASS, // register class 'SCC_CLASS'
  MCK_TTMP_512, // register class 'TTMP_512'
  MCK_VCC, // register class 'VCC'
  MCK_VCC_LO, // register class 'VCC_LO'
  MCK_Reg317, // derived register class
  MCK_Reg310, // derived register class
  MCK_Reg303, // derived register class
  MCK_Reg296, // derived register class
  MCK_Reg289, // derived register class
  MCK_Reg282, // derived register class
  MCK_Reg275, // derived register class
  MCK_Reg268, // derived register class
  MCK_Reg259, // derived register class
  MCK_Reg246, // derived register class
  MCK_Pseudo_SReg_32, // register class 'Pseudo_SReg_32'
  MCK_TTMP_288, // register class 'TTMP_288'
  MCK_TTMP_320, // register class 'TTMP_320'
  MCK_TTMP_352, // register class 'TTMP_352'
  MCK_TTMP_384, // register class 'TTMP_384'
  MCK_Reg318, // derived register class
  MCK_Reg311, // derived register class
  MCK_Reg304, // derived register class
  MCK_Reg297, // derived register class
  MCK_Reg290, // derived register class
  MCK_Reg283, // derived register class
  MCK_Reg276, // derived register class
  MCK_Reg269, // derived register class
  MCK_Reg260, // derived register class
  MCK_TTMP_160, // register class 'TTMP_160'
  MCK_TTMP_192, // register class 'TTMP_192'
  MCK_TTMP_224, // register class 'TTMP_224'
  MCK_TTMP_256, // register class 'TTMP_256'
  MCK_Reg319, // derived register class
  MCK_Reg312, // derived register class
  MCK_Reg305, // derived register class
  MCK_Reg298, // derived register class
  MCK_Reg291, // derived register class
  MCK_Reg284, // derived register class
  MCK_Reg277, // derived register class
  MCK_Reg270, // derived register class
  MCK_Reg261, // derived register class
  MCK_Reg254, // derived register class
  MCK_Reg238, // derived register class
  MCK_APERTURE_Class, // register class 'APERTURE_Class'
  MCK_TTMP_128, // register class 'TTMP_128'
  MCK_TTMP_96, // register class 'TTMP_96'
  MCK_Reg320, // derived register class
  MCK_Reg313, // derived register class
  MCK_Reg306, // derived register class
  MCK_Reg299, // derived register class
  MCK_Reg292, // derived register class
  MCK_Reg285, // derived register class
  MCK_Reg278, // derived register class
  MCK_Reg271, // derived register class
  MCK_Reg262, // derived register class
  MCK_Reg255, // derived register class
  MCK_Reg251, // derived register class
  MCK_Reg239, // derived register class
  MCK_Reg235, // derived register class
  MCK_Reg225, // derived register class
  MCK_Reg222, // derived register class
  MCK_Reg210, // derived register class
  MCK_Reg321, // derived register class
  MCK_Reg314, // derived register class
  MCK_Reg307, // derived register class
  MCK_Reg300, // derived register class
  MCK_Reg293, // derived register class
  MCK_Reg286, // derived register class
  MCK_Reg279, // derived register class
  MCK_Reg272, // derived register class
  MCK_Reg263, // derived register class
  MCK_Reg256, // derived register class
  MCK_Reg252, // derived register class
  MCK_Reg249, // derived register class
  MCK_Reg240, // derived register class
  MCK_Reg236, // derived register class
  MCK_Reg233, // derived register class
  MCK_Reg226, // derived register class
  MCK_Reg223, // derived register class
  MCK_Reg220, // derived register class
  MCK_Reg213, // derived register class
  MCK_Reg211, // derived register class
  MCK_Reg208, // derived register class
  MCK_Reg201, // derived register class
  MCK_Reg199, // derived register class
  MCK_Reg193, // derived register class
  MCK_Reg191, // derived register class
  MCK_Reg185, // derived register class
  MCK_Reg183, // derived register class
  MCK_Reg176, // derived register class
  MCK_Reg322, // derived register class
  MCK_Reg315, // derived register class
  MCK_Reg308, // derived register class
  MCK_Reg301, // derived register class
  MCK_Reg294, // derived register class
  MCK_Reg287, // derived register class
  MCK_Reg280, // derived register class
  MCK_Reg273, // derived register class
  MCK_Reg264, // derived register class
  MCK_Reg257, // derived register class
  MCK_Reg253, // derived register class
  MCK_Reg250, // derived register class
  MCK_Reg247, // derived register class
  MCK_Reg241, // derived register class
  MCK_Reg237, // derived register class
  MCK_Reg234, // derived register class
  MCK_Reg232, // derived register class
  MCK_Reg227, // derived register class
  MCK_Reg224, // derived register class
  MCK_Reg221, // derived register class
  MCK_Reg219, // derived register class
  MCK_Reg214, // derived register class
  MCK_Reg212, // derived register class
  MCK_Reg209, // derived register class
  MCK_Reg207, // derived register class
  MCK_Reg202, // derived register class
  MCK_Reg200, // derived register class
  MCK_Reg198, // derived register class
  MCK_Reg194, // derived register class
  MCK_Reg192, // derived register class
  MCK_Reg190, // derived register class
  MCK_Reg186, // derived register class
  MCK_Reg184, // derived register class
  MCK_Reg182, // derived register class
  MCK_Reg178, // derived register class
  MCK_Reg177, // derived register class
  MCK_Reg175, // derived register class
  MCK_Reg171, // derived register class
  MCK_Reg170, // derived register class
  MCK_Reg166, // derived register class
  MCK_Reg165, // derived register class
  MCK_Reg147, // derived register class
  MCK_Reg146, // derived register class
  MCK_Reg265, // derived register class
  MCK_Reg242, // derived register class
  MCK_Reg228, // derived register class
  MCK_Reg215, // derived register class
  MCK_Reg203, // derived register class
  MCK_Reg195, // derived register class
  MCK_Reg187, // derived register class
  MCK_Reg179, // derived register class
  MCK_Reg172, // derived register class
  MCK_Reg167, // derived register class
  MCK_Reg148, // derived register class
  MCK_Reg143, // derived register class
  MCK_TTMP_64, // register class 'TTMP_64'
  MCK_Gfx_CCR_SGPR_64, // register class 'Gfx_CCR_SGPR_64'
  MCK_CCR_SGPR_64, // register class 'CCR_SGPR_64'
  MCK_TTMP_32, // register class 'TTMP_32'
  MCK_TTMP_LO16, // register class 'TTMP_LO16'
  MCK_SGPR_1024, // register class 'SGPR_1024,SReg_1024'
  MCK_SGPR_512, // register class 'SGPR_512'
  MCK_SGPR_352, // register class 'SGPR_352'
  MCK_SGPR_384, // register class 'SGPR_384'
  MCK_SReg_512, // register class 'SReg_512'
  MCK_SGPR_224, // register class 'SGPR_224'
  MCK_SGPR_256, // register class 'SGPR_256'
  MCK_SGPR_288, // register class 'SGPR_288'
  MCK_SGPR_320, // register class 'SGPR_320'
  MCK_SGPR_128, // register class 'SGPR_128'
  MCK_SGPR_160, // register class 'SGPR_160'
  MCK_SGPR_192, // register class 'SGPR_192'
  MCK_SGPR_96, // register class 'SGPR_96'
  MCK_SReg_352, // register class 'SReg_352'
  MCK_SReg_384, // register class 'SReg_384'
  MCK_SReg_288, // register class 'SReg_288'
  MCK_SReg_320, // register class 'SReg_320'
  MCK_SReg_224, // register class 'SReg_224'
  MCK_SReg_256_XNULL, // register class 'SReg_256_XNULL'
  MCK_SReg_160, // register class 'SReg_160'
  MCK_SReg_192, // register class 'SReg_192'
  MCK_SReg_256, // register class 'SReg_256'
  MCK_SReg_128_XNULL, // register class 'SReg_128_XNULL'
  MCK_SReg_96, // register class 'SReg_96'
  MCK_SReg_128, // register class 'SReg_128'
  MCK_Reg860, // derived register class
  MCK_Reg861, // derived register class
  MCK_Reg827, // derived register class
  MCK_Reg862, // derived register class
  MCK_Reg828, // derived register class
  MCK_Reg863, // derived register class
  MCK_Reg829, // derived register class
  MCK_Reg864, // derived register class
  MCK_Reg830, // derived register class
  MCK_Reg865, // derived register class
  MCK_Reg831, // derived register class
  MCK_SGPR_64, // register class 'SGPR_64'
  MCK_Reg866, // derived register class
  MCK_Reg832, // derived register class
  MCK_Reg867, // derived register class
  MCK_Reg833, // derived register class
  MCK_Reg868, // derived register class
  MCK_Reg834, // derived register class
  MCK_Reg743, // derived register class
  MCK_Reg869, // derived register class
  MCK_Reg835, // derived register class
  MCK_Reg744, // derived register class
  MCK_Reg726, // derived register class
  MCK_Reg870, // derived register class
  MCK_Reg836, // derived register class
  MCK_Reg745, // derived register class
  MCK_Reg727, // derived register class
  MCK_Reg678, // derived register class
  MCK_Reg871, // derived register class
  MCK_Reg837, // derived register class
  MCK_Reg746, // derived register class
  MCK_Reg728, // derived register class
  MCK_Reg679, // derived register class
  MCK_Reg665, // derived register class
  MCK_Reg627, // derived register class
  MCK_Reg614, // derived register class
  MCK_Reg578, // derived register class
  MCK_Reg872, // derived register class
  MCK_Reg838, // derived register class
  MCK_Reg747, // derived register class
  MCK_Reg729, // derived register class
  MCK_Reg680, // derived register class
  MCK_Reg666, // derived register class
  MCK_Reg628, // derived register class
  MCK_Reg615, // derived register class
  MCK_Reg579, // derived register class
  MCK_Reg567, // derived register class
  MCK_Reg535, // derived register class
  MCK_Reg524, // derived register class
  MCK_Reg494, // derived register class
  MCK_Reg873, // derived register class
  MCK_Reg839, // derived register class
  MCK_Reg748, // derived register class
  MCK_Reg730, // derived register class
  MCK_Reg681, // derived register class
  MCK_Reg667, // derived register class
  MCK_Reg629, // derived register class
  MCK_Reg616, // derived register class
  MCK_Reg580, // derived register class
  MCK_Reg568, // derived register class
  MCK_Reg536, // derived register class
  MCK_Reg525, // derived register class
  MCK_Reg495, // derived register class
  MCK_Reg485, // derived register class
  MCK_Reg459, // derived register class
  MCK_Reg450, // derived register class
  MCK_Reg426, // derived register class
  MCK_Reg874, // derived register class
  MCK_Reg840, // derived register class
  MCK_Reg749, // derived register class
  MCK_Reg731, // derived register class
  MCK_Reg682, // derived register class
  MCK_Reg668, // derived register class
  MCK_Reg630, // derived register class
  MCK_Reg617, // derived register class
  MCK_Reg581, // derived register class
  MCK_Reg569, // derived register class
  MCK_Reg537, // derived register class
  MCK_Reg526, // derived register class
  MCK_Reg496, // derived register class
  MCK_Reg486, // derived register class
  MCK_Reg460, // derived register class
  MCK_Reg451, // derived register class
  MCK_Reg427, // derived register class
  MCK_Reg419, // derived register class
  MCK_Reg399, // derived register class
  MCK_Reg392, // derived register class
  MCK_Reg374, // derived register class
  MCK_Reg875, // derived register class
  MCK_Reg841, // derived register class
  MCK_Reg750, // derived register class
  MCK_Reg732, // derived register class
  MCK_Reg683, // derived register class
  MCK_Reg669, // derived register class
  MCK_Reg631, // derived register class
  MCK_Reg618, // derived register class
  MCK_Reg582, // derived register class
  MCK_Reg570, // derived register class
  MCK_Reg538, // derived register class
  MCK_Reg527, // derived register class
  MCK_Reg497, // derived register class
  MCK_Reg487, // derived register class
  MCK_Reg461, // derived register class
  MCK_Reg452, // derived register class
  MCK_Reg428, // derived register class
  MCK_Reg420, // derived register class
  MCK_Reg400, // derived register class
  MCK_Reg393, // derived register class
  MCK_Reg375, // derived register class
  MCK_Reg369, // derived register class
  MCK_Reg355, // derived register class
  MCK_Reg350, // derived register class
  MCK_Reg876, // derived register class
  MCK_Reg842, // derived register class
  MCK_Reg751, // derived register class
  MCK_Reg733, // derived register class
  MCK_Reg684, // derived register class
  MCK_Reg670, // derived register class
  MCK_Reg632, // derived register class
  MCK_Reg619, // derived register class
  MCK_Reg583, // derived register class
  MCK_Reg571, // derived register class
  MCK_Reg539, // derived register class
  MCK_Reg528, // derived register class
  MCK_Reg498, // derived register class
  MCK_Reg488, // derived register class
  MCK_Reg462, // derived register class
  MCK_Reg453, // derived register class
  MCK_Reg429, // derived register class
  MCK_Reg421, // derived register class
  MCK_Reg401, // derived register class
  MCK_Reg394, // derived register class
  MCK_Reg376, // derived register class
  MCK_Reg370, // derived register class
  MCK_Reg356, // derived register class
  MCK_Reg351, // derived register class
  MCK_Reg340, // derived register class
  MCK_SReg_64_XEXEC_XNULL, // register class 'SReg_64_XEXEC_XNULL'
  MCK_SReg_64_XEXEC, // register class 'SReg_64_XEXEC'
  MCK_SReg_64, // register class 'SReg_64'
  MCK_Reg37, // derived register class
  MCK_SReg_64_Encodable, // register class 'SReg_64_Encodable'
  MCK_Reg160, // derived register class
  MCK_Reg161, // derived register class
  MCK_Reg762, // derived register class
  MCK_Reg763, // derived register class
  MCK_Reg764, // derived register class
  MCK_Reg765, // derived register class
  MCK_Reg766, // derived register class
  MCK_Reg767, // derived register class
  MCK_Reg768, // derived register class
  MCK_Reg769, // derived register class
  MCK_Reg770, // derived register class
  MCK_Reg771, // derived register class
  MCK_SGPR_32, // register class 'SGPR_32'
  MCK_SGPR_HI16, // register class 'SGPR_HI16'
  MCK_SGPR_LO16, // register class 'SGPR_LO16'
  MCK_Reg772, // derived register class
  MCK_Reg773, // derived register class
  MCK_Reg774, // derived register class
  MCK_Reg775, // derived register class
  MCK_Reg776, // derived register class
  MCK_Reg877, // derived register class
  MCK_Reg777, // derived register class
  MCK_Reg138, // derived register class
  MCK_Reg878, // derived register class
  MCK_Reg778, // derived register class
  MCK_Reg693, // derived register class
  MCK_AReg_1024_Align2, // register class 'AReg_1024_Align2'
  MCK_VReg_1024_Lo256_Align2, // register class 'VReg_1024_Lo256_Align2'
  MCK_Reg879, // derived register class
  MCK_Reg844, // derived register class
  MCK_Reg779, // derived register class
  MCK_Reg694, // derived register class
  MCK_Reg880, // derived register class
  MCK_Reg845, // derived register class
  MCK_Reg780, // derived register class
  MCK_Reg695, // derived register class
  MCK_Reg881, // derived register class
  MCK_Reg846, // derived register class
  MCK_Reg781, // derived register class
  MCK_Reg696, // derived register class
  MCK_Reg882, // derived register class
  MCK_Reg847, // derived register class
  MCK_Reg782, // derived register class
  MCK_Reg697, // derived register class
  MCK_Reg640, // derived register class
  MCK_Reg883, // derived register class
  MCK_Reg848, // derived register class
  MCK_Reg783, // derived register class
  MCK_Reg698, // derived register class
  MCK_Reg641, // derived register class
  MCK_Reg591, // derived register class
  MCK_Reg884, // derived register class
  MCK_Reg849, // derived register class
  MCK_Reg784, // derived register class
  MCK_Reg699, // derived register class
  MCK_Reg642, // derived register class
  MCK_Reg592, // derived register class
  MCK_Reg546, // derived register class
  MCK_Reg885, // derived register class
  MCK_Reg850, // derived register class
  MCK_Reg785, // derived register class
  MCK_Reg752, // derived register class
  MCK_Reg700, // derived register class
  MCK_Reg643, // derived register class
  MCK_Reg593, // derived register class
  MCK_Reg547, // derived register class
  MCK_Reg505, // derived register class
  MCK_Reg132, // derived register class
  MCK_Reg886, // derived register class
  MCK_Reg851, // derived register class
  MCK_Reg786, // derived register class
  MCK_Reg753, // derived register class
  MCK_Reg701, // derived register class
  MCK_Reg644, // derived register class
  MCK_Reg594, // derived register class
  MCK_Reg548, // derived register class
  MCK_Reg506, // derived register class
  MCK_Reg468, // derived register class
  MCK_AReg_512_Align2, // register class 'AReg_512_Align2'
  MCK_VReg_512_Lo256_Align2, // register class 'VReg_512_Lo256_Align2'
  MCK_Reg887, // derived register class
  MCK_Reg852, // derived register class
  MCK_Reg787, // derived register class
  MCK_Reg754, // derived register class
  MCK_Reg735, // derived register class
  MCK_Reg702, // derived register class
  MCK_Reg685, // derived register class
  MCK_Reg645, // derived register class
  MCK_Reg595, // derived register class
  MCK_Reg549, // derived register class
  MCK_Reg507, // derived register class
  MCK_Reg469, // derived register class
  MCK_Reg435, // derived register class
  MCK_Reg126, // derived register class
  MCK_Reg888, // derived register class
  MCK_Reg853, // derived register class
  MCK_Reg788, // derived register class
  MCK_Reg755, // derived register class
  MCK_Reg736, // derived register class
  MCK_Reg703, // derived register class
  MCK_Reg686, // derived register class
  MCK_Reg646, // derived register class
  MCK_Reg633, // derived register class
  MCK_Reg596, // derived register class
  MCK_Reg584, // derived register class
  MCK_Reg550, // derived register class
  MCK_Reg508, // derived register class
  MCK_Reg470, // derived register class
  MCK_Reg436, // derived register class
  MCK_Reg406, // derived register class
  MCK_Reg120, // derived register class
  MCK_Reg114, // derived register class
  MCK_AReg_352_Align2, // register class 'AReg_352_Align2'
  MCK_AReg_384_Align2, // register class 'AReg_384_Align2'
  MCK_VReg_352_Lo256_Align2, // register class 'VReg_352_Lo256_Align2'
  MCK_VReg_384_Lo256_Align2, // register class 'VReg_384_Lo256_Align2'
  MCK_Reg889, // derived register class
  MCK_Reg854, // derived register class
  MCK_Reg789, // derived register class
  MCK_Reg756, // derived register class
  MCK_Reg737, // derived register class
  MCK_Reg704, // derived register class
  MCK_Reg687, // derived register class
  MCK_Reg672, // derived register class
  MCK_Reg647, // derived register class
  MCK_Reg634, // derived register class
  MCK_Reg621, // derived register class
  MCK_Reg597, // derived register class
  MCK_Reg585, // derived register class
  MCK_Reg551, // derived register class
  MCK_Reg540, // derived register class
  MCK_Reg509, // derived register class
  MCK_Reg499, // derived register class
  MCK_Reg471, // derived register class
  MCK_Reg437, // derived register class
  MCK_Reg407, // derived register class
  MCK_Reg381, // derived register class
  MCK_Reg108, // derived register class
  MCK_Reg102, // derived register class
  MCK_AReg_288_Align2, // register class 'AReg_288_Align2'
  MCK_AReg_320_Align2, // register class 'AReg_320_Align2'
  MCK_VReg_288_Lo256_Align2, // register class 'VReg_288_Lo256_Align2'
  MCK_VReg_320_Lo256_Align2, // register class 'VReg_320_Lo256_Align2'
  MCK_Reg890, // derived register class
  MCK_Reg855, // derived register class
  MCK_Reg790, // derived register class
  MCK_Reg757, // derived register class
  MCK_Reg738, // derived register class
  MCK_Reg705, // derived register class
  MCK_Reg688, // derived register class
  MCK_Reg673, // derived register class
  MCK_Reg648, // derived register class
  MCK_Reg635, // derived register class
  MCK_Reg622, // derived register class
  MCK_Reg598, // derived register class
  MCK_Reg586, // derived register class
  MCK_Reg573, // derived register class
  MCK_Reg552, // derived register class
  MCK_Reg541, // derived register class
  MCK_Reg530, // derived register class
  MCK_Reg510, // derived register class
  MCK_Reg500, // derived register class
  MCK_Reg472, // derived register class
  MCK_Reg463, // derived register class
  MCK_Reg438, // derived register class
  MCK_Reg430, // derived register class
  MCK_Reg408, // derived register class
  MCK_Reg382, // derived register class
  MCK_Reg360, // derived register class
  MCK_Reg96, // derived register class
  MCK_Reg90, // derived register class
  MCK_AReg_224_Align2, // register class 'AReg_224_Align2'
  MCK_AReg_256_Align2, // register class 'AReg_256_Align2'
  MCK_VReg_224_Lo256_Align2, // register class 'VReg_224_Lo256_Align2'
  MCK_VReg_256_Lo256_Align2, // register class 'VReg_256_Lo256_Align2'
  MCK_Reg891, // derived register class
  MCK_Reg856, // derived register class
  MCK_Reg791, // derived register class
  MCK_Reg758, // derived register class
  MCK_Reg739, // derived register class
  MCK_Reg706, // derived register class
  MCK_Reg689, // derived register class
  MCK_Reg674, // derived register class
  MCK_Reg649, // derived register class
  MCK_Reg636, // derived register class
  MCK_Reg623, // derived register class
  MCK_Reg599, // derived register class
  MCK_Reg587, // derived register class
  MCK_Reg574, // derived register class
  MCK_Reg553, // derived register class
  MCK_Reg542, // derived register class
  MCK_Reg531, // derived register class
  MCK_Reg511, // derived register class
  MCK_Reg501, // derived register class
  MCK_Reg490, // derived register class
  MCK_Reg473, // derived register class
  MCK_Reg464, // derived register class
  MCK_Reg455, // derived register class
  MCK_Reg439, // derived register class
  MCK_Reg431, // derived register class
  MCK_Reg409, // derived register class
  MCK_Reg402, // derived register class
  MCK_Reg383, // derived register class
  MCK_Reg377, // derived register class
  MCK_Reg361, // derived register class
  MCK_Reg343, // derived register class
  MCK_Reg84, // derived register class
  MCK_Reg78, // derived register class
  MCK_AReg_160_Align2, // register class 'AReg_160_Align2'
  MCK_AReg_192_Align2, // register class 'AReg_192_Align2'
  MCK_VReg_160_Lo256_Align2, // register class 'VReg_160_Lo256_Align2'
  MCK_VReg_192_Lo256_Align2, // register class 'VReg_192_Lo256_Align2'
  MCK_Reg892, // derived register class
  MCK_Reg857, // derived register class
  MCK_Reg792, // derived register class
  MCK_Reg759, // derived register class
  MCK_Reg740, // derived register class
  MCK_Reg707, // derived register class
  MCK_Reg690, // derived register class
  MCK_Reg675, // derived register class
  MCK_Reg650, // derived register class
  MCK_Reg637, // derived register class
  MCK_Reg624, // derived register class
  MCK_Reg600, // derived register class
  MCK_Reg588, // derived register class
  MCK_Reg575, // derived register class
  MCK_Reg554, // derived register class
  MCK_Reg543, // derived register class
  MCK_Reg532, // derived register class
  MCK_Reg512, // derived register class
  MCK_Reg502, // derived register class
  MCK_Reg491, // derived register class
  MCK_Reg474, // derived register class
  MCK_Reg465, // derived register class
  MCK_Reg456, // derived register class
  MCK_Reg440, // derived register class
  MCK_Reg432, // derived register class
  MCK_Reg423, // derived register class
  MCK_Reg410, // derived register class
  MCK_Reg403, // derived register class
  MCK_Reg396, // derived register class
  MCK_Reg384, // derived register class
  MCK_Reg378, // derived register class
  MCK_Reg362, // derived register class
  MCK_Reg357, // derived register class
  MCK_Reg344, // derived register class
  MCK_Reg335, // derived register class
  MCK_Reg72, // derived register class
  MCK_AReg_128_Align2, // register class 'AReg_128_Align2'
  MCK_AReg_96_Align2, // register class 'AReg_96_Align2'
  MCK_VReg_128_Lo256_Align2, // register class 'VReg_128_Lo256_Align2'
  MCK_VReg_96_Lo256_Align2, // register class 'VReg_96_Lo256_Align2'
  MCK_Reg893, // derived register class
  MCK_Reg858, // derived register class
  MCK_Reg793, // derived register class
  MCK_Reg760, // derived register class
  MCK_Reg741, // derived register class
  MCK_Reg708, // derived register class
  MCK_Reg691, // derived register class
  MCK_Reg676, // derived register class
  MCK_Reg651, // derived register class
  MCK_Reg638, // derived register class
  MCK_Reg625, // derived register class
  MCK_Reg601, // derived register class
  MCK_Reg589, // derived register class
  MCK_Reg576, // derived register class
  MCK_Reg555, // derived register class
  MCK_Reg544, // derived register class
  MCK_Reg533, // derived register class
  MCK_Reg513, // derived register class
  MCK_Reg503, // derived register class
  MCK_Reg492, // derived register class
  MCK_Reg475, // derived register class
  MCK_Reg466, // derived register class
  MCK_Reg457, // derived register class
  MCK_Reg441, // derived register class
  MCK_Reg433, // derived register class
  MCK_Reg424, // derived register class
  MCK_Reg411, // derived register class
  MCK_Reg404, // derived register class
  MCK_Reg397, // derived register class
  MCK_Reg385, // derived register class
  MCK_Reg379, // derived register class
  MCK_Reg372, // derived register class
  MCK_Reg363, // derived register class
  MCK_Reg358, // derived register class
  MCK_Reg353, // derived register class
  MCK_Reg345, // derived register class
  MCK_Reg336, // derived register class
  MCK_AReg_64_Align2, // register class 'AReg_64_Align2'
  MCK_VGPR_32_Lo128, // register class 'VGPR_32_Lo128'
  MCK_VReg_64_Lo256_Align2, // register class 'VReg_64_Lo256_Align2'
  MCK_Reg44, // derived register class
  MCK_Reg34, // derived register class
  MCK_Reg25, // derived register class
  MCK_SReg_32_XM0_XEXEC, // register class 'SReg_32_XM0_XEXEC'
  MCK_Reg15, // derived register class
  MCK_SReg_32_XEXEC, // register class 'SReg_32_XEXEC'
  MCK_SReg_32_XEXEC_HI, // register class 'SReg_32_XEXEC_HI'
  MCK_SReg_32_XM0, // register class 'SReg_32_XM0'
  MCK_SReg_32, // register class 'SReg_32'
  MCK_SReg_LO16, // register class 'SReg_LO16'
  MCK_SRegOrLds_32, // register class 'SRegOrLds_32'
  MCK_Reg151, // derived register class
  MCK_Reg152, // derived register class
  MCK_Reg162, // derived register class
  MCK_Reg153, // derived register class
  MCK_Reg163, // derived register class
  MCK_Reg154, // derived register class
  MCK_Reg29, // derived register class
  MCK_Reg35, // derived register class
  MCK_Reg30, // derived register class
  MCK_Reg22, // derived register class
  MCK_VS_64_Lo256, // register class 'VS_64_Lo256'
  MCK_Reg794, // derived register class
  MCK_AReg_1024, // register class 'AReg_1024'
  MCK_Reg795, // derived register class
  MCK_Reg796, // derived register class
  MCK_Reg797, // derived register class
  MCK_Reg798, // derived register class
  MCK_Reg799, // derived register class
  MCK_Reg800, // derived register class
  MCK_Reg801, // derived register class
  MCK_Reg802, // derived register class
  MCK_Reg803, // derived register class
  MCK_Reg804, // derived register class
  MCK_Reg805, // derived register class
  MCK_Reg806, // derived register class
  MCK_Reg807, // derived register class
  MCK_Reg808, // derived register class
  MCK_Reg809, // derived register class
  MCK_Reg810, // derived register class
  MCK_Reg709, // derived register class
  MCK_AReg_512, // register class 'AReg_512'
  MCK_Reg811, // derived register class
  MCK_Reg710, // derived register class
  MCK_Reg812, // derived register class
  MCK_Reg711, // derived register class
  MCK_Reg813, // derived register class
  MCK_Reg712, // derived register class
  MCK_Reg814, // derived register class
  MCK_Reg713, // derived register class
  MCK_Reg652, // derived register class
  MCK_AReg_384, // register class 'AReg_384'
  MCK_Reg815, // derived register class
  MCK_Reg714, // derived register class
  MCK_Reg653, // derived register class
  MCK_Reg602, // derived register class
  MCK_AReg_352, // register class 'AReg_352'
  MCK_Reg816, // derived register class
  MCK_Reg715, // derived register class
  MCK_Reg654, // derived register class
  MCK_Reg603, // derived register class
  MCK_Reg556, // derived register class
  MCK_AReg_320, // register class 'AReg_320'
  MCK_Reg817, // derived register class
  MCK_Reg716, // derived register class
  MCK_Reg655, // derived register class
  MCK_Reg604, // derived register class
  MCK_Reg557, // derived register class
  MCK_Reg514, // derived register class
  MCK_AReg_288, // register class 'AReg_288'
  MCK_Reg818, // derived register class
  MCK_Reg717, // derived register class
  MCK_Reg656, // derived register class
  MCK_Reg605, // derived register class
  MCK_Reg558, // derived register class
  MCK_Reg515, // derived register class
  MCK_Reg476, // derived register class
  MCK_AReg_256, // register class 'AReg_256'
  MCK_Reg819, // derived register class
  MCK_Reg718, // derived register class
  MCK_Reg657, // derived register class
  MCK_Reg606, // derived register class
  MCK_Reg559, // derived register class
  MCK_Reg516, // derived register class
  MCK_Reg477, // derived register class
  MCK_Reg442, // derived register class
  MCK_AReg_224, // register class 'AReg_224'
  MCK_Reg820, // derived register class
  MCK_Reg719, // derived register class
  MCK_Reg658, // derived register class
  MCK_Reg607, // derived register class
  MCK_Reg560, // derived register class
  MCK_Reg517, // derived register class
  MCK_Reg478, // derived register class
  MCK_Reg443, // derived register class
  MCK_Reg412, // derived register class
  MCK_AReg_192, // register class 'AReg_192'
  MCK_Reg821, // derived register class
  MCK_Reg720, // derived register class
  MCK_Reg659, // derived register class
  MCK_Reg608, // derived register class
  MCK_Reg561, // derived register class
  MCK_Reg518, // derived register class
  MCK_Reg479, // derived register class
  MCK_Reg444, // derived register class
  MCK_Reg413, // derived register class
  MCK_Reg386, // derived register class
  MCK_AReg_160, // register class 'AReg_160'
  MCK_Reg822, // derived register class
  MCK_Reg721, // derived register class
  MCK_Reg660, // derived register class
  MCK_Reg609, // derived register class
  MCK_Reg562, // derived register class
  MCK_Reg519, // derived register class
  MCK_Reg480, // derived register class
  MCK_Reg445, // derived register class
  MCK_Reg414, // derived register class
  MCK_Reg387, // derived register class
  MCK_Reg364, // derived register class
  MCK_AReg_128, // register class 'AReg_128'
  MCK_Reg823, // derived register class
  MCK_Reg722, // derived register class
  MCK_Reg661, // derived register class
  MCK_Reg610, // derived register class
  MCK_Reg563, // derived register class
  MCK_Reg520, // derived register class
  MCK_Reg481, // derived register class
  MCK_Reg446, // derived register class
  MCK_Reg415, // derived register class
  MCK_Reg388, // derived register class
  MCK_Reg365, // derived register class
  MCK_Reg346, // derived register class
  MCK_AReg_96, // register class 'AReg_96'
  MCK_Reg824, // derived register class
  MCK_Reg723, // derived register class
  MCK_Reg662, // derived register class
  MCK_Reg611, // derived register class
  MCK_Reg564, // derived register class
  MCK_Reg521, // derived register class
  MCK_Reg482, // derived register class
  MCK_Reg447, // derived register class
  MCK_Reg416, // derived register class
  MCK_Reg389, // derived register class
  MCK_Reg366, // derived register class
  MCK_Reg347, // derived register class
  MCK_Reg337, // derived register class
  MCK_AReg_64, // register class 'AReg_64'
  MCK_Reg825, // derived register class
  MCK_Reg724, // derived register class
  MCK_Reg663, // derived register class
  MCK_Reg612, // derived register class
  MCK_Reg565, // derived register class
  MCK_Reg522, // derived register class
  MCK_Reg483, // derived register class
  MCK_Reg448, // derived register class
  MCK_Reg417, // derived register class
  MCK_Reg390, // derived register class
  MCK_Reg367, // derived register class
  MCK_Reg348, // derived register class
  MCK_Reg338, // derived register class
  MCK_AGPR_32, // register class 'AGPR_32'
  MCK_AGPR_LO16, // register class 'AGPR_LO16'
  MCK_VGPR_16_Lo128, // register class 'VGPR_16_Lo128'
  MCK_VGPR_32_Lo256, // register class 'VGPR_32_Lo256'
  MCK_Reg45, // derived register class
  MCK_Reg10, // derived register class
  MCK_VS_32_Lo128, // register class 'VS_32_Lo128'
  MCK_Reg155, // derived register class
  MCK_Reg156, // derived register class
  MCK_Reg157, // derived register class
  MCK_Reg158, // derived register class
  MCK_Reg31, // derived register class
  MCK_Reg32, // derived register class
  MCK_Reg23, // derived register class
  MCK_Reg11, // derived register class
  MCK_VS_16_Lo128, // register class 'VS_16_Lo128'
  MCK_VS_32_Lo256, // register class 'VS_32_Lo256'
  MCK_Reg894, // derived register class
  MCK_VReg_1024_Align2, // register class 'VReg_1024_Align2'
  MCK_Reg761, // derived register class
  MCK_VReg_512_Align2, // register class 'VReg_512_Align2'
  MCK_Reg692, // derived register class
  MCK_Reg639, // derived register class
  MCK_Reg590, // derived register class
  MCK_VReg_352_Align2, // register class 'VReg_352_Align2'
  MCK_VReg_384_Align2, // register class 'VReg_384_Align2'
  MCK_Reg545, // derived register class
  MCK_Reg504, // derived register class
  MCK_VReg_288_Align2, // register class 'VReg_288_Align2'
  MCK_VReg_320_Align2, // register class 'VReg_320_Align2'
  MCK_Reg467, // derived register class
  MCK_Reg434, // derived register class
  MCK_VReg_224_Align2, // register class 'VReg_224_Align2'
  MCK_VReg_256_Align2, // register class 'VReg_256_Align2'
  MCK_Reg405, // derived register class
  MCK_Reg380, // derived register class
  MCK_VReg_160_Align2, // register class 'VReg_160_Align2'
  MCK_VReg_192_Align2, // register class 'VReg_192_Align2'
  MCK_Reg359, // derived register class
  MCK_VReg_128_Align2, // register class 'VReg_128_Align2'
  MCK_VReg_96_Align2, // register class 'VReg_96_Align2'
  MCK_VReg_64_Align2, // register class 'VReg_64_Align2'
  MCK_Reg164, // derived register class
  MCK_VS_128_Align2, // register class 'VS_128_Align2'
  MCK_Reg36, // derived register class
  MCK_VS_64_Align2, // register class 'VS_64_Align2'
  MCK_Reg139, // derived register class
  MCK_AV_1024_Align2, // register class 'AV_1024_Align2'
  MCK_Reg133, // derived register class
  MCK_AV_512_Align2, // register class 'AV_512_Align2'
  MCK_Reg127, // derived register class
  MCK_Reg121, // derived register class
  MCK_Reg115, // derived register class
  MCK_AV_352_Align2, // register class 'AV_352_Align2'
  MCK_AV_384_Align2, // register class 'AV_384_Align2'
  MCK_Reg109, // derived register class
  MCK_Reg103, // derived register class
  MCK_AV_288_Align2, // register class 'AV_288_Align2'
  MCK_AV_320_Align2, // register class 'AV_320_Align2'
  MCK_Reg97, // derived register class
  MCK_Reg91, // derived register class
  MCK_AV_224_Align2, // register class 'AV_224_Align2'
  MCK_AV_256_Align2, // register class 'AV_256_Align2'
  MCK_Reg85, // derived register class
  MCK_Reg79, // derived register class
  MCK_AV_160_Align2, // register class 'AV_160_Align2'
  MCK_AV_192_Align2, // register class 'AV_192_Align2'
  MCK_Reg73, // derived register class
  MCK_AV_128_Align2, // register class 'AV_128_Align2'
  MCK_AV_96_Align2, // register class 'AV_96_Align2'
  MCK_AV_64_Align2, // register class 'AV_64_Align2'
  MCK_VReg_1024, // register class 'VReg_1024'
  MCK_VReg_512, // register class 'VReg_512'
  MCK_VReg_384, // register class 'VReg_384'
  MCK_VReg_352, // register class 'VReg_352'
  MCK_VReg_320, // register class 'VReg_320'
  MCK_VReg_288, // register class 'VReg_288'
  MCK_VReg_256, // register class 'VReg_256'
  MCK_VReg_224, // register class 'VReg_224'
  MCK_VReg_192, // register class 'VReg_192'
  MCK_VReg_160, // register class 'VReg_160'
  MCK_VReg_128, // register class 'VReg_128'
  MCK_VReg_96, // register class 'VReg_96'
  MCK_VReg_64, // register class 'VReg_64'
  MCK_VGPR_32, // register class 'VGPR_32'
  MCK_VRegOrLds_32, // register class 'VRegOrLds_32'
  MCK_Reg159, // derived register class
  MCK_VS_128, // register class 'VS_128'
  MCK_Reg33, // derived register class
  MCK_VS_64, // register class 'VS_64'
  MCK_Reg12, // derived register class
  MCK_VS_32, // register class 'VS_32'
  MCK_AV_1024, // register class 'AV_1024'
  MCK_AV_512, // register class 'AV_512'
  MCK_AV_384, // register class 'AV_384'
  MCK_AV_352, // register class 'AV_352'
  MCK_AV_320, // register class 'AV_320'
  MCK_AV_288, // register class 'AV_288'
  MCK_AV_256, // register class 'AV_256'
  MCK_AV_224, // register class 'AV_224'
  MCK_AV_192, // register class 'AV_192'
  MCK_AV_160, // register class 'AV_160'
  MCK_AV_128, // register class 'AV_128'
  MCK_AV_96, // register class 'AV_96'
  MCK_AV_64, // register class 'AV_64'
  MCK_AV_32, // register class 'AV_32'
  MCK_VGPR_16, // register class 'VGPR_16'
  MCK_VS_16, // register class 'VS_16'
  MCK_LAST_REGISTER = MCK_VS_16,
  MCK_RegByHwMode_AReg_64_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AReg_96_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AReg_128_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AReg_160_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AReg_192_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AReg_224_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AReg_256_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AReg_288_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AReg_320_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AReg_352_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AReg_384_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AReg_512_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AReg_1024_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_64_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_96_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_128_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_160_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_192_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_224_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_256_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_288_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_320_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_352_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_384_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_512_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_1024_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_32_Align2, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_32_Target, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_64_Align1, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_64_Align2, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_64_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_96_Align1, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_96_Align2, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_96_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_128_Align1, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_128_Align2, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_128_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_160_Align1, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_160_Align2, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_160_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_192_Align1, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_192_Align2, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_192_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_224_Align1, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_224_Align2, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_224_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_256_Align1, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_256_Align2, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_256_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_288_Align1, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_288_Align2, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_288_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_320_Align1, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_320_Align2, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_320_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_352_Align1, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_352_Align2, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_352_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_384_Align1, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_384_Align2, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_384_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_512_Align1, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_512_Align2, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_512_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_1024_Align1, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_1024_Align2, // register class by hwmode
  MCK_RegByHwMode_AV_LdSt_1024_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_SReg_1, // register class by hwmode
  MCK_RegByHwMode_SReg_1_XEXEC, // register class by hwmode
  MCK_RegByHwMode_VReg_64_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_VReg_96_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_VReg_128_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_VReg_160_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_VReg_192_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_VReg_224_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_VReg_256_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_VReg_288_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_VReg_320_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_VReg_352_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_VReg_384_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_VReg_512_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_VReg_1024_AlignTarget, // register class by hwmode
  MCK_RegByHwMode_VS_64_AlignTarget, // register class by hwmode
  MCK_LAST_REGCLASS_BY_HWMODE = MCK_RegByHwMode_VS_64_AlignTarget,
  MCK_AV_LdSt_32_Align2_RegOp, // user defined class 'AV_LdSt_32_Align2_RegMatcher'
  MCK_SDWAWithBin32InputMods, // user defined class 'Bin32SDWAInputModsMatchClass'
  MCK_BoolReg, // user defined class 'BoolReg'
  MCK_RegOrImmWithFP16InputMods, // user defined class 'FP16InputModsMatchClass'
  MCK_SDWAWithFP16InputMods, // user defined class 'FP16SDWAInputModsMatchClass'
  MCK_RegOrImmWithFP32InputMods, // user defined class 'FP32InputModsMatchClass'
  MCK_SDWAWithFP32InputMods, // user defined class 'FP32SDWAInputModsMatchClass'
  MCK_RegOrInlineImmWithFP32InputMods, // user defined class 'FP32VCSrcInputModsMatchClass'
  MCK_VRegWithFP32InputMods, // user defined class 'FP32VRegSrcInputModsMatchClass'
  MCK_RegOrImmWithFP64InputMods, // user defined class 'FP64InputModsMatchClass'
  MCK_RegOrInlineImmWithFP64InputMods, // user defined class 'FP64VCSrcInputModsMatchClass'
  MCK_VRegWithFP64InputMods, // user defined class 'FP64VRegSrcInputModsMatchClass'
  MCK_VRegWithFPInputMods, // user defined class 'FPVRegInputModsMatchClass'
  MCK_Imm, // user defined class 'ImmAsmOperand'
  MCK_SDWAWithInt16InputMods, // user defined class 'Int16SDWAInputModsMatchClass'
  MCK_RegOrImmWithInt32InputMods, // user defined class 'Int32InputModsMatchClass'
  MCK_SDWAWithInt32InputMods, // user defined class 'Int32SDWAInputModsMatchClass'
  MCK_RegOrInlineImmWithInt32InputMods, // user defined class 'Int32VCSrcInputModsMatchClass'
  MCK_RegOrImmWithInt64InputMods, // user defined class 'Int64InputModsMatchClass'
  MCK_OpSelMods, // user defined class 'IntOpSelModsMatchClass'
  MCK_VRegWithIntInputMods, // user defined class 'IntVRegInputModsMatchClass'
  MCK_PackedFP16InputMods, // user defined class 'PackedF16InputModsMatchClass'
  MCK_PackedInt16InputMods, // user defined class 'PackedI16InputModsMatchClass'
  MCK_PackedFP32InputMods, // user defined class 'PackedVGPRF32InputModsMatchClass'
  MCK_VReg32OrOff, // user defined class 'VReg32OrOffClass'
  MCK_SSrc_b16, // user defined class 'anonymous_15441'
  MCK_SSrc_bf16, // user defined class 'anonymous_15442'
  MCK_SSrc_f16, // user defined class 'anonymous_15443'
  MCK_SSrc_b32, // user defined class 'anonymous_15444'
  MCK_SSrc_f32, // user defined class 'anonymous_15445'
  MCK_SSrc_b64, // user defined class 'anonymous_15446'
  MCK_SSrcOrLds_b32, // user defined class 'anonymous_15447'
  MCK_SCSrc_b32, // user defined class 'anonymous_15448'
  MCK_SCSrc_b64, // user defined class 'anonymous_15449'
  MCK_VSrc_b16, // user defined class 'anonymous_15450'
  MCK_VSrc_bf16, // user defined class 'anonymous_15451'
  MCK_VSrc_f16, // user defined class 'anonymous_15452'
  MCK_VSrcT_b16, // user defined class 'anonymous_15453'
  MCK_VSrcT_bf16, // user defined class 'anonymous_15454'
  MCK_VSrcT_f16, // user defined class 'anonymous_15455'
  MCK_VSrcT_b16_Lo128, // user defined class 'anonymous_15456'
  MCK_VSrcT_bf16_Lo128, // user defined class 'anonymous_15457'
  MCK_VSrcT_f16_Lo128, // user defined class 'anonymous_15458'
  MCK_VSrcFake16_b16_Lo128, // user defined class 'anonymous_15459'
  MCK_VSrcFake16_bf16_Lo128, // user defined class 'anonymous_15460'
  MCK_VSrcFake16_f16_Lo128, // user defined class 'anonymous_15461'
  MCK_VSrc_b32, // user defined class 'anonymous_15462'
  MCK_VSrc_f32, // user defined class 'anonymous_15463'
  MCK_VSrc_v2b16, // user defined class 'anonymous_15464'
  MCK_VSrc_v2bf16, // user defined class 'anonymous_15465'
  MCK_VSrc_v2f16, // user defined class 'anonymous_15466'
  MCK_VSrc_b64, // user defined class 'anonymous_15467'
  MCK_VSrc_f64, // user defined class 'anonymous_15468'
  MCK_VSrc_v2b32, // user defined class 'anonymous_15469'
  MCK_VSrc_v2f32, // user defined class 'anonymous_15470'
  MCK_VSrc_NoInline_v2f16, // user defined class 'anonymous_15471'
  MCK_VSrc_v2f16_splat, // user defined class 'anonymous_15472'
  MCK_VCSrc_b16, // user defined class 'anonymous_15473'
  MCK_VCSrc_bf16, // user defined class 'anonymous_15474'
  MCK_VCSrc_f16, // user defined class 'anonymous_15475'
  MCK_VCSrc_b32, // user defined class 'anonymous_15476'
  MCK_VCSrc_f32, // user defined class 'anonymous_15477'
  MCK_VCSrc_v2b16, // user defined class 'anonymous_15478'
  MCK_VCSrc_v2bf16, // user defined class 'anonymous_15479'
  MCK_VCSrc_v2f16, // user defined class 'anonymous_15480'
  MCK_VCSrc_b32_Lo256, // user defined class 'anonymous_15481'
  MCK_VCSrc_b64_Lo256, // user defined class 'anonymous_15482'
  MCK_VCSrc_b64, // user defined class 'anonymous_15483'
  MCK_VCSrc_f64, // user defined class 'anonymous_15484'
  MCK_VCSrc_v2b32, // user defined class 'anonymous_15485'
  MCK_VCSrcT_b16, // user defined class 'anonymous_15486'
  MCK_VCSrcT_bf16, // user defined class 'anonymous_15487'
  MCK_VCSrcT_f16, // user defined class 'anonymous_15488'
  MCK_VISrc_64_bf16, // user defined class 'anonymous_15489'
  MCK_VISrc_64_f16, // user defined class 'anonymous_15490'
  MCK_VISrc_64_b32, // user defined class 'anonymous_15491'
  MCK_VISrc_64_f64, // user defined class 'anonymous_15492'
  MCK_VISrc_128_bf16, // user defined class 'anonymous_15493'
  MCK_VISrc_128_f16, // user defined class 'anonymous_15494'
  MCK_VISrc_128_b32, // user defined class 'anonymous_15495'
  MCK_VISrc_128_f32, // user defined class 'anonymous_15496'
  MCK_VISrc_256_b32, // user defined class 'anonymous_15497'
  MCK_VISrc_256_f32, // user defined class 'anonymous_15498'
  MCK_VISrc_256_f64, // user defined class 'anonymous_15499'
  MCK_VISrc_512_b32, // user defined class 'anonymous_15500'
  MCK_VISrc_512_f32, // user defined class 'anonymous_15501'
  MCK_VISrc_512_f64, // user defined class 'anonymous_15502'
  MCK_VISrc_1024_b32, // user defined class 'anonymous_15503'
  MCK_VISrc_1024_f32, // user defined class 'anonymous_15504'
  MCK_AISrc_64_f64, // user defined class 'anonymous_15505'
  MCK_AISrc_128_f32, // user defined class 'anonymous_15506'
  MCK_AISrc_128_b32, // user defined class 'anonymous_15507'
  MCK_AISrc_256_f64, // user defined class 'anonymous_15508'
  MCK_AISrc_512_f32, // user defined class 'anonymous_15509'
  MCK_AISrc_512_b32, // user defined class 'anonymous_15510'
  MCK_AISrc_1024_f32, // user defined class 'anonymous_15511'
  MCK_AISrc_1024_b32, // user defined class 'anonymous_15512'
  MCK_S16Imm, // user defined class 'anonymous_15513'
  MCK_U16Imm, // user defined class 'anonymous_15514'
  MCK_SOPPBrTarget, // user defined class 'anonymous_15536'
  MCK_InterpSlot, // user defined class 'anonymous_15537'
  MCK_InterpAttr, // user defined class 'anonymous_15538'
  MCK_InterpAttrChan, // user defined class 'anonymous_15539'
  MCK_SplitBarrier, // user defined class 'anonymous_15540'
  MCK_SendMsg, // user defined class 'anonymous_15541'
  MCK_Swizzle, // user defined class 'anonymous_15542'
  MCK_Endpgm, // user defined class 'anonymous_15543'
  MCK_SWaitCnt, // user defined class 'anonymous_15544'
  MCK_DepCtr, // user defined class 'anonymous_15545'
  MCK_SDelayALU, // user defined class 'anonymous_15546'
  MCK_FlatOffset, // user defined class 'anonymous_15547'
  MCK_Offset, // user defined class 'anonymous_15548'
  MCK_Offset0, // user defined class 'anonymous_15549'
  MCK_Offset1, // user defined class 'anonymous_15550'
  MCK_GDS, // user defined class 'anonymous_15551'
  MCK_OModSI, // user defined class 'anonymous_15552'
  MCK_Clamp, // user defined class 'anonymous_15553'
  MCK_High, // user defined class 'anonymous_15554'
  MCK_CPol, // user defined class 'anonymous_15555'
  MCK_CPol_GLC, // user defined class 'anonymous_15556'
  MCK_CPol_NonGLC, // user defined class 'anonymous_15557'
  MCK_TFE, // user defined class 'anonymous_15558'
  MCK_UNorm, // user defined class 'anonymous_15559'
  MCK_DA, // user defined class 'anonymous_15560'
  MCK_R128A16, // user defined class 'anonymous_15561'
  MCK_A16, // user defined class 'anonymous_15562'
  MCK_D16, // user defined class 'anonymous_15563'
  MCK_LWE, // user defined class 'anonymous_15564'
  MCK_ExpCompr, // user defined class 'anonymous_15565'
  MCK_ExpVM, // user defined class 'anonymous_15566'
  MCK_FORMAT, // user defined class 'anonymous_15567'
  MCK_DMask, // user defined class 'anonymous_15568'
  MCK_Dim, // user defined class 'anonymous_15569'
  MCK_SDWADstSel, // user defined class 'anonymous_15570'
  MCK_SDWASrc0Sel, // user defined class 'anonymous_15571'
  MCK_SDWASrc1Sel, // user defined class 'anonymous_15572'
  MCK_SDWADstUnused, // user defined class 'anonymous_15573'
  MCK_OpSel, // user defined class 'anonymous_15574'
  MCK_OpSelHi, // user defined class 'anonymous_15575'
  MCK_NegLo, // user defined class 'anonymous_15576'
  MCK_NegHi, // user defined class 'anonymous_15577'
  MCK_IndexKey32bit, // user defined class 'anonymous_15578'
  MCK_IndexKey16bit, // user defined class 'anonymous_15579'
  MCK_IndexKey8bit, // user defined class 'anonymous_15580'
  MCK_DPP8, // user defined class 'anonymous_15581'
  MCK_DPPCtrl, // user defined class 'anonymous_15582'
  MCK_DppRowMask, // user defined class 'anonymous_15583'
  MCK_DppBankMask, // user defined class 'anonymous_15584'
  MCK_DppBoundCtrl, // user defined class 'anonymous_15585'
  MCK_DppFI, // user defined class 'anonymous_15586'
  MCK_BLGP, // user defined class 'anonymous_15587'
  MCK_CBSZ, // user defined class 'anonymous_15588'
  MCK_ABID, // user defined class 'anonymous_15589'
  MCK_Hwreg, // user defined class 'anonymous_15590'
  MCK_ExpTgt, // user defined class 'anonymous_15591'
  MCK_WaitVDST, // user defined class 'anonymous_15592'
  MCK_WaitEXP, // user defined class 'anonymous_15593'
  MCK_WaitVAVDst, // user defined class 'anonymous_15594'
  MCK_WaitVMVSrc, // user defined class 'anonymous_15595'
  MCK_ByteSel, // user defined class 'anonymous_15596'
  MCK_BitOp3, // user defined class 'anonymous_15597'
  MCK_MatrixAFMT, // user defined class 'anonymous_15598'
  MCK_MatrixBFMT, // user defined class 'anonymous_15599'
  MCK_MatrixAScale, // user defined class 'anonymous_15600'
  MCK_MatrixBScale, // user defined class 'anonymous_15601'
  MCK_MatrixAScaleFmt, // user defined class 'anonymous_15602'
  MCK_MatrixBScaleFmt, // user defined class 'anonymous_15603'
  MCK_MatrixAReuse, // user defined class 'anonymous_15604'
  MCK_MatrixBReuse, // user defined class 'anonymous_15605'
  MCK_ScaleSel, // user defined class 'anonymous_15606'
  MCK_KImmFP32, // user defined class 'anonymous_15607'
  MCK_KImmFP16, // user defined class 'anonymous_15608'
  MCK_KImmFP64, // user defined class 'anonymous_15609'
  MCK_Fake16VRegWithFPInputMods, // user defined class 'anonymous_15647'
  MCK_RegOrInlineImmWithFPFake16InputMods, // user defined class 'anonymous_15654'
  MCK_Fake16VRegWithIntInputMods, // user defined class 'anonymous_15718'
  MCK_RegOrInlineImmWithIntFake16InputMods, // user defined class 'anonymous_15723'
  MCK_GPRIdxMode, // user defined class 'anonymous_20747'
  MCK_RegOrImmWithFPT16InputMods, // user defined class 'anonymous_20949'
  MCK_T16_Lo128VRegWithFPInputMods, // user defined class 'anonymous_20954'
  MCK_T16VRegWithFPInputMods, // user defined class 'anonymous_20958'
  MCK_RegOrInlineImmWithFPT16InputMods, // user defined class 'anonymous_20961'
  MCK_RegOrImmWithFPFake16InputMods, // user defined class 'anonymous_20996'
  MCK_Fake16_Lo128VRegWithFPInputMods, // user defined class 'anonymous_21001'
  MCK_RegOrImmWithIntT16InputMods, // user defined class 'anonymous_21078'
  MCK_T16_Lo128VRegWithIntInputMods, // user defined class 'anonymous_21082'
  MCK_T16VRegWithIntInputMods, // user defined class 'anonymous_21085'
  MCK_RegOrInlineImmWithIntT16InputMods, // user defined class 'anonymous_21088'
  MCK_RegOrImmWithIntFake16InputMods, // user defined class 'anonymous_21119'
  MCK_Fake16_Lo128VRegWithIntInputMods, // user defined class 'anonymous_21123'
  MCK_SMRDOffset8, // user defined class 'anonymous_34671'
  MCK_SMEMOffset, // user defined class 'anonymous_34672'
  MCK_SMEMOffsetMod, // user defined class 'anonymous_34673'
  MCK_OptSMEMOffsetMod, // user defined class 'anonymous_34674'
  MCK_SMRDLiteralOffset, // user defined class 'anonymous_34675'
  NumMatchClassKinds
};

} // end anonymous namespace

static unsigned getDiagKindFromRegisterClass(MatchClassKind RegisterClass) {
  return MCTargetAsmParser::Match_InvalidOperand;
}

static MatchClassKind matchTokenString(StringRef Name) {
  switch (Name.size()) {
  default: break;
  case 1:	 // 2 strings to match.
    switch (Name[0]) {
    default: break;
    case '[':	 // 1 string to match.
      return MCK__91_;	 // "["
    case ']':	 // 1 string to match.
      return MCK__93_;	 // "]"
    }
    break;
  case 2:	 // 1 string to match.
    if (memcmp(Name.data()+0, "::", 2) != 0)
      break;
    return MCK__COLON__COLON_;	 // "::"
  case 3:	 // 4 strings to match.
    switch (Name[0]) {
    default: break;
    case 'g':	 // 1 string to match.
      if (memcmp(Name.data()+1, "ds", 2) != 0)
        break;
      return MCK_gds;	 // "gds"
    case 'l':	 // 1 string to match.
      if (memcmp(Name.data()+1, "ds", 2) != 0)
        break;
      return MCK_lds;	 // "lds"
    case 'o':	 // 1 string to match.
      if (memcmp(Name.data()+1, "ff", 2) != 0)
        break;
      return MCK_off;	 // "off"
    case 't':	 // 1 string to match.
      if (memcmp(Name.data()+1, "fe", 2) != 0)
        break;
      return MCK_tfe;	 // "tfe"
    }
    break;
  case 4:	 // 1 string to match.
    if (memcmp(Name.data()+0, "done", 4) != 0)
      break;
    return MCK_done;	 // "done"
  case 5:	 // 2 strings to match.
    switch (Name[0]) {
    default: break;
    case 'i':	 // 1 string to match.
      if (memcmp(Name.data()+1, "dxen", 4) != 0)
        break;
      return MCK_idxen;	 // "idxen"
    case 'o':	 // 1 string to match.
      if (memcmp(Name.data()+1, "ffen", 4) != 0)
        break;
      return MCK_offen;	 // "offen"
    }
    break;
  case 6:	 // 2 strings to match.
    switch (Name[0]) {
    default: break;
    case 'a':	 // 1 string to match.
      if (memcmp(Name.data()+1, "ddr64", 5) != 0)
        break;
      return MCK_addr64;	 // "addr64"
    case 'r':	 // 1 string to match.
      if (memcmp(Name.data()+1, "ow_en", 5) != 0)
        break;
      return MCK_row_95_en;	 // "row_en"
    }
    break;
  case 14:	 // 10 strings to match.
    if (memcmp(Name.data()+0, "v_dual_", 7) != 0)
      break;
    switch (Name[7]) {
    default: break;
    case 'a':	 // 2 strings to match.
      switch (Name[8]) {
      default: break;
      case 'd':	 // 1 string to match.
        if (memcmp(Name.data()+9, "d_f32", 5) != 0)
          break;
        return MCK_v_95_dual_95_add_95_f32;	 // "v_dual_add_f32"
      case 'n':	 // 1 string to match.
        if (memcmp(Name.data()+9, "d_b32", 5) != 0)
          break;
        return MCK_v_95_dual_95_and_95_b32;	 // "v_dual_and_b32"
      }
      break;
    case 'f':	 // 1 string to match.
      if (memcmp(Name.data()+8, "ma_f32", 6) != 0)
        break;
      return MCK_v_95_dual_95_fma_95_f32;	 // "v_dual_fma_f32"
    case 'm':	 // 6 strings to match.
      switch (Name[8]) {
      default: break;
      case 'a':	 // 2 strings to match.
        if (memcmp(Name.data()+9, "x_", 2) != 0)
          break;
        switch (Name[11]) {
        default: break;
        case 'f':	 // 1 string to match.
          if (memcmp(Name.data()+12, "32", 2) != 0)
            break;
          return MCK_v_95_dual_95_max_95_f32;	 // "v_dual_max_f32"
        case 'i':	 // 1 string to match.
          if (memcmp(Name.data()+12, "32", 2) != 0)
            break;
          return MCK_v_95_dual_95_max_95_i32;	 // "v_dual_max_i32"
        }
        break;
      case 'i':	 // 2 strings to match.
        if (memcmp(Name.data()+9, "n_", 2) != 0)
          break;
        switch (Name[11]) {
        default: break;
        case 'f':	 // 1 string to match.
          if (memcmp(Name.data()+12, "32", 2) != 0)
            break;
          return MCK_v_95_dual_95_min_95_f32;	 // "v_dual_min_f32"
        case 'i':	 // 1 string to match.
          if (memcmp(Name.data()+12, "32", 2) != 0)
            break;
          return MCK_v_95_dual_95_min_95_i32;	 // "v_dual_min_i32"
        }
        break;
      case 'o':	 // 1 string to match.
        if (memcmp(Name.data()+9, "v_b32", 5) != 0)
          break;
        return MCK_v_95_dual_95_mov_95_b32;	 // "v_dual_mov_b32"
      case 'u':	 // 1 string to match.
        if (memcmp(Name.data()+9, "l_f32", 5) != 0)
          break;
        return MCK_v_95_dual_95_mul_95_f32;	 // "v_dual_mul_f32"
      }
      break;
    case 's':	 // 1 string to match.
      if (memcmp(Name.data()+8, "ub_f32", 6) != 0)
        break;
      return MCK_v_95_dual_95_sub_95_f32;	 // "v_dual_sub_f32"
    }
    break;
  case 15:	 // 1 string to match.
    if (memcmp(Name.data()+0, "v_dual_fmac_f32", 15) != 0)
      break;
    return MCK_v_95_dual_95_fmac_95_f32;	 // "v_dual_fmac_f32"
  case 16:	 // 2 strings to match.
    if (memcmp(Name.data()+0, "v_dual_fma", 10) != 0)
      break;
    switch (Name[10]) {
    default: break;
    case 'a':	 // 1 string to match.
      if (memcmp(Name.data()+11, "k_f32", 5) != 0)
        break;
      return MCK_v_95_dual_95_fmaak_95_f32;	 // "v_dual_fmaak_f32"
    case 'm':	 // 1 string to match.
      if (memcmp(Name.data()+11, "k_f32", 5) != 0)
        break;
      return MCK_v_95_dual_95_fmamk_95_f32;	 // "v_dual_fmamk_f32"
    }
    break;
  case 17:	 // 4 strings to match.
    if (memcmp(Name.data()+0, "v_dual_", 7) != 0)
      break;
    switch (Name[7]) {
    default: break;
    case 'a':	 // 1 string to match.
      if (memcmp(Name.data()+8, "dd_nc_u32", 9) != 0)
        break;
      return MCK_v_95_dual_95_add_95_nc_95_u32;	 // "v_dual_add_nc_u32"
    case 'b':	 // 1 string to match.
      if (memcmp(Name.data()+8, "itop2_b32", 9) != 0)
        break;
      return MCK_v_95_dual_95_bitop2_95_b32;	 // "v_dual_bitop2_b32"
    case 's':	 // 2 strings to match.
      if (memcmp(Name.data()+8, "ub", 2) != 0)
        break;
      switch (Name[10]) {
      default: break;
      case '_':	 // 1 string to match.
        if (memcmp(Name.data()+11, "nc_u32", 6) != 0)
          break;
        return MCK_v_95_dual_95_sub_95_nc_95_u32;	 // "v_dual_sub_nc_u32"
      case 'r':	 // 1 string to match.
        if (memcmp(Name.data()+11, "ev_f32", 6) != 0)
          break;
        return MCK_v_95_dual_95_subrev_95_f32;	 // "v_dual_subrev_f32"
      }
      break;
    }
    break;
  case 18:	 // 6 strings to match.
    if (memcmp(Name.data()+0, "v_dual_", 7) != 0)
      break;
    switch (Name[7]) {
    default: break;
    case 'a':	 // 1 string to match.
      if (memcmp(Name.data()+8, "shrrev_i32", 10) != 0)
        break;
      return MCK_v_95_dual_95_ashrrev_95_i32;	 // "v_dual_ashrrev_i32"
    case 'c':	 // 1 string to match.
      if (memcmp(Name.data()+8, "ndmask_b32", 10) != 0)
        break;
      return MCK_v_95_dual_95_cndmask_95_b32;	 // "v_dual_cndmask_b32"
    case 'l':	 // 2 strings to match.
      if (memcmp(Name.data()+8, "sh", 2) != 0)
        break;
      switch (Name[10]) {
      default: break;
      case 'l':	 // 1 string to match.
        if (memcmp(Name.data()+11, "rev_b32", 7) != 0)
          break;
        return MCK_v_95_dual_95_lshlrev_95_b32;	 // "v_dual_lshlrev_b32"
      case 'r':	 // 1 string to match.
        if (memcmp(Name.data()+11, "rev_b32", 7) != 0)
          break;
        return MCK_v_95_dual_95_lshrrev_95_b32;	 // "v_dual_lshrrev_b32"
      }
      break;
    case 'm':	 // 2 strings to match.
      switch (Name[8]) {
      default: break;
      case 'a':	 // 1 string to match.
        if (memcmp(Name.data()+9, "x_num_f32", 9) != 0)
          break;
        return MCK_v_95_dual_95_max_95_num_95_f32;	 // "v_dual_max_num_f32"
      case 'i':	 // 1 string to match.
        if (memcmp(Name.data()+9, "n_num_f32", 9) != 0)
          break;
        return MCK_v_95_dual_95_min_95_num_95_f32;	 // "v_dual_min_num_f32"
      }
      break;
    }
    break;
  case 22:	 // 1 string to match.
    if (memcmp(Name.data()+0, "v_dual_dot2acc_f32_f16", 22) != 0)
      break;
    return MCK_v_95_dual_95_dot2acc_95_f32_95_f16;	 // "v_dual_dot2acc_f32_f16"
  case 23:	 // 2 strings to match.
    if (memcmp(Name.data()+0, "v_dual_", 7) != 0)
      break;
    switch (Name[7]) {
    default: break;
    case 'd':	 // 1 string to match.
      if (memcmp(Name.data()+8, "ot2acc_f32_bf16", 15) != 0)
        break;
      return MCK_v_95_dual_95_dot2acc_95_f32_95_bf16;	 // "v_dual_dot2acc_f32_bf16"
    case 'm':	 // 1 string to match.
      if (memcmp(Name.data()+8, "ul_dx9_zero_f32", 15) != 0)
        break;
      return MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32;	 // "v_dual_mul_dx9_zero_f32"
    }
    break;
  }
  return InvalidMatchClass;
}

/// isSubclass - Compute whether \p A is a subclass of \p B.
static bool isSubclass(MatchClassKind A, MatchClassKind B) {
  if (A == B)
    return true;

  [[maybe_unused]] static constexpr struct {
    uint32_t Offset;
    uint16_t Start;
    uint16_t Length;
  } Table[] = {
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 0, 0},
    {0, 41, 894},
    {894, 62, 147},
    {1041, 63, 146},
    {1187, 64, 145},
    {1332, 65, 144},
    {1476, 66, 143},
    {1619, 67, 142},
    {1761, 68, 141},
    {1902, 69, 140},
    {2042, 70, 139},
    {2181, 71, 142},
    {2323, 71, 142},
    {2465, 164, 59},
    {2524, 168, 54},
    {2578, 172, 53},
    {2631, 667, 268},
    {2899, 672, 263},
    {3162, 0, 0},
    {3162, 0, 0},
    {3162, 212, 1},
    {3163, 370, 547},
    {3710, 670, 265},
    {3975, 77, 132},
    {4107, 78, 131},
    {4238, 79, 130},
    {4368, 80, 129},
    {4497, 81, 128},
    {4625, 82, 127},
    {4752, 83, 126},
    {4878, 84, 125},
    {5003, 85, 124},
    {5127, 160, 53},
    {5180, 0, 0},
    {5180, 223, 1},
    {5181, 224, 1},
    {5182, 221, 1},
    {5183, 222, 1},
    {5184, 90, 119},
    {5303, 91, 118},
    {5421, 92, 117},
    {5538, 93, 116},
    {5654, 94, 115},
    {5769, 95, 114},
    {5883, 96, 113},
    {5996, 97, 112},
    {6108, 98, 111},
    {6219, 227, 1},
    {6220, 228, 1},
    {6221, 225, 1},
    {6222, 226, 4},
    {6226, 104, 105},
    {6331, 105, 104},
    {6435, 106, 103},
    {6538, 107, 102},
    {6640, 108, 101},
    {6741, 109, 100},
    {6841, 110, 99},
    {6940, 111, 98},
    {7038, 112, 97},
    {7135, 113, 100},
    {7235, 115, 98},
    {7333, 373, 544},
    {7877, 230, 685},
    {8562, 231, 1},
    {8563, 120, 89},
    {8652, 121, 88},
    {8740, 122, 87},
    {8827, 123, 86},
    {8913, 124, 85},
    {8998, 125, 84},
    {9082, 126, 83},
    {9165, 127, 82},
    {9247, 128, 81},
    {9328, 129, 84},
    {9412, 130, 83},
    {9495, 132, 81},
    {9576, 133, 90},
    {9666, 135, 88},
    {9754, 136, 86},
    {9840, 139, 86},
    {9926, 148, 61},
    {9987, 149, 60},
    {10047, 150, 59},
    {10106, 151, 58},
    {10164, 152, 57},
    {10221, 153, 56},
    {10277, 154, 55},
    {10332, 155, 54},
    {10386, 156, 53},
    {10439, 157, 56},
    {10495, 158, 55},
    {10550, 159, 54},
    {10604, 161, 52},
    {10656, 162, 61},
    {10717, 163, 60},
    {10777, 165, 58},
    {10835, 166, 56},
    {10891, 167, 55},
    {10946, 169, 53},
    {10999, 170, 55},
    {11054, 171, 54},
    {11108, 173, 52},
    {11160, 174, 50},
    {11210, 176, 48},
    {11258, 177, 53},
    {11311, 179, 51},
    {11362, 180, 46},
    {11408, 183, 46},
    {11454, 208, 1},
    {11455, 208, 1},
    {11456, 208, 1},
    {11457, 208, 1},
    {11458, 208, 1},
    {11459, 208, 1},
    {11460, 208, 1},
    {11461, 208, 1},
    {11462, 191, 18},
    {11480, 209, 4},
    {11484, 209, 4},
    {11488, 209, 4},
    {11492, 209, 4},
    {11496, 192, 21},
    {11517, 211, 12},
    {11529, 211, 12},
    {11541, 211, 12},
    {11553, 193, 30},
    {11583, 210, 12},
    {11595, 210, 12},
    {11607, 210, 12},
    {11619, 194, 28},
    {11647, 216, 9},
    {11656, 216, 9},
    {11665, 216, 9},
    {11674, 195, 30},
    {11704, 215, 9},
    {11713, 215, 9},
    {11722, 196, 28},
    {11750, 214, 16},
    {11766, 214, 16},
    {11782, 197, 33},
    {11815, 213, 13},
    {11828, 213, 13},
    {11841, 198, 28},
    {11869, 219, 10},
    {11879, 219, 10},
    {11889, 199, 30},
    {11919, 218, 10},
    {11929, 200, 28},
    {11957, 217, 698},
    {12655, 201, 714},
    {13369, 220, 12},
    {13381, 208, 1},
    {13382, 209, 4},
    {13386, 211, 12},
    {13398, 210, 12},
    {13410, 216, 9},
    {13419, 215, 9},
    {13428, 214, 16},
    {13444, 213, 13},
    {13457, 219, 10},
    {13467, 218, 10},
    {13477, 217, 698},
    {14175, 220, 12},
    {14187, 370, 547},
    {14734, 244, 673},
    {15407, 244, 673},
    {16080, 670, 265},
    {16345, 676, 1},
    {16346, 0, 0},
    {16346, 212, 1},
    {16347, 221, 1},
    {16348, 222, 1},
    {16349, 0, 0},
    {16349, 225, 1},
    {16350, 226, 4},
    {16354, 223, 1},
    {16355, 224, 1},
    {16356, 230, 685},
    {17041, 227, 1},
    {17042, 228, 1},
    {17043, 231, 1},
    {17044, 0, 0},
    {17044, 0, 0},
    {17044, 0, 0},
    {17044, 0, 0},
    {17044, 0, 0},
    {17044, 229, 1},
    {17045, 0, 0},
    {17045, 0, 0},
    {17045, 0, 0},
    {17045, 232, 683},
    {17728, 0, 0},
    {17728, 870, 45},
    {17773, 234, 686},
    {18459, 236, 684},
    {19143, 237, 683},
    {19826, 238, 682},
    {20508, 239, 681},
    {21189, 240, 680},
    {21869, 241, 679},
    {22548, 242, 678},
    {23226, 243, 677},
    {23903, 245, 675},
    {24578, 246, 674},
    {25252, 370, 547},
    {25799, 247, 673},
    {26472, 248, 672},
    {27144, 249, 671},
    {27815, 250, 670},
    {28485, 252, 668},
    {29153, 253, 667},
    {29820, 254, 667},
    {30487, 256, 664},
    {31151, 257, 663},
    {31814, 258, 663},
    {32477, 259, 662},
    {33139, 261, 659},
    {33798, 262, 658},
    {34456, 263, 658},
    {35114, 264, 657},
    {35771, 265, 657},
    {36428, 270, 650},
    {37078, 271, 649},
    {37727, 272, 649},
    {38376, 273, 648},
    {39024, 274, 648},
    {39672, 275, 647},
    {40319, 276, 647},
    {40966, 277, 646},
    {41612, 278, 646},
    {42258, 283, 637},
    {42895, 284, 636},
    {43531, 285, 636},
    {44167, 286, 635},
    {44802, 287, 635},
    {45437, 288, 634},
    {46071, 289, 634},
    {46705, 290, 633},
    {47338, 291, 633},
    {47971, 292, 632},
    {48603, 293, 632},
    {49235, 294, 631},
    {49866, 295, 631},
    {50497, 300, 620},
    {51117, 301, 619},
    {51736, 302, 619},
    {52355, 303, 618},
    {52973, 304, 618},
    {53591, 305, 617},
    {54208, 306, 617},
    {54825, 307, 616},
    {55441, 308, 616},
    {56057, 309, 615},
    {56672, 310, 615},
    {57287, 311, 614},
    {57901, 312, 614},
    {58515, 313, 613},
    {59128, 314, 613},
    {59741, 315, 612},
    {60353, 316, 612},
    {60965, 321, 599},
    {61564, 322, 598},
    {62162, 323, 598},
    {62760, 324, 597},
    {63357, 325, 597},
    {63954, 326, 596},
    {64550, 327, 596},
    {65146, 328, 595},
    {65741, 329, 595},
    {66336, 330, 594},
    {66930, 331, 594},
    {67524, 332, 593},
    {68117, 333, 593},
    {68710, 334, 592},
    {69302, 335, 592},
    {69894, 336, 591},
    {70485, 337, 591},
    {71076, 338, 590},
    {71666, 339, 590},
    {72256, 340, 589},
    {72845, 341, 589},
    {73434, 345, 575},
    {74009, 346, 574},
    {74583, 347, 574},
    {75157, 348, 573},
    {75730, 349, 573},
    {76303, 350, 572},
    {76875, 351, 572},
    {77447, 352, 571},
    {78018, 353, 571},
    {78589, 354, 570},
    {79159, 355, 570},
    {79729, 356, 569},
    {80298, 357, 569},
    {80867, 358, 568},
    {81435, 359, 568},
    {82003, 360, 567},
    {82570, 361, 567},
    {83137, 362, 566},
    {83703, 363, 566},
    {84269, 364, 565},
    {84834, 365, 565},
    {85399, 366, 564},
    {85963, 367, 564},
    {86527, 368, 563},
    {87090, 395, 525},
    {87615, 402, 518},
    {88133, 436, 485},
    {88618, 454, 467},
    {89085, 461, 461},
    {89546, 490, 432},
    {89978, 477, 446},
    {90424, 489, 434},
    {90858, 479, 445},
    {91303, 517, 407},
    {91710, 505, 420},
    {92130, 516, 409},
    {92539, 507, 419},
    {92958, 549, 377},
    {93335, 538, 389},
    {93724, 548, 379},
    {94103, 540, 388},
    {94491, 586, 342},
    {94833, 576, 353},
    {95186, 585, 344},
    {95530, 578, 352},
    {95882, 376, 554},
    {96436, 619, 312},
    {96748, 620, 311},
    {97059, 621, 311},
    {97370, 371, 546},
    {97916, 372, 545},
    {98461, 374, 543},
    {99004, 374, 543},
    {99547, 669, 248},
    {99795, 376, 539},
    {100334, 680, 235},
    {100569, 378, 542},
    {101111, 379, 541},
    {101652, 380, 540},
    {102192, 381, 539},
    {102731, 382, 538},
    {103269, 383, 537},
    {103806, 384, 536},
    {104342, 385, 535},
    {104877, 386, 534},
    {105411, 390, 530},
    {105941, 670, 265},
    {106206, 0, 0},
    {106206, 676, 1},
    {106207, 391, 529},
    {106736, 392, 528},
    {107264, 393, 527},
    {107791, 394, 526},
    {108317, 396, 524},
    {108841, 398, 522},
    {109363, 399, 521},
    {109884, 690, 230},
    {110114, 403, 517},
    {110631, 405, 515},
    {111146, 406, 515},
    {111661, 690, 230},
    {111891, 404, 516},
    {112407, 407, 513},
    {112920, 408, 512},
    {113432, 409, 511},
    {113943, 410, 511},
    {114454, 411, 509},
    {114963, 412, 508},
    {115471, 413, 507},
    {115978, 414, 507},
    {116485, 415, 505},
    {116990, 416, 504},
    {117494, 417, 503},
    {117997, 418, 503},
    {118500, 420, 500},
    {119000, 421, 499},
    {119499, 422, 498},
    {119997, 423, 498},
    {120495, 424, 498},
    {120993, 426, 494},
    {121487, 427, 493},
    {121980, 428, 492},
    {122472, 429, 492},
    {122964, 430, 492},
    {123456, 431, 492},
    {123948, 433, 487},
    {124435, 434, 486},
    {124921, 435, 485},
    {125406, 437, 484},
    {125890, 438, 484},
    {126374, 439, 484},
    {126858, 440, 484},
    {127342, 443, 477},
    {127819, 444, 476},
    {128295, 445, 475},
    {128770, 446, 475},
    {129245, 447, 474},
    {129719, 448, 474},
    {130193, 449, 474},
    {130667, 450, 474},
    {131141, 451, 474},
    {131615, 708, 213},
    {131828, 455, 465},
    {132293, 456, 464},
    {132757, 457, 463},
    {133220, 458, 463},
    {133683, 460, 461},
    {134144, 462, 460},
    {134604, 463, 460},
    {135064, 464, 460},
    {135524, 465, 460},
    {135984, 466, 460},
    {136444, 708, 213},
    {136657, 459, 462},
    {137119, 469, 451},
    {137570, 470, 450},
    {138020, 471, 449},
    {138469, 472, 449},
    {138918, 473, 448},
    {139366, 474, 447},
    {139813, 475, 447},
    {140260, 476, 446},
    {140706, 478, 445},
    {141151, 480, 444},
    {141595, 481, 444},
    {142039, 482, 444},
    {142483, 483, 444},
    {142927, 718, 204},
    {143131, 491, 429},
    {143560, 492, 428},
    {143988, 493, 427},
    {144415, 494, 427},
    {144842, 495, 426},
    {145268, 496, 425},
    {145693, 497, 425},
    {146118, 499, 423},
    {146541, 500, 423},
    {146964, 502, 421},
    {147385, 503, 421},
    {147806, 504, 420},
    {148226, 506, 419},
    {148645, 508, 418},
    {149063, 509, 418},
    {149481, 510, 418},
    {149899, 723, 200},
    {150099, 729, 195},
    {150294, 723, 200},
    {150494, 718, 204},
    {150698, 501, 422},
    {151120, 498, 424},
    {151544, 518, 402},
    {151946, 519, 401},
    {152347, 520, 400},
    {152747, 521, 400},
    {153147, 522, 399},
    {153546, 523, 398},
    {153944, 524, 398},
    {154342, 525, 397},
    {154739, 526, 396},
    {155135, 527, 396},
    {155531, 528, 395},
    {155926, 529, 394},
    {156320, 530, 394},
    {156714, 532, 392},
    {157106, 533, 392},
    {157498, 535, 390},
    {157888, 536, 390},
    {158278, 537, 389},
    {158667, 539, 388},
    {159055, 541, 387},
    {159442, 542, 387},
    {159829, 736, 189},
    {160018, 744, 182},
    {160200, 736, 189},
    {160389, 729, 195},
    {160584, 534, 391},
    {160975, 531, 393},
    {161368, 550, 370},
    {161738, 551, 369},
    {162107, 552, 368},
    {162475, 553, 368},
    {162843, 554, 367},
    {163210, 555, 366},
    {163576, 556, 366},
    {163942, 557, 365},
    {164307, 558, 364},
    {164671, 559, 364},
    {165035, 560, 363},
    {165398, 561, 362},
    {165760, 562, 362},
    {166122, 563, 361},
    {166483, 564, 360},
    {166843, 565, 360},
    {167203, 566, 359},
    {167562, 567, 358},
    {167920, 568, 358},
    {168278, 570, 356},
    {168634, 571, 356},
    {168990, 573, 354},
    {169344, 574, 354},
    {169698, 575, 353},
    {170051, 577, 352},
    {170403, 579, 351},
    {170754, 753, 174},
    {170928, 763, 165},
    {171093, 753, 174},
    {171267, 744, 182},
    {171449, 572, 355},
    {171804, 569, 357},
    {172161, 587, 333},
    {172494, 588, 332},
    {172826, 589, 331},
    {173157, 590, 331},
    {173488, 591, 330},
    {173818, 592, 329},
    {174147, 593, 329},
    {174476, 594, 328},
    {174804, 595, 327},
    {175131, 596, 327},
    {175458, 597, 326},
    {175784, 598, 325},
    {176109, 599, 325},
    {176434, 600, 324},
    {176758, 601, 323},
    {177081, 602, 323},
    {177404, 603, 322},
    {177726, 604, 321},
    {178047, 605, 321},
    {178368, 606, 320},
    {178688, 607, 319},
    {179007, 608, 319},
    {179326, 609, 318},
    {179644, 610, 317},
    {179961, 611, 317},
    {180278, 613, 315},
    {180593, 614, 315},
    {180908, 616, 313},
    {181221, 617, 313},
    {181534, 618, 312},
    {181846, 620, 311},
    {182157, 774, 155},
    {182312, 786, 144},
    {182456, 774, 155},
    {182611, 763, 165},
    {182776, 615, 314},
    {183090, 612, 316},
    {183406, 627, 293},
    {183699, 628, 292},
    {183991, 629, 291},
    {184282, 630, 291},
    {184573, 631, 290},
    {184863, 632, 289},
    {185152, 633, 289},
    {185441, 634, 288},
    {185729, 635, 287},
    {186016, 636, 287},
    {186303, 637, 286},
    {186589, 638, 285},
    {186874, 639, 285},
    {187159, 640, 284},
    {187443, 641, 283},
    {187726, 642, 283},
    {188009, 643, 282},
    {188291, 644, 281},
    {188572, 645, 281},
    {188853, 646, 280},
    {189133, 647, 279},
    {189412, 648, 279},
    {189691, 649, 278},
    {189969, 650, 277},
    {190246, 651, 277},
    {190523, 652, 276},
    {190799, 653, 275},
    {191074, 654, 275},
    {191349, 655, 274},
    {191623, 656, 273},
    {191896, 657, 273},
    {192169, 659, 271},
    {192440, 660, 271},
    {192711, 662, 269},
    {192980, 663, 269},
    {193249, 799, 132},
    {193381, 786, 144},
    {193525, 799, 132},
    {193657, 658, 272},
    {193929, 661, 270},
    {194199, 814, 106},
    {194305, 800, 120},
    {194425, 689, 231},
    {194656, 815, 106},
    {194762, 801, 120},
    {194882, 707, 214},
    {195096, 816, 106},
    {195202, 802, 120},
    {195322, 717, 205},
    {195527, 817, 106},
    {195633, 803, 120},
    {195753, 722, 201},
    {195954, 818, 106},
    {196060, 804, 120},
    {196180, 728, 196},
    {196376, 819, 106},
    {196482, 805, 120},
    {196602, 735, 190},
    {196792, 820, 106},
    {196898, 806, 120},
    {197018, 743, 183},
    {197201, 821, 106},
    {197307, 807, 120},
    {197427, 752, 175},
    {197602, 822, 106},
    {197708, 808, 120},
    {197828, 762, 166},
    {197994, 823, 106},
    {198100, 809, 120},
    {198220, 773, 156},
    {198376, 824, 106},
    {198482, 682, 248},
    {198730, 683, 247},
    {198977, 825, 106},
    {199083, 811, 120},
    {199203, 798, 133},
    {199336, 686, 246},
    {199582, 813, 119},
    {199701, 667, 266},
    {199967, 685, 247},
    {200214, 831, 88},
    {200302, 669, 248},
    {200550, 687, 230},
    {200780, 671, 264},
    {201044, 673, 262},
    {201306, 673, 262},
    {201568, 675, 260},
    {201828, 675, 260},
    {202088, 677, 258},
    {202346, 0, 0},
    {202346, 833, 102},
    {202448, 679, 236},
    {202684, 681, 234},
    {202918, 682, 233},
    {203151, 683, 232},
    {203383, 836, 79},
    {203462, 834, 81},
    {203543, 686, 231},
    {203774, 688, 229},
    {204003, 687, 230},
    {204233, 840, 77},
    {204310, 840, 77},
    {204387, 691, 229},
    {204616, 919, 1},
    {204617, 692, 228},
    {204845, 693, 227},
    {205072, 694, 226},
    {205298, 695, 225},
    {205523, 696, 224},
    {205747, 697, 223},
    {205970, 698, 222},
    {206192, 699, 221},
    {206413, 700, 220},
    {206633, 701, 219},
    {206852, 702, 218},
    {207070, 703, 217},
    {207287, 704, 216},
    {207503, 705, 215},
    {207718, 706, 214},
    {207932, 709, 211},
    {208143, 710, 211},
    {208354, 920, 1},
    {208355, 711, 209},
    {208564, 712, 209},
    {208773, 713, 207},
    {208980, 714, 207},
    {209187, 715, 205},
    {209392, 716, 205},
    {209597, 719, 201},
    {209798, 720, 201},
    {209999, 721, 201},
    {210200, 921, 1},
    {210201, 724, 196},
    {210397, 725, 196},
    {210593, 726, 196},
    {210789, 727, 196},
    {210985, 922, 1},
    {210986, 730, 190},
    {211176, 731, 190},
    {211366, 732, 190},
    {211556, 733, 190},
    {211746, 734, 190},
    {211936, 923, 1},
    {211937, 737, 183},
    {212120, 738, 183},
    {212303, 739, 183},
    {212486, 740, 183},
    {212669, 741, 183},
    {212852, 742, 183},
    {213035, 924, 1},
    {213036, 745, 175},
    {213211, 746, 175},
    {213386, 747, 175},
    {213561, 748, 175},
    {213736, 749, 175},
    {213911, 750, 175},
    {214086, 751, 175},
    {214261, 925, 1},
    {214262, 754, 166},
    {214428, 755, 166},
    {214594, 756, 166},
    {214760, 757, 166},
    {214926, 758, 166},
    {215092, 759, 166},
    {215258, 760, 166},
    {215424, 761, 166},
    {215590, 926, 1},
    {215591, 764, 156},
    {215747, 765, 156},
    {215903, 766, 156},
    {216059, 767, 156},
    {216215, 768, 156},
    {216371, 769, 156},
    {216527, 770, 156},
    {216683, 771, 156},
    {216839, 772, 156},
    {216995, 927, 1},
    {216996, 775, 145},
    {217141, 776, 145},
    {217286, 777, 145},
    {217431, 778, 145},
    {217576, 779, 145},
    {217721, 780, 145},
    {217866, 781, 145},
    {218011, 782, 145},
    {218156, 783, 145},
    {218301, 784, 145},
    {218446, 928, 1},
    {218447, 787, 133},
    {218580, 788, 133},
    {218713, 789, 133},
    {218846, 790, 133},
    {218979, 791, 133},
    {219112, 792, 133},
    {219245, 793, 133},
    {219378, 794, 133},
    {219511, 795, 133},
    {219644, 796, 133},
    {219777, 797, 133},
    {219910, 929, 1},
    {219911, 800, 120},
    {220031, 801, 120},
    {220151, 802, 120},
    {220271, 803, 120},
    {220391, 804, 120},
    {220511, 805, 120},
    {220631, 806, 120},
    {220751, 807, 120},
    {220871, 808, 120},
    {220991, 809, 120},
    {221111, 810, 120},
    {221231, 811, 120},
    {221351, 930, 1},
    {221352, 814, 106},
    {221458, 815, 106},
    {221564, 816, 106},
    {221670, 817, 106},
    {221776, 818, 106},
    {221882, 819, 106},
    {221988, 820, 106},
    {222094, 821, 106},
    {222200, 822, 106},
    {222306, 823, 106},
    {222412, 824, 106},
    {222518, 825, 106},
    {222624, 826, 106},
    {222730, 931, 1},
    {222731, 898, 22},
    {222753, 899, 22},
    {222775, 900, 22},
    {222797, 901, 22},
    {222819, 902, 22},
    {222841, 903, 22},
    {222863, 904, 22},
    {222885, 905, 22},
    {222907, 906, 22},
    {222929, 907, 22},
    {222951, 837, 93},
    {223044, 909, 22},
    {223066, 839, 93},
    {223159, 932, 1},
    {223160, 0, 0},
    {223160, 842, 93},
    {223253, 831, 102},
    {223355, 843, 76},
    {223431, 833, 86},
    {223517, 843, 76},
    {223593, 835, 80},
    {223673, 836, 79},
    {223752, 837, 78},
    {223830, 913, 2},
    {223832, 839, 78},
    {223910, 840, 77},
    {223987, 916, 1},
    {223988, 843, 76},
    {224064, 934, 1},
    {224065, 918, 1},
    {224066, 873, 47},
    {224113, 874, 46},
    {224159, 875, 46},
    {224205, 876, 45},
    {224250, 877, 45},
    {224295, 878, 45},
    {224340, 879, 45},
    {224385, 880, 43},
    {224428, 881, 41},
    {224469, 882, 43},
    {224512, 883, 43},
    {224555, 884, 41},
    {224596, 885, 39},
    {224635, 886, 41},
    {224676, 887, 41},
    {224717, 888, 39},
    {224756, 889, 37},
    {224793, 890, 39},
    {224832, 891, 39},
    {224871, 892, 37},
    {224908, 893, 35},
    {224943, 894, 37},
    {224980, 869, 61},
    {225041, 896, 35},
    {225076, 871, 61},
    {225137, 870, 45},
    {225182, 914, 1},
    {225183, 872, 45},
    {225228, 916, 1},
    {225229, 919, 1},
    {225230, 919, 1},
    {225231, 920, 1},
    {225232, 920, 1},
    {225233, 921, 1},
    {225234, 922, 1},
    {225235, 923, 1},
    {225236, 922, 1},
    {225237, 921, 1},
    {225238, 924, 1},
    {225239, 925, 1},
    {225240, 924, 1},
    {225241, 923, 1},
    {225242, 926, 1},
    {225243, 927, 1},
    {225244, 926, 1},
    {225245, 925, 1},
    {225246, 928, 1},
    {225247, 929, 1},
    {225248, 928, 1},
    {225249, 927, 1},
    {225250, 930, 1},
    {225251, 929, 1},
    {225252, 930, 1},
    {225253, 931, 1},
    {225254, 919, 1},
    {225255, 920, 1},
    {225256, 921, 1},
    {225257, 922, 1},
    {225258, 923, 1},
    {225259, 924, 1},
    {225260, 925, 1},
    {225261, 926, 1},
    {225262, 927, 1},
    {225263, 928, 1},
    {225264, 913, 17},
    {225281, 930, 1},
    {225282, 915, 17},
    {225299, 912, 21},
    {225320, 918, 1},
    {225321, 914, 1},
    {225322, 0, 0},
    {225322, 916, 1},
    {225323, 0, 0},
    {225323, 918, 1},
    {225324, 0, 0},
    {225324, 0, 0},
    {225324, 0, 0},
    {225324, 0, 0},
    {225324, 0, 0},
    {225324, 0, 0},
    {225324, 0, 0},
    {225324, 0, 0},
    {225324, 0, 0},
    {225324, 0, 0},
    {225324, 0, 0},
    {225324, 0, 0},
    {225324, 0, 0},
    {225324, 0, 0},
    {225324, 0, 0},
    {225324, 934, 1},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 0, 0},
    {225325, 1, 1},
    {225326, 1, 1},
    {225327, 0, 0},
    {225327, 0, 0},
    {225327, 0, 0},
    {225327, 1, 1},
    {225328, 1, 1},
    {225329, 1, 1},
    {225330, 1, 1},
    {225331, 1, 1},
    {225332, 1, 1},
    {225333, 1, 1},
    {225334, 1, 1},
    {225335, 1, 1},
    {225336, 0, 0},
    {225336, 1, 1},
    {225337, 1, 1},
    {225338, 1, 1},
    {225339, 1, 1},
    {225340, 1, 1},
    {225341, 1, 1},
    {225342, 1, 1},
    {225343, 1, 1},
    {225344, 1, 1},
    {225345, 1, 1},
    {225346, 0, 0},
    {225346, 1, 1},
    {225347, 1, 1},
    {225348, 1, 1},
    {225349, 1, 1},
    {225350, 1, 1},
    {225351, 1, 1},
    {225352, 1, 1},
    {225353, 1, 1},
    {225354, 1, 1},
    {225355, 1, 1},
    {225356, 1, 1},
    {225357, 1, 1},
    {225358, 1, 1},
    {225359, 0, 0},
    {225359, 0, 0},
    {225359, 1, 1},
    {225360, 1, 1},
    {225361, 1, 1},
    {225362, 1, 1},
    {225363, 1, 1},
    {225364, 1, 1},
    {225365, 1, 1},
    {225366, 0, 0},
    {225366, 0, 0},
    {225366, 1, 1},
    {225367, 1, 1},
    {225368, 1, 1},
    {225369, 1, 1},
    {225370, 1, 1},
    {225371, 1, 1},
    {225372, 1, 1},
    {225373, 1, 1},
    {225374, 1, 1},
    {225375, 1, 1},
    {225376, 1, 1},
    {225377, 1, 1},
    {225378, 1, 1},
    {225379, 1, 1},
    {225380, 1, 1},
    {225381, 0, 0},
    {225381, 0, 0},
    {225381, 0, 0},
    {225381, 0, 0},
    {225381, 0, 0},
    {225381, 0, 0},
    {225381, 0, 0},
    {225381, 0, 0},
    {225381, 0, 0},
    {225381, 0, 0},
    {225381, 0, 0},
    {225381, 0, 0},
    {225381, 0, 0},
    {225381, 0, 0},
    {225381, 0, 0},
    {225381, 0, 0},
    {225381, 0, 0},
    {225381, 0, 0},
    {225381, 0, 0},
    {225381, 0, 0},
    {225381, 1, 1},
    {225382, 1, 1},
    {225383, 0, 0},
    {225383, 1, 1},
    {225384, 0, 0},
  };

  static constexpr uint8_t Data[] = {
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0x00,
    0xE0,
    0x00,
    0x3C,
    0x00,
    0x1F,
    0x00,
    0x3F,
    0x00,
    0x00,
    0xF0,
    0x07,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x07,
    0x00,
    0x07,
    0xE0,
    0x01,
    0xF8,
    0x00,
    0xF8,
    0x01,
    0x00,
    0x80,
    0x3F,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x1C,
    0x00,
    0x1C,
    0x80,
    0x07,
    0xE0,
    0x03,
    0xE0,
    0x07,
    0x00,
    0x00,
    0x7E,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x38,
    0x00,
    0x38,
    0x00,
    0x0F,
    0xC0,
    0x07,
    0xC0,
    0x07,
    0x00,
    0x00,
    0xFC,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x38,
    0x00,
    0x38,
    0x00,
    0x0F,
    0xC0,
    0x03,
    0xC0,
    0x07,
    0x00,
    0x00,
    0x7C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x1C,
    0x00,
    0x1C,
    0x80,
    0x03,
    0xE0,
    0x01,
    0xE0,
    0x01,
    0x00,
    0x00,
    0x1E,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x07,
    0x00,
    0x03,
    0xE0,
    0x00,
    0x38,
    0x00,
    0x38,
    0x00,
    0x00,
    0x80,
    0x03,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x60,
    0x00,
    0x60,
    0x00,
    0x0C,
    0x00,
    0x03,
    0x00,
    0x03,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x06,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x80,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x20,
    0x03,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x01,
    0x18,
    0x00,
    0x00,
    0x40,
    0x00,
    0x40,
    0x00,
    0x06,
    0x00,
    0x00,
    0x02,
    0x00,
    0x40,
    0xC0,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x28,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x04,
    0x00,
    0x5C,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x70,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0xFE,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x60,
    0x00,
    0xE0,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x03,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0xF0,
    0x2F,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x0E,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x60,
    0x00,
    0xC0,
    0x01,
    0x70,
    0x00,
    0x3C,
    0x00,
    0x7C,
    0x00,
    0x00,
    0xC0,
    0x0F,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x1C,
    0x00,
    0x07,
    0xC0,
    0x03,
    0xC0,
    0x07,
    0x00,
    0x00,
    0xFC,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE0,
    0x00,
    0x38,
    0x00,
    0x1E,
    0x00,
    0x3E,
    0x00,
    0x00,
    0xE0,
    0x07,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x03,
    0xE0,
    0x00,
    0x78,
    0x00,
    0xF8,
    0x00,
    0x00,
    0x80,
    0x0F,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x07,
    0xC0,
    0x01,
    0xF0,
    0x00,
    0xF0,
    0x00,
    0x00,
    0x00,
    0x1F,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x07,
    0xC0,
    0x01,
    0x70,
    0x00,
    0xF0,
    0x00,
    0x00,
    0x00,
    0x0F,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x80,
    0x03,
    0x60,
    0x00,
    0x38,
    0x00,
    0x38,
    0x00,
    0x00,
    0x80,
    0x03,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x60,
    0x00,
    0x18,
    0x00,
    0x06,
    0x00,
    0x06,
    0x00,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x0C,
    0x00,
    0x01,
    0x40,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0xF9,
    0x03,
    0xC0,
    0x01,
    0xC0,
    0x03,
    0x00,
    0x00,
    0x7C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x01,
    0xE0,
    0x00,
    0xE0,
    0x01,
    0x00,
    0x00,
    0x3E,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x70,
    0x00,
    0x38,
    0x00,
    0x78,
    0x00,
    0x00,
    0x80,
    0x0F,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0E,
    0x00,
    0x07,
    0x00,
    0x0F,
    0x00,
    0x00,
    0xF0,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE0,
    0x00,
    0x70,
    0x00,
    0xF0,
    0x00,
    0x00,
    0x00,
    0x0F,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x07,
    0x80,
    0x03,
    0x80,
    0x03,
    0x00,
    0x00,
    0x78,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x1C,
    0x00,
    0x06,
    0x00,
    0x0E,
    0x00,
    0x00,
    0xE0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x18,
    0x00,
    0x0C,
    0x00,
    0x0C,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x18,
    0x00,
    0x04,
    0x00,
    0x04,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x7C,
    0x0E,
    0x00,
    0x1C,
    0x00,
    0x00,
    0xC0,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x1C,
    0x00,
    0x38,
    0x00,
    0x00,
    0x80,
    0x07,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x1C,
    0x00,
    0x38,
    0x00,
    0x00,
    0x80,
    0x07,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0E,
    0x00,
    0x1C,
    0x00,
    0x00,
    0xC0,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x03,
    0x00,
    0x07,
    0x00,
    0x00,
    0xF0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x70,
    0x00,
    0xE0,
    0x00,
    0x00,
    0x00,
    0x0E,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x07,
    0x00,
    0x06,
    0x00,
    0x00,
    0xE0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x18,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x60,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0xC0,
    0x01,
    0x80,
    0x03,
    0x00,
    0x00,
    0x78,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x0C,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x72,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0xB0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE0,
    0x07,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x1E,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x1F,
    0x00,
    0x00,
    0x80,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x38,
    0x00,
    0x00,
    0x00,
    0x07,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x38,
    0x00,
    0x00,
    0x00,
    0x07,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x1C,
    0x00,
    0x00,
    0x80,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x07,
    0x00,
    0x00,
    0xE0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE0,
    0x00,
    0x00,
    0x00,
    0x1C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0E,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x80,
    0x03,
    0x00,
    0x00,
    0x70,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x39,
    0x00,
    0x00,
    0x00,
    0x07,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC8,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x90,
    0x03,
    0x00,
    0x00,
    0xE0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x10,
    0x00,
    0x40,
    0x00,
    0x0E,
    0x00,
    0x00,
    0x00,
    0x07,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x80,
    0x03,
    0x00,
    0x00,
    0x80,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0xE0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x1C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0E,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x38,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x70,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x70,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0xC0,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC8,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE4,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x19,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x90,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x70,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x03,
    0x00,
    0x00,
    0x20,
    0x00,
    0x80,
    0x00,
    0x1C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x1C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x06,
    0x00,
    0x00,
    0x08,
    0x00,
    0x08,
    0xC0,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0xE0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x18,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x80,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x06,
    0x00,
    0x40,
    0x00,
    0x00,
    0x02,
    0x0E,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0xC8,
    0x00,
    0x00,
    0x02,
    0x00,
    0x04,
    0x40,
    0x0E,
    0x00,
    0x00,
    0x00,
    0x08,
    0x80,
    0x03,
    0x00,
    0x00,
    0x00,
    0x10,
    0xE0,
    0x7F,
    0x00,
    0x80,
    0x99,
    0x99,
    0x01,
    0x00,
    0x32,
    0x00,
    0x03,
    0x30,
    0x00,
    0x03,
    0x00,
    0x08,
    0xC0,
    0x00,
    0x0C,
    0xC0,
    0x00,
    0x0C,
    0x00,
    0x08,
    0xC0,
    0x80,
    0x01,
    0x03,
    0x06,
    0x00,
    0x80,
    0x80,
    0x01,
    0x03,
    0x06,
    0x00,
    0x20,
    0x60,
    0x00,
    0x64,
    0x00,
    0x64,
    0x00,
    0x80,
    0x00,
    0xC8,
    0x00,
    0x18,
    0x00,
    0x03,
    0x00,
    0x01,
    0x30,
    0xC0,
    0x00,
    0x03,
    0x00,
    0x20,
    0xC0,
    0x00,
    0x03,
    0x00,
    0x08,
    0x30,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFC,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x03,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE0,
    0x00,
    0x80,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xF0,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0F,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x03,
    0x70,
    0x06,
    0x60,
    0x00,
    0x06,
    0x0C,
    0x18,
    0x00,
    0x19,
    0x00,
    0x03,
    0x0C,
    0x30,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFC,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x03,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE0,
    0x00,
    0xFC,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x60,
    0x00,
    0xE0,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x03,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x70,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xF0,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0xC0,
    0x07,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x07,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE0,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x80,
    0x0F,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0E,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0xBF,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x38,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x7F,
    0x5E,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xF0,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0F,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x3F,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xF8,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x07,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0xB0,
    0x2A,
    0x95,
    0x08,
    0x01,
    0x02,
    0x40,
    0x00,
    0x80,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0xF0,
    0x3F,
    0xFE,
    0x46,
    0x55,
    0x95,
    0xA2,
    0x50,
    0x40,
    0x01,
    0x14,
    0x00,
    0x05,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xD0,
    0xFF,
    0x3F,
    0x55,
    0x84,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0xAC,
    0x52,
    0x89,
    0x10,
    0x20,
    0x00,
    0x04,
    0x00,
    0x08,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0xFE,
    0xE3,
    0x6F,
    0x54,
    0x55,
    0x29,
    0x0A,
    0x05,
    0x14,
    0x40,
    0x01,
    0x50,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFD,
    0xFF,
    0x53,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x2A,
    0x95,
    0x08,
    0x01,
    0x02,
    0x40,
    0x00,
    0x80,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0xF8,
    0x1F,
    0x5F,
    0xD2,
    0xCC,
    0x8C,
    0x61,
    0x30,
    0xC0,
    0x00,
    0x0C,
    0x00,
    0x03,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE8,
    0xFF,
    0x9F,
    0x2A,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x56,
    0x2A,
    0x11,
    0x02,
    0x04,
    0x80,
    0x00,
    0x00,
    0x01,
    0x00,
    0x20,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x7F,
    0xFC,
    0x8D,
    0xAA,
    0x2A,
    0x45,
    0xA1,
    0x80,
    0x02,
    0x28,
    0x00,
    0x0A,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA0,
    0xFF,
    0x7F,
    0xAA,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x58,
    0xA9,
    0x44,
    0x08,
    0x10,
    0x00,
    0x02,
    0x00,
    0x04,
    0x00,
    0x80,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFF,
    0xF8,
    0x92,
    0x66,
    0x66,
    0x0C,
    0x83,
    0x01,
    0x06,
    0x60,
    0x00,
    0x18,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0xFF,
    0xFF,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0xB0,
    0x54,
    0x22,
    0x04,
    0x08,
    0x00,
    0x01,
    0x00,
    0x02,
    0x00,
    0x40,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0xF8,
    0xF8,
    0x1B,
    0x55,
    0x55,
    0x8A,
    0x42,
    0x01,
    0x05,
    0x50,
    0x00,
    0x14,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x28,
    0x00,
    0x00,
    0x00,
    0x28,
    0x00,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0xFF,
    0xFF,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0xB0,
    0x54,
    0x22,
    0x04,
    0x08,
    0x00,
    0x01,
    0x00,
    0x02,
    0x00,
    0x40,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x7E,
    0x7C,
    0x49,
    0x33,
    0x33,
    0x86,
    0xC1,
    0x00,
    0x03,
    0x30,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA0,
    0xFF,
    0x7F,
    0xAA,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x98,
    0x4A,
    0x84,
    0x00,
    0x01,
    0x20,
    0x00,
    0x40,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x1C,
    0x7F,
    0xA3,
    0xAA,
    0x4A,
    0x51,
    0x28,
    0xA0,
    0x00,
    0x0A,
    0x80,
    0x02,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE8,
    0xFF,
    0x9F,
    0x2A,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0xA6,
    0x12,
    0x21,
    0x40,
    0x00,
    0x08,
    0x00,
    0x10,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0xC0,
    0xE3,
    0x4B,
    0x9A,
    0x99,
    0x31,
    0x0C,
    0x06,
    0x18,
    0x80,
    0x01,
    0x60,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFD,
    0xFF,
    0x53,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x4A,
    0x84,
    0x00,
    0x01,
    0x20,
    0x00,
    0x40,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x7F,
    0xA3,
    0xAA,
    0x4A,
    0x51,
    0x28,
    0xA0,
    0x00,
    0x0A,
    0x80,
    0x02,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE8,
    0xFF,
    0x9F,
    0x2A,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x56,
    0x22,
    0x04,
    0x08,
    0x00,
    0x01,
    0x00,
    0x02,
    0x00,
    0x40,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x60,
    0x7C,
    0x49,
    0x33,
    0x33,
    0x86,
    0xC1,
    0x00,
    0x03,
    0x30,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA0,
    0xFF,
    0x7F,
    0xAA,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0xF8,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0xC0,
    0x07,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x07,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE0,
    0x12,
    0x21,
    0x40,
    0x00,
    0x08,
    0x00,
    0x10,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0xDF,
    0xA8,
    0xAA,
    0x52,
    0x14,
    0x0A,
    0x28,
    0x80,
    0x02,
    0xA0,
    0x00,
    0x00,
    0x28,
    0x00,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x00,
    0x28,
    0x00,
    0x00,
    0x00,
    0x00,
    0x28,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFA,
    0xFF,
    0xA7,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x25,
    0x42,
    0x80,
    0x00,
    0x10,
    0x00,
    0x20,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x97,
    0x34,
    0x33,
    0x63,
    0x18,
    0x0C,
    0x30,
    0x00,
    0x03,
    0xC0,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFA,
    0xFF,
    0xA7,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x89,
    0x10,
    0x20,
    0x00,
    0x04,
    0x00,
    0x08,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x6F,
    0x54,
    0x55,
    0x29,
    0x0A,
    0x05,
    0x14,
    0x40,
    0x01,
    0x50,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFD,
    0xFF,
    0x53,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x44,
    0x08,
    0x10,
    0x00,
    0x02,
    0x00,
    0x04,
    0x00,
    0x80,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE0,
    0x92,
    0x66,
    0x66,
    0x0C,
    0x83,
    0x01,
    0x06,
    0x60,
    0x00,
    0x18,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0xFF,
    0xFF,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x42,
    0x80,
    0x00,
    0x10,
    0x00,
    0x20,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xB0,
    0x51,
    0x55,
    0xA5,
    0x28,
    0x14,
    0x50,
    0x00,
    0x05,
    0x40,
    0x01,
    0x00,
    0x50,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xF4,
    0xFF,
    0x4F,
    0x15,
    0x21,
    0x08,
    0x04,
    0x04,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x23,
    0x04,
    0x08,
    0x00,
    0x01,
    0x00,
    0x02,
    0x00,
    0x40,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x49,
    0x33,
    0x33,
    0x86,
    0xC1,
    0x00,
    0x03,
    0x30,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA0,
    0xFF,
    0x7F,
    0xAA,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x21,
    0x40,
    0x00,
    0x08,
    0x00,
    0x10,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x10,
    0x11,
    0x21,
    0x08,
    0x0C,
    0x30,
    0x00,
    0x05,
    0x40,
    0x01,
    0x00,
    0x50,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x52,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x10,
    0x20,
    0x00,
    0x04,
    0x00,
    0x08,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x24,
    0x54,
    0x55,
    0x29,
    0x0A,
    0x05,
    0x14,
    0x40,
    0x01,
    0x50,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFD,
    0xFF,
    0x53,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x10,
    0x20,
    0x00,
    0x04,
    0x00,
    0x08,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0xCD,
    0xCC,
    0x18,
    0x06,
    0x03,
    0x0C,
    0xC0,
    0x00,
    0x30,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0xFE,
    0xFF,
    0xA9,
    0x22,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x08,
    0x10,
    0x00,
    0x02,
    0x00,
    0x04,
    0x00,
    0x80,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x44,
    0x44,
    0x08,
    0x02,
    0x03,
    0x0C,
    0x40,
    0x01,
    0x50,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x04,
    0x08,
    0x00,
    0x01,
    0x00,
    0x02,
    0x00,
    0x40,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x11,
    0x11,
    0x82,
    0x80,
    0x00,
    0x02,
    0x61,
    0x00,
    0x18,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x55,
    0x84,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x10,
    0x00,
    0x02,
    0x00,
    0x04,
    0x00,
    0x80,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x12,
    0x22,
    0xAA,
    0x14,
    0x85,
    0x02,
    0x0A,
    0xA0,
    0x00,
    0x28,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0xFE,
    0xFF,
    0xA9,
    0x22,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x80,
    0x00,
    0x10,
    0x00,
    0x20,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x33,
    0x63,
    0x18,
    0x0C,
    0x30,
    0x00,
    0x03,
    0xC0,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFA,
    0xFF,
    0xA7,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x02,
    0x40,
    0x00,
    0x80,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x08,
    0x41,
    0x60,
    0x80,
    0x01,
    0x28,
    0x00,
    0x0A,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x90,
    0x2A,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x08,
    0x00,
    0x01,
    0x00,
    0x02,
    0x00,
    0x40,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x11,
    0x82,
    0x80,
    0x00,
    0x02,
    0x61,
    0x00,
    0x18,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x55,
    0x84,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x10,
    0x00,
    0x02,
    0x00,
    0x04,
    0x00,
    0x80,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x04,
    0x01,
    0x01,
    0x04,
    0x80,
    0x01,
    0x60,
    0x00,
    0x00,
    0x28,
    0x00,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x00,
    0x28,
    0x00,
    0x00,
    0x00,
    0x00,
    0x28,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x02,
    0x00,
    0x04,
    0x00,
    0x80,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x12,
    0x22,
    0x22,
    0x14,
    0x85,
    0x02,
    0x0A,
    0xA0,
    0x00,
    0x28,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0xFE,
    0xFF,
    0xA9,
    0x22,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x08,
    0x00,
    0x10,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x8A,
    0x88,
    0x31,
    0x0C,
    0x06,
    0x18,
    0x80,
    0x01,
    0x60,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFD,
    0xFF,
    0x53,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x10,
    0x00,
    0x20,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x10,
    0x18,
    0x60,
    0x00,
    0x0A,
    0x80,
    0x02,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA4,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x20,
    0x00,
    0x40,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x42,
    0x10,
    0x10,
    0x40,
    0x20,
    0x0C,
    0x00,
    0x03,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA4,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x20,
    0x00,
    0x40,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x10,
    0x10,
    0x40,
    0x00,
    0x18,
    0x00,
    0x06,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x88,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x20,
    0x00,
    0x40,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x21,
    0x08,
    0x08,
    0x20,
    0x00,
    0x08,
    0x00,
    0x02,
    0x80,
    0x80,
    0x01,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x44,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x10,
    0x00,
    0x20,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x04,
    0x04,
    0x10,
    0x00,
    0x04,
    0x00,
    0x03,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x08,
    0x00,
    0x10,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x01,
    0x01,
    0x04,
    0x00,
    0x01,
    0x80,
    0x00,
    0x04,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x02,
    0x00,
    0x04,
    0x00,
    0x80,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x40,
    0x00,
    0x01,
    0x40,
    0x00,
    0x60,
    0x00,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x08,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x24,
    0x44,
    0x44,
    0x08,
    0x02,
    0x05,
    0x14,
    0x40,
    0x01,
    0x50,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFD,
    0xFF,
    0x53,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x01,
    0x00,
    0x20,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x88,
    0x08,
    0xC1,
    0x60,
    0x80,
    0x01,
    0x18,
    0x00,
    0x06,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xD0,
    0xFF,
    0x3F,
    0x55,
    0x84,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x10,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x30,
    0x00,
    0x05,
    0x40,
    0x01,
    0x00,
    0x50,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x52,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x01,
    0x00,
    0x20,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x40,
    0x00,
    0x81,
    0x30,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x90,
    0x2A,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x08,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x08,
    0x00,
    0x03,
    0xC0,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x40,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x08,
    0x20,
    0x00,
    0x08,
    0x00,
    0x02,
    0x80,
    0x80,
    0x01,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x44,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x01,
    0x00,
    0x20,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x80,
    0x00,
    0x20,
    0x00,
    0x18,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x21,
    0x08,
    0x04,
    0x04,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x04,
    0x00,
    0x80,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x40,
    0x00,
    0x01,
    0x40,
    0x00,
    0x20,
    0x00,
    0x01,
    0x30,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x08,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x02,
    0x80,
    0x00,
    0xC0,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x10,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x80,
    0x00,
    0x02,
    0x80,
    0x00,
    0x80,
    0x00,
    0x00,
    0x80,
    0x00,
    0x10,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x10,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x02,
    0x80,
    0x00,
    0x80,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x28,
    0x00,
    0x00,
    0x00,
    0x28,
    0x00,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x10,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x01,
    0x40,
    0x00,
    0x40,
    0x00,
    0x00,
    0x80,
    0x00,
    0x02,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x08,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x20,
    0x00,
    0x20,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x28,
    0x00,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x04,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x40,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x09,
    0x11,
    0x11,
    0x82,
    0x40,
    0x00,
    0x01,
    0x50,
    0x00,
    0x14,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x28,
    0x00,
    0x00,
    0x00,
    0x28,
    0x00,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0xFF,
    0xFF,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x11,
    0x21,
    0x08,
    0x04,
    0x30,
    0x00,
    0x03,
    0xC0,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFA,
    0xFF,
    0xA7,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x20,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x01,
    0x50,
    0x00,
    0x14,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x28,
    0x00,
    0x00,
    0x00,
    0x28,
    0x00,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x55,
    0x84,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x84,
    0x01,
    0x60,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x03,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x44,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x01,
    0x03,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x88,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x20,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x18,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x21,
    0x08,
    0x04,
    0x04,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x40,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x20,
    0x00,
    0x10,
    0x80,
    0x00,
    0x18,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x21,
    0x08,
    0x04,
    0x04,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x40,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x30,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x08,
    0x04,
    0x04,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x40,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x10,
    0x00,
    0x10,
    0x00,
    0x00,
    0x10,
    0x00,
    0x02,
    0x80,
    0x01,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x20,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x08,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x02,
    0x00,
    0x00,
    0x04,
    0x10,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x10,
    0x00,
    0x10,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x80,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x20,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x02,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x20,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x20,
    0x40,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x40,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x84,
    0x88,
    0x08,
    0x41,
    0x20,
    0x80,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA0,
    0xFF,
    0x7F,
    0xAA,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x50,
    0x44,
    0x84,
    0x20,
    0x10,
    0x40,
    0x00,
    0x04,
    0x00,
    0x03,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE8,
    0xFF,
    0x9F,
    0x2A,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x20,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA4,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x84,
    0x00,
    0x60,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x40,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x22,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x28,
    0x00,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x00,
    0x28,
    0x00,
    0x00,
    0x00,
    0x00,
    0x28,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x08,
    0x80,
    0x01,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x00,
    0x28,
    0x00,
    0x00,
    0x00,
    0x00,
    0x28,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x40,
    0x00,
    0x08,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x04,
    0x10,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x20,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x02,
    0x04,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x10,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x20,
    0x20,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0A,
    0x00,
    0xC0,
    0x0A,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x3C,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x10,
    0x06,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x90,
    0x10,
    0x11,
    0x21,
    0x08,
    0x04,
    0x10,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xF4,
    0xFF,
    0x4F,
    0x15,
    0x21,
    0x08,
    0x04,
    0x04,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x8A,
    0x88,
    0x10,
    0x04,
    0x02,
    0x08,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFD,
    0xFF,
    0x53,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x04,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x90,
    0x2A,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x44,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x08,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x84,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x28,
    0x00,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x10,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x28,
    0x00,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0xC0,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x04,
    0x04,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x04,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x80,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x50,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x02,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x04,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x01,
    0x00,
    0x50,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x80,
    0x07,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0xC2,
    0x00,
    0xC0,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x04,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x80,
    0x1F,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x78,
    0x00,
    0x00,
    0x00,
    0xC8,
    0x00,
    0x00,
    0x00,
    0x01,
    0x20,
    0x0C,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x05,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x02,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x10,
    0x00,
    0x00,
    0x26,
    0x44,
    0x44,
    0x08,
    0x02,
    0x01,
    0x04,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFD,
    0xFF,
    0x53,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x22,
    0x22,
    0x04,
    0x81,
    0x00,
    0x02,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0xFF,
    0xFF,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x80,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x90,
    0x2A,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x86,
    0x00,
    0x20,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x08,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x04,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x10,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x14,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0A,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x3C,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x10,
    0x06,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x08,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x3C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0xF0,
    0x00,
    0x00,
    0x00,
    0x90,
    0x01,
    0x00,
    0x00,
    0x02,
    0x40,
    0x18,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x04,
    0x00,
    0x00,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x0D,
    0x00,
    0x7C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x01,
    0x70,
    0x00,
    0x00,
    0x00,
    0x64,
    0x00,
    0x00,
    0x80,
    0x00,
    0x10,
    0x06,
    0x00,
    0x3E,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0xF8,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE0,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x7C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0xF0,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x01,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x38,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0xF8,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE0,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x1C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x7E,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE0,
    0x01,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0xF0,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0F,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0xFF,
    0xE3,
    0x4B,
    0x10,
    0x11,
    0x21,
    0x08,
    0x04,
    0x10,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFD,
    0xFF,
    0x53,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x7F,
    0x7C,
    0x09,
    0x22,
    0x22,
    0x04,
    0x81,
    0x00,
    0x02,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA0,
    0xFF,
    0x7F,
    0xAA,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0xF8,
    0xC7,
    0x97,
    0x20,
    0x22,
    0x42,
    0x10,
    0x08,
    0x20,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFA,
    0xFF,
    0xA7,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x3F,
    0xBE,
    0x04,
    0x11,
    0x11,
    0x82,
    0x40,
    0x00,
    0x01,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xD0,
    0xFF,
    0x3F,
    0x55,
    0x84,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0xFC,
    0xF8,
    0x12,
    0x44,
    0x44,
    0x08,
    0x02,
    0x01,
    0x04,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0xFF,
    0xFF,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0xF0,
    0xF1,
    0x25,
    0x88,
    0x88,
    0x10,
    0x04,
    0x02,
    0x08,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0xFE,
    0xFF,
    0xA9,
    0x22,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0xE0,
    0xF1,
    0x25,
    0x88,
    0x88,
    0x10,
    0x04,
    0x02,
    0x08,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0xFE,
    0xFF,
    0xA9,
    0x22,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0xE0,
    0xF8,
    0x12,
    0x44,
    0x44,
    0x08,
    0x02,
    0x01,
    0x04,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0xFF,
    0xFF,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0xBE,
    0x04,
    0x11,
    0x11,
    0x82,
    0x40,
    0x00,
    0x01,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xD0,
    0xFF,
    0x3F,
    0x55,
    0x84,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0xFC,
    0x12,
    0x44,
    0x44,
    0x08,
    0x02,
    0x01,
    0x04,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0xFF,
    0xFF,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0xF0,
    0x17,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x07,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0xE0,
    0x97,
    0x20,
    0x22,
    0x42,
    0x10,
    0x08,
    0x20,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFA,
    0xFF,
    0xA7,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x97,
    0x20,
    0x22,
    0x42,
    0x10,
    0x08,
    0x20,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFA,
    0xFF,
    0xA7,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x4B,
    0x10,
    0x11,
    0x21,
    0x08,
    0x04,
    0x10,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFD,
    0xFF,
    0x53,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x12,
    0x44,
    0x44,
    0x08,
    0x02,
    0x01,
    0x04,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0xFF,
    0xFF,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x41,
    0x44,
    0x84,
    0x20,
    0x10,
    0x40,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xF4,
    0xFF,
    0x4F,
    0x15,
    0x21,
    0x08,
    0x04,
    0x04,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x43,
    0x44,
    0x84,
    0x20,
    0x10,
    0x40,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xD0,
    0xFF,
    0x3F,
    0x55,
    0x84,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x22,
    0x22,
    0x04,
    0x81,
    0x00,
    0x02,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA0,
    0xFF,
    0x7F,
    0xAA,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x46,
    0x44,
    0x08,
    0x02,
    0x01,
    0x04,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFC,
    0xFF,
    0x53,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x88,
    0x08,
    0x41,
    0x20,
    0x80,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE8,
    0xFF,
    0x9F,
    0x2A,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x46,
    0x44,
    0x08,
    0x02,
    0x02,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x8C,
    0x88,
    0x10,
    0x04,
    0x02,
    0x08,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFD,
    0xFF,
    0x53,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x88,
    0x10,
    0x04,
    0x02,
    0x08,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE0,
    0xFF,
    0xA7,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x11,
    0x21,
    0x08,
    0x04,
    0x10,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xF0,
    0xFF,
    0xA7,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x11,
    0x21,
    0x08,
    0x04,
    0x10,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFD,
    0xFF,
    0x53,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x88,
    0x10,
    0x04,
    0x04,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA9,
    0x22,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x84,
    0x20,
    0x10,
    0x40,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFC,
    0x3F,
    0x55,
    0x84,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x8C,
    0x10,
    0x04,
    0x02,
    0x08,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE0,
    0xFF,
    0x53,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x08,
    0x41,
    0x20,
    0x80,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE8,
    0xFF,
    0x9F,
    0x2A,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x46,
    0x08,
    0x02,
    0x02,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x04,
    0x81,
    0x00,
    0x02,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0xFF,
    0xA9,
    0x22,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x08,
    0x02,
    0x01,
    0x04,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0xFF,
    0xA9,
    0x22,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x08,
    0x02,
    0x01,
    0x04,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0xFF,
    0xFF,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x04,
    0x01,
    0x01,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0xAA,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x04,
    0x02,
    0x08,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xF8,
    0xA7,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x41,
    0x20,
    0x80,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE0,
    0x3F,
    0x55,
    0x84,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x02,
    0x01,
    0x04,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0xFF,
    0xFF,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x08,
    0x08,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x52,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x20,
    0x20,
    0x80,
    0x00,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x21,
    0x08,
    0x04,
    0x04,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x01,
    0x04,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xF0,
    0x53,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x40,
    0x00,
    0x01,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x7F,
    0xAA,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x08,
    0x20,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFA,
    0xFF,
    0xA7,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x01,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0xAA,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x10,
    0x40,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x88,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x01,
    0x04,
    0x00,
    0x01,
    0x80,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x40,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x3C,
    0x55,
    0x84,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x20,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x4F,
    0x15,
    0x21,
    0x08,
    0x04,
    0x04,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x08,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0xFE,
    0xFF,
    0xA9,
    0x22,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x90,
    0x2A,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x10,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x22,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x01,
    0x40,
    0x00,
    0x20,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x10,
    0x00,
    0x04,
    0x00,
    0x04,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x30,
    0x55,
    0x84,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x53,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE8,
    0xFF,
    0x9F,
    0x2A,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x52,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x21,
    0x08,
    0x04,
    0x04,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x80,
    0x00,
    0x40,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x84,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x02,
    0x00,
    0x02,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x08,
    0x00,
    0x08,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x00,
    0x04,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x08,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x08,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA0,
    0xFF,
    0x7F,
    0xAA,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x04,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x55,
    0x84,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x02,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA4,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x40,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x08,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x01,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x10,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x01,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x80,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x52,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x28,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA8,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0xFF,
    0xFF,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x22,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA0,
    0x22,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFD,
    0xFF,
    0x53,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x21,
    0x08,
    0x04,
    0x04,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x88,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xD0,
    0xFF,
    0x3F,
    0x55,
    0x84,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA4,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x44,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xD0,
    0xFF,
    0x3F,
    0x55,
    0x84,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA4,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x44,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0xC0,
    0x0A,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x3C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x06,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x04,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0xFF,
    0xFF,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x55,
    0x84,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x84,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x08,
    0x04,
    0x04,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0xC0,
    0x03,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x61,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0xA8,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0xC0,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x61,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE8,
    0xFF,
    0x9F,
    0x2A,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xA4,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x88,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x1C,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x08,
    0x03,
    0x00,
    0x03,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x0F,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x84,
    0x01,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x1A,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x80,
    0x00,
    0x38,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x03,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x1E,
    0x00,
    0x00,
    0x00,
    0x32,
    0x00,
    0x00,
    0x40,
    0x00,
    0x08,
    0x03,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x80,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0xFB,
    0xFF,
    0xA7,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0xA6,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x10,
    0x00,
    0x00,
    0x46,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x43,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x04,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x02,
    0x40,
    0x00,
    0x00,
    0x18,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x00,
    0x20,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x80,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x20,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x10,
    0x06,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x01,
    0x30,
    0x00,
    0x00,
    0x00,
    0x64,
    0x00,
    0x00,
    0x80,
    0x00,
    0x10,
    0x06,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x1E,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x03,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0x00,
    0x40,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x01,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x10,
    0x00,
    0x07,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x61,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0F,
    0x28,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x86,
    0x01,
    0xC0,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x10,
    0x00,
    0x07,
    0x00,
    0x00,
    0x40,
    0x06,
    0x00,
    0x00,
    0x08,
    0x00,
    0x61,
    0x00,
    0x60,
    0x01,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x60,
    0x00,
    0xE0,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x03,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0xF0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xF8,
    0x05,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x60,
    0xC0,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x78,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x70,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x56,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x06,
    0x1C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x80,
    0x05,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x60,
    0xC0,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x58,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x06,
    0x1C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x18,
    0x70,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x06,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x80,
    0x15,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x78,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x5C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE0,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x70,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x03,
    0x00,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE0,
    0x01,
    0x00,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0xF0,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xE0,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x70,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x70,
    0x00,
    0x00,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0E,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x1C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFC,
    0xFF,
    0xA7,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0xFF,
    0xFF,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0xF0,
    0xFF,
    0xA7,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0xFF,
    0x9F,
    0x2A,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0xFE,
    0x3F,
    0x55,
    0x84,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0xFC,
    0x3F,
    0x55,
    0x84,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0xFC,
    0x9F,
    0x2A,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0xFE,
    0xA7,
    0x8A,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0xFF,
    0x54,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0xF0,
    0x4F,
    0x15,
    0x21,
    0x08,
    0x04,
    0x04,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x7F,
    0xAA,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0xF8,
    0xA9,
    0x22,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0xE0,
    0x53,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x53,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0xA9,
    0x22,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0xAA,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x58,
    0x45,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x2A,
    0x42,
    0x10,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0xAE,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x58,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0xB0,
    0x08,
    0x41,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x58,
    0x84,
    0x20,
    0x10,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x8C,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x11,
    0x82,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x04,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x08,
    0x02,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x10,
    0x04,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x83,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x08,
    0x04,
    0x04,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x83,
    0x40,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x08,
    0x04,
    0x04,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x07,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x81,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x20,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x08,
    0x08,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x02,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x03,
    0x02,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x80,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x40,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x20,
    0x40,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x10,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x1C,
    0x20,
    0x80,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x10,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x08,
    0x20,
    0x00,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x04,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x02,
    0x08,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x80,
    0x00,
    0x02,
    0x10,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x70,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x01,
    0x08,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x40,
    0x00,
    0x02,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x10,
    0x80,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x04,
    0x20,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0xE0,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x40,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x04,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x1C,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x04,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x08,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x10,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x20,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x40,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x80,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x02,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0xE0,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x40,
    0x00,
    0x10,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x08,
    0x00,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x01,
    0x40,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x20,
    0x00,
    0x08,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x04,
    0x00,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x80,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x10,
    0x00,
    0x04,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x02,
    0x80,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x40,
    0x00,
    0x10,
    0xC0,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x61,
    0x00,
    0xE0,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x20,
    0x00,
    0x07,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC2,
    0x00,
    0xC0,
    0x00,
    0x20,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x01,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x61,
    0x00,
    0x60,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x70,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x10,
    0x06,
    0x00,
    0x0E,
    0x00,
    0x00,
    0x03,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x03,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x03,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x40,
    0x18,
    0x00,
    0x18,
    0x00,
    0x00,
    0x0E,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC2,
    0x00,
    0xC0,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x38,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x60,
    0x18,
    0x00,
    0x0C,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC1,
    0x80,
    0x02,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x38,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x0F,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x80,
    0x07,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x01,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xF0,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x70,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x1E,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xC0,
    0x07,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x10,
    0x00,
    0x00,
    0x06,
    0x00,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x20,
    0x00,
    0x00,
    0x0C,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x80,
    0x00,
    0x00,
    0x30,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x08,
    0x00,
    0x00,
    0x03,
    0x00,
    0x04,
    0x00,
    0x80,
    0x01,
    0x00,
    0xC2,
    0x00,
    0xC0,
    0x00,
    0x40,
    0x00,
    0x00,
    0x18,
    0x00,
    0x02,
    0x00,
    0xC0,
    0x00,
    0x40,
    0x00,
    0x00,
    0x38,
    0x00,
    0x00,
    0x40,
    0x00,
    0x08,
    0x03,
    0x00,
    0x03,
    0x40,
    0x00,
    0x00,
    0x38,
    0x00,
    0x00,
    0x40,
    0x00,
    0x08,
    0x03,
    0x00,
    0x03,
    0x00,
    0x00,
    0x00,
    0x00,
    0xF0,
    0x00,
    0x00,
    0x00,
    0x00,
    0x00,
    0xFC,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0x03,
    0x00,
    0x0F,
    0x00,
    0x0C,
    0x03,
    0x80,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
    0xFF,
  };

  auto &Entry = Table[A];
  unsigned Idx = B - Entry.Start;
  if (Idx >= Entry.Length)
    return false;
  Idx += Entry.Offset;
  return (Data[Idx / 8] >> (Idx % 8)) & 1;
}

static unsigned validateOperandClass(MCParsedAsmOperand &GOp, MatchClassKind Kind, const MCSubtargetInfo &STI) {
  AMDGPUOperand &Operand = (AMDGPUOperand &)GOp;
  if (Kind == InvalidMatchClass)
    return MCTargetAsmParser::Match_InvalidOperand;

  if (Operand.isToken() && Kind <= MCK_LAST_TOKEN)
    return isSubclass(matchTokenString(Operand.getToken()), Kind) ?
             MCTargetAsmParser::Match_Success :
             MCTargetAsmParser::Match_InvalidOperand;

  switch (Kind) {
  default: break;
  case MCK_AV_LdSt_32_Align2_RegOp: {
    DiagnosticPredicate DP(Operand.isAV_LdSt_32_Align2_RegOp());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SDWAWithBin32InputMods: {
    DiagnosticPredicate DP(Operand.isSDWAInt32Operand());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_BoolReg: {
    DiagnosticPredicate DP(Operand.isBoolReg());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_RegOrImmWithFP16InputMods: {
    DiagnosticPredicate DP(Operand.isRegOrImmWithFP16InputMods());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SDWAWithFP16InputMods: {
    DiagnosticPredicate DP(Operand.isSDWAFP16Operand());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_RegOrImmWithFP32InputMods: {
    DiagnosticPredicate DP(Operand.isRegOrImmWithFP32InputMods());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SDWAWithFP32InputMods: {
    DiagnosticPredicate DP(Operand.isSDWAFP32Operand());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_RegOrInlineImmWithFP32InputMods: {
    DiagnosticPredicate DP(Operand.isRegOrInlineImmWithFP32InputMods());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VRegWithFP32InputMods: {
    DiagnosticPredicate DP(Operand.isVRegWithFP32InputMods());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_RegOrImmWithFP64InputMods: {
    DiagnosticPredicate DP(Operand.isRegOrImmWithFP64InputMods());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_RegOrInlineImmWithFP64InputMods: {
    DiagnosticPredicate DP(Operand.isRegOrInlineImmWithFP64InputMods());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VRegWithFP64InputMods: {
    DiagnosticPredicate DP(Operand.isVRegWithFP64InputMods());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VRegWithFPInputMods: {
    DiagnosticPredicate DP(Operand.isVRegWithInputMods());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_Imm: {
    DiagnosticPredicate DP(Operand.isImm());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SDWAWithInt16InputMods: {
    DiagnosticPredicate DP(Operand.isSDWAInt16Operand());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_RegOrImmWithInt32InputMods: {
    DiagnosticPredicate DP(Operand.isRegOrImmWithInt32InputMods());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SDWAWithInt32InputMods: {
    DiagnosticPredicate DP(Operand.isSDWAInt32Operand());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_RegOrInlineImmWithInt32InputMods: {
    DiagnosticPredicate DP(Operand.isRegOrInlineImmWithInt32InputMods());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_RegOrImmWithInt64InputMods: {
    DiagnosticPredicate DP(Operand.isRegOrImmWithInt64InputMods());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_OpSelMods: {
    DiagnosticPredicate DP(Operand.isRegOrImm());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VRegWithIntInputMods: {
    DiagnosticPredicate DP(Operand.isVRegWithInputMods());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_PackedFP16InputMods: {
    DiagnosticPredicate DP(Operand.isPackedFP16InputMods());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_PackedInt16InputMods: {
    DiagnosticPredicate DP(Operand.isRegOrImm());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_PackedFP32InputMods: {
    DiagnosticPredicate DP(Operand.isPackedVGPRFP32InputMods());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VReg32OrOff: {
    DiagnosticPredicate DP(Operand.isVReg32OrOff());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SSrc_b16: {
    DiagnosticPredicate DP(Operand.isSSrc_b16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SSrc_bf16: {
    DiagnosticPredicate DP(Operand.isSSrc_bf16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SSrc_f16: {
    DiagnosticPredicate DP(Operand.isSSrc_f16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SSrc_b32: {
    DiagnosticPredicate DP(Operand.isSSrc_b32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SSrc_f32: {
    DiagnosticPredicate DP(Operand.isSSrc_f32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SSrc_b64: {
    DiagnosticPredicate DP(Operand.isSSrc_b64());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SSrcOrLds_b32: {
    DiagnosticPredicate DP(Operand.isSSrcOrLds_b32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SCSrc_b32: {
    DiagnosticPredicate DP(Operand.isSCSrc_b32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SCSrc_b64: {
    DiagnosticPredicate DP(Operand.isSCSrc_b64());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrc_b16: {
    DiagnosticPredicate DP(Operand.isVSrc_b16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrc_bf16: {
    DiagnosticPredicate DP(Operand.isVSrc_bf16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrc_f16: {
    DiagnosticPredicate DP(Operand.isVSrc_f16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrcT_b16: {
    DiagnosticPredicate DP(Operand.isVSrcT_b16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrcT_bf16: {
    DiagnosticPredicate DP(Operand.isVSrcT_bf16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrcT_f16: {
    DiagnosticPredicate DP(Operand.isVSrcT_f16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrcT_b16_Lo128: {
    DiagnosticPredicate DP(Operand.isVSrcT_b16_Lo128());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrcT_bf16_Lo128: {
    DiagnosticPredicate DP(Operand.isVSrcT_bf16_Lo128());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrcT_f16_Lo128: {
    DiagnosticPredicate DP(Operand.isVSrcT_f16_Lo128());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrcFake16_b16_Lo128: {
    DiagnosticPredicate DP(Operand.isVSrcFake16_b16_Lo128());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrcFake16_bf16_Lo128: {
    DiagnosticPredicate DP(Operand.isVSrcFake16_bf16_Lo128());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrcFake16_f16_Lo128: {
    DiagnosticPredicate DP(Operand.isVSrcFake16_f16_Lo128());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrc_b32: {
    DiagnosticPredicate DP(Operand.isVSrc_b32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrc_f32: {
    DiagnosticPredicate DP(Operand.isVSrc_f32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrc_v2b16: {
    DiagnosticPredicate DP(Operand.isVSrc_v2b16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrc_v2bf16: {
    DiagnosticPredicate DP(Operand.isVSrc_v2bf16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrc_v2f16: {
    DiagnosticPredicate DP(Operand.isVSrc_v2f16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrc_b64: {
    DiagnosticPredicate DP(Operand.isVSrc_b64());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrc_f64: {
    DiagnosticPredicate DP(Operand.isVSrc_f64());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrc_v2b32: {
    DiagnosticPredicate DP(Operand.isVSrc_v2b32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrc_v2f32: {
    DiagnosticPredicate DP(Operand.isVSrc_v2f32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrc_NoInline_v2f16: {
    DiagnosticPredicate DP(Operand.isVSrc_NoInline_v2f16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VSrc_v2f16_splat: {
    DiagnosticPredicate DP(Operand.isVSrc_v2f16_splat());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VCSrc_b16: {
    DiagnosticPredicate DP(Operand.isVCSrc_b16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VCSrc_bf16: {
    DiagnosticPredicate DP(Operand.isVCSrc_bf16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VCSrc_f16: {
    DiagnosticPredicate DP(Operand.isVCSrc_f16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VCSrc_b32: {
    DiagnosticPredicate DP(Operand.isVCSrc_b32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VCSrc_f32: {
    DiagnosticPredicate DP(Operand.isVCSrc_f32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VCSrc_v2b16: {
    DiagnosticPredicate DP(Operand.isVCSrc_v2b16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VCSrc_v2bf16: {
    DiagnosticPredicate DP(Operand.isVCSrc_v2bf16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VCSrc_v2f16: {
    DiagnosticPredicate DP(Operand.isVCSrc_v2f16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VCSrc_b32_Lo256: {
    DiagnosticPredicate DP(Operand.isVCSrc_b32_Lo256());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VCSrc_b64_Lo256: {
    DiagnosticPredicate DP(Operand.isVCSrc_b64_Lo256());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VCSrc_b64: {
    DiagnosticPredicate DP(Operand.isVCSrc_b64());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VCSrc_f64: {
    DiagnosticPredicate DP(Operand.isVCSrc_f64());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VCSrc_v2b32: {
    DiagnosticPredicate DP(Operand.isVCSrc_v2b32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VCSrcT_b16: {
    DiagnosticPredicate DP(Operand.isVCSrcT_b16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VCSrcT_bf16: {
    DiagnosticPredicate DP(Operand.isVCSrcT_bf16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VCSrcT_f16: {
    DiagnosticPredicate DP(Operand.isVCSrcT_f16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VISrc_64_bf16: {
    DiagnosticPredicate DP(Operand.isVISrc_64_bf16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VISrc_64_f16: {
    DiagnosticPredicate DP(Operand.isVISrc_64_f16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VISrc_64_b32: {
    DiagnosticPredicate DP(Operand.isVISrc_64_b32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VISrc_64_f64: {
    DiagnosticPredicate DP(Operand.isVISrc_64_f64());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VISrc_128_bf16: {
    DiagnosticPredicate DP(Operand.isVISrc_128_bf16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VISrc_128_f16: {
    DiagnosticPredicate DP(Operand.isVISrc_128_f16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VISrc_128_b32: {
    DiagnosticPredicate DP(Operand.isVISrc_128_b32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VISrc_128_f32: {
    DiagnosticPredicate DP(Operand.isVISrc_128_f32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VISrc_256_b32: {
    DiagnosticPredicate DP(Operand.isVISrc_256_b32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VISrc_256_f32: {
    DiagnosticPredicate DP(Operand.isVISrc_256_f32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VISrc_256_f64: {
    DiagnosticPredicate DP(Operand.isVISrc_256_f64());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VISrc_512_b32: {
    DiagnosticPredicate DP(Operand.isVISrc_512_b32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VISrc_512_f32: {
    DiagnosticPredicate DP(Operand.isVISrc_512_f32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VISrc_512_f64: {
    DiagnosticPredicate DP(Operand.isVISrc_512_f64());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VISrc_1024_b32: {
    DiagnosticPredicate DP(Operand.isVISrc_1024_b32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_VISrc_1024_f32: {
    DiagnosticPredicate DP(Operand.isVISrc_1024_f32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_AISrc_64_f64: {
    DiagnosticPredicate DP(Operand.isAISrc_64_f64());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_AISrc_128_f32: {
    DiagnosticPredicate DP(Operand.isAISrc_128_f32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_AISrc_128_b32: {
    DiagnosticPredicate DP(Operand.isAISrc_128_b32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_AISrc_256_f64: {
    DiagnosticPredicate DP(Operand.isAISrc_256_f64());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_AISrc_512_f32: {
    DiagnosticPredicate DP(Operand.isAISrc_512_f32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_AISrc_512_b32: {
    DiagnosticPredicate DP(Operand.isAISrc_512_b32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_AISrc_1024_f32: {
    DiagnosticPredicate DP(Operand.isAISrc_1024_f32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_AISrc_1024_b32: {
    DiagnosticPredicate DP(Operand.isAISrc_1024_b32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_S16Imm: {
    DiagnosticPredicate DP(Operand.isS16Imm());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_U16Imm: {
    DiagnosticPredicate DP(Operand.isU16Imm());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SOPPBrTarget: {
    DiagnosticPredicate DP(Operand.isSOPPBrTarget());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_InterpSlot: {
    DiagnosticPredicate DP(Operand.isInterpSlot());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_InterpAttr: {
    DiagnosticPredicate DP(Operand.isInterpAttr());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_InterpAttrChan: {
    DiagnosticPredicate DP(Operand.isInterpAttrChan());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SplitBarrier: {
    DiagnosticPredicate DP(Operand.isSplitBarrier());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SendMsg: {
    DiagnosticPredicate DP(Operand.isSendMsg());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_Swizzle: {
    DiagnosticPredicate DP(Operand.isSwizzle());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_Endpgm: {
    DiagnosticPredicate DP(Operand.isEndpgm());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SWaitCnt: {
    DiagnosticPredicate DP(Operand.isSWaitCnt());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_DepCtr: {
    DiagnosticPredicate DP(Operand.isDepCtr());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SDelayALU: {
    DiagnosticPredicate DP(Operand.isSDelayALU());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_FlatOffset: {
    DiagnosticPredicate DP(Operand.isFlatOffset());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_Offset: {
    DiagnosticPredicate DP(Operand.getPredicate([](const AMDGPUOperand &Op) -> bool { return Op.isImmTy(AMDGPUOperand::ImmTyOffset); })());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_Offset0: {
    DiagnosticPredicate DP(Operand.getPredicate([](const AMDGPUOperand &Op) -> bool { return Op.isImmTy(AMDGPUOperand::ImmTyOffset0); })());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_Offset1: {
    DiagnosticPredicate DP(Operand.getPredicate([](const AMDGPUOperand &Op) -> bool { return Op.isImmTy(AMDGPUOperand::ImmTyOffset1); })());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_GDS: {
    DiagnosticPredicate DP(Operand.isImmTy<AMDGPUOperand::ImmTyGDS>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_OModSI: {
    DiagnosticPredicate DP(Operand.isOModSI());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_Clamp: {
    DiagnosticPredicate DP(Operand.isImmTy<AMDGPUOperand::ImmTyClamp>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_High: {
    DiagnosticPredicate DP(Operand.isImmTy<AMDGPUOperand::ImmTyHigh>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_CPol: {
    DiagnosticPredicate DP(Operand.isCPol());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_CPol_GLC: {
    DiagnosticPredicate DP(Operand.getPredicate([](const AMDGPUOperand &Op) -> bool { return Op.isCPol() && Op.getImm() & CPol::GLC; })());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_CPol_NonGLC: {
    DiagnosticPredicate DP(Operand.getPredicate([](const AMDGPUOperand &Op) -> bool { return Op.isCPol() && !(Op.getImm() & CPol::GLC); })());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_TFE: {
    DiagnosticPredicate DP(Operand.isImmTy<AMDGPUOperand::ImmTyTFE>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_UNorm: {
    DiagnosticPredicate DP(Operand.isImmTy<AMDGPUOperand::ImmTyUNorm>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_DA: {
    DiagnosticPredicate DP(Operand.isImmTy<AMDGPUOperand::ImmTyDA>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_R128A16: {
    DiagnosticPredicate DP(Operand.isR128A16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_A16: {
    DiagnosticPredicate DP(Operand.isImmTy<AMDGPUOperand::ImmTyA16>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_D16: {
    DiagnosticPredicate DP(Operand.isImmTy<AMDGPUOperand::ImmTyD16>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_LWE: {
    DiagnosticPredicate DP(Operand.isImmTy<AMDGPUOperand::ImmTyLWE>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_ExpCompr: {
    DiagnosticPredicate DP(Operand.isImmTy<AMDGPUOperand::ImmTyExpCompr>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_ExpVM: {
    DiagnosticPredicate DP(Operand.isImmTy<AMDGPUOperand::ImmTyExpVM>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_FORMAT: {
    DiagnosticPredicate DP(Operand.isFORMAT());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_DMask: {
    DiagnosticPredicate DP(Operand.getPredicate([](const AMDGPUOperand &Op) -> bool { return Op.isImmTy(AMDGPUOperand::ImmTyDMask); })());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_Dim: {
    DiagnosticPredicate DP(Operand.isDim());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SDWADstSel: {
    DiagnosticPredicate DP(Operand.isSDWADstSel());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SDWASrc0Sel: {
    DiagnosticPredicate DP(Operand.isSDWASrc0Sel());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SDWASrc1Sel: {
    DiagnosticPredicate DP(Operand.isSDWASrc1Sel());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SDWADstUnused: {
    DiagnosticPredicate DP(Operand.isSDWADstUnused());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_OpSel: {
    DiagnosticPredicate DP(Operand.isOpSel());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_OpSelHi: {
    DiagnosticPredicate DP(Operand.isOpSelHi());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_NegLo: {
    DiagnosticPredicate DP(Operand.isNegLo());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_NegHi: {
    DiagnosticPredicate DP(Operand.isNegHi());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_IndexKey32bit: {
    DiagnosticPredicate DP(Operand.isIndexKey32bit());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_IndexKey16bit: {
    DiagnosticPredicate DP(Operand.isIndexKey16bit());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_IndexKey8bit: {
    DiagnosticPredicate DP(Operand.isIndexKey8bit());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_DPP8: {
    DiagnosticPredicate DP(Operand.isDPP8());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_DPPCtrl: {
    DiagnosticPredicate DP(Operand.isDPPCtrl());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_DppRowMask: {
    DiagnosticPredicate DP(Operand.getPredicate([](const AMDGPUOperand &Op) -> bool { return Op.isImmTy(AMDGPUOperand::ImmTyDppRowMask); })());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_DppBankMask: {
    DiagnosticPredicate DP(Operand.getPredicate([](const AMDGPUOperand &Op) -> bool { return Op.isImmTy(AMDGPUOperand::ImmTyDppBankMask); })());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_DppBoundCtrl: {
    DiagnosticPredicate DP(Operand.getPredicate([](const AMDGPUOperand &Op) -> bool { return Op.isImmTy(AMDGPUOperand::ImmTyDppBoundCtrl); })());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_DppFI: {
    DiagnosticPredicate DP(Operand.getPredicate([](const AMDGPUOperand &Op) -> bool { return Op.isImmTy(AMDGPUOperand::ImmTyDppFI); })());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_BLGP: {
    DiagnosticPredicate DP(Operand.isBLGP());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_CBSZ: {
    DiagnosticPredicate DP(Operand.getPredicate([](const AMDGPUOperand &Op) -> bool { return Op.isImmTy(AMDGPUOperand::ImmTyCBSZ); })());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_ABID: {
    DiagnosticPredicate DP(Operand.getPredicate([](const AMDGPUOperand &Op) -> bool { return Op.isImmTy(AMDGPUOperand::ImmTyABID); })());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_Hwreg: {
    DiagnosticPredicate DP(Operand.isHwreg());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_ExpTgt: {
    DiagnosticPredicate DP(Operand.isExpTgt());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_WaitVDST: {
    DiagnosticPredicate DP(Operand.getPredicate([](const AMDGPUOperand &Op) -> bool { return Op.isImmTy(AMDGPUOperand::ImmTyWaitVDST); })());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_WaitEXP: {
    DiagnosticPredicate DP(Operand.getPredicate([](const AMDGPUOperand &Op) -> bool { return Op.isImmTy(AMDGPUOperand::ImmTyWaitEXP); })());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_WaitVAVDst: {
    DiagnosticPredicate DP(Operand.getPredicate([](const AMDGPUOperand &Op) -> bool { return Op.isImmTy(AMDGPUOperand::ImmTyWaitVAVDst); })());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_WaitVMVSrc: {
    DiagnosticPredicate DP(Operand.getPredicate([](const AMDGPUOperand &Op) -> bool { return Op.isImmTy(AMDGPUOperand::ImmTyWaitVMVSrc); })());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_ByteSel: {
    DiagnosticPredicate DP(Operand.getPredicate([](const AMDGPUOperand &Op) -> bool { return Op.isImmTy(AMDGPUOperand::ImmTyByteSel); })());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_BitOp3: {
    DiagnosticPredicate DP(Operand.getPredicate([](const AMDGPUOperand &Op) -> bool { return Op.isImmTy(AMDGPUOperand::ImmTyBitOp3); })());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_MatrixAFMT: {
    DiagnosticPredicate DP(Operand.isMatrixAFMT());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_MatrixBFMT: {
    DiagnosticPredicate DP(Operand.isMatrixBFMT());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_MatrixAScale: {
    DiagnosticPredicate DP(Operand.isMatrixAScale());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_MatrixBScale: {
    DiagnosticPredicate DP(Operand.isMatrixBScale());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_MatrixAScaleFmt: {
    DiagnosticPredicate DP(Operand.isMatrixAScaleFmt());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_MatrixBScaleFmt: {
    DiagnosticPredicate DP(Operand.isMatrixBScaleFmt());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_MatrixAReuse: {
    DiagnosticPredicate DP(Operand.isImmTy<AMDGPUOperand::ImmTyMatrixAReuse>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_MatrixBReuse: {
    DiagnosticPredicate DP(Operand.isImmTy<AMDGPUOperand::ImmTyMatrixBReuse>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_ScaleSel: {
    DiagnosticPredicate DP(Operand.getPredicate([](const AMDGPUOperand &Op) -> bool { return Op.isImmTy(AMDGPUOperand::ImmTyScaleSel); })());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_KImmFP32: {
    DiagnosticPredicate DP(Operand.isKImmFP32());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_KImmFP16: {
    DiagnosticPredicate DP(Operand.isKImmFP16());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_KImmFP64: {
    DiagnosticPredicate DP(Operand.isKImmFP64());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_Fake16VRegWithFPInputMods: {
    DiagnosticPredicate DP(Operand.isT16VRegWithInputMods<true>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_RegOrInlineImmWithFPFake16InputMods: {
    DiagnosticPredicate DP(Operand.isRegOrInlineImmWithFP16InputMods<true>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_Fake16VRegWithIntInputMods: {
    DiagnosticPredicate DP(Operand.isT16VRegWithInputMods<true>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_RegOrInlineImmWithIntFake16InputMods: {
    DiagnosticPredicate DP(Operand.isRegOrInlineImmWithIntT16InputMods<true>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_GPRIdxMode: {
    DiagnosticPredicate DP(Operand.isGPRIdxMode());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_RegOrImmWithFPT16InputMods: {
    DiagnosticPredicate DP(Operand.isRegOrImmWithFPT16InputMods<false>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_T16_Lo128VRegWithFPInputMods: {
    DiagnosticPredicate DP(Operand.isT16_Lo128VRegWithInputMods<false>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_T16VRegWithFPInputMods: {
    DiagnosticPredicate DP(Operand.isT16VRegWithInputMods<false>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_RegOrInlineImmWithFPT16InputMods: {
    DiagnosticPredicate DP(Operand.isRegOrInlineImmWithFP16InputMods<false>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_RegOrImmWithFPFake16InputMods: {
    DiagnosticPredicate DP(Operand.isRegOrImmWithFPT16InputMods<true>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_Fake16_Lo128VRegWithFPInputMods: {
    DiagnosticPredicate DP(Operand.isT16_Lo128VRegWithInputMods<true>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_RegOrImmWithIntT16InputMods: {
    DiagnosticPredicate DP(Operand.isRegOrImmWithIntT16InputMods<false>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_T16_Lo128VRegWithIntInputMods: {
    DiagnosticPredicate DP(Operand.isT16_Lo128VRegWithInputMods<false>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_T16VRegWithIntInputMods: {
    DiagnosticPredicate DP(Operand.isT16VRegWithInputMods<false>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_RegOrInlineImmWithIntT16InputMods: {
    DiagnosticPredicate DP(Operand.isRegOrInlineImmWithIntT16InputMods<false>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_RegOrImmWithIntFake16InputMods: {
    DiagnosticPredicate DP(Operand.isRegOrImmWithIntT16InputMods<true>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_Fake16_Lo128VRegWithIntInputMods: {
    DiagnosticPredicate DP(Operand.isT16_Lo128VRegWithInputMods<true>());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SMRDOffset8: {
    DiagnosticPredicate DP(Operand.isSMRDOffset8());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SMEMOffset: {
    DiagnosticPredicate DP(Operand.isSMEMOffset());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SMEMOffsetMod: {
    DiagnosticPredicate DP(Operand.getPredicate([](const AMDGPUOperand &Op) -> bool { return Op.isImmTy(AMDGPUOperand::ImmTySMEMOffsetMod); })());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_OptSMEMOffsetMod: {
    DiagnosticPredicate DP(Operand.getPredicate([](const AMDGPUOperand &Op) -> bool { return Op.isImmTy(AMDGPUOperand::ImmTySMEMOffsetMod); })());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  case MCK_SMRDLiteralOffset: {
    DiagnosticPredicate DP(Operand.isSMRDLiteralOffset());
    if (DP.isMatch())
      return MCTargetAsmParser::Match_Success;
    break;
  }
  } // end switch (Kind)

  if (Operand.isReg() && Kind > MCK_LAST_REGISTER && Kind <= MCK_LAST_REGCLASS_BY_HWMODE) {
    static constexpr MatchClassKind RegClassByHwModeMatchTable[5][83] = {
      { // DefaultMode
        MCK_AReg_64, // AReg_64_AlignTarget
        MCK_AReg_96, // AReg_96_AlignTarget
        MCK_AReg_128, // AReg_128_AlignTarget
        MCK_AReg_160, // AReg_160_AlignTarget
        MCK_AReg_192, // AReg_192_AlignTarget
        MCK_AReg_224, // AReg_224_AlignTarget
        MCK_AReg_256, // AReg_256_AlignTarget
        MCK_AReg_288, // AReg_288_AlignTarget
        MCK_AReg_320, // AReg_320_AlignTarget
        MCK_AReg_352, // AReg_352_AlignTarget
        MCK_AReg_384, // AReg_384_AlignTarget
        MCK_AReg_512, // AReg_512_AlignTarget
        MCK_AReg_1024, // AReg_1024_AlignTarget
        MCK_AV_64, // AV_64_AlignTarget
        MCK_AV_96, // AV_96_AlignTarget
        MCK_AV_128, // AV_128_AlignTarget
        MCK_AV_160, // AV_160_AlignTarget
        MCK_AV_192, // AV_192_AlignTarget
        MCK_AV_224, // AV_224_AlignTarget
        MCK_AV_256, // AV_256_AlignTarget
        MCK_AV_288, // AV_288_AlignTarget
        MCK_AV_320, // AV_320_AlignTarget
        MCK_AV_352, // AV_352_AlignTarget
        MCK_AV_384, // AV_384_AlignTarget
        MCK_AV_512, // AV_512_AlignTarget
        MCK_AV_1024, // AV_1024_AlignTarget
        MCK_VGPR_32, // AV_LdSt_32_Align2
        MCK_VGPR_32, // AV_LdSt_32_Target
        MCK_VReg_64, // AV_LdSt_64_Align1
        MCK_VReg_64_Align2, // AV_LdSt_64_Align2
        MCK_VReg_64, // AV_LdSt_64_AlignTarget
        MCK_VReg_96, // AV_LdSt_96_Align1
        MCK_VReg_96_Align2, // AV_LdSt_96_Align2
        MCK_VReg_96, // AV_LdSt_96_AlignTarget
        MCK_VReg_128, // AV_LdSt_128_Align1
        MCK_VReg_128_Align2, // AV_LdSt_128_Align2
        MCK_VReg_128, // AV_LdSt_128_AlignTarget
        MCK_VReg_160, // AV_LdSt_160_Align1
        MCK_VReg_160_Align2, // AV_LdSt_160_Align2
        MCK_VReg_160, // AV_LdSt_160_AlignTarget
        MCK_VReg_192, // AV_LdSt_192_Align1
        MCK_VReg_192_Align2, // AV_LdSt_192_Align2
        MCK_VReg_192, // AV_LdSt_192_AlignTarget
        MCK_VReg_224, // AV_LdSt_224_Align1
        MCK_VReg_224_Align2, // AV_LdSt_224_Align2
        MCK_VReg_224, // AV_LdSt_224_AlignTarget
        MCK_VReg_256, // AV_LdSt_256_Align1
        MCK_VReg_256_Align2, // AV_LdSt_256_Align2
        MCK_VReg_256, // AV_LdSt_256_AlignTarget
        MCK_VReg_288, // AV_LdSt_288_Align1
        MCK_VReg_288_Align2, // AV_LdSt_288_Align2
        MCK_VReg_288, // AV_LdSt_288_AlignTarget
        MCK_VReg_320, // AV_LdSt_320_Align1
        MCK_VReg_320_Align2, // AV_LdSt_320_Align2
        MCK_VReg_320, // AV_LdSt_320_AlignTarget
        MCK_VReg_352, // AV_LdSt_352_Align1
        MCK_VReg_352_Align2, // AV_LdSt_352_Align2
        MCK_VReg_352, // AV_LdSt_352_AlignTarget
        MCK_VReg_384, // AV_LdSt_384_Align1
        MCK_VReg_384_Align2, // AV_LdSt_384_Align2
        MCK_VReg_384, // AV_LdSt_384_AlignTarget
        MCK_VReg_512, // AV_LdSt_512_Align1
        MCK_VReg_512_Align2, // AV_LdSt_512_Align2
        MCK_VReg_512, // AV_LdSt_512_AlignTarget
        MCK_VReg_1024, // AV_LdSt_1024_Align1
        MCK_VReg_1024_Align2, // AV_LdSt_1024_Align2
        MCK_VReg_1024, // AV_LdSt_1024_AlignTarget
        MCK_SReg_64, // SReg_1
        MCK_SReg_64_XEXEC, // SReg_1_XEXEC
        MCK_VReg_64, // VReg_64_AlignTarget
        MCK_VReg_96, // VReg_96_AlignTarget
        MCK_VReg_128, // VReg_128_AlignTarget
        MCK_VReg_160, // VReg_160_AlignTarget
        MCK_VReg_192, // VReg_192_AlignTarget
        MCK_VReg_224, // VReg_224_AlignTarget
        MCK_VReg_256, // VReg_256_AlignTarget
        MCK_VReg_288, // VReg_288_AlignTarget
        MCK_VReg_320, // VReg_320_AlignTarget
        MCK_VReg_352, // VReg_352_AlignTarget
        MCK_VReg_384, // VReg_384_AlignTarget
        MCK_VReg_512, // VReg_512_AlignTarget
        MCK_VReg_1024, // VReg_1024_AlignTarget
        MCK_VS_64, // VS_64_AlignTarget
      },
      { // AVAlign2LoadStoreMode
        MCK_AReg_64_Align2, // AReg_64_AlignTarget
        MCK_AReg_96_Align2, // AReg_96_AlignTarget
        MCK_AReg_128_Align2, // AReg_128_AlignTarget
        MCK_AReg_160_Align2, // AReg_160_AlignTarget
        MCK_AReg_192_Align2, // AReg_192_AlignTarget
        MCK_AReg_224_Align2, // AReg_224_AlignTarget
        MCK_AReg_256_Align2, // AReg_256_AlignTarget
        MCK_AReg_288_Align2, // AReg_288_AlignTarget
        MCK_AReg_320_Align2, // AReg_320_AlignTarget
        MCK_AReg_352_Align2, // AReg_352_AlignTarget
        MCK_AReg_384_Align2, // AReg_384_AlignTarget
        MCK_AReg_512_Align2, // AReg_512_AlignTarget
        MCK_AReg_1024_Align2, // AReg_1024_AlignTarget
        MCK_AV_64_Align2, // AV_64_AlignTarget
        MCK_AV_96_Align2, // AV_96_AlignTarget
        MCK_AV_128_Align2, // AV_128_AlignTarget
        MCK_AV_160_Align2, // AV_160_AlignTarget
        MCK_AV_192_Align2, // AV_192_AlignTarget
        MCK_AV_224_Align2, // AV_224_AlignTarget
        MCK_AV_256_Align2, // AV_256_AlignTarget
        MCK_AV_288_Align2, // AV_288_AlignTarget
        MCK_AV_320_Align2, // AV_320_AlignTarget
        MCK_AV_352_Align2, // AV_352_AlignTarget
        MCK_AV_384_Align2, // AV_384_AlignTarget
        MCK_AV_512_Align2, // AV_512_AlignTarget
        MCK_AV_1024_Align2, // AV_1024_AlignTarget
        MCK_AV_64_Align2, // AV_LdSt_32_Align2
        MCK_AV_32, // AV_LdSt_32_Target
        MCK_AV_64, // AV_LdSt_64_Align1
        MCK_AV_64_Align2, // AV_LdSt_64_Align2
        MCK_AV_64_Align2, // AV_LdSt_64_AlignTarget
        MCK_AV_96, // AV_LdSt_96_Align1
        MCK_AV_96_Align2, // AV_LdSt_96_Align2
        MCK_AV_96_Align2, // AV_LdSt_96_AlignTarget
        MCK_AV_128, // AV_LdSt_128_Align1
        MCK_AV_128_Align2, // AV_LdSt_128_Align2
        MCK_AV_128_Align2, // AV_LdSt_128_AlignTarget
        MCK_AV_160, // AV_LdSt_160_Align1
        MCK_AV_160_Align2, // AV_LdSt_160_Align2
        MCK_AV_160_Align2, // AV_LdSt_160_AlignTarget
        MCK_AV_192, // AV_LdSt_192_Align1
        MCK_AV_192_Align2, // AV_LdSt_192_Align2
        MCK_AV_192_Align2, // AV_LdSt_192_AlignTarget
        MCK_AV_224, // AV_LdSt_224_Align1
        MCK_AV_224_Align2, // AV_LdSt_224_Align2
        MCK_AV_224_Align2, // AV_LdSt_224_AlignTarget
        MCK_AV_256, // AV_LdSt_256_Align1
        MCK_AV_256_Align2, // AV_LdSt_256_Align2
        MCK_AV_256_Align2, // AV_LdSt_256_AlignTarget
        MCK_AV_288, // AV_LdSt_288_Align1
        MCK_AV_288_Align2, // AV_LdSt_288_Align2
        MCK_AV_288_Align2, // AV_LdSt_288_AlignTarget
        MCK_AV_320, // AV_LdSt_320_Align1
        MCK_AV_320_Align2, // AV_LdSt_320_Align2
        MCK_AV_320_Align2, // AV_LdSt_320_AlignTarget
        MCK_AV_352, // AV_LdSt_352_Align1
        MCK_AV_352_Align2, // AV_LdSt_352_Align2
        MCK_AV_352_Align2, // AV_LdSt_352_AlignTarget
        MCK_AV_384, // AV_LdSt_384_Align1
        MCK_AV_384_Align2, // AV_LdSt_384_Align2
        MCK_AV_384_Align2, // AV_LdSt_384_AlignTarget
        MCK_AV_512, // AV_LdSt_512_Align1
        MCK_AV_512_Align2, // AV_LdSt_512_Align2
        MCK_AV_512_Align2, // AV_LdSt_512_AlignTarget
        MCK_AV_1024, // AV_LdSt_1024_Align1
        MCK_AV_1024_Align2, // AV_LdSt_1024_Align2
        MCK_AV_1024_Align2, // AV_LdSt_1024_AlignTarget
        MCK_SReg_64, // SReg_1
        MCK_SReg_64_XEXEC, // SReg_1_XEXEC
        MCK_VReg_64_Align2, // VReg_64_AlignTarget
        MCK_VReg_96_Align2, // VReg_96_AlignTarget
        MCK_VReg_128_Align2, // VReg_128_AlignTarget
        MCK_VReg_160_Align2, // VReg_160_AlignTarget
        MCK_VReg_192_Align2, // VReg_192_AlignTarget
        MCK_VReg_224_Align2, // VReg_224_AlignTarget
        MCK_VReg_256_Align2, // VReg_256_AlignTarget
        MCK_VReg_288_Align2, // VReg_288_AlignTarget
        MCK_VReg_320_Align2, // VReg_320_AlignTarget
        MCK_VReg_352_Align2, // VReg_352_AlignTarget
        MCK_VReg_384_Align2, // VReg_384_AlignTarget
        MCK_VReg_512_Align2, // VReg_512_AlignTarget
        MCK_VReg_1024_Align2, // VReg_1024_AlignTarget
        MCK_VS_64_Align2, // VS_64_AlignTarget
      },
      { // AlignedVGPRNoAGPRMode_Wave32
        InvalidMatchClass, // Missing mode entry for AReg_64_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_96_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_128_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_160_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_192_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_224_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_256_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_288_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_320_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_352_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_384_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_512_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_1024_AlignTarget
        MCK_VReg_64_Align2, // AV_64_AlignTarget
        MCK_VReg_96_Align2, // AV_96_AlignTarget
        MCK_VReg_128_Align2, // AV_128_AlignTarget
        MCK_VReg_160_Align2, // AV_160_AlignTarget
        MCK_VReg_192_Align2, // AV_192_AlignTarget
        MCK_VReg_224_Align2, // AV_224_AlignTarget
        MCK_VReg_256_Align2, // AV_256_AlignTarget
        MCK_VReg_288_Align2, // AV_288_AlignTarget
        MCK_VReg_320_Align2, // AV_320_AlignTarget
        MCK_VReg_352_Align2, // AV_352_AlignTarget
        MCK_VReg_384_Align2, // AV_384_AlignTarget
        MCK_VReg_512_Align2, // AV_512_AlignTarget
        MCK_VReg_1024_Align2, // AV_1024_AlignTarget
        MCK_VReg_64_Align2, // AV_LdSt_32_Align2
        MCK_VGPR_32, // AV_LdSt_32_Target
        MCK_VReg_64, // AV_LdSt_64_Align1
        MCK_VReg_64_Align2, // AV_LdSt_64_Align2
        MCK_VReg_64_Align2, // AV_LdSt_64_AlignTarget
        MCK_VReg_96, // AV_LdSt_96_Align1
        MCK_VReg_96_Align2, // AV_LdSt_96_Align2
        MCK_VReg_96_Align2, // AV_LdSt_96_AlignTarget
        MCK_VReg_128, // AV_LdSt_128_Align1
        MCK_VReg_128_Align2, // AV_LdSt_128_Align2
        MCK_VReg_128_Align2, // AV_LdSt_128_AlignTarget
        MCK_VReg_160, // AV_LdSt_160_Align1
        MCK_VReg_160_Align2, // AV_LdSt_160_Align2
        MCK_VReg_160_Align2, // AV_LdSt_160_AlignTarget
        MCK_VReg_192, // AV_LdSt_192_Align1
        MCK_VReg_192_Align2, // AV_LdSt_192_Align2
        MCK_VReg_192_Align2, // AV_LdSt_192_AlignTarget
        MCK_VReg_224, // AV_LdSt_224_Align1
        MCK_VReg_224_Align2, // AV_LdSt_224_Align2
        MCK_VReg_224_Align2, // AV_LdSt_224_AlignTarget
        MCK_VReg_256, // AV_LdSt_256_Align1
        MCK_VReg_256_Align2, // AV_LdSt_256_Align2
        MCK_VReg_256_Align2, // AV_LdSt_256_AlignTarget
        MCK_VReg_288, // AV_LdSt_288_Align1
        MCK_VReg_288_Align2, // AV_LdSt_288_Align2
        MCK_VReg_288_Align2, // AV_LdSt_288_AlignTarget
        MCK_VReg_320, // AV_LdSt_320_Align1
        MCK_VReg_320_Align2, // AV_LdSt_320_Align2
        MCK_VReg_320_Align2, // AV_LdSt_320_AlignTarget
        MCK_VReg_352, // AV_LdSt_352_Align1
        MCK_VReg_352_Align2, // AV_LdSt_352_Align2
        MCK_VReg_352_Align2, // AV_LdSt_352_AlignTarget
        MCK_VReg_384, // AV_LdSt_384_Align1
        MCK_VReg_384_Align2, // AV_LdSt_384_Align2
        MCK_VReg_384_Align2, // AV_LdSt_384_AlignTarget
        MCK_VReg_512, // AV_LdSt_512_Align1
        MCK_VReg_512_Align2, // AV_LdSt_512_Align2
        MCK_VReg_512_Align2, // AV_LdSt_512_AlignTarget
        MCK_VReg_1024, // AV_LdSt_1024_Align1
        MCK_VReg_1024_Align2, // AV_LdSt_1024_Align2
        MCK_VReg_1024_Align2, // AV_LdSt_1024_AlignTarget
        MCK_SReg_32, // SReg_1
        MCK_SReg_32_XM0_XEXEC, // SReg_1_XEXEC
        MCK_VReg_64_Align2, // VReg_64_AlignTarget
        MCK_VReg_96_Align2, // VReg_96_AlignTarget
        MCK_VReg_128_Align2, // VReg_128_AlignTarget
        MCK_VReg_160_Align2, // VReg_160_AlignTarget
        MCK_VReg_192_Align2, // VReg_192_AlignTarget
        MCK_VReg_224_Align2, // VReg_224_AlignTarget
        MCK_VReg_256_Align2, // VReg_256_AlignTarget
        MCK_VReg_288_Align2, // VReg_288_AlignTarget
        MCK_VReg_320_Align2, // VReg_320_AlignTarget
        MCK_VReg_352_Align2, // VReg_352_AlignTarget
        MCK_VReg_384_Align2, // VReg_384_AlignTarget
        MCK_VReg_512_Align2, // VReg_512_AlignTarget
        MCK_VReg_1024_Align2, // VReg_1024_AlignTarget
        MCK_VS_64_Align2, // VS_64_AlignTarget
      },
      { // AlignedVGPRNoAGPRMode_Wave64
        InvalidMatchClass, // Missing mode entry for AReg_64_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_96_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_128_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_160_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_192_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_224_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_256_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_288_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_320_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_352_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_384_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_512_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_1024_AlignTarget
        MCK_VReg_64_Align2, // AV_64_AlignTarget
        MCK_VReg_96_Align2, // AV_96_AlignTarget
        MCK_VReg_128_Align2, // AV_128_AlignTarget
        MCK_VReg_160_Align2, // AV_160_AlignTarget
        MCK_VReg_192_Align2, // AV_192_AlignTarget
        MCK_VReg_224_Align2, // AV_224_AlignTarget
        MCK_VReg_256_Align2, // AV_256_AlignTarget
        MCK_VReg_288_Align2, // AV_288_AlignTarget
        MCK_VReg_320_Align2, // AV_320_AlignTarget
        MCK_VReg_352_Align2, // AV_352_AlignTarget
        MCK_VReg_384_Align2, // AV_384_AlignTarget
        MCK_VReg_512_Align2, // AV_512_AlignTarget
        MCK_VReg_1024_Align2, // AV_1024_AlignTarget
        MCK_VReg_64_Align2, // AV_LdSt_32_Align2
        MCK_VGPR_32, // AV_LdSt_32_Target
        MCK_VReg_64, // AV_LdSt_64_Align1
        MCK_VReg_64_Align2, // AV_LdSt_64_Align2
        MCK_VReg_64_Align2, // AV_LdSt_64_AlignTarget
        MCK_VReg_96, // AV_LdSt_96_Align1
        MCK_VReg_96_Align2, // AV_LdSt_96_Align2
        MCK_VReg_96_Align2, // AV_LdSt_96_AlignTarget
        MCK_VReg_128, // AV_LdSt_128_Align1
        MCK_VReg_128_Align2, // AV_LdSt_128_Align2
        MCK_VReg_128_Align2, // AV_LdSt_128_AlignTarget
        MCK_VReg_160, // AV_LdSt_160_Align1
        MCK_VReg_160_Align2, // AV_LdSt_160_Align2
        MCK_VReg_160_Align2, // AV_LdSt_160_AlignTarget
        MCK_VReg_192, // AV_LdSt_192_Align1
        MCK_VReg_192_Align2, // AV_LdSt_192_Align2
        MCK_VReg_192_Align2, // AV_LdSt_192_AlignTarget
        MCK_VReg_224, // AV_LdSt_224_Align1
        MCK_VReg_224_Align2, // AV_LdSt_224_Align2
        MCK_VReg_224_Align2, // AV_LdSt_224_AlignTarget
        MCK_VReg_256, // AV_LdSt_256_Align1
        MCK_VReg_256_Align2, // AV_LdSt_256_Align2
        MCK_VReg_256_Align2, // AV_LdSt_256_AlignTarget
        MCK_VReg_288, // AV_LdSt_288_Align1
        MCK_VReg_288_Align2, // AV_LdSt_288_Align2
        MCK_VReg_288_Align2, // AV_LdSt_288_AlignTarget
        MCK_VReg_320, // AV_LdSt_320_Align1
        MCK_VReg_320_Align2, // AV_LdSt_320_Align2
        MCK_VReg_320_Align2, // AV_LdSt_320_AlignTarget
        MCK_VReg_352, // AV_LdSt_352_Align1
        MCK_VReg_352_Align2, // AV_LdSt_352_Align2
        MCK_VReg_352_Align2, // AV_LdSt_352_AlignTarget
        MCK_VReg_384, // AV_LdSt_384_Align1
        MCK_VReg_384_Align2, // AV_LdSt_384_Align2
        MCK_VReg_384_Align2, // AV_LdSt_384_AlignTarget
        MCK_VReg_512, // AV_LdSt_512_Align1
        MCK_VReg_512_Align2, // AV_LdSt_512_Align2
        MCK_VReg_512_Align2, // AV_LdSt_512_AlignTarget
        MCK_VReg_1024, // AV_LdSt_1024_Align1
        MCK_VReg_1024_Align2, // AV_LdSt_1024_Align2
        MCK_VReg_1024_Align2, // AV_LdSt_1024_AlignTarget
        MCK_SReg_64, // SReg_1
        MCK_SReg_64_XEXEC, // SReg_1_XEXEC
        MCK_VReg_64_Align2, // VReg_64_AlignTarget
        MCK_VReg_96_Align2, // VReg_96_AlignTarget
        MCK_VReg_128_Align2, // VReg_128_AlignTarget
        MCK_VReg_160_Align2, // VReg_160_AlignTarget
        MCK_VReg_192_Align2, // VReg_192_AlignTarget
        MCK_VReg_224_Align2, // VReg_224_AlignTarget
        MCK_VReg_256_Align2, // VReg_256_AlignTarget
        MCK_VReg_288_Align2, // VReg_288_AlignTarget
        MCK_VReg_320_Align2, // VReg_320_AlignTarget
        MCK_VReg_352_Align2, // VReg_352_AlignTarget
        MCK_VReg_384_Align2, // VReg_384_AlignTarget
        MCK_VReg_512_Align2, // VReg_512_AlignTarget
        MCK_VReg_1024_Align2, // VReg_1024_AlignTarget
        MCK_VS_64_Align2, // VS_64_AlignTarget
      },
      { // anonymous_14459
        InvalidMatchClass, // Missing mode entry for AReg_64_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_96_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_128_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_160_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_192_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_224_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_256_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_288_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_320_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_352_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_384_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_512_AlignTarget
        InvalidMatchClass, // Missing mode entry for AReg_1024_AlignTarget
        MCK_AV_64, // AV_64_AlignTarget
        MCK_AV_96, // AV_96_AlignTarget
        MCK_AV_128, // AV_128_AlignTarget
        MCK_AV_160, // AV_160_AlignTarget
        MCK_AV_192, // AV_192_AlignTarget
        MCK_AV_224, // AV_224_AlignTarget
        MCK_AV_256, // AV_256_AlignTarget
        MCK_AV_288, // AV_288_AlignTarget
        MCK_AV_320, // AV_320_AlignTarget
        MCK_AV_352, // AV_352_AlignTarget
        MCK_AV_384, // AV_384_AlignTarget
        MCK_AV_512, // AV_512_AlignTarget
        MCK_AV_1024, // AV_1024_AlignTarget
        MCK_VGPR_32, // AV_LdSt_32_Align2
        MCK_VGPR_32, // AV_LdSt_32_Target
        MCK_VReg_64, // AV_LdSt_64_Align1
        MCK_VReg_64_Align2, // AV_LdSt_64_Align2
        MCK_VReg_64, // AV_LdSt_64_AlignTarget
        MCK_VReg_96, // AV_LdSt_96_Align1
        MCK_VReg_96_Align2, // AV_LdSt_96_Align2
        MCK_VReg_96, // AV_LdSt_96_AlignTarget
        MCK_VReg_128, // AV_LdSt_128_Align1
        MCK_VReg_128_Align2, // AV_LdSt_128_Align2
        MCK_VReg_128, // AV_LdSt_128_AlignTarget
        MCK_VReg_160, // AV_LdSt_160_Align1
        MCK_VReg_160_Align2, // AV_LdSt_160_Align2
        MCK_VReg_160, // AV_LdSt_160_AlignTarget
        MCK_VReg_192, // AV_LdSt_192_Align1
        MCK_VReg_192_Align2, // AV_LdSt_192_Align2
        MCK_VReg_192, // AV_LdSt_192_AlignTarget
        MCK_VReg_224, // AV_LdSt_224_Align1
        MCK_VReg_224_Align2, // AV_LdSt_224_Align2
        MCK_VReg_224, // AV_LdSt_224_AlignTarget
        MCK_VReg_256, // AV_LdSt_256_Align1
        MCK_VReg_256_Align2, // AV_LdSt_256_Align2
        MCK_VReg_256, // AV_LdSt_256_AlignTarget
        MCK_VReg_288, // AV_LdSt_288_Align1
        MCK_VReg_288_Align2, // AV_LdSt_288_Align2
        MCK_VReg_288, // AV_LdSt_288_AlignTarget
        MCK_VReg_320, // AV_LdSt_320_Align1
        MCK_VReg_320_Align2, // AV_LdSt_320_Align2
        MCK_VReg_320, // AV_LdSt_320_AlignTarget
        MCK_VReg_352, // AV_LdSt_352_Align1
        MCK_VReg_352_Align2, // AV_LdSt_352_Align2
        MCK_VReg_352, // AV_LdSt_352_AlignTarget
        MCK_VReg_384, // AV_LdSt_384_Align1
        MCK_VReg_384_Align2, // AV_LdSt_384_Align2
        MCK_VReg_384, // AV_LdSt_384_AlignTarget
        MCK_VReg_512, // AV_LdSt_512_Align1
        MCK_VReg_512_Align2, // AV_LdSt_512_Align2
        MCK_VReg_512, // AV_LdSt_512_AlignTarget
        MCK_VReg_1024, // AV_LdSt_1024_Align1
        MCK_VReg_1024_Align2, // AV_LdSt_1024_Align2
        MCK_VReg_1024, // AV_LdSt_1024_AlignTarget
        MCK_SReg_32, // SReg_1
        MCK_SReg_32_XM0_XEXEC, // SReg_1_XEXEC
        MCK_VReg_64, // VReg_64_AlignTarget
        MCK_VReg_96, // VReg_96_AlignTarget
        MCK_VReg_128, // VReg_128_AlignTarget
        MCK_VReg_160, // VReg_160_AlignTarget
        MCK_VReg_192, // VReg_192_AlignTarget
        MCK_VReg_224, // VReg_224_AlignTarget
        MCK_VReg_256, // VReg_256_AlignTarget
        MCK_VReg_288, // VReg_288_AlignTarget
        MCK_VReg_320, // VReg_320_AlignTarget
        MCK_VReg_352, // VReg_352_AlignTarget
        MCK_VReg_384, // VReg_384_AlignTarget
        MCK_VReg_512, // VReg_512_AlignTarget
        MCK_VReg_1024, // VReg_1024_AlignTarget
        MCK_VS_64, // VS_64_AlignTarget
      },
    };

    static_assert(MCK_LAST_REGCLASS_BY_HWMODE - MCK_LAST_REGISTER == 83);
    const unsigned HwMode = STI.getHwMode(MCSubtargetInfo::HwMode_RegInfo);
Kind = RegClassByHwModeMatchTable[HwMode][Kind - (MCK_LAST_REGISTER + 1)];
  }

  if (Operand.isReg()) {
    static constexpr uint16_t Table[AMDGPU::NUM_TARGET_REGS] = {
      InvalidMatchClass,
      InvalidMatchClass,
      MCK_SReg_64,
      MCK_SReg_32_XM0,
      MCK_Reg15,
      MCK_SReg_64_XEXEC_XNULL,
      MCK_SReg_32_XM0_XEXEC,
      InvalidMatchClass,
      InvalidMatchClass,
      MCK_SReg_32_XM0_XEXEC,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      MCK_Pseudo_SReg_32,
      MCK_Reg43,
      InvalidMatchClass,
      InvalidMatchClass,
      MCK_Pseudo_SReg_128,
      MCK_SCC_CLASS,
      MCK_SReg_32_XM0_XEXEC,
      MCK_SReg_32_XM0_XEXEC,
      MCK_Pseudo_SReg_32,
      MCK_SReg_32_XM0_XEXEC,
      MCK_SReg_64_XEXEC_XNULL,
      MCK_SReg_32_XM0_XEXEC,
      MCK_SReg_32_XM0_XEXEC,
      MCK_SReg_32_XM0_XEXEC,
      MCK_APERTURE_Class,
      MCK_SReg_32_XM0_XEXEC,
      MCK_APERTURE_Class,
      MCK_SReg_32_XM0_XEXEC,
      MCK_SReg_32_XM0_XEXEC,
      MCK_APERTURE_Class,
      MCK_SReg_32_XM0_XEXEC,
      MCK_APERTURE_Class,
      MCK_SReg_32_XM0_XEXEC,
      MCK_SReg_32_XM0_XEXEC,
      MCK_SReg_64_XEXEC_XNULL,
      MCK_SReg_32_XM0_XEXEC,
      MCK_SReg_32_XM0_XEXEC,
      InvalidMatchClass,
      MCK_SReg_64_XEXEC_XNULL,
      MCK_SReg_32_XM0_XEXEC,
      MCK_SReg_32_XM0_XEXEC,
      MCK_VCC,
      MCK_SReg_32_XM0_XEXEC,
      MCK_VCC_LO,
      MCK_SReg_64_XEXEC_XNULL,
      MCK_SReg_32_XM0_XEXEC,
      MCK_SReg_32_XM0_XEXEC,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      MCK_AGPR_32,
      InvalidMatchClass,
      MCK_SReg_LO16,
      InvalidMatchClass,
      MCK_SReg_LO16,
      InvalidMatchClass,
      MCK_SReg_LO16,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      MCK_SReg_LO16,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      MCK_M0,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SGPR_32,
      MCK_SReg_64_XEXEC,
      MCK_SReg_128,
      MCK_SReg_256,
      InvalidMatchClass,
      InvalidMatchClass,
      MCK_SReg_LO16,
      MCK_SReg_LO16,
      InvalidMatchClass,
      InvalidMatchClass,
      MCK_SReg_LO16,
      InvalidMatchClass,
      MCK_SReg_LO16,
      InvalidMatchClass,
      MCK_SReg_LO16,
      InvalidMatchClass,
      MCK_SReg_LO16,
      InvalidMatchClass,
      MCK_SReg_LO16,
      InvalidMatchClass,
      MCK_SReg_LO16,
      InvalidMatchClass,
      MCK_SReg_LO16,
      InvalidMatchClass,
      MCK_SReg_LO16,
      InvalidMatchClass,
      MCK_SReg_LO16,
      InvalidMatchClass,
      MCK_SReg_LO16,
      InvalidMatchClass,
      MCK_SReg_LO16,
      InvalidMatchClass,
      MCK_SReg_LO16,
      InvalidMatchClass,
      MCK_SReg_LO16,
      InvalidMatchClass,
      MCK_SReg_LO16,
      MCK_TTMP_32,
      MCK_TTMP_32,
      MCK_TTMP_32,
      MCK_TTMP_32,
      MCK_TTMP_32,
      MCK_TTMP_32,
      MCK_TTMP_32,
      MCK_TTMP_32,
      MCK_TTMP_32,
      MCK_TTMP_32,
      MCK_TTMP_32,
      MCK_TTMP_32,
      MCK_TTMP_32,
      MCK_TTMP_32,
      MCK_TTMP_32,
      MCK_TTMP_32,
      InvalidMatchClass,
      MCK_SReg_LO16,
      InvalidMatchClass,
      MCK_SReg_LO16,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo128,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32_Lo256,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      MCK_VGPR_32,
      InvalidMatchClass,
      MCK_SReg_LO16,
      InvalidMatchClass,
      MCK_SReg_LO16,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      MCK_AGPR_LO16,
      InvalidMatchClass,
      MCK_SReg_LO16,
      InvalidMatchClass,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_HI16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      MCK_SGPR_LO16,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      MCK_TTMP_LO16,
      MCK_TTMP_LO16,
      MCK_TTMP_LO16,
      MCK_TTMP_LO16,
      MCK_TTMP_LO16,
      MCK_TTMP_LO16,
      MCK_TTMP_LO16,
      MCK_TTMP_LO16,
      MCK_TTMP_LO16,
      MCK_TTMP_LO16,
      MCK_TTMP_LO16,
      MCK_TTMP_LO16,
      MCK_TTMP_LO16,
      MCK_TTMP_LO16,
      MCK_TTMP_LO16,
      MCK_TTMP_LO16,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16_Lo128,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      MCK_VGPR_16,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      InvalidMatchClass,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_64,
      MCK_AReg_64_Align2,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_96_Align2,
      MCK_Reg72,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_Reg78,
      MCK_AReg_128_Align2,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_160_Align2,
      MCK_Reg84,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_Reg90,
      MCK_AReg_192_Align2,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_224_Align2,
      MCK_Reg96,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_Reg102,
      MCK_AReg_256_Align2,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_288_Align2,
      MCK_Reg108,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_Reg114,
      MCK_AReg_320_Align2,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_352_Align2,
      MCK_Reg120,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_Reg126,
      MCK_AReg_384_Align2,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_Reg132,
      MCK_AReg_512_Align2,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_Reg138,
      MCK_AReg_1024_Align2,
      MCK_CCR_SGPR_64,
      MCK_CCR_SGPR_64,
      MCK_CCR_SGPR_64,
      MCK_CCR_SGPR_64,
      MCK_CCR_SGPR_64,
      MCK_CCR_SGPR_64,
      MCK_CCR_SGPR_64,
      MCK_CCR_SGPR_64,
      MCK_CCR_SGPR_64,
      MCK_CCR_SGPR_64,
      MCK_CCR_SGPR_64,
      MCK_CCR_SGPR_64,
      MCK_CCR_SGPR_64,
      MCK_CCR_SGPR_64,
      MCK_CCR_SGPR_64,
      MCK_SGPR_64,
      MCK_SGPR_64,
      MCK_SGPR_64,
      MCK_Gfx_CCR_SGPR_64,
      MCK_Gfx_CCR_SGPR_64,
      MCK_Gfx_CCR_SGPR_64,
      MCK_Gfx_CCR_SGPR_64,
      MCK_Gfx_CCR_SGPR_64,
      MCK_Gfx_CCR_SGPR_64,
      MCK_Gfx_CCR_SGPR_64,
      MCK_Gfx_CCR_SGPR_64,
      MCK_Gfx_CCR_SGPR_64,
      MCK_Gfx_CCR_SGPR_64,
      MCK_Gfx_CCR_SGPR_64,
      MCK_Gfx_CCR_SGPR_64,
      MCK_Gfx_CCR_SGPR_64,
      MCK_Gfx_CCR_SGPR_64,
      MCK_SGPR_64,
      MCK_SGPR_64,
      MCK_SGPR_64,
      MCK_SGPR_64,
      MCK_SGPR_64,
      MCK_SGPR_64,
      MCK_SGPR_64,
      MCK_SGPR_64,
      MCK_SGPR_64,
      MCK_SGPR_64,
      MCK_SGPR_64,
      MCK_SGPR_64,
      MCK_SGPR_64,
      MCK_SGPR_64,
      MCK_SGPR_64,
      MCK_SGPR_64,
      MCK_SGPR_64,
      MCK_SGPR_64,
      MCK_SGPR_64,
      MCK_SGPR_64,
      MCK_SGPR_64,
      MCK_Reg143,
      MCK_Reg143,
      MCK_Reg143,
      MCK_Reg143,
      MCK_Reg143,
      MCK_Reg143,
      MCK_Reg143,
      MCK_Reg143,
      MCK_SGPR_96,
      MCK_Reg146,
      MCK_Reg146,
      MCK_Reg146,
      MCK_Reg146,
      MCK_Reg146,
      MCK_Reg146,
      MCK_Reg146,
      MCK_SGPR_96,
      MCK_SGPR_96,
      MCK_SGPR_96,
      MCK_SGPR_96,
      MCK_SGPR_96,
      MCK_SGPR_96,
      MCK_SGPR_96,
      MCK_SGPR_96,
      MCK_SGPR_96,
      MCK_SGPR_96,
      MCK_Reg147,
      MCK_Reg147,
      MCK_Reg147,
      MCK_Reg147,
      MCK_Reg147,
      MCK_Reg147,
      MCK_Reg147,
      MCK_Reg148,
      MCK_SGPR_128,
      MCK_Reg165,
      MCK_Reg165,
      MCK_Reg165,
      MCK_Reg165,
      MCK_Reg165,
      MCK_Reg165,
      MCK_Reg165,
      MCK_SGPR_128,
      MCK_SGPR_128,
      MCK_SGPR_128,
      MCK_SGPR_128,
      MCK_SGPR_128,
      MCK_SGPR_128,
      MCK_SGPR_128,
      MCK_SGPR_128,
      MCK_SGPR_128,
      MCK_SGPR_128,
      MCK_Reg166,
      MCK_Reg166,
      MCK_Reg166,
      MCK_Reg166,
      MCK_Reg166,
      MCK_Reg166,
      MCK_Reg166,
      MCK_Reg167,
      MCK_SGPR_160,
      MCK_Reg170,
      MCK_Reg170,
      MCK_Reg170,
      MCK_Reg170,
      MCK_Reg170,
      MCK_Reg170,
      MCK_Reg170,
      MCK_SGPR_160,
      MCK_SGPR_160,
      MCK_SGPR_160,
      MCK_SGPR_160,
      MCK_SGPR_160,
      MCK_SGPR_160,
      MCK_SGPR_160,
      MCK_SGPR_160,
      MCK_SGPR_160,
      MCK_SGPR_160,
      MCK_Reg171,
      MCK_Reg171,
      MCK_Reg171,
      MCK_Reg171,
      MCK_Reg171,
      MCK_Reg171,
      MCK_Reg171,
      MCK_Reg172,
      MCK_Reg175,
      MCK_Reg176,
      MCK_Reg176,
      MCK_Reg176,
      MCK_Reg176,
      MCK_Reg176,
      MCK_Reg176,
      MCK_Reg177,
      MCK_SGPR_192,
      MCK_SGPR_192,
      MCK_SGPR_192,
      MCK_SGPR_192,
      MCK_SGPR_192,
      MCK_SGPR_192,
      MCK_SGPR_192,
      MCK_SGPR_192,
      MCK_SGPR_192,
      MCK_SGPR_192,
      MCK_Reg178,
      MCK_Reg178,
      MCK_Reg178,
      MCK_Reg178,
      MCK_Reg178,
      MCK_Reg178,
      MCK_Reg178,
      MCK_Reg179,
      MCK_Reg182,
      MCK_Reg183,
      MCK_Reg183,
      MCK_Reg183,
      MCK_Reg183,
      MCK_Reg183,
      MCK_Reg183,
      MCK_Reg184,
      MCK_SGPR_224,
      MCK_SGPR_224,
      MCK_SGPR_224,
      MCK_SGPR_224,
      MCK_SGPR_224,
      MCK_SGPR_224,
      MCK_SGPR_224,
      MCK_SGPR_224,
      MCK_SGPR_224,
      MCK_Reg185,
      MCK_Reg185,
      MCK_Reg185,
      MCK_Reg185,
      MCK_Reg185,
      MCK_Reg185,
      MCK_Reg186,
      MCK_Reg187,
      MCK_Reg190,
      MCK_Reg191,
      MCK_Reg191,
      MCK_Reg191,
      MCK_Reg191,
      MCK_Reg191,
      MCK_Reg191,
      MCK_Reg192,
      MCK_SGPR_256,
      MCK_SGPR_256,
      MCK_SGPR_256,
      MCK_SGPR_256,
      MCK_SGPR_256,
      MCK_SGPR_256,
      MCK_SGPR_256,
      MCK_SGPR_256,
      MCK_SGPR_256,
      MCK_Reg193,
      MCK_Reg193,
      MCK_Reg193,
      MCK_Reg193,
      MCK_Reg193,
      MCK_Reg193,
      MCK_Reg194,
      MCK_Reg195,
      MCK_Reg198,
      MCK_Reg199,
      MCK_Reg199,
      MCK_Reg199,
      MCK_Reg199,
      MCK_Reg199,
      MCK_Reg199,
      MCK_Reg200,
      MCK_SGPR_288,
      MCK_SGPR_288,
      MCK_SGPR_288,
      MCK_SGPR_288,
      MCK_SGPR_288,
      MCK_SGPR_288,
      MCK_SGPR_288,
      MCK_SGPR_288,
      MCK_SGPR_288,
      MCK_Reg201,
      MCK_Reg201,
      MCK_Reg201,
      MCK_Reg201,
      MCK_Reg201,
      MCK_Reg201,
      MCK_Reg202,
      MCK_Reg206,
      MCK_Reg208,
      MCK_Reg210,
      MCK_Reg210,
      MCK_Reg210,
      MCK_Reg210,
      MCK_Reg210,
      MCK_Reg211,
      MCK_Reg212,
      MCK_SGPR_320,
      MCK_SGPR_320,
      MCK_SGPR_320,
      MCK_SGPR_320,
      MCK_SGPR_320,
      MCK_SGPR_320,
      MCK_SGPR_320,
      MCK_SGPR_320,
      MCK_SGPR_320,
      MCK_Reg213,
      MCK_Reg213,
      MCK_Reg213,
      MCK_Reg213,
      MCK_Reg213,
      MCK_Reg213,
      MCK_Reg214,
      MCK_Reg218,
      MCK_Reg220,
      MCK_Reg222,
      MCK_Reg222,
      MCK_Reg222,
      MCK_Reg222,
      MCK_Reg222,
      MCK_Reg223,
      MCK_Reg224,
      MCK_SGPR_352,
      MCK_SGPR_352,
      MCK_SGPR_352,
      MCK_SGPR_352,
      MCK_SGPR_352,
      MCK_SGPR_352,
      MCK_SGPR_352,
      MCK_SGPR_352,
      MCK_Reg225,
      MCK_Reg225,
      MCK_Reg225,
      MCK_Reg225,
      MCK_Reg225,
      MCK_Reg226,
      MCK_Reg227,
      MCK_Reg231,
      MCK_Reg233,
      MCK_Reg235,
      MCK_Reg235,
      MCK_Reg235,
      MCK_Reg235,
      MCK_Reg235,
      MCK_Reg236,
      MCK_Reg237,
      MCK_SGPR_384,
      MCK_SGPR_384,
      MCK_SGPR_384,
      MCK_SGPR_384,
      MCK_SGPR_384,
      MCK_SGPR_384,
      MCK_SGPR_384,
      MCK_SGPR_384,
      MCK_Reg238,
      MCK_Reg238,
      MCK_Reg238,
      MCK_Reg238,
      MCK_Reg239,
      MCK_Reg240,
      MCK_Reg245,
      MCK_Reg248,
      MCK_Reg251,
      MCK_Reg254,
      MCK_Reg254,
      MCK_Reg254,
      MCK_Reg254,
      MCK_Reg255,
      MCK_Reg256,
      MCK_Reg257,
      MCK_SGPR_512,
      MCK_SGPR_512,
      MCK_SGPR_512,
      MCK_SGPR_512,
      MCK_SGPR_512,
      MCK_SGPR_512,
      MCK_SGPR_512,
      MCK_Reg258,
      MCK_Reg259,
      MCK_Reg267,
      MCK_Reg274,
      MCK_Reg281,
      MCK_Reg288,
      MCK_Reg295,
      MCK_Reg302,
      MCK_Reg309,
      MCK_Reg316,
      MCK_Reg317,
      MCK_Reg318,
      MCK_Reg319,
      MCK_Reg320,
      MCK_Reg321,
      MCK_Reg322,
      MCK_SGPR_1024,
      MCK_SGPR_1024,
      MCK_SGPR_1024,
      MCK_TTMP_64,
      MCK_TTMP_64,
      MCK_TTMP_64,
      MCK_TTMP_64,
      MCK_TTMP_64,
      MCK_TTMP_64,
      MCK_TTMP_64,
      MCK_TTMP_64,
      MCK_TTMP_96,
      MCK_TTMP_96,
      MCK_TTMP_96,
      MCK_TTMP_96,
      MCK_TTMP_128,
      MCK_TTMP_128,
      MCK_TTMP_128,
      MCK_TTMP_128,
      MCK_TTMP_160,
      MCK_TTMP_160,
      MCK_TTMP_160,
      MCK_TTMP_192,
      MCK_TTMP_192,
      MCK_TTMP_192,
      MCK_TTMP_224,
      MCK_TTMP_224,
      MCK_TTMP_224,
      MCK_TTMP_256,
      MCK_TTMP_256,
      MCK_TTMP_256,
      MCK_TTMP_288,
      MCK_TTMP_288,
      MCK_TTMP_320,
      MCK_TTMP_320,
      MCK_TTMP_352,
      MCK_TTMP_352,
      MCK_TTMP_384,
      MCK_TTMP_384,
      MCK_TTMP_512,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg335,
      MCK_Reg340,
      MCK_Reg336,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg337,
      MCK_VReg_64_Lo256_Align2,
      MCK_Reg338,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_VReg_64,
      MCK_VReg_64_Align2,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg350,
      MCK_Reg355,
      MCK_Reg351,
      MCK_Reg356,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_VReg_96_Lo256_Align2,
      MCK_Reg357,
      MCK_Reg353,
      MCK_Reg358,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_VReg_96_Align2,
      MCK_Reg359,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg374,
      MCK_Reg369,
      MCK_Reg375,
      MCK_Reg370,
      MCK_Reg376,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg377,
      MCK_VReg_128_Lo256_Align2,
      MCK_Reg378,
      MCK_Reg372,
      MCK_Reg379,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg380,
      MCK_VReg_128_Align2,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg392,
      MCK_Reg399,
      MCK_Reg393,
      MCK_Reg400,
      MCK_Reg394,
      MCK_Reg401,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_VReg_160_Lo256_Align2,
      MCK_Reg402,
      MCK_Reg396,
      MCK_Reg403,
      MCK_Reg397,
      MCK_Reg404,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_VReg_160_Align2,
      MCK_Reg405,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg426,
      MCK_Reg419,
      MCK_Reg427,
      MCK_Reg420,
      MCK_Reg428,
      MCK_Reg421,
      MCK_Reg429,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg430,
      MCK_VReg_192_Lo256_Align2,
      MCK_Reg431,
      MCK_Reg423,
      MCK_Reg432,
      MCK_Reg424,
      MCK_Reg433,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg434,
      MCK_VReg_192_Align2,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg450,
      MCK_Reg459,
      MCK_Reg451,
      MCK_Reg460,
      MCK_Reg452,
      MCK_Reg461,
      MCK_Reg453,
      MCK_Reg462,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_VReg_224_Lo256_Align2,
      MCK_Reg463,
      MCK_Reg455,
      MCK_Reg464,
      MCK_Reg456,
      MCK_Reg465,
      MCK_Reg457,
      MCK_Reg466,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_VReg_224_Align2,
      MCK_Reg467,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg494,
      MCK_Reg485,
      MCK_Reg495,
      MCK_Reg486,
      MCK_Reg496,
      MCK_Reg487,
      MCK_Reg497,
      MCK_Reg488,
      MCK_Reg498,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg499,
      MCK_VReg_256_Lo256_Align2,
      MCK_Reg500,
      MCK_Reg490,
      MCK_Reg501,
      MCK_Reg491,
      MCK_Reg502,
      MCK_Reg492,
      MCK_Reg503,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg504,
      MCK_VReg_256_Align2,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg524,
      MCK_Reg535,
      MCK_Reg525,
      MCK_Reg536,
      MCK_Reg526,
      MCK_Reg537,
      MCK_Reg527,
      MCK_Reg538,
      MCK_Reg528,
      MCK_Reg539,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_VReg_288_Lo256_Align2,
      MCK_Reg540,
      MCK_Reg530,
      MCK_Reg541,
      MCK_Reg531,
      MCK_Reg542,
      MCK_Reg532,
      MCK_Reg543,
      MCK_Reg533,
      MCK_Reg544,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_VReg_288_Align2,
      MCK_Reg545,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg578,
      MCK_Reg567,
      MCK_Reg579,
      MCK_Reg568,
      MCK_Reg580,
      MCK_Reg569,
      MCK_Reg581,
      MCK_Reg570,
      MCK_Reg582,
      MCK_Reg571,
      MCK_Reg583,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg584,
      MCK_VReg_320_Lo256_Align2,
      MCK_Reg585,
      MCK_Reg573,
      MCK_Reg586,
      MCK_Reg574,
      MCK_Reg587,
      MCK_Reg575,
      MCK_Reg588,
      MCK_Reg576,
      MCK_Reg589,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg590,
      MCK_VReg_320_Align2,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg614,
      MCK_Reg627,
      MCK_Reg615,
      MCK_Reg628,
      MCK_Reg616,
      MCK_Reg629,
      MCK_Reg617,
      MCK_Reg630,
      MCK_Reg618,
      MCK_Reg631,
      MCK_Reg619,
      MCK_Reg632,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_VReg_352_Lo256_Align2,
      MCK_Reg633,
      MCK_Reg621,
      MCK_Reg634,
      MCK_Reg622,
      MCK_Reg635,
      MCK_Reg623,
      MCK_Reg636,
      MCK_Reg624,
      MCK_Reg637,
      MCK_Reg625,
      MCK_Reg638,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_VReg_352_Align2,
      MCK_Reg639,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg678,
      MCK_Reg665,
      MCK_Reg679,
      MCK_Reg666,
      MCK_Reg680,
      MCK_Reg667,
      MCK_Reg681,
      MCK_Reg668,
      MCK_Reg682,
      MCK_Reg669,
      MCK_Reg683,
      MCK_Reg670,
      MCK_Reg684,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg685,
      MCK_VReg_384_Lo256_Align2,
      MCK_Reg686,
      MCK_Reg672,
      MCK_Reg687,
      MCK_Reg673,
      MCK_Reg688,
      MCK_Reg674,
      MCK_Reg689,
      MCK_Reg675,
      MCK_Reg690,
      MCK_Reg676,
      MCK_Reg691,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg692,
      MCK_VReg_384_Align2,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg743,
      MCK_Reg726,
      MCK_Reg744,
      MCK_Reg727,
      MCK_Reg745,
      MCK_Reg728,
      MCK_Reg746,
      MCK_Reg729,
      MCK_Reg747,
      MCK_Reg730,
      MCK_Reg748,
      MCK_Reg731,
      MCK_Reg749,
      MCK_Reg732,
      MCK_Reg750,
      MCK_Reg733,
      MCK_Reg751,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg752,
      MCK_VReg_512_Lo256_Align2,
      MCK_Reg753,
      MCK_Reg735,
      MCK_Reg754,
      MCK_Reg736,
      MCK_Reg755,
      MCK_Reg737,
      MCK_Reg756,
      MCK_Reg738,
      MCK_Reg757,
      MCK_Reg739,
      MCK_Reg758,
      MCK_Reg740,
      MCK_Reg759,
      MCK_Reg741,
      MCK_Reg760,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg761,
      MCK_VReg_512_Align2,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg860,
      MCK_Reg827,
      MCK_Reg861,
      MCK_Reg828,
      MCK_Reg862,
      MCK_Reg829,
      MCK_Reg863,
      MCK_Reg830,
      MCK_Reg864,
      MCK_Reg831,
      MCK_Reg865,
      MCK_Reg832,
      MCK_Reg866,
      MCK_Reg833,
      MCK_Reg867,
      MCK_Reg834,
      MCK_Reg868,
      MCK_Reg835,
      MCK_Reg869,
      MCK_Reg836,
      MCK_Reg870,
      MCK_Reg837,
      MCK_Reg871,
      MCK_Reg838,
      MCK_Reg872,
      MCK_Reg839,
      MCK_Reg873,
      MCK_Reg840,
      MCK_Reg874,
      MCK_Reg841,
      MCK_Reg875,
      MCK_Reg842,
      MCK_Reg876,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg877,
      MCK_VReg_1024_Lo256_Align2,
      MCK_Reg878,
      MCK_Reg844,
      MCK_Reg879,
      MCK_Reg845,
      MCK_Reg880,
      MCK_Reg846,
      MCK_Reg881,
      MCK_Reg847,
      MCK_Reg882,
      MCK_Reg848,
      MCK_Reg883,
      MCK_Reg849,
      MCK_Reg884,
      MCK_Reg850,
      MCK_Reg885,
      MCK_Reg851,
      MCK_Reg886,
      MCK_Reg852,
      MCK_Reg887,
      MCK_Reg853,
      MCK_Reg888,
      MCK_Reg854,
      MCK_Reg889,
      MCK_Reg855,
      MCK_Reg890,
      MCK_Reg856,
      MCK_Reg891,
      MCK_Reg857,
      MCK_Reg892,
      MCK_Reg858,
      MCK_Reg893,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
      MCK_Reg894,
      MCK_VReg_1024_Align2,
    };

    MCRegister Reg = Operand.getReg();
    MatchClassKind OpKind = Reg.isPhysical() ? (MatchClassKind)Table[Reg.id()] : InvalidMatchClass;
    return isSubclass(OpKind, Kind) ? (unsigned)MCTargetAsmParser::Match_Success :
                                      getDiagKindFromRegisterClass(Kind);
  }

  if (Kind > MCK_LAST_TOKEN && Kind <= MCK_LAST_REGISTER)
    return getDiagKindFromRegisterClass(Kind);

  return MCTargetAsmParser::Match_InvalidOperand;
}

#ifndef NDEBUG
const char *getMatchClassName(MatchClassKind Kind) {
  switch (Kind) {
  case InvalidMatchClass: return "InvalidMatchClass";
  case OptionalMatchClass: return "OptionalMatchClass";
  case MCK__COLON__COLON_: return "MCK__COLON__COLON_";
  case MCK__91_: return "MCK__91_";
  case MCK__93_: return "MCK__93_";
  case MCK_addr64: return "MCK_addr64";
  case MCK_done: return "MCK_done";
  case MCK_gds: return "MCK_gds";
  case MCK_idxen: return "MCK_idxen";
  case MCK_lds: return "MCK_lds";
  case MCK_off: return "MCK_off";
  case MCK_offen: return "MCK_offen";
  case MCK_row_95_en: return "MCK_row_95_en";
  case MCK_tfe: return "MCK_tfe";
  case MCK_v_95_dual_95_add_95_f32: return "MCK_v_95_dual_95_add_95_f32";
  case MCK_v_95_dual_95_add_95_nc_95_u32: return "MCK_v_95_dual_95_add_95_nc_95_u32";
  case MCK_v_95_dual_95_and_95_b32: return "MCK_v_95_dual_95_and_95_b32";
  case MCK_v_95_dual_95_ashrrev_95_i32: return "MCK_v_95_dual_95_ashrrev_95_i32";
  case MCK_v_95_dual_95_bitop2_95_b32: return "MCK_v_95_dual_95_bitop2_95_b32";
  case MCK_v_95_dual_95_cndmask_95_b32: return "MCK_v_95_dual_95_cndmask_95_b32";
  case MCK_v_95_dual_95_dot2acc_95_f32_95_bf16: return "MCK_v_95_dual_95_dot2acc_95_f32_95_bf16";
  case MCK_v_95_dual_95_dot2acc_95_f32_95_f16: return "MCK_v_95_dual_95_dot2acc_95_f32_95_f16";
  case MCK_v_95_dual_95_fma_95_f32: return "MCK_v_95_dual_95_fma_95_f32";
  case MCK_v_95_dual_95_fmaak_95_f32: return "MCK_v_95_dual_95_fmaak_95_f32";
  case MCK_v_95_dual_95_fmac_95_f32: return "MCK_v_95_dual_95_fmac_95_f32";
  case MCK_v_95_dual_95_fmamk_95_f32: return "MCK_v_95_dual_95_fmamk_95_f32";
  case MCK_v_95_dual_95_lshlrev_95_b32: return "MCK_v_95_dual_95_lshlrev_95_b32";
  case MCK_v_95_dual_95_lshrrev_95_b32: return "MCK_v_95_dual_95_lshrrev_95_b32";
  case MCK_v_95_dual_95_max_95_f32: return "MCK_v_95_dual_95_max_95_f32";
  case MCK_v_95_dual_95_max_95_i32: return "MCK_v_95_dual_95_max_95_i32";
  case MCK_v_95_dual_95_max_95_num_95_f32: return "MCK_v_95_dual_95_max_95_num_95_f32";
  case MCK_v_95_dual_95_min_95_f32: return "MCK_v_95_dual_95_min_95_f32";
  case MCK_v_95_dual_95_min_95_i32: return "MCK_v_95_dual_95_min_95_i32";
  case MCK_v_95_dual_95_min_95_num_95_f32: return "MCK_v_95_dual_95_min_95_num_95_f32";
  case MCK_v_95_dual_95_mov_95_b32: return "MCK_v_95_dual_95_mov_95_b32";
  case MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32: return "MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32";
  case MCK_v_95_dual_95_mul_95_f32: return "MCK_v_95_dual_95_mul_95_f32";
  case MCK_v_95_dual_95_sub_95_f32: return "MCK_v_95_dual_95_sub_95_f32";
  case MCK_v_95_dual_95_sub_95_nc_95_u32: return "MCK_v_95_dual_95_sub_95_nc_95_u32";
  case MCK_v_95_dual_95_subrev_95_f32: return "MCK_v_95_dual_95_subrev_95_f32";
  case MCK_VReg_1: return "MCK_VReg_1";
  case MCK_Reg316: return "MCK_Reg316";
  case MCK_Reg309: return "MCK_Reg309";
  case MCK_Reg302: return "MCK_Reg302";
  case MCK_Reg295: return "MCK_Reg295";
  case MCK_Reg288: return "MCK_Reg288";
  case MCK_Reg281: return "MCK_Reg281";
  case MCK_Reg274: return "MCK_Reg274";
  case MCK_Reg267: return "MCK_Reg267";
  case MCK_Reg258: return "MCK_Reg258";
  case MCK_Reg248: return "MCK_Reg248";
  case MCK_Reg245: return "MCK_Reg245";
  case MCK_Reg231: return "MCK_Reg231";
  case MCK_Reg218: return "MCK_Reg218";
  case MCK_Reg206: return "MCK_Reg206";
  case MCK_Reg43: return "MCK_Reg43";
  case MCK_M0: return "MCK_M0";
  case MCK_Pseudo_SReg_128: return "MCK_Pseudo_SReg_128";
  case MCK_SCC_CLASS: return "MCK_SCC_CLASS";
  case MCK_TTMP_512: return "MCK_TTMP_512";
  case MCK_VCC: return "MCK_VCC";
  case MCK_VCC_LO: return "MCK_VCC_LO";
  case MCK_Reg317: return "MCK_Reg317";
  case MCK_Reg310: return "MCK_Reg310";
  case MCK_Reg303: return "MCK_Reg303";
  case MCK_Reg296: return "MCK_Reg296";
  case MCK_Reg289: return "MCK_Reg289";
  case MCK_Reg282: return "MCK_Reg282";
  case MCK_Reg275: return "MCK_Reg275";
  case MCK_Reg268: return "MCK_Reg268";
  case MCK_Reg259: return "MCK_Reg259";
  case MCK_Reg246: return "MCK_Reg246";
  case MCK_Pseudo_SReg_32: return "MCK_Pseudo_SReg_32";
  case MCK_TTMP_288: return "MCK_TTMP_288";
  case MCK_TTMP_320: return "MCK_TTMP_320";
  case MCK_TTMP_352: return "MCK_TTMP_352";
  case MCK_TTMP_384: return "MCK_TTMP_384";
  case MCK_Reg318: return "MCK_Reg318";
  case MCK_Reg311: return "MCK_Reg311";
  case MCK_Reg304: return "MCK_Reg304";
  case MCK_Reg297: return "MCK_Reg297";
  case MCK_Reg290: return "MCK_Reg290";
  case MCK_Reg283: return "MCK_Reg283";
  case MCK_Reg276: return "MCK_Reg276";
  case MCK_Reg269: return "MCK_Reg269";
  case MCK_Reg260: return "MCK_Reg260";
  case MCK_TTMP_160: return "MCK_TTMP_160";
  case MCK_TTMP_192: return "MCK_TTMP_192";
  case MCK_TTMP_224: return "MCK_TTMP_224";
  case MCK_TTMP_256: return "MCK_TTMP_256";
  case MCK_Reg319: return "MCK_Reg319";
  case MCK_Reg312: return "MCK_Reg312";
  case MCK_Reg305: return "MCK_Reg305";
  case MCK_Reg298: return "MCK_Reg298";
  case MCK_Reg291: return "MCK_Reg291";
  case MCK_Reg284: return "MCK_Reg284";
  case MCK_Reg277: return "MCK_Reg277";
  case MCK_Reg270: return "MCK_Reg270";
  case MCK_Reg261: return "MCK_Reg261";
  case MCK_Reg254: return "MCK_Reg254";
  case MCK_Reg238: return "MCK_Reg238";
  case MCK_APERTURE_Class: return "MCK_APERTURE_Class";
  case MCK_TTMP_128: return "MCK_TTMP_128";
  case MCK_TTMP_96: return "MCK_TTMP_96";
  case MCK_Reg320: return "MCK_Reg320";
  case MCK_Reg313: return "MCK_Reg313";
  case MCK_Reg306: return "MCK_Reg306";
  case MCK_Reg299: return "MCK_Reg299";
  case MCK_Reg292: return "MCK_Reg292";
  case MCK_Reg285: return "MCK_Reg285";
  case MCK_Reg278: return "MCK_Reg278";
  case MCK_Reg271: return "MCK_Reg271";
  case MCK_Reg262: return "MCK_Reg262";
  case MCK_Reg255: return "MCK_Reg255";
  case MCK_Reg251: return "MCK_Reg251";
  case MCK_Reg239: return "MCK_Reg239";
  case MCK_Reg235: return "MCK_Reg235";
  case MCK_Reg225: return "MCK_Reg225";
  case MCK_Reg222: return "MCK_Reg222";
  case MCK_Reg210: return "MCK_Reg210";
  case MCK_Reg321: return "MCK_Reg321";
  case MCK_Reg314: return "MCK_Reg314";
  case MCK_Reg307: return "MCK_Reg307";
  case MCK_Reg300: return "MCK_Reg300";
  case MCK_Reg293: return "MCK_Reg293";
  case MCK_Reg286: return "MCK_Reg286";
  case MCK_Reg279: return "MCK_Reg279";
  case MCK_Reg272: return "MCK_Reg272";
  case MCK_Reg263: return "MCK_Reg263";
  case MCK_Reg256: return "MCK_Reg256";
  case MCK_Reg252: return "MCK_Reg252";
  case MCK_Reg249: return "MCK_Reg249";
  case MCK_Reg240: return "MCK_Reg240";
  case MCK_Reg236: return "MCK_Reg236";
  case MCK_Reg233: return "MCK_Reg233";
  case MCK_Reg226: return "MCK_Reg226";
  case MCK_Reg223: return "MCK_Reg223";
  case MCK_Reg220: return "MCK_Reg220";
  case MCK_Reg213: return "MCK_Reg213";
  case MCK_Reg211: return "MCK_Reg211";
  case MCK_Reg208: return "MCK_Reg208";
  case MCK_Reg201: return "MCK_Reg201";
  case MCK_Reg199: return "MCK_Reg199";
  case MCK_Reg193: return "MCK_Reg193";
  case MCK_Reg191: return "MCK_Reg191";
  case MCK_Reg185: return "MCK_Reg185";
  case MCK_Reg183: return "MCK_Reg183";
  case MCK_Reg176: return "MCK_Reg176";
  case MCK_Reg322: return "MCK_Reg322";
  case MCK_Reg315: return "MCK_Reg315";
  case MCK_Reg308: return "MCK_Reg308";
  case MCK_Reg301: return "MCK_Reg301";
  case MCK_Reg294: return "MCK_Reg294";
  case MCK_Reg287: return "MCK_Reg287";
  case MCK_Reg280: return "MCK_Reg280";
  case MCK_Reg273: return "MCK_Reg273";
  case MCK_Reg264: return "MCK_Reg264";
  case MCK_Reg257: return "MCK_Reg257";
  case MCK_Reg253: return "MCK_Reg253";
  case MCK_Reg250: return "MCK_Reg250";
  case MCK_Reg247: return "MCK_Reg247";
  case MCK_Reg241: return "MCK_Reg241";
  case MCK_Reg237: return "MCK_Reg237";
  case MCK_Reg234: return "MCK_Reg234";
  case MCK_Reg232: return "MCK_Reg232";
  case MCK_Reg227: return "MCK_Reg227";
  case MCK_Reg224: return "MCK_Reg224";
  case MCK_Reg221: return "MCK_Reg221";
  case MCK_Reg219: return "MCK_Reg219";
  case MCK_Reg214: return "MCK_Reg214";
  case MCK_Reg212: return "MCK_Reg212";
  case MCK_Reg209: return "MCK_Reg209";
  case MCK_Reg207: return "MCK_Reg207";
  case MCK_Reg202: return "MCK_Reg202";
  case MCK_Reg200: return "MCK_Reg200";
  case MCK_Reg198: return "MCK_Reg198";
  case MCK_Reg194: return "MCK_Reg194";
  case MCK_Reg192: return "MCK_Reg192";
  case MCK_Reg190: return "MCK_Reg190";
  case MCK_Reg186: return "MCK_Reg186";
  case MCK_Reg184: return "MCK_Reg184";
  case MCK_Reg182: return "MCK_Reg182";
  case MCK_Reg178: return "MCK_Reg178";
  case MCK_Reg177: return "MCK_Reg177";
  case MCK_Reg175: return "MCK_Reg175";
  case MCK_Reg171: return "MCK_Reg171";
  case MCK_Reg170: return "MCK_Reg170";
  case MCK_Reg166: return "MCK_Reg166";
  case MCK_Reg165: return "MCK_Reg165";
  case MCK_Reg147: return "MCK_Reg147";
  case MCK_Reg146: return "MCK_Reg146";
  case MCK_Reg265: return "MCK_Reg265";
  case MCK_Reg242: return "MCK_Reg242";
  case MCK_Reg228: return "MCK_Reg228";
  case MCK_Reg215: return "MCK_Reg215";
  case MCK_Reg203: return "MCK_Reg203";
  case MCK_Reg195: return "MCK_Reg195";
  case MCK_Reg187: return "MCK_Reg187";
  case MCK_Reg179: return "MCK_Reg179";
  case MCK_Reg172: return "MCK_Reg172";
  case MCK_Reg167: return "MCK_Reg167";
  case MCK_Reg148: return "MCK_Reg148";
  case MCK_Reg143: return "MCK_Reg143";
  case MCK_TTMP_64: return "MCK_TTMP_64";
  case MCK_Gfx_CCR_SGPR_64: return "MCK_Gfx_CCR_SGPR_64";
  case MCK_CCR_SGPR_64: return "MCK_CCR_SGPR_64";
  case MCK_TTMP_32: return "MCK_TTMP_32";
  case MCK_TTMP_LO16: return "MCK_TTMP_LO16";
  case MCK_SGPR_1024: return "MCK_SGPR_1024";
  case MCK_SGPR_512: return "MCK_SGPR_512";
  case MCK_SGPR_352: return "MCK_SGPR_352";
  case MCK_SGPR_384: return "MCK_SGPR_384";
  case MCK_SReg_512: return "MCK_SReg_512";
  case MCK_SGPR_224: return "MCK_SGPR_224";
  case MCK_SGPR_256: return "MCK_SGPR_256";
  case MCK_SGPR_288: return "MCK_SGPR_288";
  case MCK_SGPR_320: return "MCK_SGPR_320";
  case MCK_SGPR_128: return "MCK_SGPR_128";
  case MCK_SGPR_160: return "MCK_SGPR_160";
  case MCK_SGPR_192: return "MCK_SGPR_192";
  case MCK_SGPR_96: return "MCK_SGPR_96";
  case MCK_SReg_352: return "MCK_SReg_352";
  case MCK_SReg_384: return "MCK_SReg_384";
  case MCK_SReg_288: return "MCK_SReg_288";
  case MCK_SReg_320: return "MCK_SReg_320";
  case MCK_SReg_224: return "MCK_SReg_224";
  case MCK_SReg_256_XNULL: return "MCK_SReg_256_XNULL";
  case MCK_SReg_160: return "MCK_SReg_160";
  case MCK_SReg_192: return "MCK_SReg_192";
  case MCK_SReg_256: return "MCK_SReg_256";
  case MCK_SReg_128_XNULL: return "MCK_SReg_128_XNULL";
  case MCK_SReg_96: return "MCK_SReg_96";
  case MCK_SReg_128: return "MCK_SReg_128";
  case MCK_Reg860: return "MCK_Reg860";
  case MCK_Reg861: return "MCK_Reg861";
  case MCK_Reg827: return "MCK_Reg827";
  case MCK_Reg862: return "MCK_Reg862";
  case MCK_Reg828: return "MCK_Reg828";
  case MCK_Reg863: return "MCK_Reg863";
  case MCK_Reg829: return "MCK_Reg829";
  case MCK_Reg864: return "MCK_Reg864";
  case MCK_Reg830: return "MCK_Reg830";
  case MCK_Reg865: return "MCK_Reg865";
  case MCK_Reg831: return "MCK_Reg831";
  case MCK_SGPR_64: return "MCK_SGPR_64";
  case MCK_Reg866: return "MCK_Reg866";
  case MCK_Reg832: return "MCK_Reg832";
  case MCK_Reg867: return "MCK_Reg867";
  case MCK_Reg833: return "MCK_Reg833";
  case MCK_Reg868: return "MCK_Reg868";
  case MCK_Reg834: return "MCK_Reg834";
  case MCK_Reg743: return "MCK_Reg743";
  case MCK_Reg869: return "MCK_Reg869";
  case MCK_Reg835: return "MCK_Reg835";
  case MCK_Reg744: return "MCK_Reg744";
  case MCK_Reg726: return "MCK_Reg726";
  case MCK_Reg870: return "MCK_Reg870";
  case MCK_Reg836: return "MCK_Reg836";
  case MCK_Reg745: return "MCK_Reg745";
  case MCK_Reg727: return "MCK_Reg727";
  case MCK_Reg678: return "MCK_Reg678";
  case MCK_Reg871: return "MCK_Reg871";
  case MCK_Reg837: return "MCK_Reg837";
  case MCK_Reg746: return "MCK_Reg746";
  case MCK_Reg728: return "MCK_Reg728";
  case MCK_Reg679: return "MCK_Reg679";
  case MCK_Reg665: return "MCK_Reg665";
  case MCK_Reg627: return "MCK_Reg627";
  case MCK_Reg614: return "MCK_Reg614";
  case MCK_Reg578: return "MCK_Reg578";
  case MCK_Reg872: return "MCK_Reg872";
  case MCK_Reg838: return "MCK_Reg838";
  case MCK_Reg747: return "MCK_Reg747";
  case MCK_Reg729: return "MCK_Reg729";
  case MCK_Reg680: return "MCK_Reg680";
  case MCK_Reg666: return "MCK_Reg666";
  case MCK_Reg628: return "MCK_Reg628";
  case MCK_Reg615: return "MCK_Reg615";
  case MCK_Reg579: return "MCK_Reg579";
  case MCK_Reg567: return "MCK_Reg567";
  case MCK_Reg535: return "MCK_Reg535";
  case MCK_Reg524: return "MCK_Reg524";
  case MCK_Reg494: return "MCK_Reg494";
  case MCK_Reg873: return "MCK_Reg873";
  case MCK_Reg839: return "MCK_Reg839";
  case MCK_Reg748: return "MCK_Reg748";
  case MCK_Reg730: return "MCK_Reg730";
  case MCK_Reg681: return "MCK_Reg681";
  case MCK_Reg667: return "MCK_Reg667";
  case MCK_Reg629: return "MCK_Reg629";
  case MCK_Reg616: return "MCK_Reg616";
  case MCK_Reg580: return "MCK_Reg580";
  case MCK_Reg568: return "MCK_Reg568";
  case MCK_Reg536: return "MCK_Reg536";
  case MCK_Reg525: return "MCK_Reg525";
  case MCK_Reg495: return "MCK_Reg495";
  case MCK_Reg485: return "MCK_Reg485";
  case MCK_Reg459: return "MCK_Reg459";
  case MCK_Reg450: return "MCK_Reg450";
  case MCK_Reg426: return "MCK_Reg426";
  case MCK_Reg874: return "MCK_Reg874";
  case MCK_Reg840: return "MCK_Reg840";
  case MCK_Reg749: return "MCK_Reg749";
  case MCK_Reg731: return "MCK_Reg731";
  case MCK_Reg682: return "MCK_Reg682";
  case MCK_Reg668: return "MCK_Reg668";
  case MCK_Reg630: return "MCK_Reg630";
  case MCK_Reg617: return "MCK_Reg617";
  case MCK_Reg581: return "MCK_Reg581";
  case MCK_Reg569: return "MCK_Reg569";
  case MCK_Reg537: return "MCK_Reg537";
  case MCK_Reg526: return "MCK_Reg526";
  case MCK_Reg496: return "MCK_Reg496";
  case MCK_Reg486: return "MCK_Reg486";
  case MCK_Reg460: return "MCK_Reg460";
  case MCK_Reg451: return "MCK_Reg451";
  case MCK_Reg427: return "MCK_Reg427";
  case MCK_Reg419: return "MCK_Reg419";
  case MCK_Reg399: return "MCK_Reg399";
  case MCK_Reg392: return "MCK_Reg392";
  case MCK_Reg374: return "MCK_Reg374";
  case MCK_Reg875: return "MCK_Reg875";
  case MCK_Reg841: return "MCK_Reg841";
  case MCK_Reg750: return "MCK_Reg750";
  case MCK_Reg732: return "MCK_Reg732";
  case MCK_Reg683: return "MCK_Reg683";
  case MCK_Reg669: return "MCK_Reg669";
  case MCK_Reg631: return "MCK_Reg631";
  case MCK_Reg618: return "MCK_Reg618";
  case MCK_Reg582: return "MCK_Reg582";
  case MCK_Reg570: return "MCK_Reg570";
  case MCK_Reg538: return "MCK_Reg538";
  case MCK_Reg527: return "MCK_Reg527";
  case MCK_Reg497: return "MCK_Reg497";
  case MCK_Reg487: return "MCK_Reg487";
  case MCK_Reg461: return "MCK_Reg461";
  case MCK_Reg452: return "MCK_Reg452";
  case MCK_Reg428: return "MCK_Reg428";
  case MCK_Reg420: return "MCK_Reg420";
  case MCK_Reg400: return "MCK_Reg400";
  case MCK_Reg393: return "MCK_Reg393";
  case MCK_Reg375: return "MCK_Reg375";
  case MCK_Reg369: return "MCK_Reg369";
  case MCK_Reg355: return "MCK_Reg355";
  case MCK_Reg350: return "MCK_Reg350";
  case MCK_Reg876: return "MCK_Reg876";
  case MCK_Reg842: return "MCK_Reg842";
  case MCK_Reg751: return "MCK_Reg751";
  case MCK_Reg733: return "MCK_Reg733";
  case MCK_Reg684: return "MCK_Reg684";
  case MCK_Reg670: return "MCK_Reg670";
  case MCK_Reg632: return "MCK_Reg632";
  case MCK_Reg619: return "MCK_Reg619";
  case MCK_Reg583: return "MCK_Reg583";
  case MCK_Reg571: return "MCK_Reg571";
  case MCK_Reg539: return "MCK_Reg539";
  case MCK_Reg528: return "MCK_Reg528";
  case MCK_Reg498: return "MCK_Reg498";
  case MCK_Reg488: return "MCK_Reg488";
  case MCK_Reg462: return "MCK_Reg462";
  case MCK_Reg453: return "MCK_Reg453";
  case MCK_Reg429: return "MCK_Reg429";
  case MCK_Reg421: return "MCK_Reg421";
  case MCK_Reg401: return "MCK_Reg401";
  case MCK_Reg394: return "MCK_Reg394";
  case MCK_Reg376: return "MCK_Reg376";
  case MCK_Reg370: return "MCK_Reg370";
  case MCK_Reg356: return "MCK_Reg356";
  case MCK_Reg351: return "MCK_Reg351";
  case MCK_Reg340: return "MCK_Reg340";
  case MCK_SReg_64_XEXEC_XNULL: return "MCK_SReg_64_XEXEC_XNULL";
  case MCK_SReg_64_XEXEC: return "MCK_SReg_64_XEXEC";
  case MCK_SReg_64: return "MCK_SReg_64";
  case MCK_Reg37: return "MCK_Reg37";
  case MCK_SReg_64_Encodable: return "MCK_SReg_64_Encodable";
  case MCK_Reg160: return "MCK_Reg160";
  case MCK_Reg161: return "MCK_Reg161";
  case MCK_Reg762: return "MCK_Reg762";
  case MCK_Reg763: return "MCK_Reg763";
  case MCK_Reg764: return "MCK_Reg764";
  case MCK_Reg765: return "MCK_Reg765";
  case MCK_Reg766: return "MCK_Reg766";
  case MCK_Reg767: return "MCK_Reg767";
  case MCK_Reg768: return "MCK_Reg768";
  case MCK_Reg769: return "MCK_Reg769";
  case MCK_Reg770: return "MCK_Reg770";
  case MCK_Reg771: return "MCK_Reg771";
  case MCK_SGPR_32: return "MCK_SGPR_32";
  case MCK_SGPR_HI16: return "MCK_SGPR_HI16";
  case MCK_SGPR_LO16: return "MCK_SGPR_LO16";
  case MCK_Reg772: return "MCK_Reg772";
  case MCK_Reg773: return "MCK_Reg773";
  case MCK_Reg774: return "MCK_Reg774";
  case MCK_Reg775: return "MCK_Reg775";
  case MCK_Reg776: return "MCK_Reg776";
  case MCK_Reg877: return "MCK_Reg877";
  case MCK_Reg777: return "MCK_Reg777";
  case MCK_Reg138: return "MCK_Reg138";
  case MCK_Reg878: return "MCK_Reg878";
  case MCK_Reg778: return "MCK_Reg778";
  case MCK_Reg693: return "MCK_Reg693";
  case MCK_AReg_1024_Align2: return "MCK_AReg_1024_Align2";
  case MCK_VReg_1024_Lo256_Align2: return "MCK_VReg_1024_Lo256_Align2";
  case MCK_Reg879: return "MCK_Reg879";
  case MCK_Reg844: return "MCK_Reg844";
  case MCK_Reg779: return "MCK_Reg779";
  case MCK_Reg694: return "MCK_Reg694";
  case MCK_Reg880: return "MCK_Reg880";
  case MCK_Reg845: return "MCK_Reg845";
  case MCK_Reg780: return "MCK_Reg780";
  case MCK_Reg695: return "MCK_Reg695";
  case MCK_Reg881: return "MCK_Reg881";
  case MCK_Reg846: return "MCK_Reg846";
  case MCK_Reg781: return "MCK_Reg781";
  case MCK_Reg696: return "MCK_Reg696";
  case MCK_Reg882: return "MCK_Reg882";
  case MCK_Reg847: return "MCK_Reg847";
  case MCK_Reg782: return "MCK_Reg782";
  case MCK_Reg697: return "MCK_Reg697";
  case MCK_Reg640: return "MCK_Reg640";
  case MCK_Reg883: return "MCK_Reg883";
  case MCK_Reg848: return "MCK_Reg848";
  case MCK_Reg783: return "MCK_Reg783";
  case MCK_Reg698: return "MCK_Reg698";
  case MCK_Reg641: return "MCK_Reg641";
  case MCK_Reg591: return "MCK_Reg591";
  case MCK_Reg884: return "MCK_Reg884";
  case MCK_Reg849: return "MCK_Reg849";
  case MCK_Reg784: return "MCK_Reg784";
  case MCK_Reg699: return "MCK_Reg699";
  case MCK_Reg642: return "MCK_Reg642";
  case MCK_Reg592: return "MCK_Reg592";
  case MCK_Reg546: return "MCK_Reg546";
  case MCK_Reg885: return "MCK_Reg885";
  case MCK_Reg850: return "MCK_Reg850";
  case MCK_Reg785: return "MCK_Reg785";
  case MCK_Reg752: return "MCK_Reg752";
  case MCK_Reg700: return "MCK_Reg700";
  case MCK_Reg643: return "MCK_Reg643";
  case MCK_Reg593: return "MCK_Reg593";
  case MCK_Reg547: return "MCK_Reg547";
  case MCK_Reg505: return "MCK_Reg505";
  case MCK_Reg132: return "MCK_Reg132";
  case MCK_Reg886: return "MCK_Reg886";
  case MCK_Reg851: return "MCK_Reg851";
  case MCK_Reg786: return "MCK_Reg786";
  case MCK_Reg753: return "MCK_Reg753";
  case MCK_Reg701: return "MCK_Reg701";
  case MCK_Reg644: return "MCK_Reg644";
  case MCK_Reg594: return "MCK_Reg594";
  case MCK_Reg548: return "MCK_Reg548";
  case MCK_Reg506: return "MCK_Reg506";
  case MCK_Reg468: return "MCK_Reg468";
  case MCK_AReg_512_Align2: return "MCK_AReg_512_Align2";
  case MCK_VReg_512_Lo256_Align2: return "MCK_VReg_512_Lo256_Align2";
  case MCK_Reg887: return "MCK_Reg887";
  case MCK_Reg852: return "MCK_Reg852";
  case MCK_Reg787: return "MCK_Reg787";
  case MCK_Reg754: return "MCK_Reg754";
  case MCK_Reg735: return "MCK_Reg735";
  case MCK_Reg702: return "MCK_Reg702";
  case MCK_Reg685: return "MCK_Reg685";
  case MCK_Reg645: return "MCK_Reg645";
  case MCK_Reg595: return "MCK_Reg595";
  case MCK_Reg549: return "MCK_Reg549";
  case MCK_Reg507: return "MCK_Reg507";
  case MCK_Reg469: return "MCK_Reg469";
  case MCK_Reg435: return "MCK_Reg435";
  case MCK_Reg126: return "MCK_Reg126";
  case MCK_Reg888: return "MCK_Reg888";
  case MCK_Reg853: return "MCK_Reg853";
  case MCK_Reg788: return "MCK_Reg788";
  case MCK_Reg755: return "MCK_Reg755";
  case MCK_Reg736: return "MCK_Reg736";
  case MCK_Reg703: return "MCK_Reg703";
  case MCK_Reg686: return "MCK_Reg686";
  case MCK_Reg646: return "MCK_Reg646";
  case MCK_Reg633: return "MCK_Reg633";
  case MCK_Reg596: return "MCK_Reg596";
  case MCK_Reg584: return "MCK_Reg584";
  case MCK_Reg550: return "MCK_Reg550";
  case MCK_Reg508: return "MCK_Reg508";
  case MCK_Reg470: return "MCK_Reg470";
  case MCK_Reg436: return "MCK_Reg436";
  case MCK_Reg406: return "MCK_Reg406";
  case MCK_Reg120: return "MCK_Reg120";
  case MCK_Reg114: return "MCK_Reg114";
  case MCK_AReg_352_Align2: return "MCK_AReg_352_Align2";
  case MCK_AReg_384_Align2: return "MCK_AReg_384_Align2";
  case MCK_VReg_352_Lo256_Align2: return "MCK_VReg_352_Lo256_Align2";
  case MCK_VReg_384_Lo256_Align2: return "MCK_VReg_384_Lo256_Align2";
  case MCK_Reg889: return "MCK_Reg889";
  case MCK_Reg854: return "MCK_Reg854";
  case MCK_Reg789: return "MCK_Reg789";
  case MCK_Reg756: return "MCK_Reg756";
  case MCK_Reg737: return "MCK_Reg737";
  case MCK_Reg704: return "MCK_Reg704";
  case MCK_Reg687: return "MCK_Reg687";
  case MCK_Reg672: return "MCK_Reg672";
  case MCK_Reg647: return "MCK_Reg647";
  case MCK_Reg634: return "MCK_Reg634";
  case MCK_Reg621: return "MCK_Reg621";
  case MCK_Reg597: return "MCK_Reg597";
  case MCK_Reg585: return "MCK_Reg585";
  case MCK_Reg551: return "MCK_Reg551";
  case MCK_Reg540: return "MCK_Reg540";
  case MCK_Reg509: return "MCK_Reg509";
  case MCK_Reg499: return "MCK_Reg499";
  case MCK_Reg471: return "MCK_Reg471";
  case MCK_Reg437: return "MCK_Reg437";
  case MCK_Reg407: return "MCK_Reg407";
  case MCK_Reg381: return "MCK_Reg381";
  case MCK_Reg108: return "MCK_Reg108";
  case MCK_Reg102: return "MCK_Reg102";
  case MCK_AReg_288_Align2: return "MCK_AReg_288_Align2";
  case MCK_AReg_320_Align2: return "MCK_AReg_320_Align2";
  case MCK_VReg_288_Lo256_Align2: return "MCK_VReg_288_Lo256_Align2";
  case MCK_VReg_320_Lo256_Align2: return "MCK_VReg_320_Lo256_Align2";
  case MCK_Reg890: return "MCK_Reg890";
  case MCK_Reg855: return "MCK_Reg855";
  case MCK_Reg790: return "MCK_Reg790";
  case MCK_Reg757: return "MCK_Reg757";
  case MCK_Reg738: return "MCK_Reg738";
  case MCK_Reg705: return "MCK_Reg705";
  case MCK_Reg688: return "MCK_Reg688";
  case MCK_Reg673: return "MCK_Reg673";
  case MCK_Reg648: return "MCK_Reg648";
  case MCK_Reg635: return "MCK_Reg635";
  case MCK_Reg622: return "MCK_Reg622";
  case MCK_Reg598: return "MCK_Reg598";
  case MCK_Reg586: return "MCK_Reg586";
  case MCK_Reg573: return "MCK_Reg573";
  case MCK_Reg552: return "MCK_Reg552";
  case MCK_Reg541: return "MCK_Reg541";
  case MCK_Reg530: return "MCK_Reg530";
  case MCK_Reg510: return "MCK_Reg510";
  case MCK_Reg500: return "MCK_Reg500";
  case MCK_Reg472: return "MCK_Reg472";
  case MCK_Reg463: return "MCK_Reg463";
  case MCK_Reg438: return "MCK_Reg438";
  case MCK_Reg430: return "MCK_Reg430";
  case MCK_Reg408: return "MCK_Reg408";
  case MCK_Reg382: return "MCK_Reg382";
  case MCK_Reg360: return "MCK_Reg360";
  case MCK_Reg96: return "MCK_Reg96";
  case MCK_Reg90: return "MCK_Reg90";
  case MCK_AReg_224_Align2: return "MCK_AReg_224_Align2";
  case MCK_AReg_256_Align2: return "MCK_AReg_256_Align2";
  case MCK_VReg_224_Lo256_Align2: return "MCK_VReg_224_Lo256_Align2";
  case MCK_VReg_256_Lo256_Align2: return "MCK_VReg_256_Lo256_Align2";
  case MCK_Reg891: return "MCK_Reg891";
  case MCK_Reg856: return "MCK_Reg856";
  case MCK_Reg791: return "MCK_Reg791";
  case MCK_Reg758: return "MCK_Reg758";
  case MCK_Reg739: return "MCK_Reg739";
  case MCK_Reg706: return "MCK_Reg706";
  case MCK_Reg689: return "MCK_Reg689";
  case MCK_Reg674: return "MCK_Reg674";
  case MCK_Reg649: return "MCK_Reg649";
  case MCK_Reg636: return "MCK_Reg636";
  case MCK_Reg623: return "MCK_Reg623";
  case MCK_Reg599: return "MCK_Reg599";
  case MCK_Reg587: return "MCK_Reg587";
  case MCK_Reg574: return "MCK_Reg574";
  case MCK_Reg553: return "MCK_Reg553";
  case MCK_Reg542: return "MCK_Reg542";
  case MCK_Reg531: return "MCK_Reg531";
  case MCK_Reg511: return "MCK_Reg511";
  case MCK_Reg501: return "MCK_Reg501";
  case MCK_Reg490: return "MCK_Reg490";
  case MCK_Reg473: return "MCK_Reg473";
  case MCK_Reg464: return "MCK_Reg464";
  case MCK_Reg455: return "MCK_Reg455";
  case MCK_Reg439: return "MCK_Reg439";
  case MCK_Reg431: return "MCK_Reg431";
  case MCK_Reg409: return "MCK_Reg409";
  case MCK_Reg402: return "MCK_Reg402";
  case MCK_Reg383: return "MCK_Reg383";
  case MCK_Reg377: return "MCK_Reg377";
  case MCK_Reg361: return "MCK_Reg361";
  case MCK_Reg343: return "MCK_Reg343";
  case MCK_Reg84: return "MCK_Reg84";
  case MCK_Reg78: return "MCK_Reg78";
  case MCK_AReg_160_Align2: return "MCK_AReg_160_Align2";
  case MCK_AReg_192_Align2: return "MCK_AReg_192_Align2";
  case MCK_VReg_160_Lo256_Align2: return "MCK_VReg_160_Lo256_Align2";
  case MCK_VReg_192_Lo256_Align2: return "MCK_VReg_192_Lo256_Align2";
  case MCK_Reg892: return "MCK_Reg892";
  case MCK_Reg857: return "MCK_Reg857";
  case MCK_Reg792: return "MCK_Reg792";
  case MCK_Reg759: return "MCK_Reg759";
  case MCK_Reg740: return "MCK_Reg740";
  case MCK_Reg707: return "MCK_Reg707";
  case MCK_Reg690: return "MCK_Reg690";
  case MCK_Reg675: return "MCK_Reg675";
  case MCK_Reg650: return "MCK_Reg650";
  case MCK_Reg637: return "MCK_Reg637";
  case MCK_Reg624: return "MCK_Reg624";
  case MCK_Reg600: return "MCK_Reg600";
  case MCK_Reg588: return "MCK_Reg588";
  case MCK_Reg575: return "MCK_Reg575";
  case MCK_Reg554: return "MCK_Reg554";
  case MCK_Reg543: return "MCK_Reg543";
  case MCK_Reg532: return "MCK_Reg532";
  case MCK_Reg512: return "MCK_Reg512";
  case MCK_Reg502: return "MCK_Reg502";
  case MCK_Reg491: return "MCK_Reg491";
  case MCK_Reg474: return "MCK_Reg474";
  case MCK_Reg465: return "MCK_Reg465";
  case MCK_Reg456: return "MCK_Reg456";
  case MCK_Reg440: return "MCK_Reg440";
  case MCK_Reg432: return "MCK_Reg432";
  case MCK_Reg423: return "MCK_Reg423";
  case MCK_Reg410: return "MCK_Reg410";
  case MCK_Reg403: return "MCK_Reg403";
  case MCK_Reg396: return "MCK_Reg396";
  case MCK_Reg384: return "MCK_Reg384";
  case MCK_Reg378: return "MCK_Reg378";
  case MCK_Reg362: return "MCK_Reg362";
  case MCK_Reg357: return "MCK_Reg357";
  case MCK_Reg344: return "MCK_Reg344";
  case MCK_Reg335: return "MCK_Reg335";
  case MCK_Reg72: return "MCK_Reg72";
  case MCK_AReg_128_Align2: return "MCK_AReg_128_Align2";
  case MCK_AReg_96_Align2: return "MCK_AReg_96_Align2";
  case MCK_VReg_128_Lo256_Align2: return "MCK_VReg_128_Lo256_Align2";
  case MCK_VReg_96_Lo256_Align2: return "MCK_VReg_96_Lo256_Align2";
  case MCK_Reg893: return "MCK_Reg893";
  case MCK_Reg858: return "MCK_Reg858";
  case MCK_Reg793: return "MCK_Reg793";
  case MCK_Reg760: return "MCK_Reg760";
  case MCK_Reg741: return "MCK_Reg741";
  case MCK_Reg708: return "MCK_Reg708";
  case MCK_Reg691: return "MCK_Reg691";
  case MCK_Reg676: return "MCK_Reg676";
  case MCK_Reg651: return "MCK_Reg651";
  case MCK_Reg638: return "MCK_Reg638";
  case MCK_Reg625: return "MCK_Reg625";
  case MCK_Reg601: return "MCK_Reg601";
  case MCK_Reg589: return "MCK_Reg589";
  case MCK_Reg576: return "MCK_Reg576";
  case MCK_Reg555: return "MCK_Reg555";
  case MCK_Reg544: return "MCK_Reg544";
  case MCK_Reg533: return "MCK_Reg533";
  case MCK_Reg513: return "MCK_Reg513";
  case MCK_Reg503: return "MCK_Reg503";
  case MCK_Reg492: return "MCK_Reg492";
  case MCK_Reg475: return "MCK_Reg475";
  case MCK_Reg466: return "MCK_Reg466";
  case MCK_Reg457: return "MCK_Reg457";
  case MCK_Reg441: return "MCK_Reg441";
  case MCK_Reg433: return "MCK_Reg433";
  case MCK_Reg424: return "MCK_Reg424";
  case MCK_Reg411: return "MCK_Reg411";
  case MCK_Reg404: return "MCK_Reg404";
  case MCK_Reg397: return "MCK_Reg397";
  case MCK_Reg385: return "MCK_Reg385";
  case MCK_Reg379: return "MCK_Reg379";
  case MCK_Reg372: return "MCK_Reg372";
  case MCK_Reg363: return "MCK_Reg363";
  case MCK_Reg358: return "MCK_Reg358";
  case MCK_Reg353: return "MCK_Reg353";
  case MCK_Reg345: return "MCK_Reg345";
  case MCK_Reg336: return "MCK_Reg336";
  case MCK_AReg_64_Align2: return "MCK_AReg_64_Align2";
  case MCK_VGPR_32_Lo128: return "MCK_VGPR_32_Lo128";
  case MCK_VReg_64_Lo256_Align2: return "MCK_VReg_64_Lo256_Align2";
  case MCK_Reg44: return "MCK_Reg44";
  case MCK_Reg34: return "MCK_Reg34";
  case MCK_Reg25: return "MCK_Reg25";
  case MCK_SReg_32_XM0_XEXEC: return "MCK_SReg_32_XM0_XEXEC";
  case MCK_Reg15: return "MCK_Reg15";
  case MCK_SReg_32_XEXEC: return "MCK_SReg_32_XEXEC";
  case MCK_SReg_32_XEXEC_HI: return "MCK_SReg_32_XEXEC_HI";
  case MCK_SReg_32_XM0: return "MCK_SReg_32_XM0";
  case MCK_SReg_32: return "MCK_SReg_32";
  case MCK_SReg_LO16: return "MCK_SReg_LO16";
  case MCK_SRegOrLds_32: return "MCK_SRegOrLds_32";
  case MCK_Reg151: return "MCK_Reg151";
  case MCK_Reg152: return "MCK_Reg152";
  case MCK_Reg162: return "MCK_Reg162";
  case MCK_Reg153: return "MCK_Reg153";
  case MCK_Reg163: return "MCK_Reg163";
  case MCK_Reg154: return "MCK_Reg154";
  case MCK_Reg29: return "MCK_Reg29";
  case MCK_Reg35: return "MCK_Reg35";
  case MCK_Reg30: return "MCK_Reg30";
  case MCK_Reg22: return "MCK_Reg22";
  case MCK_VS_64_Lo256: return "MCK_VS_64_Lo256";
  case MCK_Reg794: return "MCK_Reg794";
  case MCK_AReg_1024: return "MCK_AReg_1024";
  case MCK_Reg795: return "MCK_Reg795";
  case MCK_Reg796: return "MCK_Reg796";
  case MCK_Reg797: return "MCK_Reg797";
  case MCK_Reg798: return "MCK_Reg798";
  case MCK_Reg799: return "MCK_Reg799";
  case MCK_Reg800: return "MCK_Reg800";
  case MCK_Reg801: return "MCK_Reg801";
  case MCK_Reg802: return "MCK_Reg802";
  case MCK_Reg803: return "MCK_Reg803";
  case MCK_Reg804: return "MCK_Reg804";
  case MCK_Reg805: return "MCK_Reg805";
  case MCK_Reg806: return "MCK_Reg806";
  case MCK_Reg807: return "MCK_Reg807";
  case MCK_Reg808: return "MCK_Reg808";
  case MCK_Reg809: return "MCK_Reg809";
  case MCK_Reg810: return "MCK_Reg810";
  case MCK_Reg709: return "MCK_Reg709";
  case MCK_AReg_512: return "MCK_AReg_512";
  case MCK_Reg811: return "MCK_Reg811";
  case MCK_Reg710: return "MCK_Reg710";
  case MCK_Reg812: return "MCK_Reg812";
  case MCK_Reg711: return "MCK_Reg711";
  case MCK_Reg813: return "MCK_Reg813";
  case MCK_Reg712: return "MCK_Reg712";
  case MCK_Reg814: return "MCK_Reg814";
  case MCK_Reg713: return "MCK_Reg713";
  case MCK_Reg652: return "MCK_Reg652";
  case MCK_AReg_384: return "MCK_AReg_384";
  case MCK_Reg815: return "MCK_Reg815";
  case MCK_Reg714: return "MCK_Reg714";
  case MCK_Reg653: return "MCK_Reg653";
  case MCK_Reg602: return "MCK_Reg602";
  case MCK_AReg_352: return "MCK_AReg_352";
  case MCK_Reg816: return "MCK_Reg816";
  case MCK_Reg715: return "MCK_Reg715";
  case MCK_Reg654: return "MCK_Reg654";
  case MCK_Reg603: return "MCK_Reg603";
  case MCK_Reg556: return "MCK_Reg556";
  case MCK_AReg_320: return "MCK_AReg_320";
  case MCK_Reg817: return "MCK_Reg817";
  case MCK_Reg716: return "MCK_Reg716";
  case MCK_Reg655: return "MCK_Reg655";
  case MCK_Reg604: return "MCK_Reg604";
  case MCK_Reg557: return "MCK_Reg557";
  case MCK_Reg514: return "MCK_Reg514";
  case MCK_AReg_288: return "MCK_AReg_288";
  case MCK_Reg818: return "MCK_Reg818";
  case MCK_Reg717: return "MCK_Reg717";
  case MCK_Reg656: return "MCK_Reg656";
  case MCK_Reg605: return "MCK_Reg605";
  case MCK_Reg558: return "MCK_Reg558";
  case MCK_Reg515: return "MCK_Reg515";
  case MCK_Reg476: return "MCK_Reg476";
  case MCK_AReg_256: return "MCK_AReg_256";
  case MCK_Reg819: return "MCK_Reg819";
  case MCK_Reg718: return "MCK_Reg718";
  case MCK_Reg657: return "MCK_Reg657";
  case MCK_Reg606: return "MCK_Reg606";
  case MCK_Reg559: return "MCK_Reg559";
  case MCK_Reg516: return "MCK_Reg516";
  case MCK_Reg477: return "MCK_Reg477";
  case MCK_Reg442: return "MCK_Reg442";
  case MCK_AReg_224: return "MCK_AReg_224";
  case MCK_Reg820: return "MCK_Reg820";
  case MCK_Reg719: return "MCK_Reg719";
  case MCK_Reg658: return "MCK_Reg658";
  case MCK_Reg607: return "MCK_Reg607";
  case MCK_Reg560: return "MCK_Reg560";
  case MCK_Reg517: return "MCK_Reg517";
  case MCK_Reg478: return "MCK_Reg478";
  case MCK_Reg443: return "MCK_Reg443";
  case MCK_Reg412: return "MCK_Reg412";
  case MCK_AReg_192: return "MCK_AReg_192";
  case MCK_Reg821: return "MCK_Reg821";
  case MCK_Reg720: return "MCK_Reg720";
  case MCK_Reg659: return "MCK_Reg659";
  case MCK_Reg608: return "MCK_Reg608";
  case MCK_Reg561: return "MCK_Reg561";
  case MCK_Reg518: return "MCK_Reg518";
  case MCK_Reg479: return "MCK_Reg479";
  case MCK_Reg444: return "MCK_Reg444";
  case MCK_Reg413: return "MCK_Reg413";
  case MCK_Reg386: return "MCK_Reg386";
  case MCK_AReg_160: return "MCK_AReg_160";
  case MCK_Reg822: return "MCK_Reg822";
  case MCK_Reg721: return "MCK_Reg721";
  case MCK_Reg660: return "MCK_Reg660";
  case MCK_Reg609: return "MCK_Reg609";
  case MCK_Reg562: return "MCK_Reg562";
  case MCK_Reg519: return "MCK_Reg519";
  case MCK_Reg480: return "MCK_Reg480";
  case MCK_Reg445: return "MCK_Reg445";
  case MCK_Reg414: return "MCK_Reg414";
  case MCK_Reg387: return "MCK_Reg387";
  case MCK_Reg364: return "MCK_Reg364";
  case MCK_AReg_128: return "MCK_AReg_128";
  case MCK_Reg823: return "MCK_Reg823";
  case MCK_Reg722: return "MCK_Reg722";
  case MCK_Reg661: return "MCK_Reg661";
  case MCK_Reg610: return "MCK_Reg610";
  case MCK_Reg563: return "MCK_Reg563";
  case MCK_Reg520: return "MCK_Reg520";
  case MCK_Reg481: return "MCK_Reg481";
  case MCK_Reg446: return "MCK_Reg446";
  case MCK_Reg415: return "MCK_Reg415";
  case MCK_Reg388: return "MCK_Reg388";
  case MCK_Reg365: return "MCK_Reg365";
  case MCK_Reg346: return "MCK_Reg346";
  case MCK_AReg_96: return "MCK_AReg_96";
  case MCK_Reg824: return "MCK_Reg824";
  case MCK_Reg723: return "MCK_Reg723";
  case MCK_Reg662: return "MCK_Reg662";
  case MCK_Reg611: return "MCK_Reg611";
  case MCK_Reg564: return "MCK_Reg564";
  case MCK_Reg521: return "MCK_Reg521";
  case MCK_Reg482: return "MCK_Reg482";
  case MCK_Reg447: return "MCK_Reg447";
  case MCK_Reg416: return "MCK_Reg416";
  case MCK_Reg389: return "MCK_Reg389";
  case MCK_Reg366: return "MCK_Reg366";
  case MCK_Reg347: return "MCK_Reg347";
  case MCK_Reg337: return "MCK_Reg337";
  case MCK_AReg_64: return "MCK_AReg_64";
  case MCK_Reg825: return "MCK_Reg825";
  case MCK_Reg724: return "MCK_Reg724";
  case MCK_Reg663: return "MCK_Reg663";
  case MCK_Reg612: return "MCK_Reg612";
  case MCK_Reg565: return "MCK_Reg565";
  case MCK_Reg522: return "MCK_Reg522";
  case MCK_Reg483: return "MCK_Reg483";
  case MCK_Reg448: return "MCK_Reg448";
  case MCK_Reg417: return "MCK_Reg417";
  case MCK_Reg390: return "MCK_Reg390";
  case MCK_Reg367: return "MCK_Reg367";
  case MCK_Reg348: return "MCK_Reg348";
  case MCK_Reg338: return "MCK_Reg338";
  case MCK_AGPR_32: return "MCK_AGPR_32";
  case MCK_AGPR_LO16: return "MCK_AGPR_LO16";
  case MCK_VGPR_16_Lo128: return "MCK_VGPR_16_Lo128";
  case MCK_VGPR_32_Lo256: return "MCK_VGPR_32_Lo256";
  case MCK_Reg45: return "MCK_Reg45";
  case MCK_Reg10: return "MCK_Reg10";
  case MCK_VS_32_Lo128: return "MCK_VS_32_Lo128";
  case MCK_Reg155: return "MCK_Reg155";
  case MCK_Reg156: return "MCK_Reg156";
  case MCK_Reg157: return "MCK_Reg157";
  case MCK_Reg158: return "MCK_Reg158";
  case MCK_Reg31: return "MCK_Reg31";
  case MCK_Reg32: return "MCK_Reg32";
  case MCK_Reg23: return "MCK_Reg23";
  case MCK_Reg11: return "MCK_Reg11";
  case MCK_VS_16_Lo128: return "MCK_VS_16_Lo128";
  case MCK_VS_32_Lo256: return "MCK_VS_32_Lo256";
  case MCK_Reg894: return "MCK_Reg894";
  case MCK_VReg_1024_Align2: return "MCK_VReg_1024_Align2";
  case MCK_Reg761: return "MCK_Reg761";
  case MCK_VReg_512_Align2: return "MCK_VReg_512_Align2";
  case MCK_Reg692: return "MCK_Reg692";
  case MCK_Reg639: return "MCK_Reg639";
  case MCK_Reg590: return "MCK_Reg590";
  case MCK_VReg_352_Align2: return "MCK_VReg_352_Align2";
  case MCK_VReg_384_Align2: return "MCK_VReg_384_Align2";
  case MCK_Reg545: return "MCK_Reg545";
  case MCK_Reg504: return "MCK_Reg504";
  case MCK_VReg_288_Align2: return "MCK_VReg_288_Align2";
  case MCK_VReg_320_Align2: return "MCK_VReg_320_Align2";
  case MCK_Reg467: return "MCK_Reg467";
  case MCK_Reg434: return "MCK_Reg434";
  case MCK_VReg_224_Align2: return "MCK_VReg_224_Align2";
  case MCK_VReg_256_Align2: return "MCK_VReg_256_Align2";
  case MCK_Reg405: return "MCK_Reg405";
  case MCK_Reg380: return "MCK_Reg380";
  case MCK_VReg_160_Align2: return "MCK_VReg_160_Align2";
  case MCK_VReg_192_Align2: return "MCK_VReg_192_Align2";
  case MCK_Reg359: return "MCK_Reg359";
  case MCK_VReg_128_Align2: return "MCK_VReg_128_Align2";
  case MCK_VReg_96_Align2: return "MCK_VReg_96_Align2";
  case MCK_VReg_64_Align2: return "MCK_VReg_64_Align2";
  case MCK_Reg164: return "MCK_Reg164";
  case MCK_VS_128_Align2: return "MCK_VS_128_Align2";
  case MCK_Reg36: return "MCK_Reg36";
  case MCK_VS_64_Align2: return "MCK_VS_64_Align2";
  case MCK_Reg139: return "MCK_Reg139";
  case MCK_AV_1024_Align2: return "MCK_AV_1024_Align2";
  case MCK_Reg133: return "MCK_Reg133";
  case MCK_AV_512_Align2: return "MCK_AV_512_Align2";
  case MCK_Reg127: return "MCK_Reg127";
  case MCK_Reg121: return "MCK_Reg121";
  case MCK_Reg115: return "MCK_Reg115";
  case MCK_AV_352_Align2: return "MCK_AV_352_Align2";
  case MCK_AV_384_Align2: return "MCK_AV_384_Align2";
  case MCK_Reg109: return "MCK_Reg109";
  case MCK_Reg103: return "MCK_Reg103";
  case MCK_AV_288_Align2: return "MCK_AV_288_Align2";
  case MCK_AV_320_Align2: return "MCK_AV_320_Align2";
  case MCK_Reg97: return "MCK_Reg97";
  case MCK_Reg91: return "MCK_Reg91";
  case MCK_AV_224_Align2: return "MCK_AV_224_Align2";
  case MCK_AV_256_Align2: return "MCK_AV_256_Align2";
  case MCK_Reg85: return "MCK_Reg85";
  case MCK_Reg79: return "MCK_Reg79";
  case MCK_AV_160_Align2: return "MCK_AV_160_Align2";
  case MCK_AV_192_Align2: return "MCK_AV_192_Align2";
  case MCK_Reg73: return "MCK_Reg73";
  case MCK_AV_128_Align2: return "MCK_AV_128_Align2";
  case MCK_AV_96_Align2: return "MCK_AV_96_Align2";
  case MCK_AV_64_Align2: return "MCK_AV_64_Align2";
  case MCK_VReg_1024: return "MCK_VReg_1024";
  case MCK_VReg_512: return "MCK_VReg_512";
  case MCK_VReg_384: return "MCK_VReg_384";
  case MCK_VReg_352: return "MCK_VReg_352";
  case MCK_VReg_320: return "MCK_VReg_320";
  case MCK_VReg_288: return "MCK_VReg_288";
  case MCK_VReg_256: return "MCK_VReg_256";
  case MCK_VReg_224: return "MCK_VReg_224";
  case MCK_VReg_192: return "MCK_VReg_192";
  case MCK_VReg_160: return "MCK_VReg_160";
  case MCK_VReg_128: return "MCK_VReg_128";
  case MCK_VReg_96: return "MCK_VReg_96";
  case MCK_VReg_64: return "MCK_VReg_64";
  case MCK_VGPR_32: return "MCK_VGPR_32";
  case MCK_VRegOrLds_32: return "MCK_VRegOrLds_32";
  case MCK_Reg159: return "MCK_Reg159";
  case MCK_VS_128: return "MCK_VS_128";
  case MCK_Reg33: return "MCK_Reg33";
  case MCK_VS_64: return "MCK_VS_64";
  case MCK_Reg12: return "MCK_Reg12";
  case MCK_VS_32: return "MCK_VS_32";
  case MCK_AV_1024: return "MCK_AV_1024";
  case MCK_AV_512: return "MCK_AV_512";
  case MCK_AV_384: return "MCK_AV_384";
  case MCK_AV_352: return "MCK_AV_352";
  case MCK_AV_320: return "MCK_AV_320";
  case MCK_AV_288: return "MCK_AV_288";
  case MCK_AV_256: return "MCK_AV_256";
  case MCK_AV_224: return "MCK_AV_224";
  case MCK_AV_192: return "MCK_AV_192";
  case MCK_AV_160: return "MCK_AV_160";
  case MCK_AV_128: return "MCK_AV_128";
  case MCK_AV_96: return "MCK_AV_96";
  case MCK_AV_64: return "MCK_AV_64";
  case MCK_AV_32: return "MCK_AV_32";
  case MCK_VGPR_16: return "MCK_VGPR_16";
  case MCK_VS_16: return "MCK_VS_16";
  case MCK_RegByHwMode_AReg_64_AlignTarget: return "MCK_RegByHwMode_AReg_64_AlignTarget";
  case MCK_RegByHwMode_AReg_96_AlignTarget: return "MCK_RegByHwMode_AReg_96_AlignTarget";
  case MCK_RegByHwMode_AReg_128_AlignTarget: return "MCK_RegByHwMode_AReg_128_AlignTarget";
  case MCK_RegByHwMode_AReg_160_AlignTarget: return "MCK_RegByHwMode_AReg_160_AlignTarget";
  case MCK_RegByHwMode_AReg_192_AlignTarget: return "MCK_RegByHwMode_AReg_192_AlignTarget";
  case MCK_RegByHwMode_AReg_224_AlignTarget: return "MCK_RegByHwMode_AReg_224_AlignTarget";
  case MCK_RegByHwMode_AReg_256_AlignTarget: return "MCK_RegByHwMode_AReg_256_AlignTarget";
  case MCK_RegByHwMode_AReg_288_AlignTarget: return "MCK_RegByHwMode_AReg_288_AlignTarget";
  case MCK_RegByHwMode_AReg_320_AlignTarget: return "MCK_RegByHwMode_AReg_320_AlignTarget";
  case MCK_RegByHwMode_AReg_352_AlignTarget: return "MCK_RegByHwMode_AReg_352_AlignTarget";
  case MCK_RegByHwMode_AReg_384_AlignTarget: return "MCK_RegByHwMode_AReg_384_AlignTarget";
  case MCK_RegByHwMode_AReg_512_AlignTarget: return "MCK_RegByHwMode_AReg_512_AlignTarget";
  case MCK_RegByHwMode_AReg_1024_AlignTarget: return "MCK_RegByHwMode_AReg_1024_AlignTarget";
  case MCK_RegByHwMode_AV_64_AlignTarget: return "MCK_RegByHwMode_AV_64_AlignTarget";
  case MCK_RegByHwMode_AV_96_AlignTarget: return "MCK_RegByHwMode_AV_96_AlignTarget";
  case MCK_RegByHwMode_AV_128_AlignTarget: return "MCK_RegByHwMode_AV_128_AlignTarget";
  case MCK_RegByHwMode_AV_160_AlignTarget: return "MCK_RegByHwMode_AV_160_AlignTarget";
  case MCK_RegByHwMode_AV_192_AlignTarget: return "MCK_RegByHwMode_AV_192_AlignTarget";
  case MCK_RegByHwMode_AV_224_AlignTarget: return "MCK_RegByHwMode_AV_224_AlignTarget";
  case MCK_RegByHwMode_AV_256_AlignTarget: return "MCK_RegByHwMode_AV_256_AlignTarget";
  case MCK_RegByHwMode_AV_288_AlignTarget: return "MCK_RegByHwMode_AV_288_AlignTarget";
  case MCK_RegByHwMode_AV_320_AlignTarget: return "MCK_RegByHwMode_AV_320_AlignTarget";
  case MCK_RegByHwMode_AV_352_AlignTarget: return "MCK_RegByHwMode_AV_352_AlignTarget";
  case MCK_RegByHwMode_AV_384_AlignTarget: return "MCK_RegByHwMode_AV_384_AlignTarget";
  case MCK_RegByHwMode_AV_512_AlignTarget: return "MCK_RegByHwMode_AV_512_AlignTarget";
  case MCK_RegByHwMode_AV_1024_AlignTarget: return "MCK_RegByHwMode_AV_1024_AlignTarget";
  case MCK_RegByHwMode_AV_LdSt_32_Align2: return "MCK_RegByHwMode_AV_LdSt_32_Align2";
  case MCK_RegByHwMode_AV_LdSt_32_Target: return "MCK_RegByHwMode_AV_LdSt_32_Target";
  case MCK_RegByHwMode_AV_LdSt_64_Align1: return "MCK_RegByHwMode_AV_LdSt_64_Align1";
  case MCK_RegByHwMode_AV_LdSt_64_Align2: return "MCK_RegByHwMode_AV_LdSt_64_Align2";
  case MCK_RegByHwMode_AV_LdSt_64_AlignTarget: return "MCK_RegByHwMode_AV_LdSt_64_AlignTarget";
  case MCK_RegByHwMode_AV_LdSt_96_Align1: return "MCK_RegByHwMode_AV_LdSt_96_Align1";
  case MCK_RegByHwMode_AV_LdSt_96_Align2: return "MCK_RegByHwMode_AV_LdSt_96_Align2";
  case MCK_RegByHwMode_AV_LdSt_96_AlignTarget: return "MCK_RegByHwMode_AV_LdSt_96_AlignTarget";
  case MCK_RegByHwMode_AV_LdSt_128_Align1: return "MCK_RegByHwMode_AV_LdSt_128_Align1";
  case MCK_RegByHwMode_AV_LdSt_128_Align2: return "MCK_RegByHwMode_AV_LdSt_128_Align2";
  case MCK_RegByHwMode_AV_LdSt_128_AlignTarget: return "MCK_RegByHwMode_AV_LdSt_128_AlignTarget";
  case MCK_RegByHwMode_AV_LdSt_160_Align1: return "MCK_RegByHwMode_AV_LdSt_160_Align1";
  case MCK_RegByHwMode_AV_LdSt_160_Align2: return "MCK_RegByHwMode_AV_LdSt_160_Align2";
  case MCK_RegByHwMode_AV_LdSt_160_AlignTarget: return "MCK_RegByHwMode_AV_LdSt_160_AlignTarget";
  case MCK_RegByHwMode_AV_LdSt_192_Align1: return "MCK_RegByHwMode_AV_LdSt_192_Align1";
  case MCK_RegByHwMode_AV_LdSt_192_Align2: return "MCK_RegByHwMode_AV_LdSt_192_Align2";
  case MCK_RegByHwMode_AV_LdSt_192_AlignTarget: return "MCK_RegByHwMode_AV_LdSt_192_AlignTarget";
  case MCK_RegByHwMode_AV_LdSt_224_Align1: return "MCK_RegByHwMode_AV_LdSt_224_Align1";
  case MCK_RegByHwMode_AV_LdSt_224_Align2: return "MCK_RegByHwMode_AV_LdSt_224_Align2";
  case MCK_RegByHwMode_AV_LdSt_224_AlignTarget: return "MCK_RegByHwMode_AV_LdSt_224_AlignTarget";
  case MCK_RegByHwMode_AV_LdSt_256_Align1: return "MCK_RegByHwMode_AV_LdSt_256_Align1";
  case MCK_RegByHwMode_AV_LdSt_256_Align2: return "MCK_RegByHwMode_AV_LdSt_256_Align2";
  case MCK_RegByHwMode_AV_LdSt_256_AlignTarget: return "MCK_RegByHwMode_AV_LdSt_256_AlignTarget";
  case MCK_RegByHwMode_AV_LdSt_288_Align1: return "MCK_RegByHwMode_AV_LdSt_288_Align1";
  case MCK_RegByHwMode_AV_LdSt_288_Align2: return "MCK_RegByHwMode_AV_LdSt_288_Align2";
  case MCK_RegByHwMode_AV_LdSt_288_AlignTarget: return "MCK_RegByHwMode_AV_LdSt_288_AlignTarget";
  case MCK_RegByHwMode_AV_LdSt_320_Align1: return "MCK_RegByHwMode_AV_LdSt_320_Align1";
  case MCK_RegByHwMode_AV_LdSt_320_Align2: return "MCK_RegByHwMode_AV_LdSt_320_Align2";
  case MCK_RegByHwMode_AV_LdSt_320_AlignTarget: return "MCK_RegByHwMode_AV_LdSt_320_AlignTarget";
  case MCK_RegByHwMode_AV_LdSt_352_Align1: return "MCK_RegByHwMode_AV_LdSt_352_Align1";
  case MCK_RegByHwMode_AV_LdSt_352_Align2: return "MCK_RegByHwMode_AV_LdSt_352_Align2";
  case MCK_RegByHwMode_AV_LdSt_352_AlignTarget: return "MCK_RegByHwMode_AV_LdSt_352_AlignTarget";
  case MCK_RegByHwMode_AV_LdSt_384_Align1: return "MCK_RegByHwMode_AV_LdSt_384_Align1";
  case MCK_RegByHwMode_AV_LdSt_384_Align2: return "MCK_RegByHwMode_AV_LdSt_384_Align2";
  case MCK_RegByHwMode_AV_LdSt_384_AlignTarget: return "MCK_RegByHwMode_AV_LdSt_384_AlignTarget";
  case MCK_RegByHwMode_AV_LdSt_512_Align1: return "MCK_RegByHwMode_AV_LdSt_512_Align1";
  case MCK_RegByHwMode_AV_LdSt_512_Align2: return "MCK_RegByHwMode_AV_LdSt_512_Align2";
  case MCK_RegByHwMode_AV_LdSt_512_AlignTarget: return "MCK_RegByHwMode_AV_LdSt_512_AlignTarget";
  case MCK_RegByHwMode_AV_LdSt_1024_Align1: return "MCK_RegByHwMode_AV_LdSt_1024_Align1";
  case MCK_RegByHwMode_AV_LdSt_1024_Align2: return "MCK_RegByHwMode_AV_LdSt_1024_Align2";
  case MCK_RegByHwMode_AV_LdSt_1024_AlignTarget: return "MCK_RegByHwMode_AV_LdSt_1024_AlignTarget";
  case MCK_RegByHwMode_SReg_1: return "MCK_RegByHwMode_SReg_1";
  case MCK_RegByHwMode_SReg_1_XEXEC: return "MCK_RegByHwMode_SReg_1_XEXEC";
  case MCK_RegByHwMode_VReg_64_AlignTarget: return "MCK_RegByHwMode_VReg_64_AlignTarget";
  case MCK_RegByHwMode_VReg_96_AlignTarget: return "MCK_RegByHwMode_VReg_96_AlignTarget";
  case MCK_RegByHwMode_VReg_128_AlignTarget: return "MCK_RegByHwMode_VReg_128_AlignTarget";
  case MCK_RegByHwMode_VReg_160_AlignTarget: return "MCK_RegByHwMode_VReg_160_AlignTarget";
  case MCK_RegByHwMode_VReg_192_AlignTarget: return "MCK_RegByHwMode_VReg_192_AlignTarget";
  case MCK_RegByHwMode_VReg_224_AlignTarget: return "MCK_RegByHwMode_VReg_224_AlignTarget";
  case MCK_RegByHwMode_VReg_256_AlignTarget: return "MCK_RegByHwMode_VReg_256_AlignTarget";
  case MCK_RegByHwMode_VReg_288_AlignTarget: return "MCK_RegByHwMode_VReg_288_AlignTarget";
  case MCK_RegByHwMode_VReg_320_AlignTarget: return "MCK_RegByHwMode_VReg_320_AlignTarget";
  case MCK_RegByHwMode_VReg_352_AlignTarget: return "MCK_RegByHwMode_VReg_352_AlignTarget";
  case MCK_RegByHwMode_VReg_384_AlignTarget: return "MCK_RegByHwMode_VReg_384_AlignTarget";
  case MCK_RegByHwMode_VReg_512_AlignTarget: return "MCK_RegByHwMode_VReg_512_AlignTarget";
  case MCK_RegByHwMode_VReg_1024_AlignTarget: return "MCK_RegByHwMode_VReg_1024_AlignTarget";
  case MCK_RegByHwMode_VS_64_AlignTarget: return "MCK_RegByHwMode_VS_64_AlignTarget";
  case MCK_AV_LdSt_32_Align2_RegOp: return "MCK_AV_LdSt_32_Align2_RegOp";
  case MCK_SDWAWithBin32InputMods: return "MCK_SDWAWithBin32InputMods";
  case MCK_BoolReg: return "MCK_BoolReg";
  case MCK_RegOrImmWithFP16InputMods: return "MCK_RegOrImmWithFP16InputMods";
  case MCK_SDWAWithFP16InputMods: return "MCK_SDWAWithFP16InputMods";
  case MCK_RegOrImmWithFP32InputMods: return "MCK_RegOrImmWithFP32InputMods";
  case MCK_SDWAWithFP32InputMods: return "MCK_SDWAWithFP32InputMods";
  case MCK_RegOrInlineImmWithFP32InputMods: return "MCK_RegOrInlineImmWithFP32InputMods";
  case MCK_VRegWithFP32InputMods: return "MCK_VRegWithFP32InputMods";
  case MCK_RegOrImmWithFP64InputMods: return "MCK_RegOrImmWithFP64InputMods";
  case MCK_RegOrInlineImmWithFP64InputMods: return "MCK_RegOrInlineImmWithFP64InputMods";
  case MCK_VRegWithFP64InputMods: return "MCK_VRegWithFP64InputMods";
  case MCK_VRegWithFPInputMods: return "MCK_VRegWithFPInputMods";
  case MCK_Imm: return "MCK_Imm";
  case MCK_SDWAWithInt16InputMods: return "MCK_SDWAWithInt16InputMods";
  case MCK_RegOrImmWithInt32InputMods: return "MCK_RegOrImmWithInt32InputMods";
  case MCK_SDWAWithInt32InputMods: return "MCK_SDWAWithInt32InputMods";
  case MCK_RegOrInlineImmWithInt32InputMods: return "MCK_RegOrInlineImmWithInt32InputMods";
  case MCK_RegOrImmWithInt64InputMods: return "MCK_RegOrImmWithInt64InputMods";
  case MCK_OpSelMods: return "MCK_OpSelMods";
  case MCK_VRegWithIntInputMods: return "MCK_VRegWithIntInputMods";
  case MCK_PackedFP16InputMods: return "MCK_PackedFP16InputMods";
  case MCK_PackedInt16InputMods: return "MCK_PackedInt16InputMods";
  case MCK_PackedFP32InputMods: return "MCK_PackedFP32InputMods";
  case MCK_VReg32OrOff: return "MCK_VReg32OrOff";
  case MCK_SSrc_b16: return "MCK_SSrc_b16";
  case MCK_SSrc_bf16: return "MCK_SSrc_bf16";
  case MCK_SSrc_f16: return "MCK_SSrc_f16";
  case MCK_SSrc_b32: return "MCK_SSrc_b32";
  case MCK_SSrc_f32: return "MCK_SSrc_f32";
  case MCK_SSrc_b64: return "MCK_SSrc_b64";
  case MCK_SSrcOrLds_b32: return "MCK_SSrcOrLds_b32";
  case MCK_SCSrc_b32: return "MCK_SCSrc_b32";
  case MCK_SCSrc_b64: return "MCK_SCSrc_b64";
  case MCK_VSrc_b16: return "MCK_VSrc_b16";
  case MCK_VSrc_bf16: return "MCK_VSrc_bf16";
  case MCK_VSrc_f16: return "MCK_VSrc_f16";
  case MCK_VSrcT_b16: return "MCK_VSrcT_b16";
  case MCK_VSrcT_bf16: return "MCK_VSrcT_bf16";
  case MCK_VSrcT_f16: return "MCK_VSrcT_f16";
  case MCK_VSrcT_b16_Lo128: return "MCK_VSrcT_b16_Lo128";
  case MCK_VSrcT_bf16_Lo128: return "MCK_VSrcT_bf16_Lo128";
  case MCK_VSrcT_f16_Lo128: return "MCK_VSrcT_f16_Lo128";
  case MCK_VSrcFake16_b16_Lo128: return "MCK_VSrcFake16_b16_Lo128";
  case MCK_VSrcFake16_bf16_Lo128: return "MCK_VSrcFake16_bf16_Lo128";
  case MCK_VSrcFake16_f16_Lo128: return "MCK_VSrcFake16_f16_Lo128";
  case MCK_VSrc_b32: return "MCK_VSrc_b32";
  case MCK_VSrc_f32: return "MCK_VSrc_f32";
  case MCK_VSrc_v2b16: return "MCK_VSrc_v2b16";
  case MCK_VSrc_v2bf16: return "MCK_VSrc_v2bf16";
  case MCK_VSrc_v2f16: return "MCK_VSrc_v2f16";
  case MCK_VSrc_b64: return "MCK_VSrc_b64";
  case MCK_VSrc_f64: return "MCK_VSrc_f64";
  case MCK_VSrc_v2b32: return "MCK_VSrc_v2b32";
  case MCK_VSrc_v2f32: return "MCK_VSrc_v2f32";
  case MCK_VSrc_NoInline_v2f16: return "MCK_VSrc_NoInline_v2f16";
  case MCK_VSrc_v2f16_splat: return "MCK_VSrc_v2f16_splat";
  case MCK_VCSrc_b16: return "MCK_VCSrc_b16";
  case MCK_VCSrc_bf16: return "MCK_VCSrc_bf16";
  case MCK_VCSrc_f16: return "MCK_VCSrc_f16";
  case MCK_VCSrc_b32: return "MCK_VCSrc_b32";
  case MCK_VCSrc_f32: return "MCK_VCSrc_f32";
  case MCK_VCSrc_v2b16: return "MCK_VCSrc_v2b16";
  case MCK_VCSrc_v2bf16: return "MCK_VCSrc_v2bf16";
  case MCK_VCSrc_v2f16: return "MCK_VCSrc_v2f16";
  case MCK_VCSrc_b32_Lo256: return "MCK_VCSrc_b32_Lo256";
  case MCK_VCSrc_b64_Lo256: return "MCK_VCSrc_b64_Lo256";
  case MCK_VCSrc_b64: return "MCK_VCSrc_b64";
  case MCK_VCSrc_f64: return "MCK_VCSrc_f64";
  case MCK_VCSrc_v2b32: return "MCK_VCSrc_v2b32";
  case MCK_VCSrcT_b16: return "MCK_VCSrcT_b16";
  case MCK_VCSrcT_bf16: return "MCK_VCSrcT_bf16";
  case MCK_VCSrcT_f16: return "MCK_VCSrcT_f16";
  case MCK_VISrc_64_bf16: return "MCK_VISrc_64_bf16";
  case MCK_VISrc_64_f16: return "MCK_VISrc_64_f16";
  case MCK_VISrc_64_b32: return "MCK_VISrc_64_b32";
  case MCK_VISrc_64_f64: return "MCK_VISrc_64_f64";
  case MCK_VISrc_128_bf16: return "MCK_VISrc_128_bf16";
  case MCK_VISrc_128_f16: return "MCK_VISrc_128_f16";
  case MCK_VISrc_128_b32: return "MCK_VISrc_128_b32";
  case MCK_VISrc_128_f32: return "MCK_VISrc_128_f32";
  case MCK_VISrc_256_b32: return "MCK_VISrc_256_b32";
  case MCK_VISrc_256_f32: return "MCK_VISrc_256_f32";
  case MCK_VISrc_256_f64: return "MCK_VISrc_256_f64";
  case MCK_VISrc_512_b32: return "MCK_VISrc_512_b32";
  case MCK_VISrc_512_f32: return "MCK_VISrc_512_f32";
  case MCK_VISrc_512_f64: return "MCK_VISrc_512_f64";
  case MCK_VISrc_1024_b32: return "MCK_VISrc_1024_b32";
  case MCK_VISrc_1024_f32: return "MCK_VISrc_1024_f32";
  case MCK_AISrc_64_f64: return "MCK_AISrc_64_f64";
  case MCK_AISrc_128_f32: return "MCK_AISrc_128_f32";
  case MCK_AISrc_128_b32: return "MCK_AISrc_128_b32";
  case MCK_AISrc_256_f64: return "MCK_AISrc_256_f64";
  case MCK_AISrc_512_f32: return "MCK_AISrc_512_f32";
  case MCK_AISrc_512_b32: return "MCK_AISrc_512_b32";
  case MCK_AISrc_1024_f32: return "MCK_AISrc_1024_f32";
  case MCK_AISrc_1024_b32: return "MCK_AISrc_1024_b32";
  case MCK_S16Imm: return "MCK_S16Imm";
  case MCK_U16Imm: return "MCK_U16Imm";
  case MCK_SOPPBrTarget: return "MCK_SOPPBrTarget";
  case MCK_InterpSlot: return "MCK_InterpSlot";
  case MCK_InterpAttr: return "MCK_InterpAttr";
  case MCK_InterpAttrChan: return "MCK_InterpAttrChan";
  case MCK_SplitBarrier: return "MCK_SplitBarrier";
  case MCK_SendMsg: return "MCK_SendMsg";
  case MCK_Swizzle: return "MCK_Swizzle";
  case MCK_Endpgm: return "MCK_Endpgm";
  case MCK_SWaitCnt: return "MCK_SWaitCnt";
  case MCK_DepCtr: return "MCK_DepCtr";
  case MCK_SDelayALU: return "MCK_SDelayALU";
  case MCK_FlatOffset: return "MCK_FlatOffset";
  case MCK_Offset: return "MCK_Offset";
  case MCK_Offset0: return "MCK_Offset0";
  case MCK_Offset1: return "MCK_Offset1";
  case MCK_GDS: return "MCK_GDS";
  case MCK_OModSI: return "MCK_OModSI";
  case MCK_Clamp: return "MCK_Clamp";
  case MCK_High: return "MCK_High";
  case MCK_CPol: return "MCK_CPol";
  case MCK_CPol_GLC: return "MCK_CPol_GLC";
  case MCK_CPol_NonGLC: return "MCK_CPol_NonGLC";
  case MCK_TFE: return "MCK_TFE";
  case MCK_UNorm: return "MCK_UNorm";
  case MCK_DA: return "MCK_DA";
  case MCK_R128A16: return "MCK_R128A16";
  case MCK_A16: return "MCK_A16";
  case MCK_D16: return "MCK_D16";
  case MCK_LWE: return "MCK_LWE";
  case MCK_ExpCompr: return "MCK_ExpCompr";
  case MCK_ExpVM: return "MCK_ExpVM";
  case MCK_FORMAT: return "MCK_FORMAT";
  case MCK_DMask: return "MCK_DMask";
  case MCK_Dim: return "MCK_Dim";
  case MCK_SDWADstSel: return "MCK_SDWADstSel";
  case MCK_SDWASrc0Sel: return "MCK_SDWASrc0Sel";
  case MCK_SDWASrc1Sel: return "MCK_SDWASrc1Sel";
  case MCK_SDWADstUnused: return "MCK_SDWADstUnused";
  case MCK_OpSel: return "MCK_OpSel";
  case MCK_OpSelHi: return "MCK_OpSelHi";
  case MCK_NegLo: return "MCK_NegLo";
  case MCK_NegHi: return "MCK_NegHi";
  case MCK_IndexKey32bit: return "MCK_IndexKey32bit";
  case MCK_IndexKey16bit: return "MCK_IndexKey16bit";
  case MCK_IndexKey8bit: return "MCK_IndexKey8bit";
  case MCK_DPP8: return "MCK_DPP8";
  case MCK_DPPCtrl: return "MCK_DPPCtrl";
  case MCK_DppRowMask: return "MCK_DppRowMask";
  case MCK_DppBankMask: return "MCK_DppBankMask";
  case MCK_DppBoundCtrl: return "MCK_DppBoundCtrl";
  case MCK_DppFI: return "MCK_DppFI";
  case MCK_BLGP: return "MCK_BLGP";
  case MCK_CBSZ: return "MCK_CBSZ";
  case MCK_ABID: return "MCK_ABID";
  case MCK_Hwreg: return "MCK_Hwreg";
  case MCK_ExpTgt: return "MCK_ExpTgt";
  case MCK_WaitVDST: return "MCK_WaitVDST";
  case MCK_WaitEXP: return "MCK_WaitEXP";
  case MCK_WaitVAVDst: return "MCK_WaitVAVDst";
  case MCK_WaitVMVSrc: return "MCK_WaitVMVSrc";
  case MCK_ByteSel: return "MCK_ByteSel";
  case MCK_BitOp3: return "MCK_BitOp3";
  case MCK_MatrixAFMT: return "MCK_MatrixAFMT";
  case MCK_MatrixBFMT: return "MCK_MatrixBFMT";
  case MCK_MatrixAScale: return "MCK_MatrixAScale";
  case MCK_MatrixBScale: return "MCK_MatrixBScale";
  case MCK_MatrixAScaleFmt: return "MCK_MatrixAScaleFmt";
  case MCK_MatrixBScaleFmt: return "MCK_MatrixBScaleFmt";
  case MCK_MatrixAReuse: return "MCK_MatrixAReuse";
  case MCK_MatrixBReuse: return "MCK_MatrixBReuse";
  case MCK_ScaleSel: return "MCK_ScaleSel";
  case MCK_KImmFP32: return "MCK_KImmFP32";
  case MCK_KImmFP16: return "MCK_KImmFP16";
  case MCK_KImmFP64: return "MCK_KImmFP64";
  case MCK_Fake16VRegWithFPInputMods: return "MCK_Fake16VRegWithFPInputMods";
  case MCK_RegOrInlineImmWithFPFake16InputMods: return "MCK_RegOrInlineImmWithFPFake16InputMods";
  case MCK_Fake16VRegWithIntInputMods: return "MCK_Fake16VRegWithIntInputMods";
  case MCK_RegOrInlineImmWithIntFake16InputMods: return "MCK_RegOrInlineImmWithIntFake16InputMods";
  case MCK_GPRIdxMode: return "MCK_GPRIdxMode";
  case MCK_RegOrImmWithFPT16InputMods: return "MCK_RegOrImmWithFPT16InputMods";
  case MCK_T16_Lo128VRegWithFPInputMods: return "MCK_T16_Lo128VRegWithFPInputMods";
  case MCK_T16VRegWithFPInputMods: return "MCK_T16VRegWithFPInputMods";
  case MCK_RegOrInlineImmWithFPT16InputMods: return "MCK_RegOrInlineImmWithFPT16InputMods";
  case MCK_RegOrImmWithFPFake16InputMods: return "MCK_RegOrImmWithFPFake16InputMods";
  case MCK_Fake16_Lo128VRegWithFPInputMods: return "MCK_Fake16_Lo128VRegWithFPInputMods";
  case MCK_RegOrImmWithIntT16InputMods: return "MCK_RegOrImmWithIntT16InputMods";
  case MCK_T16_Lo128VRegWithIntInputMods: return "MCK_T16_Lo128VRegWithIntInputMods";
  case MCK_T16VRegWithIntInputMods: return "MCK_T16VRegWithIntInputMods";
  case MCK_RegOrInlineImmWithIntT16InputMods: return "MCK_RegOrInlineImmWithIntT16InputMods";
  case MCK_RegOrImmWithIntFake16InputMods: return "MCK_RegOrImmWithIntFake16InputMods";
  case MCK_Fake16_Lo128VRegWithIntInputMods: return "MCK_Fake16_Lo128VRegWithIntInputMods";
  case MCK_SMRDOffset8: return "MCK_SMRDOffset8";
  case MCK_SMEMOffset: return "MCK_SMEMOffset";
  case MCK_SMEMOffsetMod: return "MCK_SMEMOffsetMod";
  case MCK_OptSMEMOffsetMod: return "MCK_OptSMEMOffsetMod";
  case MCK_SMRDLiteralOffset: return "MCK_SMRDLiteralOffset";
  case NumMatchClassKinds: return "NumMatchClassKinds";
  }
  llvm_unreachable("unhandled MatchClassKind!");
}

#endif // NDEBUG
FeatureBitset AMDGPUAsmParser::
ComputeAvailableFeatures(const FeatureBitset &FB) const {
  FeatureBitset Features;
  if (FB[AMDGPU::FeatureSouthernIslands])
    Features.set(Feature_isGFX6Bit);
  if (!FB[AMDGPU::FeatureGCN3Encoding] && !FB[AMDGPU::FeatureGFX10Insts])
    Features.set(Feature_isGFX6GFX7Bit);
  if (!FB[AMDGPU::FeatureGCN3Encoding] && !FB[AMDGPU::FeatureGFX11Insts])
    Features.set(Feature_isGFX6GFX7GFX10Bit);
  if (!FB[AMDGPU::FeatureGCN3Encoding])
    Features.set(Feature_isGFX6GFX7GFX10PlusBit);
  if (!FB[AMDGPU::FeatureGCN3Encoding] && FB[AMDGPU::FeatureCIInsts] && !FB[AMDGPU::FeatureGFX10Insts])
    Features.set(Feature_isGFX7OnlyBit);
  if (!FB[AMDGPU::FeatureGCN3Encoding] && FB[AMDGPU::FeatureCIInsts] && !FB[AMDGPU::FeatureGFX11Insts])
    Features.set(Feature_isGFX7GFX10Bit);
  if (!FB[AMDGPU::FeatureGCN3Encoding] && FB[AMDGPU::FeatureCIInsts])
    Features.set(Feature_isGFX7GFX10GFX11Bit);
  if (FB[AMDGPU::FeatureGFX7GFX8GFX9Insts])
    Features.set(Feature_isGFX7GFX8GFX9Bit);
  if (!FB[AMDGPU::FeatureGFX10Insts])
    Features.set(Feature_isGFX6GFX7GFX8GFX9Bit);
  if (!FB[AMDGPU::FeatureGFX10Insts] && !FB[AMDGPU::FeatureGFX90AInsts])
    Features.set(Feature_isGFX6GFX7GFX8GFX9NotGFX90ABit);
  if (!FB[AMDGPU::FeatureGFX11Insts])
    Features.set(Feature_isGFX6GFX7GFX8GFX9GFX10Bit);
  if (!FB[AMDGPU::FeatureGFX12Insts])
    Features.set(Feature_isNotGFX12PlusBit);
  if (FB[AMDGPU::FeatureCIInsts] && !FB[AMDGPU::FeatureGFX11Insts])
    Features.set(Feature_isGFX7GFX8GFX9GFX10Bit);
  if (FB[AMDGPU::FeatureGFX8Insts] && !FB[AMDGPU::FeatureGFX12Insts])
    Features.set(Feature_isGFX8GFX9GFX10GFX11Bit);
  if (FB[AMDGPU::FeatureCIInsts])
    Features.set(Feature_isGFX7PlusBit);
  if (FB[AMDGPU::FeatureGFX8Insts])
    Features.set(Feature_isGFX8PlusBit);
  if (FB[AMDGPU::FeatureVolcanicIslands])
    Features.set(Feature_isGFX8OnlyBit);
  if (FB[AMDGPU::FeatureGFX9Insts])
    Features.set(Feature_isGFX9PlusBit);
  if (FB[AMDGPU::FeatureGCN3Encoding] && FB[AMDGPU::FeatureGFX9Insts])
    Features.set(Feature_isGFX9OnlyBit);
  if (FB[AMDGPU::FeatureGCN3Encoding] && !FB[AMDGPU::FeatureGFX90AInsts])
    Features.set(Feature_isGCN3ExcludingGFX90ABit);
  if (FB[AMDGPU::FeatureGFX90AInsts])
    Features.set(Feature_isGFX90APlusBit);
  if (!FB[AMDGPU::FeatureGFX90AInsts])
    Features.set(Feature_isNotGFX90APlusBit);
  if (FB[AMDGPU::FeatureGFX8Insts] && FB[AMDGPU::FeatureGCN3Encoding] && !FB[AMDGPU::FeatureGFX90AInsts])
    Features.set(Feature_isGFX8GFX9NotGFX90ABit);
  if (FB[AMDGPU::FeatureGFX90AInsts] && !FB[AMDGPU::FeatureGFX940Insts])
    Features.set(Feature_isGFX90AOnlyBit);
  if (FB[AMDGPU::FeatureMAIInsts] && !FB[AMDGPU::FeatureGFX940Insts])
    Features.set(Feature_isGFX908orGFX90ABit);
  if (FB[AMDGPU::FeatureGFX940Insts])
    Features.set(Feature_isGFX940PlusBit);
  if (!FB[AMDGPU::FeatureGFX940Insts])
    Features.set(Feature_isNotGFX940PlusBit);
  if (FB[AMDGPU::FeatureGFX950Insts])
    Features.set(Feature_HasGFX950InstsBit);
  if (FB[AMDGPU::FeaturePermlane16Swap])
    Features.set(Feature_HasPermlane16SwapBit);
  if (FB[AMDGPU::FeaturePermlane32Swap])
    Features.set(Feature_HasPermlane32SwapBit);
  if (FB[AMDGPU::FeatureGFX8Insts] && FB[AMDGPU::FeatureGCN3Encoding] && !FB[AMDGPU::FeatureGFX940Insts])
    Features.set(Feature_isGFX8GFX9NotGFX940Bit);
  if (FB[AMDGPU::FeatureGFX8Insts] && FB[AMDGPU::FeatureGCN3Encoding])
    Features.set(Feature_isGFX8GFX9Bit);
  if (FB[AMDGPU::FeatureGFX10Insts] && !FB[AMDGPU::FeatureGFX11Insts])
    Features.set(Feature_isGFX10OnlyBit);
  if (FB[AMDGPU::FeatureGFX10Insts])
    Features.set(Feature_isGFX10PlusBit);
  if (FB[AMDGPU::FeatureGFX10Insts] && !FB[AMDGPU::FeatureGFX12Insts])
    Features.set(Feature_isGFX10GFX11Bit);
  if (FB[AMDGPU::FeatureGFX10Insts] && !FB[AMDGPU::FeatureGFX10_3Insts])
    Features.set(Feature_isGFX10Before1030Bit);
  if (FB[AMDGPU::FeatureGFX9Insts] && !FB[AMDGPU::FeatureGFX11Insts])
    Features.set(Feature_isGFX9GFX10Bit);
  if (FB[AMDGPU::FeatureGFX9Insts] && !FB[AMDGPU::FeatureGFX12Insts])
    Features.set(Feature_isGFX9GFX10GFX11Bit);
  if (FB[AMDGPU::FeatureGFX8Insts] && !FB[AMDGPU::FeatureGFX11Insts])
    Features.set(Feature_isGFX8GFX9GFX10Bit);
  if (FB[AMDGPU::FeatureGFX11Insts] && !FB[AMDGPU::FeatureGFX12Insts])
    Features.set(Feature_isGFX11OnlyBit);
  if (FB[AMDGPU::FeatureGFX11Insts])
    Features.set(Feature_isGFX11PlusBit);
  if (FB[AMDGPU::FeatureGFX12Insts])
    Features.set(Feature_isGFX12OnlyBit);
  if (FB[AMDGPU::FeatureGFX12Insts] && !FB[AMDGPU::FeatureGFX1250Insts])
    Features.set(Feature_isGFX12Not12_50Bit);
  if (FB[AMDGPU::FeatureGFX12Insts])
    Features.set(Feature_isGFX12PlusBit);
  if (FB[AMDGPU::FeatureGFX12Insts] && !FB[AMDGPU::FeatureGFX1250Insts])
    Features.set(Feature_isGFX12PlusNot12_50Bit);
  if (FB[AMDGPU::FeatureGFX1250Insts])
    Features.set(Feature_isGFX125xOnlyBit);
  if (FB[AMDGPU::FeatureGFX1250Insts])
    Features.set(Feature_isGFX1250PlusBit);
  if (!FB[AMDGPU::FeatureGFX1250Insts])
    Features.set(Feature_isNotGFX1250PlusBit);
  if (FB[AMDGPU::FeatureGFX940Insts] || FB[AMDGPU::FeatureGFX1250Insts])
    Features.set(Feature_isGFX940orGFX1250Bit);
  if (FB[AMDGPU::FeatureIEEEMinimumMaximumInsts])
    Features.set(Feature_HasIEEEMinimumMaximumInstsBit);
  if (FB[AMDGPU::FeatureMinimum3Maximum3F32])
    Features.set(Feature_HasMinimum3Maximum3F32Bit);
  if (FB[AMDGPU::FeatureMinimum3Maximum3F16])
    Features.set(Feature_HasMinimum3Maximum3F16Bit);
  if (FB[AMDGPU::FeatureMin3Max3PKF16])
    Features.set(Feature_HasMin3Max3PKF16Bit);
  if (FB[AMDGPU::FeatureMinimum3Maximum3PKF16])
    Features.set(Feature_HasMinimum3Maximum3PKF16Bit);
  if (FB[AMDGPU::FeatureFlatAddressSpace])
    Features.set(Feature_HasFlatAddressSpaceBit);
  if (FB[AMDGPU::FeatureFlatBufferGlobalAtomicFaddF64Inst])
    Features.set(Feature_HasFlatBufferGlobalAtomicFaddF64InstBit);
  if (FB[AMDGPU::FeatureAtomicFMinFMaxF32GlobalInsts])
    Features.set(Feature_HasAtomicFMinFMaxF32GlobalInstsBit);
  if (FB[AMDGPU::FeatureAtomicFMinFMaxF64GlobalInsts])
    Features.set(Feature_HasAtomicFMinFMaxF64GlobalInstsBit);
  if (FB[AMDGPU::FeatureAtomicFMinFMaxF32FlatInsts])
    Features.set(Feature_HasAtomicFMinFMaxF32FlatInstsBit);
  if (FB[AMDGPU::FeatureAtomicFMinFMaxF64FlatInsts])
    Features.set(Feature_HasAtomicFMinFMaxF64FlatInstsBit);
  if (FB[AMDGPU::FeatureGFX12Insts])
    Features.set(Feature_HasAtomicCondSubClampFlatInstsBit);
  if (FB[AMDGPU::FeatureGFX90AInsts] || FB[AMDGPU::FeatureGFX1250Insts])
    Features.set(Feature_HasLdsAtomicAddF64Bit);
  if (FB[AMDGPU::FeatureFlatGlobalInsts])
    Features.set(Feature_HasFlatGlobalInstsBit);
  if (FB[AMDGPU::FeatureFlatScratchInsts])
    Features.set(Feature_HasFlatScratchInstsBit);
  if (FB[AMDGPU::FeatureScalarFlatScratchInsts])
    Features.set(Feature_HasScalarFlatScratchInstsBit);
  if (FB[AMDGPU::FeatureGFX9Insts])
    Features.set(Feature_HasD16LoadStoreBit);
  if (FB[AMDGPU::FeatureGFX10_3Insts] || FB[AMDGPU::FeatureGFX940Insts])
    Features.set(Feature_HasFlatScratchSTModeBit);
  if (FB[AMDGPU::FeatureGFX940Insts] || FB[AMDGPU::FeatureGFX11Insts])
    Features.set(Feature_HasFlatScratchSVSModeBit);
  if (FB[AMDGPU::FeatureFlatGVSMode])
    Features.set(Feature_HasFlatGVSModeBit);
  if (FB[AMDGPU::FeatureGFX10_AEncoding])
    Features.set(Feature_HasGFX10_AEncodingBit);
  if (FB[AMDGPU::FeatureGFX10_BEncoding])
    Features.set(Feature_HasGFX10_BEncodingBit);
  if (FB[AMDGPU::FeatureUnpackedD16VMem])
    Features.set(Feature_HasUnpackedD16VMemBit);
  if (!FB[AMDGPU::FeatureUnpackedD16VMem])
    Features.set(Feature_HasPackedD16VMemBit);
  if (FB[AMDGPU::FeatureHasRestrictedSOffset])
    Features.set(Feature_HasRestrictedSOffsetBit);
  if (!FB[AMDGPU::FeatureHasRestrictedSOffset])
    Features.set(Feature_HasUnrestrictedSOffsetBit);
  if (FB[AMDGPU::FeatureGFX9Insts] && !FB[AMDGPU::FeatureSRAMECC])
    Features.set(Feature_D16PreservesUnusedBitsBit);
  if (!FB[AMDGPU::FeatureGFX1250Insts])
    Features.set(Feature_HasMTBUFInstsBit);
  if (!FB[AMDGPU::FeatureGFX1250Insts])
    Features.set(Feature_HasFormattedMUBUFInstsBit);
  if (!FB[AMDGPU::FeatureGFX90AInsts] && !FB[AMDGPU::FeatureGFX1250Insts])
    Features.set(Feature_HasExportInstsBit);
  if (FB[AMDGPU::FeatureGFX11Insts] && !FB[AMDGPU::FeatureGFX1250Insts])
    Features.set(Feature_HasVINTERPEncodingBit);
  if (FB[AMDGPU::FeatureGFX9Insts])
    Features.set(Feature_HasDSAddTidBit);
  if (FB[AMDGPU::FeatureGFX8Insts])
    Features.set(Feature_HasLDSFPAtomicAddF32Bit);
  if (FB[AMDGPU::FeatureAddNoCarryInsts])
    Features.set(Feature_HasAddNoCarryInstsBit);
  if (FB[AMDGPU::Feature16BitInsts])
    Features.set(Feature_Has16BitInstsBit);
  if (FB[AMDGPU::FeatureTrue16BitInsts])
    Features.set(Feature_HasTrue16BitInstsBit);
  if (!FB[AMDGPU::FeatureTrue16BitInsts])
    Features.set(Feature_NotHasTrue16BitInstsBit);
  if (FB[AMDGPU::FeatureTrue16BitInsts] && FB[AMDGPU::FeatureRealTrue16Insts])
    Features.set(Feature_UseRealTrue16InstsBit);
  if (!(FB[AMDGPU::FeatureTrue16BitInsts] && FB[AMDGPU::FeatureRealTrue16Insts]))
    Features.set(Feature_NotUseRealTrue16InstsBit);
  if (FB[AMDGPU::FeatureTrue16BitInsts])
    Features.set(Feature_UseFakeTrue16InstsBit);
  if (FB[AMDGPU::FeatureTrue16BitInsts] && FB[AMDGPU::FeatureRealTrue16Insts] && FB[AMDGPU::FeatureD16Writes32BitVgpr])
    Features.set(Feature_HasD16Writes32BitVgprBit);
  if (FB[AMDGPU::FeatureTrue16BitInsts] && FB[AMDGPU::FeatureRealTrue16Insts] && !FB[AMDGPU::FeatureD16Writes32BitVgpr])
    Features.set(Feature_NotHasD16Writes32BitVgprBit);
  if (FB[AMDGPU::FeatureBF16TransInsts])
    Features.set(Feature_HasBF16TransInstsBit);
  if (FB[AMDGPU::FeatureBF16ConversionInsts])
    Features.set(Feature_HasBF16ConversionInstsBit);
  if (FB[AMDGPU::FeatureBF16PackedInsts])
    Features.set(Feature_HasBF16PackedInstsBit);
  if (FB[AMDGPU::FeatureVOP3P])
    Features.set(Feature_HasVOP3PInstsBit);
  if (!FB[AMDGPU::FeatureGFX9Insts] && FB[AMDGPU::FeatureSDWA])
    Features.set(Feature_HasSDWA8Bit);
  if (FB[AMDGPU::FeatureGCN3Encoding] && FB[AMDGPU::FeatureGFX9Insts] && FB[AMDGPU::FeatureSDWA])
    Features.set(Feature_HasSDWA9Bit);
  if (!FB[AMDGPU::FeatureGCN3Encoding] && FB[AMDGPU::FeatureGFX10Insts] && FB[AMDGPU::FeatureSDWA])
    Features.set(Feature_HasSDWA10Bit);
  if (FB[AMDGPU::FeatureGCN3Encoding] && FB[AMDGPU::FeatureDPP])
    Features.set(Feature_HasDPPBit);
  if (!FB[AMDGPU::FeatureGCN3Encoding] && FB[AMDGPU::FeatureGFX10Insts] && FB[AMDGPU::FeatureDPP8])
    Features.set(Feature_HasDPP8Bit);
  if (FB[AMDGPU::FeatureDPALU_DPP])
    Features.set(Feature_HasDPALU_DPPBit);
  if (FB[AMDGPU::FeaturePackedFP32Ops])
    Features.set(Feature_HasPackedFP32OpsBit);
  if (FB[AMDGPU::FeatureGFX90AInsts])
    Features.set(Feature_HasPkMovB32Bit);
  if (FB[AMDGPU::FeatureGFX10Insts] || FB[AMDGPU::FeatureGFX940Insts])
    Features.set(Feature_HasFmaakFmamkF32InstsBit);
  if (FB[AMDGPU::FeatureGFX1250Insts])
    Features.set(Feature_HasFmaakFmamkF64InstsBit);
  if (FB[AMDGPU::FeatureAddMinMaxInsts])
    Features.set(Feature_HasAddMinMaxInstsBit);
  if (FB[AMDGPU::FeaturePkAddMinMaxInsts])
    Features.set(Feature_HasPkAddMinMaxInstsBit);
  if (FB[AMDGPU::FeatureGFX1250Insts])
    Features.set(Feature_HasPkMinMax3InstsBit);
  if (FB[AMDGPU::FeatureGFX1250Insts])
    Features.set(Feature_HasSGetShaderCyclesInstBit);
  if (FB[AMDGPU::FeatureImageInsts])
    Features.set(Feature_HasImageInstsBit);
  if (FB[AMDGPU::FeatureExtendedImageInsts])
    Features.set(Feature_HasExtendedImageInstsBit);
  if (FB[AMDGPU::FeatureR128A16])
    Features.set(Feature_HasR128A16Bit);
  if (FB[AMDGPU::FeatureA16])
    Features.set(Feature_HasA16Bit);
  if (FB[AMDGPU::FeatureG16])
    Features.set(Feature_HasG16Bit);
  if (!FB[AMDGPU::FeatureGCN3Encoding] && FB[AMDGPU::FeatureGFX10Insts] && FB[AMDGPU::FeatureDPP])
    Features.set(Feature_HasDPP16Bit);
  if (FB[AMDGPU::FeatureIntClamp])
    Features.set(Feature_HasIntClampBit);
  if (FB[AMDGPU::FeatureMadMixInsts])
    Features.set(Feature_HasMadMixInstsBit);
  if (FB[AMDGPU::FeatureScalarStores])
    Features.set(Feature_HasScalarStoresBit);
  if (FB[AMDGPU::FeatureScalarAtomics])
    Features.set(Feature_HasScalarAtomicsBit);
  if (FB[AMDGPU::FeatureNoSdstCMPX])
    Features.set(Feature_HasNoSdstCMPXBit);
  if (!FB[AMDGPU::FeatureNoSdstCMPX])
    Features.set(Feature_HasSdstCMPXBit);
  if (FB[AMDGPU::FeatureVGPRIndexMode])
    Features.set(Feature_HasVGPRIndexModeBit);
  if (FB[AMDGPU::FeatureMovrel])
    Features.set(Feature_HasMovrelBit);
  if (FB[AMDGPU::FeatureFmaMixInsts])
    Features.set(Feature_HasFmaMixInstsBit);
  if (FB[AMDGPU::FeatureFmaMixBF16Insts])
    Features.set(Feature_HasFmaMixBF16InstsBit);
  if (FB[AMDGPU::FeatureDLInsts])
    Features.set(Feature_HasDLInstsBit);
  if (FB[AMDGPU::FeatureFmacF64Inst])
    Features.set(Feature_HasFmacF64InstBit);
  if (FB[AMDGPU::FeatureDot1Insts])
    Features.set(Feature_HasDot1InstsBit);
  if (FB[AMDGPU::FeatureDot2Insts])
    Features.set(Feature_HasDot2InstsBit);
  if (FB[AMDGPU::FeatureDot3Insts])
    Features.set(Feature_HasDot3InstsBit);
  if (FB[AMDGPU::FeatureDot4Insts])
    Features.set(Feature_HasDot4InstsBit);
  if (FB[AMDGPU::FeatureDot5Insts])
    Features.set(Feature_HasDot5InstsBit);
  if (FB[AMDGPU::FeatureDot6Insts])
    Features.set(Feature_HasDot6InstsBit);
  if (FB[AMDGPU::FeatureDot7Insts])
    Features.set(Feature_HasDot7InstsBit);
  if (FB[AMDGPU::FeatureDot8Insts])
    Features.set(Feature_HasDot8InstsBit);
  if (FB[AMDGPU::FeatureDot9Insts])
    Features.set(Feature_HasDot9InstsBit);
  if (FB[AMDGPU::FeatureDot10Insts])
    Features.set(Feature_HasDot10InstsBit);
  if (FB[AMDGPU::FeatureDot11Insts])
    Features.set(Feature_HasDot11InstsBit);
  if (FB[AMDGPU::FeatureDot12Insts])
    Features.set(Feature_HasDot12InstsBit);
  if (FB[AMDGPU::FeatureDot13Insts])
    Features.set(Feature_HasDot13InstsBit);
  if (FB[AMDGPU::FeatureGetWaveIdInst])
    Features.set(Feature_HasGetWaveIdInstBit);
  if (FB[AMDGPU::FeatureMAIInsts])
    Features.set(Feature_HasMAIInstsBit);
  if (!FB[AMDGPU::FeatureMAIInsts])
    Features.set(Feature_NotHasMAIInstsBit);
  if (FB[AMDGPU::FeatureSMemRealTime])
    Features.set(Feature_HasSMemRealTimeBit);
  if (FB[AMDGPU::FeatureSMemTimeInst])
    Features.set(Feature_HasSMemTimeInstBit);
  if (FB[AMDGPU::FeatureShaderCyclesRegister])
    Features.set(Feature_HasShaderCyclesRegisterBit);
  if (FB[AMDGPU::FeatureFP8Insts])
    Features.set(Feature_HasFP8InstsBit);
  if (FB[AMDGPU::FeatureFP8ConversionInsts])
    Features.set(Feature_HasFP8ConversionInstsBit);
  if (FB[AMDGPU::FeatureCubeInsts])
    Features.set(Feature_HasCubeInstsBit);
  if (FB[AMDGPU::FeatureLerpInst])
    Features.set(Feature_HasLerpInstBit);
  if (FB[AMDGPU::FeatureSadInsts])
    Features.set(Feature_HasSadInstsBit);
  if (FB[AMDGPU::FeatureQsadInsts])
    Features.set(Feature_HasQsadInstsBit);
  if (FB[AMDGPU::FeatureCvtNormInsts])
    Features.set(Feature_HasCvtNormInstsBit);
  if (FB[AMDGPU::FeatureCvtPkNormVOP2Insts])
    Features.set(Feature_HasCvtPkNormVOP2InstsBit);
  if (FB[AMDGPU::FeatureCvtPkNormVOP3Insts])
    Features.set(Feature_HasCvtPkNormVOP3InstsBit);
  if (FB[AMDGPU::FeatureFP8E5M3Insts])
    Features.set(Feature_HasFP8E5M3InstsBit);
  if (!FB[AMDGPU::FeatureFP8E5M3Insts])
    Features.set(Feature_NotHasFP8E5M3InstsBit);
  if (FB[AMDGPU::FeaturePkFmacF16Inst])
    Features.set(Feature_HasPkFmacF16InstBit);
  if (FB[AMDGPU::FeatureMadMacF32Insts])
    Features.set(Feature_HasMadMacF32InstsBit);
  if (FB[AMDGPU::FeatureGFX10_3Insts])
    Features.set(Feature_HasFmaLegacy32Bit);
  if (FB[AMDGPU::FeatureGFX10_3Insts] && !FB[AMDGPU::FeatureGFX12Insts])
    Features.set(Feature_HasFmacLegacy32Bit);
  if (FB[AMDGPU::FeatureAtomicDsPkAdd16Insts])
    Features.set(Feature_HasAtomicDsPkAdd16InstsBit);
  if (FB[AMDGPU::FeatureGFX12Insts])
    Features.set(Feature_HasAtomicDsCondSubClampInstsBit);
  if (FB[AMDGPU::FeatureAtomicFlatPkAdd16Insts])
    Features.set(Feature_HasAtomicFlatPkAdd16InstsBit);
  if (FB[AMDGPU::FeatureAtomicFaddRtnInsts])
    Features.set(Feature_HasAtomicFaddRtnInstsBit);
  if (FB[AMDGPU::FeatureAtomicFaddNoRtnInsts])
    Features.set(Feature_HasAtomicFaddNoRtnInstsBit);
  if (FB[AMDGPU::FeatureAtomicBufferGlobalPkAddF16NoRtnInsts] || FB[AMDGPU::FeatureAtomicBufferGlobalPkAddF16Insts])
    Features.set(Feature_HasAtomicBufferGlobalPkAddF16NoRtnInstsBit);
  if (FB[AMDGPU::FeatureAtomicBufferGlobalPkAddF16Insts])
    Features.set(Feature_HasAtomicBufferGlobalPkAddF16InstsBit);
  if (FB[AMDGPU::FeatureAtomicGlobalPkAddBF16Inst])
    Features.set(Feature_HasAtomicGlobalPkAddBF16InstBit);
  if (FB[AMDGPU::FeatureAtomicBufferPkAddBF16Inst])
    Features.set(Feature_HasAtomicBufferPkAddBF16InstBit);
  if (FB[AMDGPU::FeatureFlatAtomicFaddF32Inst])
    Features.set(Feature_HasFlatAtomicFaddF32InstBit);
  if (FB[AMDGPU::FeatureDefaultComponentZero])
    Features.set(Feature_HasDefaultComponentZeroBit);
  if (FB[AMDGPU::FeatureDefaultComponentBroadcast])
    Features.set(Feature_HasDefaultComponentBroadcastBit);
  if (FB[AMDGPU::FeatureDsSrc2Insts])
    Features.set(Feature_HasDsSrc2InstsBit);
  if (FB[AMDGPU::FeatureGFX1250Insts])
    Features.set(Feature_HasAddPC64InstBit);
  if (FB[AMDGPU::FeatureUnalignedAccessMode])
    Features.set(Feature_HasUnalignedAccessModeBit);
  if (FB[AMDGPU::FeatureSALUFloatInsts])
    Features.set(Feature_HasSALUFloatInstsBit);
  if (!FB[AMDGPU::FeatureSALUFloatInsts])
    Features.set(Feature_NotHasSALUFloatInstsBit);
  if (FB[AMDGPU::FeaturePseudoScalarTrans])
    Features.set(Feature_HasPseudoScalarTransBit);
  if (FB[AMDGPU::FeatureBitOp3Insts])
    Features.set(Feature_HasBitOp3InstsBit);
  if (FB[AMDGPU::FeatureTanhInsts])
    Features.set(Feature_HasTanhInstsBit);
  if (FB[AMDGPU::FeatureTensorCvtLutInsts])
    Features.set(Feature_HasTensorCvtLutInstsBit);
  if (FB[AMDGPU::FeatureTransposeLoadF4F6Insts])
    Features.set(Feature_HasTransposeLoadF4F6InstsBit);
  if (FB[AMDGPU::FeaturePrngInst])
    Features.set(Feature_HasPrngInstBit);
  if (FB[AMDGPU::FeatureBVHDualAndBVH8Insts])
    Features.set(Feature_HasBVHDualAndBVH8InstsBit);
  if (FB[AMDGPU::Feature64BitLiterals])
    Features.set(Feature_Has64BitLiteralsBit);
  if (FB[AMDGPU::Feature1024AddressableVGPRs])
    Features.set(Feature_Has1024AddressableVGPRsBit);
  if (FB[AMDGPU::FeatureMcastLoadInsts])
    Features.set(Feature_HasMcastLoadInstsBit);
  if (FB[AMDGPU::FeatureWaitXcnt])
    Features.set(Feature_HasWaitXcntBit);
  if (FB[AMDGPU::FeatureFP8ConversionScaleInsts])
    Features.set(Feature_HasFP8ConversionScaleInstsBit);
  if (FB[AMDGPU::FeatureBF8ConversionScaleInsts])
    Features.set(Feature_HasBF8ConversionScaleInstsBit);
  if (FB[AMDGPU::FeatureFP4ConversionScaleInsts])
    Features.set(Feature_HasFP4ConversionScaleInstsBit);
  if (FB[AMDGPU::FeatureFP6BF6ConversionScaleInsts])
    Features.set(Feature_HasFP6BF6ConversionScaleInstsBit);
  if (FB[AMDGPU::FeatureF16BF16ToFP6BF6ConversionScaleInsts])
    Features.set(Feature_HasF16BF16ToFP6BF6ConversionScaleInstsBit);
  if (FB[AMDGPU::FeatureCvtPkF16F32Inst])
    Features.set(Feature_HasCvtPkF16F32InstBit);
  if (FB[AMDGPU::FeatureF32ToF16BF16ConversionSRInsts])
    Features.set(Feature_HasF32ToF16BF16ConversionSRInstsBit);
  if (FB[AMDGPU::FeatureXF32Insts])
    Features.set(Feature_HasXF32InstsBit);
  if (FB[AMDGPU::FeatureVmemPrefInsts])
    Features.set(Feature_HasVmemPrefInstsBit);
  if (FB[AMDGPU::FeatureAshrPkInsts])
    Features.set(Feature_HasAshrPkInstsBit);
  if (FB[AMDGPU::FeatureLshlAddU64Inst])
    Features.set(Feature_HasLshlAddU64InstBit);
  if (FB[AMDGPU::FeatureAddSubU64Insts])
    Features.set(Feature_HasAddSubU64InstsBit);
  if (FB[AMDGPU::FeatureMadU32Inst])
    Features.set(Feature_HasMadU32InstBit);
  if (FB[AMDGPU::FeatureLdsBarrierArriveAtomic])
    Features.set(Feature_HasLdsBarrierArriveAtomicBit);
  if (FB[AMDGPU::FeatureSetPrioIncWgInst])
    Features.set(Feature_HasSetPrioIncWgInstBit);
  if (FB[AMDGPU::FeatureSWakeupBarrier])
    Features.set(Feature_HasSWakeupBarrierBit);
  if (FB[AMDGPU::FeatureRequiresAlignedVGPRs])
    Features.set(Feature_NeedsAlignedVGPRsBit);
  if (!FB[AMDGPU::FeatureRequiresAlignedVGPRs])
    Features.set(Feature_NotNeedsAlignedVGPRsBit);
  if (FB[AMDGPU::FeatureWavefrontSize32] || FB[AMDGPU::FeatureAssemblerPermissiveWavesize])
    Features.set(Feature_isWave32Bit);
  if (FB[AMDGPU::FeatureWavefrontSize64] || FB[AMDGPU::FeatureAssemblerPermissiveWavesize])
    Features.set(Feature_isWave64Bit);
  if (FB[AMDGPU::FeatureWavefrontSize32])
    Features.set(Feature_isWave32StrictBit);
  if (FB[AMDGPU::FeatureWavefrontSize64])
    Features.set(Feature_isWave64StrictBit);
  return Features;
}

static bool checkAsmTiedOperandConstraints(const AMDGPUAsmParser&AsmParser,
                               unsigned Kind, const OperandVector &Operands,
                               ArrayRef<unsigned> DefaultsOffset,
                               uint64_t &ErrorInfo) {
  assert(Kind < CVT_NUM_SIGNATURES && "Invalid signature!");
  const uint8_t *Converter = ConversionTable[Kind];
  for (const uint8_t *p = Converter; *p; p += 2) {
    switch (*p) {
    case CVT_Tied: {
      unsigned OpIdx = *(p + 1);
      assert(OpIdx < (size_t)(std::end(TiedAsmOperandTable) -
                              std::begin(TiedAsmOperandTable)) &&
             "Tied operand not found");
      unsigned OpndNum1 = TiedAsmOperandTable[OpIdx][1];
      unsigned OpndNum2 = TiedAsmOperandTable[OpIdx][2];
      OpndNum1 = OpndNum1 - DefaultsOffset[OpndNum1];
      OpndNum2 = OpndNum2 - DefaultsOffset[OpndNum2];
      if (OpndNum1 != OpndNum2) {
        auto &SrcOp1 = Operands[OpndNum1];
        auto &SrcOp2 = Operands[OpndNum2];
        if (!AsmParser.areEqualRegs(*SrcOp1, *SrcOp2)) {
          ErrorInfo = OpndNum2;
          return false;
        }
      }
      break;
    }
    default:
      break;
    }
  }
  return true;
}

static const char MnemonicTable[] =
    "\021buffer_atomic_add\025buffer_atomic_add_f32\025buffer_atomic_add_f64"
    "\025buffer_atomic_add_u32\025buffer_atomic_add_u64\024buffer_atomic_add"
    "_x2\021buffer_atomic_and\025buffer_atomic_and_b32\025buffer_atomic_and_"
    "b64\024buffer_atomic_and_x2\025buffer_atomic_cmpswap\031buffer_atomic_c"
    "mpswap_b32\031buffer_atomic_cmpswap_b64\031buffer_atomic_cmpswap_f32\030"
    "buffer_atomic_cmpswap_x2\032buffer_atomic_cond_sub_u32\022buffer_atomic"
    "_csub\026buffer_atomic_csub_u32\021buffer_atomic_dec\025buffer_atomic_d"
    "ec_u32\025buffer_atomic_dec_u64\024buffer_atomic_dec_x2\026buffer_atomi"
    "c_fcmpswap\031buffer_atomic_fcmpswap_x2\022buffer_atomic_fmax\025buffer"
    "_atomic_fmax_x2\022buffer_atomic_fmin\025buffer_atomic_fmin_x2\021buffe"
    "r_atomic_inc\025buffer_atomic_inc_u32\025buffer_atomic_inc_u64\024buffe"
    "r_atomic_inc_x2\025buffer_atomic_max_f32\025buffer_atomic_max_f64\025bu"
    "ffer_atomic_max_i32\025buffer_atomic_max_i64\031buffer_atomic_max_num_f"
    "32\031buffer_atomic_max_num_f64\025buffer_atomic_max_u32\025buffer_atom"
    "ic_max_u64\025buffer_atomic_min_f32\025buffer_atomic_min_f64\025buffer_"
    "atomic_min_i32\025buffer_atomic_min_i64\031buffer_atomic_min_num_f32\031"
    "buffer_atomic_min_num_f64\025buffer_atomic_min_u32\025buffer_atomic_min"
    "_u64\020buffer_atomic_or\024buffer_atomic_or_b32\024buffer_atomic_or_b6"
    "4\023buffer_atomic_or_x2\031buffer_atomic_pk_add_bf16\030buffer_atomic_"
    "pk_add_f16\022buffer_atomic_smax\025buffer_atomic_smax_x2\022buffer_ato"
    "mic_smin\025buffer_atomic_smin_x2\021buffer_atomic_sub\033buffer_atomic"
    "_sub_clamp_u32\025buffer_atomic_sub_u32\025buffer_atomic_sub_u64\024buf"
    "fer_atomic_sub_x2\022buffer_atomic_swap\026buffer_atomic_swap_b32\026bu"
    "ffer_atomic_swap_b64\025buffer_atomic_swap_x2\022buffer_atomic_umax\025"
    "buffer_atomic_umax_x2\022buffer_atomic_umin\025buffer_atomic_umin_x2\021"
    "buffer_atomic_xor\025buffer_atomic_xor_b32\025buffer_atomic_xor_b64\024"
    "buffer_atomic_xor_x2\016buffer_gl0_inv\016buffer_gl1_inv\nbuffer_inv\014"
    "buffer_invl2\020buffer_load_b128\017buffer_load_b32\017buffer_load_b64\017"
    "buffer_load_b96\023buffer_load_d16_b16\030buffer_load_d16_format_x\031b"
    "uffer_load_d16_format_xy\032buffer_load_d16_format_xyz\033buffer_load_d"
    "16_format_xyzw\026buffer_load_d16_hi_b16\033buffer_load_d16_hi_format_x"
    "\025buffer_load_d16_hi_i8\025buffer_load_d16_hi_u8\022buffer_load_d16_i"
    "8\022buffer_load_d16_u8\021buffer_load_dword\023buffer_load_dwordx2\023"
    "buffer_load_dwordx3\023buffer_load_dwordx4\033buffer_load_format_d16_hi"
    "_x\030buffer_load_format_d16_x\031buffer_load_format_d16_xy\032buffer_l"
    "oad_format_d16_xyz\033buffer_load_format_d16_xyzw\024buffer_load_format"
    "_x\025buffer_load_format_xy\026buffer_load_format_xyz\027buffer_load_fo"
    "rmat_xyzw\017buffer_load_i16\016buffer_load_i8\021buffer_load_sbyte\025"
    "buffer_load_sbyte_d16\030buffer_load_sbyte_d16_hi\025buffer_load_short_"
    "d16\030buffer_load_short_d16_hi\022buffer_load_sshort\017buffer_load_u1"
    "6\016buffer_load_u8\021buffer_load_ubyte\025buffer_load_ubyte_d16\030bu"
    "ffer_load_ubyte_d16_hi\022buffer_load_ushort\021buffer_store_b128\020bu"
    "ffer_store_b16\020buffer_store_b32\020buffer_store_b64\017buffer_store_"
    "b8\020buffer_store_b96\021buffer_store_byte\030buffer_store_byte_d16_hi"
    "\031buffer_store_d16_format_x\032buffer_store_d16_format_xy\033buffer_s"
    "tore_d16_format_xyz\034buffer_store_d16_format_xyzw\027buffer_store_d16"
    "_hi_b16\026buffer_store_d16_hi_b8\034buffer_store_d16_hi_format_x\022bu"
    "ffer_store_dword\024buffer_store_dwordx2\024buffer_store_dwordx3\024buf"
    "fer_store_dwordx4\034buffer_store_format_d16_hi_x\031buffer_store_forma"
    "t_d16_x\032buffer_store_format_d16_xy\033buffer_store_format_d16_xyz\034"
    "buffer_store_format_d16_xyzw\025buffer_store_format_x\026buffer_store_f"
    "ormat_xy\027buffer_store_format_xyz\030buffer_store_format_xyzw\026buff"
    "er_store_lds_dword\022buffer_store_short\031buffer_store_short_d16_hi\016"
    "buffer_wbinvl1\021buffer_wbinvl1_sc\022buffer_wbinvl1_vol\013buffer_wbl"
    "2\036cluster_load_async_to_lds_b128\035cluster_load_async_to_lds_b32\035"
    "cluster_load_async_to_lds_b64\034cluster_load_async_to_lds_b8\021cluste"
    "r_load_b128\020cluster_load_b32\020cluster_load_b64\nds_add_f32\nds_add"
    "_f64\021ds_add_gs_reg_rtn\016ds_add_rtn_f32\016ds_add_rtn_f64\016ds_add"
    "_rtn_u32\016ds_add_rtn_u64\017ds_add_src2_f32\017ds_add_src2_u32\017ds_"
    "add_src2_u64\nds_add_u32\nds_add_u64\nds_and_b32\nds_and_b64\016ds_and_"
    "rtn_b32\016ds_and_rtn_b64\017ds_and_src2_b32\017ds_and_src2_b64\tds_app"
    "end\"ds_atomic_async_barrier_arrive_b64 ds_atomic_barrier_arrive_rtn_b6"
    "4\017ds_bpermute_b32\022ds_bpermute_fi_b32\037ds_bvh_stack_push4_pop1_r"
    "tn_b32\037ds_bvh_stack_push8_pop1_rtn_b32\037ds_bvh_stack_push8_pop2_rt"
    "n_b64\024ds_bvh_stack_rtn_b32\014ds_cmpst_b32\014ds_cmpst_b64\014ds_cmp"
    "st_f32\014ds_cmpst_f64\020ds_cmpst_rtn_b32\020ds_cmpst_rtn_b64\020ds_cm"
    "pst_rtn_f32\020ds_cmpst_rtn_f64\017ds_cmpstore_b32\017ds_cmpstore_b64\017"
    "ds_cmpstore_f32\017ds_cmpstore_f64\023ds_cmpstore_rtn_b32\023ds_cmpstor"
    "e_rtn_b64\023ds_cmpstore_rtn_f32\023ds_cmpstore_rtn_f64\023ds_cond_sub_"
    "rtn_u32\017ds_cond_sub_u32\025ds_condxchg32_rtn_b64\nds_consume\016ds_d"
    "ec_rtn_u32\016ds_dec_rtn_u64\017ds_dec_src2_u32\017ds_dec_src2_u64\nds_"
    "dec_u32\nds_dec_u64\016ds_direct_load\016ds_gws_barrier\013ds_gws_init\016"
    "ds_gws_sema_br\015ds_gws_sema_p\027ds_gws_sema_release_all\015ds_gws_se"
    "ma_v\016ds_inc_rtn_u32\016ds_inc_rtn_u64\017ds_inc_src2_u32\017ds_inc_s"
    "rc2_u64\nds_inc_u32\nds_inc_u64\021ds_load_2addr_b32\021ds_load_2addr_b"
    "64\032ds_load_2addr_stride64_b32\032ds_load_2addr_stride64_b64\022ds_lo"
    "ad_addtid_b32\014ds_load_b128\013ds_load_b32\013ds_load_b64\013ds_load_"
    "b96\013ds_load_i16\nds_load_i8\016ds_load_i8_d16\021ds_load_i8_d16_hi\021"
    "ds_load_tr16_b128\017ds_load_tr4_b64\017ds_load_tr6_b96\017ds_load_tr8_"
    "b64\013ds_load_u16\017ds_load_u16_d16\022ds_load_u16_d16_hi\nds_load_u8"
    "\016ds_load_u8_d16\021ds_load_u8_d16_hi\nds_max_f32\nds_max_f64\nds_max"
    "_i32\nds_max_i64\016ds_max_num_f32\016ds_max_num_f64\022ds_max_num_rtn_"
    "f32\022ds_max_num_rtn_f64\016ds_max_rtn_f32\016ds_max_rtn_f64\016ds_max"
    "_rtn_i32\016ds_max_rtn_i64\016ds_max_rtn_u32\016ds_max_rtn_u64\017ds_ma"
    "x_src2_f32\017ds_max_src2_f64\017ds_max_src2_i32\017ds_max_src2_i64\017"
    "ds_max_src2_u32\017ds_max_src2_u64\nds_max_u32\nds_max_u64\nds_min_f32\n"
    "ds_min_f64\nds_min_i32\nds_min_i64\016ds_min_num_f32\016ds_min_num_f64\022"
    "ds_min_num_rtn_f32\022ds_min_num_rtn_f64\016ds_min_rtn_f32\016ds_min_rt"
    "n_f64\016ds_min_rtn_i32\016ds_min_rtn_i64\016ds_min_rtn_u32\016ds_min_r"
    "tn_u64\017ds_min_src2_f32\017ds_min_src2_f64\017ds_min_src2_i32\017ds_m"
    "in_src2_i64\017ds_min_src2_u32\017ds_min_src2_u64\nds_min_u32\nds_min_u"
    "64\014ds_mskor_b32\014ds_mskor_b64\020ds_mskor_rtn_b32\020ds_mskor_rtn_"
    "b64\006ds_nop\tds_or_b32\tds_or_b64\015ds_or_rtn_b32\015ds_or_rtn_b64\016"
    "ds_or_src2_b32\016ds_or_src2_b64\020ds_ordered_count\015ds_param_load\016"
    "ds_permute_b32\016ds_pk_add_bf16\015ds_pk_add_f16\022ds_pk_add_rtn_bf16"
    "\021ds_pk_add_rtn_f16\014ds_read2_b32\014ds_read2_b64\020ds_read2st64_b"
    "32\020ds_read2st64_b64\022ds_read_addtid_b32\014ds_read_b128\013ds_read"
    "_b32\013ds_read_b64\022ds_read_b64_tr_b16\021ds_read_b64_tr_b4\021ds_re"
    "ad_b64_tr_b8\013ds_read_b96\021ds_read_b96_tr_b6\013ds_read_i16\nds_rea"
    "d_i8\016ds_read_i8_d16\021ds_read_i8_d16_hi\013ds_read_u16\017ds_read_u"
    "16_d16\022ds_read_u16_d16_hi\nds_read_u8\016ds_read_u8_d16\021ds_read_u"
    "8_d16_hi\017ds_rsub_rtn_u32\017ds_rsub_rtn_u64\020ds_rsub_src2_u32\020d"
    "s_rsub_src2_u64\013ds_rsub_u32\013ds_rsub_u64\022ds_store_2addr_b32\022"
    "ds_store_2addr_b64\033ds_store_2addr_stride64_b32\033ds_store_2addr_str"
    "ide64_b64\023ds_store_addtid_b32\015ds_store_b128\014ds_store_b16\023ds"
    "_store_b16_d16_hi\014ds_store_b32\014ds_store_b64\013ds_store_b8\022ds_"
    "store_b8_d16_hi\014ds_store_b96\032ds_storexchg_2addr_rtn_b32\032ds_sto"
    "rexchg_2addr_rtn_b64#ds_storexchg_2addr_stride64_rtn_b32#ds_storexchg_2"
    "addr_stride64_rtn_b64\024ds_storexchg_rtn_b32\024ds_storexchg_rtn_b64\024"
    "ds_sub_clamp_rtn_u32\020ds_sub_clamp_u32\021ds_sub_gs_reg_rtn\016ds_sub"
    "_rtn_u32\016ds_sub_rtn_u64\017ds_sub_src2_u32\017ds_sub_src2_u64\nds_su"
    "b_u32\nds_sub_u64\016ds_swizzle_b32\017ds_wrap_rtn_b32\015ds_write2_b32"
    "\015ds_write2_b64\021ds_write2st64_b32\021ds_write2st64_b64\023ds_write"
    "_addtid_b32\015ds_write_b128\014ds_write_b16\023ds_write_b16_d16_hi\014"
    "ds_write_b32\014ds_write_b64\013ds_write_b8\022ds_write_b8_d16_hi\014ds"
    "_write_b96\021ds_write_src2_b32\021ds_write_src2_b64\022ds_wrxchg2_rtn_"
    "b32\022ds_wrxchg2_rtn_b64\026ds_wrxchg2st64_rtn_b32\026ds_wrxchg2st64_r"
    "tn_b64\021ds_wrxchg_rtn_b32\021ds_wrxchg_rtn_b64\nds_xor_b32\nds_xor_b6"
    "4\016ds_xor_rtn_b32\016ds_xor_rtn_b64\017ds_xor_src2_b32\017ds_xor_src2"
    "_b64\003exp\006export\017flat_atomic_add\023flat_atomic_add_f32\023flat"
    "_atomic_add_f64\023flat_atomic_add_u32\023flat_atomic_add_u64\022flat_a"
    "tomic_add_x2\017flat_atomic_and\023flat_atomic_and_b32\023flat_atomic_a"
    "nd_b64\022flat_atomic_and_x2\023flat_atomic_cmpswap\027flat_atomic_cmps"
    "wap_b32\027flat_atomic_cmpswap_b64\027flat_atomic_cmpswap_f32\026flat_a"
    "tomic_cmpswap_x2\030flat_atomic_cond_sub_u32\017flat_atomic_dec\023flat"
    "_atomic_dec_u32\023flat_atomic_dec_u64\022flat_atomic_dec_x2\024flat_at"
    "omic_fcmpswap\027flat_atomic_fcmpswap_x2\020flat_atomic_fmax\023flat_at"
    "omic_fmax_x2\020flat_atomic_fmin\023flat_atomic_fmin_x2\017flat_atomic_"
    "inc\023flat_atomic_inc_u32\023flat_atomic_inc_u64\022flat_atomic_inc_x2"
    "\023flat_atomic_max_f32\023flat_atomic_max_f64\023flat_atomic_max_i32\023"
    "flat_atomic_max_i64\027flat_atomic_max_num_f32\027flat_atomic_max_num_f"
    "64\023flat_atomic_max_u32\023flat_atomic_max_u64\023flat_atomic_min_f32"
    "\023flat_atomic_min_f64\023flat_atomic_min_i32\023flat_atomic_min_i64\027"
    "flat_atomic_min_num_f32\027flat_atomic_min_num_f64\023flat_atomic_min_u"
    "32\023flat_atomic_min_u64\016flat_atomic_or\022flat_atomic_or_b32\022fl"
    "at_atomic_or_b64\021flat_atomic_or_x2\027flat_atomic_pk_add_bf16\026fla"
    "t_atomic_pk_add_f16\020flat_atomic_smax\023flat_atomic_smax_x2\020flat_"
    "atomic_smin\023flat_atomic_smin_x2\017flat_atomic_sub\031flat_atomic_su"
    "b_clamp_u32\023flat_atomic_sub_u32\023flat_atomic_sub_u64\022flat_atomi"
    "c_sub_x2\020flat_atomic_swap\024flat_atomic_swap_b32\024flat_atomic_swa"
    "p_b64\023flat_atomic_swap_x2\020flat_atomic_umax\023flat_atomic_umax_x2"
    "\020flat_atomic_umin\023flat_atomic_umin_x2\017flat_atomic_xor\023flat_"
    "atomic_xor_b32\023flat_atomic_xor_b64\022flat_atomic_xor_x2\016flat_loa"
    "d_b128\015flat_load_b32\015flat_load_b64\015flat_load_b96\021flat_load_"
    "d16_b16\024flat_load_d16_hi_b16\023flat_load_d16_hi_i8\023flat_load_d16"
    "_hi_u8\020flat_load_d16_i8\020flat_load_d16_u8\017flat_load_dword\021fl"
    "at_load_dwordx2\021flat_load_dwordx3\021flat_load_dwordx4\015flat_load_"
    "i16\014flat_load_i8\026flat_load_monitor_b128\025flat_load_monitor_b32\025"
    "flat_load_monitor_b64\017flat_load_sbyte\023flat_load_sbyte_d16\026flat"
    "_load_sbyte_d16_hi\023flat_load_short_d16\026flat_load_short_d16_hi\020"
    "flat_load_sshort\015flat_load_u16\014flat_load_u8\017flat_load_ubyte\023"
    "flat_load_ubyte_d16\026flat_load_ubyte_d16_hi\020flat_load_ushort\020fl"
    "at_prefetch_b8\017flat_store_b128\016flat_store_b16\016flat_store_b32\016"
    "flat_store_b64\015flat_store_b8\016flat_store_b96\017flat_store_byte\026"
    "flat_store_byte_d16_hi\025flat_store_d16_hi_b16\024flat_store_d16_hi_b8"
    "\020flat_store_dword\022flat_store_dwordx2\022flat_store_dwordx3\022fla"
    "t_store_dwordx4\020flat_store_short\027flat_store_short_d16_hi\021globa"
    "l_atomic_add\025global_atomic_add_f32\025global_atomic_add_f64\025globa"
    "l_atomic_add_u32\025global_atomic_add_u64\024global_atomic_add_x2\021gl"
    "obal_atomic_and\025global_atomic_and_b32\025global_atomic_and_b64\024gl"
    "obal_atomic_and_x2\025global_atomic_cmpswap\031global_atomic_cmpswap_b3"
    "2\031global_atomic_cmpswap_b64\031global_atomic_cmpswap_f32\030global_a"
    "tomic_cmpswap_x2\032global_atomic_cond_sub_u32\022global_atomic_csub\026"
    "global_atomic_csub_u32\021global_atomic_dec\025global_atomic_dec_u32\025"
    "global_atomic_dec_u64\024global_atomic_dec_x2\026global_atomic_fcmpswap"
    "\031global_atomic_fcmpswap_x2\022global_atomic_fmax\025global_atomic_fm"
    "ax_x2\022global_atomic_fmin\025global_atomic_fmin_x2\021global_atomic_i"
    "nc\025global_atomic_inc_u32\025global_atomic_inc_u64\024global_atomic_i"
    "nc_x2\025global_atomic_max_f32\025global_atomic_max_f64\025global_atomi"
    "c_max_i32\025global_atomic_max_i64\031global_atomic_max_num_f32\031glob"
    "al_atomic_max_num_f64\025global_atomic_max_u32\025global_atomic_max_u64"
    "\025global_atomic_min_f32\025global_atomic_min_f64\025global_atomic_min"
    "_i32\025global_atomic_min_i64\031global_atomic_min_num_f32\031global_at"
    "omic_min_num_f64\025global_atomic_min_u32\025global_atomic_min_u64\020g"
    "lobal_atomic_or\024global_atomic_or_b32\024global_atomic_or_b64\023glob"
    "al_atomic_or_x2\035global_atomic_ordered_add_b64\031global_atomic_pk_ad"
    "d_bf16\030global_atomic_pk_add_f16\022global_atomic_smax\025global_atom"
    "ic_smax_x2\022global_atomic_smin\025global_atomic_smin_x2\021global_ato"
    "mic_sub\033global_atomic_sub_clamp_u32\025global_atomic_sub_u32\025glob"
    "al_atomic_sub_u64\024global_atomic_sub_x2\022global_atomic_swap\026glob"
    "al_atomic_swap_b32\026global_atomic_swap_b64\025global_atomic_swap_x2\022"
    "global_atomic_umax\025global_atomic_umax_x2\022global_atomic_umin\025gl"
    "obal_atomic_umin_x2\021global_atomic_xor\025global_atomic_xor_b32\025gl"
    "obal_atomic_xor_b64\024global_atomic_xor_x2\nglobal_inv\026global_load_"
    "addtid_b32\035global_load_async_to_lds_b128\034global_load_async_to_lds"
    "_b32\034global_load_async_to_lds_b64\033global_load_async_to_lds_b8\020"
    "global_load_b128\017global_load_b32\017global_load_b64\017global_load_b"
    "96\021global_load_block\023global_load_d16_b16\026global_load_d16_hi_b1"
    "6\025global_load_d16_hi_i8\025global_load_d16_hi_u8\022global_load_d16_"
    "i8\022global_load_d16_u8\021global_load_dword\030global_load_dword_addt"
    "id\023global_load_dwordx2\023global_load_dwordx3\023global_load_dwordx4"
    "\017global_load_i16\016global_load_i8\025global_load_lds_dword\027globa"
    "l_load_lds_dwordx3\027global_load_lds_dwordx4\025global_load_lds_sbyte\026"
    "global_load_lds_sshort\025global_load_lds_ubyte\026global_load_lds_usho"
    "rt\030global_load_monitor_b128\027global_load_monitor_b32\027global_loa"
    "d_monitor_b64\021global_load_sbyte\025global_load_sbyte_d16\030global_l"
    "oad_sbyte_d16_hi\025global_load_short_d16\030global_load_short_d16_hi\022"
    "global_load_sshort\025global_load_tr16_b128\023global_load_tr4_b64\023g"
    "lobal_load_tr6_b96\023global_load_tr8_b64\023global_load_tr_b128\022glo"
    "bal_load_tr_b64\017global_load_u16\016global_load_u8\021global_load_uby"
    "te\025global_load_ubyte_d16\030global_load_ubyte_d16_hi\022global_load_"
    "ushort\022global_prefetch_b8\027global_store_addtid_b32 global_store_as"
    "ync_from_lds_b128\037global_store_async_from_lds_b32\037global_store_as"
    "ync_from_lds_b64\036global_store_async_from_lds_b8\021global_store_b128"
    "\020global_store_b16\020global_store_b32\020global_store_b64\017global_"
    "store_b8\020global_store_b96\022global_store_block\021global_store_byte"
    "\030global_store_byte_d16_hi\027global_store_d16_hi_b16\026global_store"
    "_d16_hi_b8\022global_store_dword\031global_store_dword_addtid\024global"
    "_store_dwordx2\024global_store_dwordx3\024global_store_dwordx4\022globa"
    "l_store_short\031global_store_short_d16_hi\tglobal_wb\014global_wbinv\020"
    "image_atomic_add\024image_atomic_add_flt\025image_atomic_add_uint\020im"
    "age_atomic_and\024image_atomic_cmpswap\020image_atomic_dec\025image_ato"
    "mic_dec_uint\025image_atomic_fcmpswap\021image_atomic_fmax\021image_ato"
    "mic_fmin\020image_atomic_inc\025image_atomic_inc_uint\024image_atomic_m"
    "ax_flt\024image_atomic_max_int\025image_atomic_max_uint\024image_atomic"
    "_min_flt\024image_atomic_min_int\025image_atomic_min_uint\017image_atom"
    "ic_or\030image_atomic_pk_add_bf16\027image_atomic_pk_add_f16\021image_a"
    "tomic_rsub\021image_atomic_smax\021image_atomic_smin\020image_atomic_su"
    "b\025image_atomic_sub_uint\021image_atomic_swap\021image_atomic_umax\021"
    "image_atomic_umin\020image_atomic_xor\031image_bvh64_intersect_ray\030i"
    "mage_bvh8_intersect_ray\034image_bvh_dual_intersect_ray\027image_bvh_in"
    "tersect_ray\015image_gather4\017image_gather4_b\022image_gather4_b_cl\024"
    "image_gather4_b_cl_o\021image_gather4_b_o\017image_gather4_c\021image_g"
    "ather4_c_b\024image_gather4_c_b_cl\026image_gather4_c_b_cl_o\023image_g"
    "ather4_c_b_o\022image_gather4_c_cl\024image_gather4_c_cl_o\021image_gat"
    "her4_c_l\023image_gather4_c_l_o\022image_gather4_c_lz\024image_gather4_"
    "c_lz_o\021image_gather4_c_o\020image_gather4_cl\022image_gather4_cl_o\017"
    "image_gather4_l\021image_gather4_l_o\020image_gather4_lz\022image_gathe"
    "r4_lz_o\017image_gather4_o\016image_gather4h\015image_get_lod\021image_"
    "get_resinfo\nimage_load\016image_load_mip\022image_load_mip_pck\026imag"
    "e_load_mip_pck_sgn\016image_load_pck\022image_load_pck_sgn\017image_msa"
    "a_load\014image_sample\016image_sample_b\021image_sample_b_cl\023image_"
    "sample_b_cl_o\020image_sample_b_o\016image_sample_c\020image_sample_c_b"
    "\023image_sample_c_b_cl\025image_sample_c_b_cl_o\022image_sample_c_b_o\021"
    "image_sample_c_cd\024image_sample_c_cd_cl\030image_sample_c_cd_cl_g16\026"
    "image_sample_c_cd_cl_o\032image_sample_c_cd_cl_o_g16\025image_sample_c_"
    "cd_g16\023image_sample_c_cd_o\027image_sample_c_cd_o_g16\021image_sampl"
    "e_c_cl\023image_sample_c_cl_o\020image_sample_c_d\023image_sample_c_d_c"
    "l\027image_sample_c_d_cl_g16\025image_sample_c_d_cl_o\031image_sample_c"
    "_d_cl_o_g16\024image_sample_c_d_g16\022image_sample_c_d_o\026image_samp"
    "le_c_d_o_g16\020image_sample_c_l\022image_sample_c_l_o\021image_sample_"
    "c_lz\023image_sample_c_lz_o\020image_sample_c_o\017image_sample_cd\022i"
    "mage_sample_cd_cl\026image_sample_cd_cl_g16\024image_sample_cd_cl_o\030"
    "image_sample_cd_cl_o_g16\023image_sample_cd_g16\021image_sample_cd_o\025"
    "image_sample_cd_o_g16\017image_sample_cl\021image_sample_cl_o\016image_"
    "sample_d\021image_sample_d_cl\025image_sample_d_cl_g16\023image_sample_"
    "d_cl_o\027image_sample_d_cl_o_g16\022image_sample_d_g16\020image_sample"
    "_d_o\024image_sample_d_o_g16\016image_sample_l\020image_sample_l_o\017i"
    "mage_sample_lz\021image_sample_lz_o\016image_sample_o\013image_store\017"
    "image_store_mip\023image_store_mip_pck\017image_store_pck\017lds_direct"
    "_load\016lds_param_load\ts_abs_i32\015s_absdiff_i32\017s_add_co_ci_u32\014"
    "s_add_co_i32\014s_add_co_u32\ts_add_f16\ts_add_f32\ts_add_i32\014s_add_"
    "nc_u64\014s_add_pc_i64\ts_add_u32\ns_addc_u32\015s_addk_co_i32\ns_addk_"
    "i32\014s_alloc_vgpr\ts_and_b32\ts_and_b64\027s_and_not0_saveexec_b32\027"
    "s_and_not0_saveexec_b64\025s_and_not0_wrexec_b32\025s_and_not0_wrexec_b"
    "64\016s_and_not1_b32\016s_and_not1_b64\027s_and_not1_saveexec_b32\027s_"
    "and_not1_saveexec_b64\025s_and_not1_wrexec_b32\025s_and_not1_wrexec_b64"
    "\022s_and_saveexec_b32\022s_and_saveexec_b64\024s_andn1_saveexec_b32\024"
    "s_andn1_saveexec_b64\022s_andn1_wrexec_b32\022s_andn1_wrexec_b64\013s_a"
    "ndn2_b32\013s_andn2_b64\024s_andn2_saveexec_b32\024s_andn2_saveexec_b64"
    "\022s_andn2_wrexec_b32\022s_andn2_wrexec_b64\ns_ashr_i32\ns_ashr_i64\013"
    "s_atc_probe\022s_atc_probe_buffer\014s_atomic_add\017s_atomic_add_x2\014"
    "s_atomic_and\017s_atomic_and_x2\020s_atomic_cmpswap\023s_atomic_cmpswap"
    "_x2\014s_atomic_dec\017s_atomic_dec_x2\014s_atomic_inc\017s_atomic_inc_"
    "x2\013s_atomic_or\016s_atomic_or_x2\015s_atomic_smax\020s_atomic_smax_x"
    "2\015s_atomic_smin\020s_atomic_smin_x2\014s_atomic_sub\017s_atomic_sub_"
    "x2\015s_atomic_swap\020s_atomic_swap_x2\015s_atomic_umax\020s_atomic_um"
    "ax_x2\015s_atomic_umin\020s_atomic_umin_x2\014s_atomic_xor\017s_atomic_"
    "xor_x2\ts_barrier\016s_barrier_init\016s_barrier_join\017s_barrier_leav"
    "e\020s_barrier_signal\030s_barrier_signal_isfirst\016s_barrier_wait\017"
    "s_bcnt0_i32_b32\017s_bcnt0_i32_b64\017s_bcnt1_i32_b32\017s_bcnt1_i32_b6"
    "4\ts_bfe_i32\ts_bfe_i64\ts_bfe_u32\ts_bfe_u64\ts_bfm_b32\ts_bfm_b64\015"
    "s_bitcmp0_b32\015s_bitcmp0_b64\015s_bitcmp1_b32\015s_bitcmp1_b64\026s_b"
    "itreplicate_b64_b32\015s_bitset0_b32\015s_bitset0_b64\015s_bitset1_b32\015"
    "s_bitset1_b64\010s_branch\ns_brev_b32\ns_brev_b64\023s_buffer_atomic_ad"
    "d\026s_buffer_atomic_add_x2\023s_buffer_atomic_and\026s_buffer_atomic_a"
    "nd_x2\027s_buffer_atomic_cmpswap\032s_buffer_atomic_cmpswap_x2\023s_buf"
    "fer_atomic_dec\026s_buffer_atomic_dec_x2\023s_buffer_atomic_inc\026s_bu"
    "ffer_atomic_inc_x2\022s_buffer_atomic_or\025s_buffer_atomic_or_x2\024s_"
    "buffer_atomic_smax\027s_buffer_atomic_smax_x2\024s_buffer_atomic_smin\027"
    "s_buffer_atomic_smin_x2\023s_buffer_atomic_sub\026s_buffer_atomic_sub_x"
    "2\024s_buffer_atomic_swap\027s_buffer_atomic_swap_x2\024s_buffer_atomic"
    "_umax\027s_buffer_atomic_umax_x2\024s_buffer_atomic_umin\027s_buffer_at"
    "omic_umin_x2\023s_buffer_atomic_xor\026s_buffer_atomic_xor_x2\022s_buff"
    "er_load_b128\022s_buffer_load_b256\021s_buffer_load_b32\022s_buffer_loa"
    "d_b512\021s_buffer_load_b64\021s_buffer_load_b96\023s_buffer_load_dword"
    "\026s_buffer_load_dwordx16\025s_buffer_load_dwordx2\025s_buffer_load_dw"
    "ordx4\025s_buffer_load_dwordx8\021s_buffer_load_i16\020s_buffer_load_i8"
    "\021s_buffer_load_u16\020s_buffer_load_u8\026s_buffer_prefetch_data\024"
    "s_buffer_store_dword\026s_buffer_store_dwordx2\026s_buffer_store_dwordx"
    "4\ns_call_b64\ns_call_i64\021s_cbranch_cdbgsys\032s_cbranch_cdbgsys_and"
    "_user\031s_cbranch_cdbgsys_or_user\022s_cbranch_cdbguser\020s_cbranch_e"
    "xecnz\017s_cbranch_execz\020s_cbranch_g_fork\020s_cbranch_i_fork\016s_c"
    "branch_join\016s_cbranch_scc0\016s_cbranch_scc1\017s_cbranch_vccnz\016s"
    "_cbranch_vccz\ns_ceil_f16\ns_ceil_f32\010s_clause\ts_cls_i32\015s_cls_i"
    "32_i64\015s_clz_i32_u32\015s_clz_i32_u64\ns_cmov_b32\ns_cmov_b64\013s_c"
    "movk_i32\014s_cmp_eq_f16\014s_cmp_eq_f32\014s_cmp_eq_i32\014s_cmp_eq_u3"
    "2\014s_cmp_eq_u64\014s_cmp_ge_f16\014s_cmp_ge_f32\014s_cmp_ge_i32\014s_"
    "cmp_ge_u32\014s_cmp_gt_f16\014s_cmp_gt_f32\014s_cmp_gt_i32\014s_cmp_gt_"
    "u32\014s_cmp_le_f16\014s_cmp_le_f32\014s_cmp_le_i32\014s_cmp_le_u32\014"
    "s_cmp_lg_f16\014s_cmp_lg_f32\014s_cmp_lg_i32\014s_cmp_lg_u32\014s_cmp_l"
    "g_u64\014s_cmp_lt_f16\014s_cmp_lt_f32\014s_cmp_lt_i32\014s_cmp_lt_u32\015"
    "s_cmp_neq_f16\015s_cmp_neq_f32\015s_cmp_nge_f16\015s_cmp_nge_f32\015s_c"
    "mp_ngt_f16\015s_cmp_ngt_f32\015s_cmp_nle_f16\015s_cmp_nle_f32\015s_cmp_"
    "nlg_f16\015s_cmp_nlg_f32\015s_cmp_nlt_f16\015s_cmp_nlt_f32\013s_cmp_o_f"
    "16\013s_cmp_o_f32\013s_cmp_u_f16\013s_cmp_u_f32\015s_cmpk_eq_i32\015s_c"
    "mpk_eq_u32\015s_cmpk_ge_i32\015s_cmpk_ge_u32\015s_cmpk_gt_i32\015s_cmpk"
    "_gt_u32\015s_cmpk_le_i32\015s_cmpk_le_u32\015s_cmpk_lg_i32\015s_cmpk_lg"
    "_u32\015s_cmpk_lt_i32\015s_cmpk_lt_u32\ns_code_end\015s_cselect_b32\015"
    "s_cselect_b64\015s_ctz_i32_b32\015s_ctz_i32_b64\015s_cvt_f16_f32\015s_c"
    "vt_f32_f16\015s_cvt_f32_i32\015s_cvt_f32_u32\020s_cvt_hi_f32_f16\015s_c"
    "vt_i32_f32\024s_cvt_pk_rtz_f16_f32\015s_cvt_u32_f32\020s_dcache_discard"
    "\023s_dcache_discard_x2\014s_dcache_inv\020s_dcache_inv_vol\013s_dcache"
    "_wb\017s_dcache_wb_vol\016s_decperflevel\013s_delay_alu\015s_denorm_mod"
    "e\010s_endpgm\030s_endpgm_ordered_ps_done\016s_endpgm_saved\015s_ff0_i3"
    "2_b32\015s_ff0_i32_b64\015s_ff1_i32_b32\015s_ff1_i32_b64\013s_flbit_i32"
    "\017s_flbit_i32_b32\017s_flbit_i32_b64\017s_flbit_i32_i64\013s_floor_f1"
    "6\013s_floor_f32\013s_fmaak_f32\ns_fmac_f16\ns_fmac_f32\013s_fmamk_f32\023"
    "s_get_barrier_state\014s_get_pc_i64\027s_get_shader_cycles_u64\031s_get"
    "_waveid_in_workgroup\013s_getpc_b64\014s_getreg_b32\ts_gl1_inv\014s_ica"
    "che_inv\016s_incperflevel\017s_inst_prefetch\013s_load_b128\013s_load_b"
    "256\ns_load_b32\013s_load_b512\ns_load_b64\ns_load_b96\014s_load_dword\017"
    "s_load_dwordx16\016s_load_dwordx2\016s_load_dwordx4\016s_load_dwordx8\n"
    "s_load_i16\ts_load_i8\ns_load_u16\ts_load_u8\017s_lshl1_add_u32\017s_ls"
    "hl2_add_u32\017s_lshl3_add_u32\017s_lshl4_add_u32\ns_lshl_b32\ns_lshl_b"
    "64\ns_lshr_b32\ns_lshr_b64\ts_max_f16\ts_max_f32\ts_max_i32\015s_max_nu"
    "m_f16\015s_max_num_f32\ts_max_u32\015s_maximum_f16\015s_maximum_f32\015"
    "s_memrealtime\ts_memtime\ts_min_f16\ts_min_f32\ts_min_i32\015s_min_num_"
    "f16\015s_min_num_f32\ts_min_u32\015s_minimum_f16\015s_minimum_f32\017s_"
    "monitor_sleep\ts_mov_b32\ts_mov_b64\ns_movk_i32\015s_movreld_b32\015s_m"
    "ovreld_b64\015s_movrels_b32\015s_movrels_b64\020s_movrelsd_2_b32\ts_mul"
    "_f16\ts_mul_f32\014s_mul_hi_i32\014s_mul_hi_u32\ts_mul_i32\ts_mul_u64\n"
    "s_mulk_i32\ns_nand_b32\ns_nand_b64\023s_nand_saveexec_b32\023s_nand_sav"
    "eexec_b64\005s_nop\ts_nor_b32\ts_nor_b64\022s_nor_saveexec_b32\022s_nor"
    "_saveexec_b64\ts_not_b32\ts_not_b64\010s_or_b32\010s_or_b64\026s_or_not"
    "0_saveexec_b32\026s_or_not0_saveexec_b64\015s_or_not1_b32\015s_or_not1_"
    "b64\026s_or_not1_saveexec_b32\026s_or_not1_saveexec_b64\021s_or_saveexe"
    "c_b32\021s_or_saveexec_b64\023s_orn1_saveexec_b32\023s_orn1_saveexec_b6"
    "4\ns_orn2_b32\ns_orn2_b64\023s_orn2_saveexec_b32\023s_orn2_saveexec_b64"
    "\021s_pack_hh_b32_b16\021s_pack_hl_b32_b16\021s_pack_lh_b32_b16\021s_pa"
    "ck_ll_b32_b16\017s_prefetch_data\026s_prefetch_data_pc_rel\017s_prefetc"
    "h_inst\026s_prefetch_inst_pc_rel\016s_quadmask_b32\016s_quadmask_b64\ts"
    "_rfe_b64\ts_rfe_i64\021s_rfe_restore_b64\013s_rndne_f16\013s_rndne_f32\014"
    "s_round_mode\024s_scratch_load_dword\026s_scratch_load_dwordx2\026s_scr"
    "atch_load_dwordx4\025s_scratch_store_dword\027s_scratch_store_dwordx2\027"
    "s_scratch_store_dwordx4\ts_sendmsg\021s_sendmsg_rtn_b32\021s_sendmsg_rt"
    "n_b64\015s_sendmsghalt\021s_set_gpr_idx_idx\022s_set_gpr_idx_mode\021s_"
    "set_gpr_idx_off\020s_set_gpr_idx_on\034s_set_inst_prefetch_distance\014"
    "s_set_pc_i64\016s_set_vgpr_msb\ts_sethalt\ts_setkill\013s_setpc_b64\ts_"
    "setprio\020s_setprio_inc_wg\014s_setreg_b32\022s_setreg_imm32_b32\ns_se"
    "tvskip\016s_sext_i32_i16\015s_sext_i32_i8\007s_sleep\013s_sleep_var\015"
    "s_store_dword\017s_store_dwordx2\017s_store_dwordx4\017s_sub_co_ci_u32\014"
    "s_sub_co_i32\014s_sub_co_u32\ts_sub_f16\ts_sub_f32\ts_sub_i32\014s_sub_"
    "nc_u64\ts_sub_u32\ns_subb_u32\026s_subvector_loop_begin\024s_subvector_"
    "loop_end\015s_swap_pc_i64\014s_swappc_b64\006s_trap\013s_trunc_f16\013s"
    "_trunc_f32\014s_ttracedata\020s_ttracedata_imm\ts_version\ns_wait_alu\017"
    "s_wait_asynccnt\015s_wait_bvhcnt\014s_wait_dscnt\014s_wait_event\015s_w"
    "ait_expcnt\013s_wait_idle\014s_wait_kmcnt\016s_wait_loadcnt\024s_wait_l"
    "oadcnt_dscnt\020s_wait_samplecnt\017s_wait_storecnt\025s_wait_storecnt_"
    "dscnt\020s_wait_tensorcnt\013s_wait_xcnt\ts_waitcnt\020s_waitcnt_depctr"
    "\020s_waitcnt_expcnt\021s_waitcnt_lgkmcnt\017s_waitcnt_vmcnt\017s_waitc"
    "nt_vscnt\010s_wakeup\020s_wakeup_barrier\ts_wqm_b32\ts_wqm_b64\ns_xnor_"
    "b32\ns_xnor_b64\023s_xnor_saveexec_b32\023s_xnor_saveexec_b64\ts_xor_b3"
    "2\ts_xor_b64\022s_xor_saveexec_b32\022s_xor_saveexec_b64\021scratch_loa"
    "d_b128\020scratch_load_b32\020scratch_load_b64\020scratch_load_b96\022s"
    "cratch_load_block\024scratch_load_d16_b16\027scratch_load_d16_hi_b16\026"
    "scratch_load_d16_hi_i8\026scratch_load_d16_hi_u8\023scratch_load_d16_i8"
    "\023scratch_load_d16_u8\022scratch_load_dword\024scratch_load_dwordx2\024"
    "scratch_load_dwordx3\024scratch_load_dwordx4\020scratch_load_i16\017scr"
    "atch_load_i8\026scratch_load_lds_dword\026scratch_load_lds_sbyte\027scr"
    "atch_load_lds_sshort\026scratch_load_lds_ubyte\027scratch_load_lds_usho"
    "rt\022scratch_load_sbyte\026scratch_load_sbyte_d16\031scratch_load_sbyt"
    "e_d16_hi\026scratch_load_short_d16\031scratch_load_short_d16_hi\023scra"
    "tch_load_sshort\020scratch_load_u16\017scratch_load_u8\022scratch_load_"
    "ubyte\026scratch_load_ubyte_d16\031scratch_load_ubyte_d16_hi\023scratch"
    "_load_ushort\022scratch_store_b128\021scratch_store_b16\021scratch_stor"
    "e_b32\021scratch_store_b64\020scratch_store_b8\021scratch_store_b96\023"
    "scratch_store_block\022scratch_store_byte\031scratch_store_byte_d16_hi\030"
    "scratch_store_d16_hi_b16\027scratch_store_d16_hi_b8\023scratch_store_dw"
    "ord\025scratch_store_dwordx2\025scratch_store_dwordx3\025scratch_store_"
    "dwordx4\023scratch_store_short\032scratch_store_short_d16_hi\031tbuffer"
    "_load_d16_format_x\032tbuffer_load_d16_format_xy\033tbuffer_load_d16_fo"
    "rmat_xyz\034tbuffer_load_d16_format_xyzw\031tbuffer_load_format_d16_x\032"
    "tbuffer_load_format_d16_xy\033tbuffer_load_format_d16_xyz\034tbuffer_lo"
    "ad_format_d16_xyzw\025tbuffer_load_format_x\026tbuffer_load_format_xy\027"
    "tbuffer_load_format_xyz\030tbuffer_load_format_xyzw\032tbuffer_store_d1"
    "6_format_x\033tbuffer_store_d16_format_xy\034tbuffer_store_d16_format_x"
    "yz\035tbuffer_store_d16_format_xyzw\032tbuffer_store_format_d16_x\033tb"
    "uffer_store_format_d16_xy\034tbuffer_store_format_d16_xyz\035tbuffer_st"
    "ore_format_d16_xyzw\026tbuffer_store_format_x\027tbuffer_store_format_x"
    "y\030tbuffer_store_format_xyz\031tbuffer_store_format_xyzw\022tensor_lo"
    "ad_to_lds\013tensor_save\013tensor_stop\025tensor_store_from_lds\021v_a"
    "ccvgpr_mov_b32\022v_accvgpr_read_b32\023v_accvgpr_write_b32\nv_add3_u32"
    "\017v_add_co_ci_u32\014v_add_co_u32\tv_add_f16\tv_add_f32\tv_add_f64\tv"
    "_add_i16\tv_add_i32\016v_add_lshl_u32\015v_add_max_i32\015v_add_max_u32"
    "\015v_add_min_i32\015v_add_min_u32\014v_add_nc_i16\014v_add_nc_i32\014v"
    "_add_nc_u16\014v_add_nc_u32\014v_add_nc_u64\tv_add_u16\tv_add_u32\015v_"
    "addc_co_u32\nv_addc_u32\016v_alignbit_b32\017v_alignbyte_b32\tv_and_b16"
    "\tv_and_b32\014v_and_or_b32\nv_ashr_i32\nv_ashr_i64\020v_ashr_pk_i8_i32"
    "\020v_ashr_pk_u8_i32\015v_ashrrev_i16\015v_ashrrev_i32\015v_ashrrev_i64"
    "\016v_bcnt_u32_b32\tv_bfe_i32\tv_bfe_u32\tv_bfi_b32\tv_bfm_b32\013v_bfr"
    "ev_b32\014v_bitop3_b16\014v_bitop3_b32\nv_ceil_f16\nv_ceil_f32\nv_ceil_"
    "f64\tv_clrexcp\tv_cls_i32\015v_clz_i32_u32\017v_cmp_class_f16\023v_cmp_"
    "class_f16_e32\017v_cmp_class_f32\023v_cmp_class_f32_e32\017v_cmp_class_"
    "f64\023v_cmp_class_f64_e32\014v_cmp_eq_f16\020v_cmp_eq_f16_e32\014v_cmp"
    "_eq_f32\020v_cmp_eq_f32_e32\014v_cmp_eq_f64\020v_cmp_eq_f64_e32\014v_cm"
    "p_eq_i16\020v_cmp_eq_i16_e32\014v_cmp_eq_i32\020v_cmp_eq_i32_e32\014v_c"
    "mp_eq_i64\020v_cmp_eq_i64_e32\014v_cmp_eq_u16\020v_cmp_eq_u16_e32\014v_"
    "cmp_eq_u32\020v_cmp_eq_u32_e32\014v_cmp_eq_u64\020v_cmp_eq_u64_e32\013v"
    "_cmp_f_f16\017v_cmp_f_f16_e32\013v_cmp_f_f32\017v_cmp_f_f32_e32\013v_cm"
    "p_f_f64\017v_cmp_f_f64_e32\013v_cmp_f_i16\017v_cmp_f_i16_e32\013v_cmp_f"
    "_i32\017v_cmp_f_i32_e32\013v_cmp_f_i64\017v_cmp_f_i64_e32\013v_cmp_f_u1"
    "6\017v_cmp_f_u16_e32\013v_cmp_f_u32\017v_cmp_f_u32_e32\013v_cmp_f_u64\017"
    "v_cmp_f_u64_e32\014v_cmp_ge_f16\020v_cmp_ge_f16_e32\014v_cmp_ge_f32\020"
    "v_cmp_ge_f32_e32\014v_cmp_ge_f64\020v_cmp_ge_f64_e32\014v_cmp_ge_i16\020"
    "v_cmp_ge_i16_e32\014v_cmp_ge_i32\020v_cmp_ge_i32_e32\014v_cmp_ge_i64\020"
    "v_cmp_ge_i64_e32\014v_cmp_ge_u16\020v_cmp_ge_u16_e32\014v_cmp_ge_u32\020"
    "v_cmp_ge_u32_e32\014v_cmp_ge_u64\020v_cmp_ge_u64_e32\014v_cmp_gt_f16\020"
    "v_cmp_gt_f16_e32\014v_cmp_gt_f32\020v_cmp_gt_f32_e32\014v_cmp_gt_f64\020"
    "v_cmp_gt_f64_e32\014v_cmp_gt_i16\020v_cmp_gt_i16_e32\014v_cmp_gt_i32\020"
    "v_cmp_gt_i32_e32\014v_cmp_gt_i64\020v_cmp_gt_i64_e32\014v_cmp_gt_u16\020"
    "v_cmp_gt_u16_e32\014v_cmp_gt_u32\020v_cmp_gt_u32_e32\014v_cmp_gt_u64\020"
    "v_cmp_gt_u64_e32\014v_cmp_le_f16\020v_cmp_le_f16_e32\014v_cmp_le_f32\020"
    "v_cmp_le_f32_e32\014v_cmp_le_f64\020v_cmp_le_f64_e32\014v_cmp_le_i16\020"
    "v_cmp_le_i16_e32\014v_cmp_le_i32\020v_cmp_le_i32_e32\014v_cmp_le_i64\020"
    "v_cmp_le_i64_e32\014v_cmp_le_u16\020v_cmp_le_u16_e32\014v_cmp_le_u32\020"
    "v_cmp_le_u32_e32\014v_cmp_le_u64\020v_cmp_le_u64_e32\014v_cmp_lg_f16\020"
    "v_cmp_lg_f16_e32\014v_cmp_lg_f32\020v_cmp_lg_f32_e32\014v_cmp_lg_f64\020"
    "v_cmp_lg_f64_e32\014v_cmp_lt_f16\020v_cmp_lt_f16_e32\014v_cmp_lt_f32\020"
    "v_cmp_lt_f32_e32\014v_cmp_lt_f64\020v_cmp_lt_f64_e32\014v_cmp_lt_i16\020"
    "v_cmp_lt_i16_e32\014v_cmp_lt_i32\020v_cmp_lt_i32_e32\014v_cmp_lt_i64\020"
    "v_cmp_lt_i64_e32\014v_cmp_lt_u16\020v_cmp_lt_u16_e32\014v_cmp_lt_u32\020"
    "v_cmp_lt_u32_e32\014v_cmp_lt_u64\020v_cmp_lt_u64_e32\014v_cmp_ne_i16\020"
    "v_cmp_ne_i16_e32\014v_cmp_ne_i32\020v_cmp_ne_i32_e32\014v_cmp_ne_i64\020"
    "v_cmp_ne_i64_e32\014v_cmp_ne_u16\020v_cmp_ne_u16_e32\014v_cmp_ne_u32\020"
    "v_cmp_ne_u32_e32\014v_cmp_ne_u64\020v_cmp_ne_u64_e32\015v_cmp_neq_f16\021"
    "v_cmp_neq_f16_e32\015v_cmp_neq_f32\021v_cmp_neq_f32_e32\015v_cmp_neq_f6"
    "4\021v_cmp_neq_f64_e32\015v_cmp_nge_f16\021v_cmp_nge_f16_e32\015v_cmp_n"
    "ge_f32\021v_cmp_nge_f32_e32\015v_cmp_nge_f64\021v_cmp_nge_f64_e32\015v_"
    "cmp_ngt_f16\021v_cmp_ngt_f16_e32\015v_cmp_ngt_f32\021v_cmp_ngt_f32_e32\015"
    "v_cmp_ngt_f64\021v_cmp_ngt_f64_e32\015v_cmp_nle_f16\021v_cmp_nle_f16_e3"
    "2\015v_cmp_nle_f32\021v_cmp_nle_f32_e32\015v_cmp_nle_f64\021v_cmp_nle_f"
    "64_e32\015v_cmp_nlg_f16\021v_cmp_nlg_f16_e32\015v_cmp_nlg_f32\021v_cmp_"
    "nlg_f32_e32\015v_cmp_nlg_f64\021v_cmp_nlg_f64_e32\015v_cmp_nlt_f16\021v"
    "_cmp_nlt_f16_e32\015v_cmp_nlt_f32\021v_cmp_nlt_f32_e32\015v_cmp_nlt_f64"
    "\021v_cmp_nlt_f64_e32\013v_cmp_o_f16\017v_cmp_o_f16_e32\013v_cmp_o_f32\017"
    "v_cmp_o_f32_e32\013v_cmp_o_f64\017v_cmp_o_f64_e32\013v_cmp_t_f16\017v_c"
    "mp_t_f16_e32\013v_cmp_t_f32\017v_cmp_t_f32_e32\013v_cmp_t_f64\017v_cmp_"
    "t_f64_e32\013v_cmp_t_i16\017v_cmp_t_i16_e32\013v_cmp_t_i32\017v_cmp_t_i"
    "32_e32\013v_cmp_t_i64\017v_cmp_t_i64_e32\013v_cmp_t_u16\017v_cmp_t_u16_"
    "e32\013v_cmp_t_u32\017v_cmp_t_u32_e32\013v_cmp_t_u64\017v_cmp_t_u64_e32"
    "\015v_cmp_tru_f16\021v_cmp_tru_f16_e32\015v_cmp_tru_f32\021v_cmp_tru_f3"
    "2_e32\015v_cmp_tru_f64\021v_cmp_tru_f64_e32\013v_cmp_u_f16\017v_cmp_u_f"
    "16_e32\013v_cmp_u_f32\017v_cmp_u_f32_e32\013v_cmp_u_f64\017v_cmp_u_f64_"
    "e32\015v_cmps_eq_f32\021v_cmps_eq_f32_e32\015v_cmps_eq_f64\021v_cmps_eq"
    "_f64_e32\014v_cmps_f_f32\020v_cmps_f_f32_e32\014v_cmps_f_f64\020v_cmps_"
    "f_f64_e32\015v_cmps_ge_f32\021v_cmps_ge_f32_e32\015v_cmps_ge_f64\021v_c"
    "mps_ge_f64_e32\015v_cmps_gt_f32\021v_cmps_gt_f32_e32\015v_cmps_gt_f64\021"
    "v_cmps_gt_f64_e32\015v_cmps_le_f32\021v_cmps_le_f32_e32\015v_cmps_le_f6"
    "4\021v_cmps_le_f64_e32\015v_cmps_lg_f32\021v_cmps_lg_f32_e32\015v_cmps_"
    "lg_f64\021v_cmps_lg_f64_e32\015v_cmps_lt_f32\021v_cmps_lt_f32_e32\015v_"
    "cmps_lt_f64\021v_cmps_lt_f64_e32\016v_cmps_neq_f32\022v_cmps_neq_f32_e3"
    "2\016v_cmps_neq_f64\022v_cmps_neq_f64_e32\016v_cmps_nge_f32\022v_cmps_n"
    "ge_f32_e32\016v_cmps_nge_f64\022v_cmps_nge_f64_e32\016v_cmps_ngt_f32\022"
    "v_cmps_ngt_f32_e32\016v_cmps_ngt_f64\022v_cmps_ngt_f64_e32\016v_cmps_nl"
    "e_f32\022v_cmps_nle_f32_e32\016v_cmps_nle_f64\022v_cmps_nle_f64_e32\016"
    "v_cmps_nlg_f32\022v_cmps_nlg_f32_e32\016v_cmps_nlg_f64\022v_cmps_nlg_f6"
    "4_e32\016v_cmps_nlt_f32\022v_cmps_nlt_f32_e32\016v_cmps_nlt_f64\022v_cm"
    "ps_nlt_f64_e32\014v_cmps_o_f32\020v_cmps_o_f32_e32\014v_cmps_o_f64\020v"
    "_cmps_o_f64_e32\016v_cmps_tru_f32\022v_cmps_tru_f32_e32\016v_cmps_tru_f"
    "64\022v_cmps_tru_f64_e32\014v_cmps_u_f32\020v_cmps_u_f32_e32\014v_cmps_"
    "u_f64\020v_cmps_u_f64_e32\016v_cmpsx_eq_f32\022v_cmpsx_eq_f32_e32\016v_"
    "cmpsx_eq_f64\022v_cmpsx_eq_f64_e32\015v_cmpsx_f_f32\021v_cmpsx_f_f32_e3"
    "2\015v_cmpsx_f_f64\021v_cmpsx_f_f64_e32\016v_cmpsx_ge_f32\022v_cmpsx_ge"
    "_f32_e32\016v_cmpsx_ge_f64\022v_cmpsx_ge_f64_e32\016v_cmpsx_gt_f32\022v"
    "_cmpsx_gt_f32_e32\016v_cmpsx_gt_f64\022v_cmpsx_gt_f64_e32\016v_cmpsx_le"
    "_f32\022v_cmpsx_le_f32_e32\016v_cmpsx_le_f64\022v_cmpsx_le_f64_e32\016v"
    "_cmpsx_lg_f32\022v_cmpsx_lg_f32_e32\016v_cmpsx_lg_f64\022v_cmpsx_lg_f64"
    "_e32\016v_cmpsx_lt_f32\022v_cmpsx_lt_f32_e32\016v_cmpsx_lt_f64\022v_cmp"
    "sx_lt_f64_e32\017v_cmpsx_neq_f32\023v_cmpsx_neq_f32_e32\017v_cmpsx_neq_"
    "f64\023v_cmpsx_neq_f64_e32\017v_cmpsx_nge_f32\023v_cmpsx_nge_f32_e32\017"
    "v_cmpsx_nge_f64\023v_cmpsx_nge_f64_e32\017v_cmpsx_ngt_f32\023v_cmpsx_ng"
    "t_f32_e32\017v_cmpsx_ngt_f64\023v_cmpsx_ngt_f64_e32\017v_cmpsx_nle_f32\023"
    "v_cmpsx_nle_f32_e32\017v_cmpsx_nle_f64\023v_cmpsx_nle_f64_e32\017v_cmps"
    "x_nlg_f32\023v_cmpsx_nlg_f32_e32\017v_cmpsx_nlg_f64\023v_cmpsx_nlg_f64_"
    "e32\017v_cmpsx_nlt_f32\023v_cmpsx_nlt_f32_e32\017v_cmpsx_nlt_f64\023v_c"
    "mpsx_nlt_f64_e32\015v_cmpsx_o_f32\021v_cmpsx_o_f32_e32\015v_cmpsx_o_f64"
    "\021v_cmpsx_o_f64_e32\017v_cmpsx_tru_f32\023v_cmpsx_tru_f32_e32\017v_cm"
    "psx_tru_f64\023v_cmpsx_tru_f64_e32\015v_cmpsx_u_f32\021v_cmpsx_u_f32_e3"
    "2\015v_cmpsx_u_f64\021v_cmpsx_u_f64_e32\020v_cmpx_class_f16\024v_cmpx_c"
    "lass_f16_e32\020v_cmpx_class_f32\024v_cmpx_class_f32_e32\020v_cmpx_clas"
    "s_f64\024v_cmpx_class_f64_e32\015v_cmpx_eq_f16\021v_cmpx_eq_f16_e32\015"
    "v_cmpx_eq_f32\021v_cmpx_eq_f32_e32\015v_cmpx_eq_f64\021v_cmpx_eq_f64_e3"
    "2\015v_cmpx_eq_i16\021v_cmpx_eq_i16_e32\015v_cmpx_eq_i32\021v_cmpx_eq_i"
    "32_e32\015v_cmpx_eq_i64\021v_cmpx_eq_i64_e32\015v_cmpx_eq_u16\021v_cmpx"
    "_eq_u16_e32\015v_cmpx_eq_u32\021v_cmpx_eq_u32_e32\015v_cmpx_eq_u64\021v"
    "_cmpx_eq_u64_e32\014v_cmpx_f_f16\020v_cmpx_f_f16_e32\014v_cmpx_f_f32\020"
    "v_cmpx_f_f32_e32\014v_cmpx_f_f64\020v_cmpx_f_f64_e32\014v_cmpx_f_i16\020"
    "v_cmpx_f_i16_e32\014v_cmpx_f_i32\020v_cmpx_f_i32_e32\014v_cmpx_f_i64\020"
    "v_cmpx_f_i64_e32\014v_cmpx_f_u16\020v_cmpx_f_u16_e32\014v_cmpx_f_u32\020"
    "v_cmpx_f_u32_e32\014v_cmpx_f_u64\020v_cmpx_f_u64_e32\015v_cmpx_ge_f16\021"
    "v_cmpx_ge_f16_e32\015v_cmpx_ge_f32\021v_cmpx_ge_f32_e32\015v_cmpx_ge_f6"
    "4\021v_cmpx_ge_f64_e32\015v_cmpx_ge_i16\021v_cmpx_ge_i16_e32\015v_cmpx_"
    "ge_i32\021v_cmpx_ge_i32_e32\015v_cmpx_ge_i64\021v_cmpx_ge_i64_e32\015v_"
    "cmpx_ge_u16\021v_cmpx_ge_u16_e32\015v_cmpx_ge_u32\021v_cmpx_ge_u32_e32\015"
    "v_cmpx_ge_u64\021v_cmpx_ge_u64_e32\015v_cmpx_gt_f16\021v_cmpx_gt_f16_e3"
    "2\015v_cmpx_gt_f32\021v_cmpx_gt_f32_e32\015v_cmpx_gt_f64\021v_cmpx_gt_f"
    "64_e32\015v_cmpx_gt_i16\021v_cmpx_gt_i16_e32\015v_cmpx_gt_i32\021v_cmpx"
    "_gt_i32_e32\015v_cmpx_gt_i64\021v_cmpx_gt_i64_e32\015v_cmpx_gt_u16\021v"
    "_cmpx_gt_u16_e32\015v_cmpx_gt_u32\021v_cmpx_gt_u32_e32\015v_cmpx_gt_u64"
    "\021v_cmpx_gt_u64_e32\015v_cmpx_le_f16\021v_cmpx_le_f16_e32\015v_cmpx_l"
    "e_f32\021v_cmpx_le_f32_e32\015v_cmpx_le_f64\021v_cmpx_le_f64_e32\015v_c"
    "mpx_le_i16\021v_cmpx_le_i16_e32\015v_cmpx_le_i32\021v_cmpx_le_i32_e32\015"
    "v_cmpx_le_i64\021v_cmpx_le_i64_e32\015v_cmpx_le_u16\021v_cmpx_le_u16_e3"
    "2\015v_cmpx_le_u32\021v_cmpx_le_u32_e32\015v_cmpx_le_u64\021v_cmpx_le_u"
    "64_e32\015v_cmpx_lg_f16\021v_cmpx_lg_f16_e32\015v_cmpx_lg_f32\021v_cmpx"
    "_lg_f32_e32\015v_cmpx_lg_f64\021v_cmpx_lg_f64_e32\015v_cmpx_lt_f16\021v"
    "_cmpx_lt_f16_e32\015v_cmpx_lt_f32\021v_cmpx_lt_f32_e32\015v_cmpx_lt_f64"
    "\021v_cmpx_lt_f64_e32\015v_cmpx_lt_i16\021v_cmpx_lt_i16_e32\015v_cmpx_l"
    "t_i32\021v_cmpx_lt_i32_e32\015v_cmpx_lt_i64\021v_cmpx_lt_i64_e32\015v_c"
    "mpx_lt_u16\021v_cmpx_lt_u16_e32\015v_cmpx_lt_u32\021v_cmpx_lt_u32_e32\015"
    "v_cmpx_lt_u64\021v_cmpx_lt_u64_e32\015v_cmpx_ne_i16\021v_cmpx_ne_i16_e3"
    "2\015v_cmpx_ne_i32\021v_cmpx_ne_i32_e32\015v_cmpx_ne_i64\021v_cmpx_ne_i"
    "64_e32\015v_cmpx_ne_u16\021v_cmpx_ne_u16_e32\015v_cmpx_ne_u32\021v_cmpx"
    "_ne_u32_e32\015v_cmpx_ne_u64\021v_cmpx_ne_u64_e32\016v_cmpx_neq_f16\022"
    "v_cmpx_neq_f16_e32\016v_cmpx_neq_f32\022v_cmpx_neq_f32_e32\016v_cmpx_ne"
    "q_f64\022v_cmpx_neq_f64_e32\016v_cmpx_nge_f16\022v_cmpx_nge_f16_e32\016"
    "v_cmpx_nge_f32\022v_cmpx_nge_f32_e32\016v_cmpx_nge_f64\022v_cmpx_nge_f6"
    "4_e32\016v_cmpx_ngt_f16\022v_cmpx_ngt_f16_e32\016v_cmpx_ngt_f32\022v_cm"
    "px_ngt_f32_e32\016v_cmpx_ngt_f64\022v_cmpx_ngt_f64_e32\016v_cmpx_nle_f1"
    "6\022v_cmpx_nle_f16_e32\016v_cmpx_nle_f32\022v_cmpx_nle_f32_e32\016v_cm"
    "px_nle_f64\022v_cmpx_nle_f64_e32\016v_cmpx_nlg_f16\022v_cmpx_nlg_f16_e3"
    "2\016v_cmpx_nlg_f32\022v_cmpx_nlg_f32_e32\016v_cmpx_nlg_f64\022v_cmpx_n"
    "lg_f64_e32\016v_cmpx_nlt_f16\022v_cmpx_nlt_f16_e32\016v_cmpx_nlt_f32\022"
    "v_cmpx_nlt_f32_e32\016v_cmpx_nlt_f64\022v_cmpx_nlt_f64_e32\014v_cmpx_o_"
    "f16\020v_cmpx_o_f16_e32\014v_cmpx_o_f32\020v_cmpx_o_f32_e32\014v_cmpx_o"
    "_f64\020v_cmpx_o_f64_e32\014v_cmpx_t_f16\020v_cmpx_t_f16_e32\014v_cmpx_"
    "t_f32\020v_cmpx_t_f32_e32\014v_cmpx_t_f64\020v_cmpx_t_f64_e32\014v_cmpx"
    "_t_i16\020v_cmpx_t_i16_e32\014v_cmpx_t_i32\020v_cmpx_t_i32_e32\014v_cmp"
    "x_t_i64\020v_cmpx_t_i64_e32\014v_cmpx_t_u16\020v_cmpx_t_u16_e32\014v_cm"
    "px_t_u32\020v_cmpx_t_u32_e32\014v_cmpx_t_u64\020v_cmpx_t_u64_e32\016v_c"
    "mpx_tru_f16\022v_cmpx_tru_f16_e32\016v_cmpx_tru_f32\022v_cmpx_tru_f32_e"
    "32\016v_cmpx_tru_f64\022v_cmpx_tru_f64_e32\014v_cmpx_u_f16\020v_cmpx_u_"
    "f16_e32\014v_cmpx_u_f32\020v_cmpx_u_f32_e32\014v_cmpx_u_f64\020v_cmpx_u"
    "_f64_e32\015v_cndmask_b16\015v_cndmask_b32\nv_cos_bf16\tv_cos_f16\tv_co"
    "s_f32\015v_ctz_i32_b32\014v_cubeid_f32\014v_cubema_f32\014v_cubesc_f32\014"
    "v_cubetc_f32\015v_cvt_f16_bf8\015v_cvt_f16_f32\015v_cvt_f16_fp8\015v_cv"
    "t_f16_i16\015v_cvt_f16_u16\016v_cvt_f32_bf16\015v_cvt_f32_bf8\015v_cvt_"
    "f32_f16\015v_cvt_f32_f64\015v_cvt_f32_fp8\015v_cvt_f32_i32\015v_cvt_f32"
    "_u32\020v_cvt_f32_ubyte0\020v_cvt_f32_ubyte1\020v_cvt_f32_ubyte2\020v_c"
    "vt_f32_ubyte3\015v_cvt_f64_f32\015v_cvt_f64_i32\015v_cvt_f64_u32\023v_c"
    "vt_floor_i32_f32\021v_cvt_flr_i32_f32\015v_cvt_i16_f16\015v_cvt_i32_f32"
    "\015v_cvt_i32_f64\015v_cvt_i32_i16\025v_cvt_nearest_i32_f32\022v_cvt_no"
    "rm_i16_f16\022v_cvt_norm_u16_f16\020v_cvt_off_f32_i4\021v_cvt_pk_bf16_f"
    "32\020v_cvt_pk_bf8_f16\020v_cvt_pk_bf8_f32\020v_cvt_pk_f16_bf8\020v_cvt"
    "_pk_f16_f32\020v_cvt_pk_f16_fp8\020v_cvt_pk_f32_bf8\020v_cvt_pk_f32_fp8"
    "\020v_cvt_pk_fp8_f16\020v_cvt_pk_fp8_f32\020v_cvt_pk_i16_f32\020v_cvt_p"
    "k_i16_i32\025v_cvt_pk_norm_i16_f16\025v_cvt_pk_norm_i16_f32\025v_cvt_pk"
    "_norm_u16_f16\025v_cvt_pk_norm_u16_f32\024v_cvt_pk_rtz_f16_f32\020v_cvt"
    "_pk_u16_f32\020v_cvt_pk_u16_u32\017v_cvt_pk_u8_f32\024v_cvt_pkaccum_u8_"
    "f32\024v_cvt_pknorm_i16_f16\024v_cvt_pknorm_i16_f32\024v_cvt_pknorm_u16"
    "_f16\024v_cvt_pknorm_u16_f32\023v_cvt_pkrtz_f16_f32\021v_cvt_rpi_i32_f3"
    "2\031v_cvt_scale_pk16_bf16_bf6\031v_cvt_scale_pk16_bf16_fp6\030v_cvt_sc"
    "ale_pk16_f16_bf6\030v_cvt_scale_pk16_f16_fp6\030v_cvt_scale_pk16_f32_bf"
    "6\030v_cvt_scale_pk16_f32_fp6\030v_cvt_scale_pk8_bf16_bf8\030v_cvt_scal"
    "e_pk8_bf16_fp4\030v_cvt_scale_pk8_bf16_fp8\027v_cvt_scale_pk8_f16_bf8\027"
    "v_cvt_scale_pk8_f16_fp4\027v_cvt_scale_pk8_f16_fp8\027v_cvt_scale_pk8_f"
    "32_bf8\027v_cvt_scale_pk8_f32_fp4\027v_cvt_scale_pk8_f32_fp8\035v_cvt_s"
    "calef32_2xpk16_bf6_f32\035v_cvt_scalef32_2xpk16_fp6_f32\026v_cvt_scalef"
    "32_f16_bf8\026v_cvt_scalef32_f16_fp8\026v_cvt_scalef32_f32_bf8\026v_cvt"
    "_scalef32_f32_fp8\034v_cvt_scalef32_pk16_bf6_bf16\033v_cvt_scalef32_pk1"
    "6_bf6_f16\033v_cvt_scalef32_pk16_bf6_f32\034v_cvt_scalef32_pk16_fp6_bf1"
    "6\033v_cvt_scalef32_pk16_fp6_f16\033v_cvt_scalef32_pk16_fp6_f32\034v_cv"
    "t_scalef32_pk32_bf16_bf6\034v_cvt_scalef32_pk32_bf16_fp6\034v_cvt_scale"
    "f32_pk32_bf6_bf16\033v_cvt_scalef32_pk32_bf6_f16\033v_cvt_scalef32_pk32"
    "_f16_bf6\033v_cvt_scalef32_pk32_f16_fp6\033v_cvt_scalef32_pk32_f32_bf6\033"
    "v_cvt_scalef32_pk32_f32_fp6\034v_cvt_scalef32_pk32_fp6_bf16\033v_cvt_sc"
    "alef32_pk32_fp6_f16\033v_cvt_scalef32_pk8_bf8_bf16\032v_cvt_scalef32_pk"
    "8_bf8_f16\032v_cvt_scalef32_pk8_bf8_f32\033v_cvt_scalef32_pk8_fp4_bf16\032"
    "v_cvt_scalef32_pk8_fp4_f16\032v_cvt_scalef32_pk8_fp4_f32\033v_cvt_scale"
    "f32_pk8_fp8_bf16\032v_cvt_scalef32_pk8_fp8_f16\032v_cvt_scalef32_pk8_fp"
    "8_f32\032v_cvt_scalef32_pk_bf16_bf8\032v_cvt_scalef32_pk_bf16_fp4\032v_"
    "cvt_scalef32_pk_bf16_fp8\032v_cvt_scalef32_pk_bf8_bf16\031v_cvt_scalef3"
    "2_pk_bf8_f16\031v_cvt_scalef32_pk_bf8_f32\031v_cvt_scalef32_pk_f16_bf8\031"
    "v_cvt_scalef32_pk_f16_fp4\031v_cvt_scalef32_pk_f16_fp8\031v_cvt_scalef3"
    "2_pk_f32_bf8\031v_cvt_scalef32_pk_f32_fp4\031v_cvt_scalef32_pk_f32_fp8\032"
    "v_cvt_scalef32_pk_fp4_bf16\031v_cvt_scalef32_pk_fp4_f16\031v_cvt_scalef"
    "32_pk_fp4_f32\032v_cvt_scalef32_pk_fp8_bf16\031v_cvt_scalef32_pk_fp8_f1"
    "6\031v_cvt_scalef32_pk_fp8_f32\032v_cvt_scalef32_sr_bf8_bf16\031v_cvt_s"
    "calef32_sr_bf8_f16\031v_cvt_scalef32_sr_bf8_f32\032v_cvt_scalef32_sr_fp"
    "8_bf16\031v_cvt_scalef32_sr_fp8_f16\031v_cvt_scalef32_sr_fp8_f32\037v_c"
    "vt_scalef32_sr_pk16_bf6_bf16\036v_cvt_scalef32_sr_pk16_bf6_f16\036v_cvt"
    "_scalef32_sr_pk16_bf6_f32\037v_cvt_scalef32_sr_pk16_fp6_bf16\036v_cvt_s"
    "calef32_sr_pk16_fp6_f16\036v_cvt_scalef32_sr_pk16_fp6_f32\037v_cvt_scal"
    "ef32_sr_pk32_bf6_bf16\036v_cvt_scalef32_sr_pk32_bf6_f16\036v_cvt_scalef"
    "32_sr_pk32_bf6_f32\037v_cvt_scalef32_sr_pk32_fp6_bf16\036v_cvt_scalef32"
    "_sr_pk32_fp6_f16\036v_cvt_scalef32_sr_pk32_fp6_f32\036v_cvt_scalef32_sr"
    "_pk8_bf8_bf16\035v_cvt_scalef32_sr_pk8_bf8_f16\035v_cvt_scalef32_sr_pk8"
    "_bf8_f32\036v_cvt_scalef32_sr_pk8_fp4_bf16\035v_cvt_scalef32_sr_pk8_fp4"
    "_f16\035v_cvt_scalef32_sr_pk8_fp4_f32\036v_cvt_scalef32_sr_pk8_fp8_bf16"
    "\035v_cvt_scalef32_sr_pk8_fp8_f16\035v_cvt_scalef32_sr_pk8_fp8_f32\035v"
    "_cvt_scalef32_sr_pk_fp4_bf16\034v_cvt_scalef32_sr_pk_fp4_f16\034v_cvt_s"
    "calef32_sr_pk_fp4_f32\021v_cvt_sr_bf16_f32\020v_cvt_sr_bf8_f16\020v_cvt"
    "_sr_bf8_f32\020v_cvt_sr_f16_f32\020v_cvt_sr_fp8_f16\020v_cvt_sr_fp8_f32"
    "\024v_cvt_sr_pk_bf16_f32\023v_cvt_sr_pk_f16_f32\015v_cvt_u16_f16\015v_c"
    "vt_u32_f32\015v_cvt_u32_f64\015v_cvt_u32_u16\017v_div_fixup_f16\017v_di"
    "v_fixup_f32\017v_div_fixup_f64\026v_div_fixup_legacy_f16\016v_div_fmas_"
    "f32\016v_div_fmas_f64\017v_div_scale_f32\017v_div_scale_f64\020v_dot2_b"
    "f16_bf16\016v_dot2_f16_f16\017v_dot2_f32_bf16\016v_dot2_f32_f16\016v_do"
    "t2_i32_i16\016v_dot2_u32_u16\021v_dot2acc_f32_f16\020v_dot2c_f32_bf16\017"
    "v_dot2c_f32_f16\017v_dot2c_i32_i16\022v_dot4_f32_bf8_bf8\022v_dot4_f32_"
    "bf8_fp8\022v_dot4_f32_fp8_bf8\022v_dot4_f32_fp8_fp8\015v_dot4_i32_i8\016"
    "v_dot4_i32_iu8\015v_dot4_u32_u8\016v_dot4c_i32_i8\015v_dot8_i32_i4\016v"
    "_dot8_i32_iu4\015v_dot8_u32_u4\016v_dot8c_i32_i4\016v_dual_add_f32\016v"
    "_dual_add_f64\021v_dual_add_nc_u32\022v_dual_ashrrev_i32\022v_dual_cndm"
    "ask_b32\027v_dual_dot2acc_f32_bf16\026v_dual_dot2acc_f32_f16\016v_dual_"
    "fma_f32\016v_dual_fma_f64\020v_dual_fmaak_f32\017v_dual_fmac_f32\020v_d"
    "ual_fmamk_f32\022v_dual_lshlrev_b32\022v_dual_lshrrev_b32\016v_dual_max"
    "_f32\022v_dual_max_num_f32\022v_dual_max_num_f64\016v_dual_min_f32\022v"
    "_dual_min_num_f32\022v_dual_min_num_f64\016v_dual_mov_b32\027v_dual_mul"
    "_dx9_zero_f32\016v_dual_mul_f32\016v_dual_mul_f64\016v_dual_sub_f32\021"
    "v_dual_sub_nc_u32\021v_dual_subrev_f32\nv_exp_bf16\tv_exp_f16\tv_exp_f3"
    "2\020v_exp_legacy_f32\nv_ffbh_i32\nv_ffbh_u32\nv_ffbl_b32\013v_floor_f1"
    "6\013v_floor_f32\013v_floor_f64\022v_fma_dx9_zero_f32\tv_fma_f16\tv_fma"
    "_f32\tv_fma_f64\020v_fma_legacy_f16\020v_fma_legacy_f32\015v_fma_mix_f3"
    "2\022v_fma_mix_f32_bf16\020v_fma_mixhi_bf16\017v_fma_mixhi_f16\020v_fma"
    "_mixlo_bf16\017v_fma_mixlo_f16\013v_fmaak_f16\013v_fmaak_f32\013v_fmaak"
    "_f64\023v_fmac_dx9_zero_f32\nv_fmac_f16\nv_fmac_f32\nv_fmac_f64\021v_fm"
    "ac_legacy_f32\013v_fmamk_f16\013v_fmamk_f32\013v_fmamk_f64\013v_fract_f"
    "16\013v_fract_f32\013v_fract_f64\023v_frexp_exp_i16_f16\023v_frexp_exp_"
    "i32_f32\023v_frexp_exp_i32_f64\020v_frexp_mant_f16\020v_frexp_mant_f32\020"
    "v_frexp_mant_f64\tv_illegal\020v_interp_mov_f32\024v_interp_p10_f16_f32"
    "\020v_interp_p10_f32\030v_interp_p10_rtz_f16_f32\017v_interp_p1_f32\021"
    "v_interp_p1ll_f16\021v_interp_p1lv_f16\017v_interp_p2_f16\023v_interp_p"
    "2_f16_f32\017v_interp_p2_f32\026v_interp_p2_legacy_f16\027v_interp_p2_r"
    "tz_f16_f32\013v_ldexp_f16\013v_ldexp_f32\013v_ldexp_f64\tv_lerp_u8\nv_l"
    "og_bf16\017v_log_clamp_f32\tv_log_f16\tv_log_f32\020v_log_legacy_f32\016"
    "v_lshl_add_u32\016v_lshl_add_u64\nv_lshl_b32\nv_lshl_b64\015v_lshl_or_b"
    "32\015v_lshlrev_b16\015v_lshlrev_b32\015v_lshlrev_b64\nv_lshr_b32\nv_ls"
    "hr_b64\015v_lshrrev_b16\015v_lshrrev_b32\015v_lshrrev_b64\tv_mac_f16\tv"
    "_mac_f32\020v_mac_legacy_f32\020v_mad_co_i64_i32\020v_mad_co_u64_u32\tv"
    "_mad_f16\tv_mad_f32\tv_mad_i16\015v_mad_i32_i16\015v_mad_i32_i24\015v_m"
    "ad_i64_i32\020v_mad_legacy_f16\020v_mad_legacy_f32\020v_mad_legacy_i16\020"
    "v_mad_legacy_u16\015v_mad_mix_f32\017v_mad_mixhi_f16\017v_mad_mixlo_f16"
    "\020v_mad_nc_i64_i32\020v_mad_nc_u64_u32\tv_mad_u16\tv_mad_u32\015v_mad"
    "_u32_u16\015v_mad_u32_u24\015v_mad_u64_u32\013v_madak_f16\013v_madak_f3"
    "2\013v_madmk_f16\013v_madmk_f32\nv_max3_f16\nv_max3_f32\nv_max3_i16\nv_"
    "max3_i32\016v_max3_num_f16\016v_max3_num_f32\nv_max3_u16\nv_max3_u32\tv"
    "_max_f16\tv_max_f32\tv_max_f64\tv_max_i16\tv_max_i32\tv_max_i64\020v_ma"
    "x_legacy_f32\015v_max_num_f16\015v_max_num_f32\015v_max_num_f64\tv_max_"
    "u16\tv_max_u32\tv_max_u64\016v_maximum3_f16\016v_maximum3_f32\015v_maxi"
    "mum_f16\015v_maximum_f32\015v_maximum_f64\024v_maximumminimum_f16\024v_"
    "maximumminimum_f32\014v_maxmin_f16\014v_maxmin_f32\014v_maxmin_i32\020v"
    "_maxmin_num_f16\020v_maxmin_num_f32\014v_maxmin_u32\022v_mbcnt_hi_u32_b"
    "32\022v_mbcnt_lo_u32_b32\nv_med3_f16\nv_med3_f32\nv_med3_i16\nv_med3_i3"
    "2\016v_med3_num_f16\016v_med3_num_f32\nv_med3_u16\nv_med3_u32\033v_mfma"
    "_f32_16x16x128_f8f6f4\030v_mfma_f32_16x16x16_bf16\027v_mfma_f32_16x16x1"
    "6_f16\027v_mfma_f32_16x16x16bf16\032v_mfma_f32_16x16x16bf16_1k\026v_mfm"
    "a_f32_16x16x16f16\031v_mfma_f32_16x16x1_4b_f32\025v_mfma_f32_16x16x1f32"
    "\026v_mfma_f32_16x16x2bf16\030v_mfma_f32_16x16x32_bf16\033v_mfma_f32_16"
    "x16x32_bf8_bf8\033v_mfma_f32_16x16x32_bf8_fp8\027v_mfma_f32_16x16x32_f1"
    "6\033v_mfma_f32_16x16x32_fp8_bf8\033v_mfma_f32_16x16x32_fp8_fp8\027v_mf"
    "ma_f32_16x16x32bf16\026v_mfma_f32_16x16x32f16\032v_mfma_f32_16x16x4_4b_"
    "bf16\031v_mfma_f32_16x16x4_4b_f16\026v_mfma_f32_16x16x4_f32\026v_mfma_f"
    "32_16x16x4bf16\031v_mfma_f32_16x16x4bf16_1k\025v_mfma_f32_16x16x4f16\025"
    "v_mfma_f32_16x16x4f32\027v_mfma_f32_16x16x8_xf32\026v_mfma_f32_16x16x8b"
    "f16\026v_mfma_f32_16x16x8xf32\030v_mfma_f32_32x32x16_bf16\033v_mfma_f32"
    "_32x32x16_bf8_bf8\033v_mfma_f32_32x32x16_bf8_fp8\027v_mfma_f32_32x32x16"
    "_f16\033v_mfma_f32_32x32x16_fp8_bf8\033v_mfma_f32_32x32x16_fp8_fp8\027v"
    "_mfma_f32_32x32x16bf16\026v_mfma_f32_32x32x16f16\031v_mfma_f32_32x32x1_"
    "2b_f32\025v_mfma_f32_32x32x1f32\026v_mfma_f32_32x32x2_f32\026v_mfma_f32"
    "_32x32x2bf16\025v_mfma_f32_32x32x2f32\032v_mfma_f32_32x32x4_2b_bf16\031"
    "v_mfma_f32_32x32x4_2b_f16\027v_mfma_f32_32x32x4_xf32\026v_mfma_f32_32x3"
    "2x4bf16\031v_mfma_f32_32x32x4bf16_1k\025v_mfma_f32_32x32x4f16\026v_mfma"
    "_f32_32x32x4xf32\032v_mfma_f32_32x32x64_f8f6f4\027v_mfma_f32_32x32x8_bf"
    "16\026v_mfma_f32_32x32x8_f16\026v_mfma_f32_32x32x8bf16\031v_mfma_f32_32"
    "x32x8bf16_1k\025v_mfma_f32_32x32x8f16\030v_mfma_f32_4x4x1_16b_f32\023v_"
    "mfma_f32_4x4x1f32\024v_mfma_f32_4x4x2bf16\031v_mfma_f32_4x4x4_16b_bf16\030"
    "v_mfma_f32_4x4x4_16b_f16\024v_mfma_f32_4x4x4bf16\027v_mfma_f32_4x4x4bf1"
    "6_1k\023v_mfma_f32_4x4x4f16\026v_mfma_f64_16x16x4_f64\025v_mfma_f64_16x"
    "16x4f64\027v_mfma_f64_4x4x4_4b_f64\023v_mfma_f64_4x4x4f64\025v_mfma_i32"
    "_16x16x16i8\026v_mfma_i32_16x16x32_i8\025v_mfma_i32_16x16x32i8\030v_mfm"
    "a_i32_16x16x4_4b_i8\024v_mfma_i32_16x16x4i8\026v_mfma_i32_16x16x64_i8\025"
    "v_mfma_i32_16x16x64i8\026v_mfma_i32_32x32x16_i8\025v_mfma_i32_32x32x16i"
    "8\026v_mfma_i32_32x32x32_i8\025v_mfma_i32_32x32x32i8\030v_mfma_i32_32x3"
    "2x4_2b_i8\024v_mfma_i32_32x32x4i8\024v_mfma_i32_32x32x8i8\027v_mfma_i32"
    "_4x4x4_16b_i8\022v_mfma_i32_4x4x4i8\023v_mfma_ld_scale_b32!v_mfma_scale"
    "_f32_16x16x128_f8f6f4 v_mfma_scale_f32_32x32x64_f8f6f4\nv_min3_f16\nv_m"
    "in3_f32\nv_min3_i16\nv_min3_i32\016v_min3_num_f16\016v_min3_num_f32\nv_"
    "min3_u16\nv_min3_u32\tv_min_f16\tv_min_f32\tv_min_f64\tv_min_i16\tv_min"
    "_i32\tv_min_i64\020v_min_legacy_f32\015v_min_num_f16\015v_min_num_f32\015"
    "v_min_num_f64\tv_min_u16\tv_min_u32\tv_min_u64\016v_minimum3_f16\016v_m"
    "inimum3_f32\015v_minimum_f16\015v_minimum_f32\015v_minimum_f64\024v_min"
    "imummaximum_f16\024v_minimummaximum_f32\014v_minmax_f16\014v_minmax_f32"
    "\014v_minmax_i32\020v_minmax_num_f16\020v_minmax_num_f32\014v_minmax_u3"
    "2\tv_mov_b16\tv_mov_b32\tv_mov_b64\015v_movreld_b32\015v_movrels_b32\020"
    "v_movrelsd_2_b32\016v_movrelsd_b32\021v_mqsad_pk_u16_u8\016v_mqsad_u32_"
    "u8\tv_msad_u8\022v_mul_dx9_zero_f32\tv_mul_f16\tv_mul_f32\tv_mul_f64\014"
    "v_mul_hi_i32\020v_mul_hi_i32_i24\014v_mul_hi_u32\020v_mul_hi_u32_u24\015"
    "v_mul_i32_i24\020v_mul_legacy_f32\014v_mul_lo_i32\014v_mul_lo_u16\014v_"
    "mul_lo_u32\015v_mul_u32_u24\tv_mul_u64\014v_mullit_f32\005v_nop\tv_not_"
    "b16\tv_not_b32\tv_or3_b32\010v_or_b16\010v_or_b32\016v_pack_b32_f16\nv_"
    "perm_b32\021v_perm_pk16_b4_u4\021v_perm_pk16_b6_u4\021v_perm_pk16_b8_u4"
    "\020v_permlane16_b32\025v_permlane16_swap_b32\024v_permlane16_var_b32\025"
    "v_permlane32_swap_b32\020v_permlane64_b32\024v_permlane_bcast_b32\023v_"
    "permlane_down_b32\026v_permlane_idx_gen_b32\021v_permlane_up_b32\022v_p"
    "ermlane_xor_b32\021v_permlanex16_b32\025v_permlanex16_var_b32\013v_pipe"
    "flush\015v_pk_add_bf16\014v_pk_add_f16\014v_pk_add_f32\014v_pk_add_i16\020"
    "v_pk_add_max_i16\020v_pk_add_max_u16\020v_pk_add_min_i16\020v_pk_add_mi"
    "n_u16\014v_pk_add_u16\020v_pk_ashrrev_i16\015v_pk_fma_bf16\014v_pk_fma_"
    "f16\014v_pk_fma_f32\015v_pk_fmac_f16\020v_pk_lshlrev_b16\020v_pk_lshrre"
    "v_b16\014v_pk_mad_i16\014v_pk_mad_u16\015v_pk_max3_i16\021v_pk_max3_num"
    "_f16\015v_pk_max3_u16\014v_pk_max_f16\014v_pk_max_i16\021v_pk_max_num_b"
    "f16\020v_pk_max_num_f16\014v_pk_max_u16\021v_pk_maximum3_f16\020v_pk_ma"
    "ximum_f16\015v_pk_min3_i16\021v_pk_min3_num_f16\015v_pk_min3_u16\014v_p"
    "k_min_f16\014v_pk_min_i16\021v_pk_min_num_bf16\020v_pk_min_num_f16\014v"
    "_pk_min_u16\021v_pk_minimum3_f16\020v_pk_minimum_f16\014v_pk_mov_b32\015"
    "v_pk_mul_bf16\014v_pk_mul_f16\014v_pk_mul_f32\017v_pk_mul_lo_u16\014v_p"
    "k_sub_i16\014v_pk_sub_u16\nv_prng_b32\020v_qsad_pk_u16_u8\nv_rcp_bf16\017"
    "v_rcp_clamp_f32\017v_rcp_clamp_f64\tv_rcp_f16\tv_rcp_f32\tv_rcp_f64\017"
    "v_rcp_iflag_f32\020v_rcp_legacy_f32\023v_readfirstlane_b32\016v_readlan"
    "e_b32\013v_rndne_f16\013v_rndne_f32\013v_rndne_f64\nv_rsq_bf16\017v_rsq"
    "_clamp_f32\017v_rsq_clamp_f64\tv_rsq_f16\tv_rsq_f32\tv_rsq_f64\020v_rsq"
    "_legacy_f32\013v_s_exp_f16\013v_s_exp_f32\013v_s_log_f16\013v_s_log_f32"
    "\013v_s_rcp_f16\013v_s_rcp_f32\013v_s_rsq_f16\013v_s_rsq_f32\014v_s_sqr"
    "t_f16\014v_s_sqrt_f32\013v_sad_hi_u8\tv_sad_u16\tv_sad_u32\010v_sad_u8\017"
    "v_sat_pk4_i4_i8\017v_sat_pk4_u4_u8\017v_sat_pk_u8_i16\032v_screen_parti"
    "tion_4se_b32\nv_sin_bf16\tv_sin_f16\tv_sin_f32\036v_smfmac_f32_16x16x12"
    "8_bf8_bf8\036v_smfmac_f32_16x16x128_bf8_fp8\036v_smfmac_f32_16x16x128_f"
    "p8_bf8\036v_smfmac_f32_16x16x128_fp8_fp8\032v_smfmac_f32_16x16x32_bf16\031"
    "v_smfmac_f32_16x16x32_f16\032v_smfmac_f32_16x16x64_bf16\035v_smfmac_f32"
    "_16x16x64_bf8_bf8\035v_smfmac_f32_16x16x64_bf8_fp8\031v_smfmac_f32_16x1"
    "6x64_f16\035v_smfmac_f32_16x16x64_fp8_bf8\035v_smfmac_f32_16x16x64_fp8_"
    "fp8\032v_smfmac_f32_32x32x16_bf16\031v_smfmac_f32_32x32x16_f16\032v_smf"
    "mac_f32_32x32x32_bf16\035v_smfmac_f32_32x32x32_bf8_bf8\035v_smfmac_f32_"
    "32x32x32_bf8_fp8\031v_smfmac_f32_32x32x32_f16\035v_smfmac_f32_32x32x32_"
    "fp8_bf8\035v_smfmac_f32_32x32x32_fp8_fp8\035v_smfmac_f32_32x32x64_bf8_b"
    "f8\035v_smfmac_f32_32x32x64_bf8_fp8\035v_smfmac_f32_32x32x64_fp8_bf8\035"
    "v_smfmac_f32_32x32x64_fp8_fp8\031v_smfmac_i32_16x16x128_i8\030v_smfmac_"
    "i32_16x16x64_i8\030v_smfmac_i32_32x32x32_i8\030v_smfmac_i32_32x32x64_i8"
    "\013v_sqrt_bf16\nv_sqrt_f16\nv_sqrt_f32\nv_sqrt_f64\017v_sub_co_ci_u32\014"
    "v_sub_co_u32\tv_sub_f16\tv_sub_f32\tv_sub_i16\tv_sub_i32\014v_sub_nc_i1"
    "6\014v_sub_nc_i32\014v_sub_nc_u16\014v_sub_nc_u32\014v_sub_nc_u64\tv_su"
    "b_u16\tv_sub_u32\015v_subb_co_u32\nv_subb_u32\020v_subbrev_co_u32\015v_"
    "subbrev_u32\022v_subrev_co_ci_u32\017v_subrev_co_u32\014v_subrev_f16\014"
    "v_subrev_f32\014v_subrev_i32\017v_subrev_nc_u32\014v_subrev_u16\014v_su"
    "brev_u32\nv_swap_b16\nv_swap_b32\015v_swaprel_b32\033v_swmmac_bf16_16x1"
    "6x32_bf16\033v_swmmac_bf16_16x16x64_bf16\036v_swmmac_bf16f32_16x16x64_b"
    "f16\036v_swmmac_f16_16x16x128_bf8_bf8\036v_swmmac_f16_16x16x128_bf8_fp8"
    "\036v_swmmac_f16_16x16x128_fp8_bf8\036v_swmmac_f16_16x16x128_fp8_fp8\031"
    "v_swmmac_f16_16x16x32_f16\031v_swmmac_f16_16x16x64_f16\036v_swmmac_f32_"
    "16x16x128_bf8_bf8\036v_swmmac_f32_16x16x128_bf8_fp8\036v_swmmac_f32_16x"
    "16x128_fp8_bf8\036v_swmmac_f32_16x16x128_fp8_fp8\032v_swmmac_f32_16x16x"
    "32_bf16\035v_swmmac_f32_16x16x32_bf8_bf8\035v_swmmac_f32_16x16x32_bf8_f"
    "p8\031v_swmmac_f32_16x16x32_f16\035v_swmmac_f32_16x16x32_fp8_bf8\035v_s"
    "wmmac_f32_16x16x32_fp8_fp8\032v_swmmac_f32_16x16x64_bf16\031v_swmmac_f3"
    "2_16x16x64_f16\032v_swmmac_i32_16x16x128_iu8\031v_swmmac_i32_16x16x32_i"
    "u4\031v_swmmac_i32_16x16x32_iu8\031v_swmmac_i32_16x16x64_iu4\013v_tanh_"
    "bf16\nv_tanh_f16\nv_tanh_f32\020v_trig_preop_f64\013v_trunc_f16\013v_tr"
    "unc_f32\013v_trunc_f64\031v_wmma_bf16_16x16x16_bf16\031v_wmma_bf16_16x1"
    "6x32_bf16\034v_wmma_bf16f32_16x16x32_bf16\034v_wmma_f16_16x16x128_bf8_b"
    "f8\034v_wmma_f16_16x16x128_bf8_fp8\034v_wmma_f16_16x16x128_fp8_bf8\034v"
    "_wmma_f16_16x16x128_fp8_fp8\027v_wmma_f16_16x16x16_f16\027v_wmma_f16_16"
    "x16x32_f16\033v_wmma_f16_16x16x64_bf8_bf8\033v_wmma_f16_16x16x64_bf8_fp"
    "8\033v_wmma_f16_16x16x64_fp8_bf8\033v_wmma_f16_16x16x64_fp8_fp8\034v_wm"
    "ma_f32_16x16x128_bf8_bf8\034v_wmma_f32_16x16x128_bf8_fp8\033v_wmma_f32_"
    "16x16x128_f8f6f4\034v_wmma_f32_16x16x128_fp8_bf8\034v_wmma_f32_16x16x12"
    "8_fp8_fp8\030v_wmma_f32_16x16x16_bf16\033v_wmma_f32_16x16x16_bf8_bf8\033"
    "v_wmma_f32_16x16x16_bf8_fp8\027v_wmma_f32_16x16x16_f16\033v_wmma_f32_16"
    "x16x16_fp8_bf8\033v_wmma_f32_16x16x16_fp8_fp8\030v_wmma_f32_16x16x32_bf"
    "16\027v_wmma_f32_16x16x32_f16\026v_wmma_f32_16x16x4_f32\033v_wmma_f32_1"
    "6x16x64_bf8_bf8\033v_wmma_f32_16x16x64_bf8_fp8\033v_wmma_f32_16x16x64_f"
    "p8_bf8\033v_wmma_f32_16x16x64_fp8_fp8\027v_wmma_f32_32x16x128_f4\027v_w"
    "mma_i32_16x16x16_iu4\027v_wmma_i32_16x16x16_iu8\027v_wmma_i32_16x16x32_"
    "iu4\027v_wmma_i32_16x16x64_iu8\034v_wmma_ld_scale16_paired_b64\032v_wmm"
    "a_ld_scale_paired_b32#v_wmma_scale16_f32_16x16x128_f8f6f4\037v_wmma_sca"
    "le16_f32_32x16x128_f4!v_wmma_scale_f32_16x16x128_f8f6f4\035v_wmma_scale"
    "_f32_32x16x128_f4\017v_writelane_b32\tv_xad_u32\nv_xnor_b32\nv_xor3_b32"
    "\tv_xor_b16\tv_xor_b32";

// Feature bitsets.
enum : uint16_t {
  AMFBS_None,
  AMFBS_HasDPP,
  AMFBS_HasGFX950Insts,
  AMFBS_HasMAIInsts,
  AMFBS_HasSDWA8,
  AMFBS_HasSDWA9,
  AMFBS_HasUnpackedD16VMem,
  AMFBS_HasVOP3PInsts,
  AMFBS_isGFX10Only,
  AMFBS_isGFX10Plus,
  AMFBS_isGFX11Only,
  AMFBS_isGFX1250Plus,
  AMFBS_isGFX125xOnly,
  AMFBS_isGFX12Not12_50,
  AMFBS_isGFX12Only,
  AMFBS_isGFX12Plus,
  AMFBS_isGFX6,
  AMFBS_isGFX6GFX7,
  AMFBS_isGFX7Only,
  AMFBS_isGFX8GFX9,
  AMFBS_isGFX8GFX9NotGFX90A,
  AMFBS_isGFX8Only,
  AMFBS_isGFX90AOnly,
  AMFBS_isGFX90APlus,
  AMFBS_isGFX940Plus,
  AMFBS_isGFX9Only,
  AMFBS_Has1024AddressableVGPRs_isGFX12Only,
  AMFBS_Has16BitInsts_HasDPP,
  AMFBS_Has16BitInsts_HasSDWA8,
  AMFBS_Has16BitInsts_HasSDWA9,
  AMFBS_Has16BitInsts_isGFX10Only,
  AMFBS_Has16BitInsts_isGFX11Only,
  AMFBS_Has16BitInsts_isGFX12Only,
  AMFBS_Has16BitInsts_isGFX8GFX9,
  AMFBS_Has16BitInsts_isGFX8Only,
  AMFBS_Has16BitInsts_isGFX9Only,
  AMFBS_HasAddMinMaxInsts_isGFX125xOnly,
  AMFBS_HasAddNoCarryInsts_isGFX10Only,
  AMFBS_HasAddNoCarryInsts_isGFX11Only,
  AMFBS_HasAddNoCarryInsts_isGFX12Only,
  AMFBS_HasAddNoCarryInsts_isGFX9Only,
  AMFBS_HasAddPC64Inst_isGFX12Only,
  AMFBS_HasAddSubU64Insts_isGFX125xOnly,
  AMFBS_HasAshrPkInsts_isGFX125xOnly,
  AMFBS_HasAshrPkInsts_isGFX8GFX9,
  AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only,
  AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A,
  AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940,
  AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly,
  AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus,
  AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only,
  AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A,
  AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX940,
  AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly,
  AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus,
  AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only,
  AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A,
  AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly,
  AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus,
  AMFBS_HasAtomicDsPkAdd16Insts_isGFX12Plus,
  AMFBS_HasAtomicDsPkAdd16Insts_isGFX8GFX9,
  AMFBS_HasAtomicDsPkAdd16Insts_isGFX90APlus,
  AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only,
  AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only,
  AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only,
  AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7,
  AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX10Only,
  AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly,
  AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX7Only,
  AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9,
  AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX940Plus,
  AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only,
  AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly,
  AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only,
  AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7,
  AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9,
  AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus,
  AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only,
  AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only,
  AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A,
  AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX940,
  AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly,
  AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus,
  AMFBS_HasAtomicFaddRtnInsts_isGFX11Only,
  AMFBS_HasAtomicFaddRtnInsts_isGFX12Only,
  AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A,
  AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940,
  AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly,
  AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus,
  AMFBS_HasAtomicFlatPkAdd16Insts_isGFX12Only,
  AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus,
  AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only,
  AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus,
  AMFBS_HasBF16ConversionInsts_isGFX125xOnly,
  AMFBS_HasBF16ConversionInsts_isGFX8GFX9,
  AMFBS_HasBF16PackedInsts_isGFX125xOnly,
  AMFBS_HasBF8ConversionScaleInsts_isGFX8GFX9,
  AMFBS_HasBitOp3Insts_isGFX125xOnly,
  AMFBS_HasBitOp3Insts_isGFX9Only,
  AMFBS_HasCubeInsts_isGFX10Only,
  AMFBS_HasCubeInsts_isGFX11Only,
  AMFBS_HasCubeInsts_isGFX12Only,
  AMFBS_HasCubeInsts_isGFX6GFX7,
  AMFBS_HasCubeInsts_isGFX8GFX9,
  AMFBS_HasCvtNormInsts_HasSDWA8,
  AMFBS_HasCvtPkF16F32Inst_isGFX125xOnly,
  AMFBS_HasCvtPkF16F32Inst_isGFX9Only,
  AMFBS_HasCvtPkNormVOP2Insts_isGFX10Only,
  AMFBS_HasCvtPkNormVOP2Insts_isGFX11Only,
  AMFBS_HasCvtPkNormVOP2Insts_isGFX12Only,
  AMFBS_HasCvtPkNormVOP2Insts_isGFX6GFX7,
  AMFBS_HasCvtPkNormVOP2Insts_isGFX8GFX9,
  AMFBS_HasCvtPkNormVOP3Insts_isGFX11Only,
  AMFBS_HasCvtPkNormVOP3Insts_isGFX12Only,
  AMFBS_HasD16LoadStore_isGFX10Only,
  AMFBS_HasD16LoadStore_isGFX11Only,
  AMFBS_HasD16LoadStore_isGFX12Only,
  AMFBS_HasD16LoadStore_isGFX12Plus,
  AMFBS_HasD16LoadStore_isGFX8GFX9,
  AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A,
  AMFBS_HasD16LoadStore_isGFX90APlus,
  AMFBS_HasDLInsts_HasDPP,
  AMFBS_HasDLInsts_HasSDWA8,
  AMFBS_HasDLInsts_HasSDWA9,
  AMFBS_HasDLInsts_isGFX10Only,
  AMFBS_HasDLInsts_isGFX11Only,
  AMFBS_HasDLInsts_isGFX12Only,
  AMFBS_HasDLInsts_isGFX8GFX9,
  AMFBS_HasDPALU_DPP_isGFX125xOnly,
  AMFBS_HasDPALU_DPP_isGFX12Only,
  AMFBS_HasDPP16_isGFX11Only,
  AMFBS_HasDPP16_isGFX12Only,
  AMFBS_HasDSAddTid_isGFX10Only,
  AMFBS_HasDSAddTid_isGFX11Only,
  AMFBS_HasDSAddTid_isGFX12Plus,
  AMFBS_HasDSAddTid_isGFX8GFX9,
  AMFBS_HasDot10Insts_HasVOP3PInsts,
  AMFBS_HasDot10Insts_isGFX10Only,
  AMFBS_HasDot10Insts_isGFX11Only,
  AMFBS_HasDot10Insts_isGFX12Only,
  AMFBS_HasDot11Insts_isGFX12Only,
  AMFBS_HasDot12Insts_HasVOP3PInsts,
  AMFBS_HasDot12Insts_isGFX11Only,
  AMFBS_HasDot12Insts_isGFX12Only,
  AMFBS_HasDot13Insts_isGFX8GFX9,
  AMFBS_HasDot1Insts_HasVOP3PInsts,
  AMFBS_HasDot1Insts_isGFX10Only,
  AMFBS_HasDot2Insts_HasVOP3PInsts,
  AMFBS_HasDot2Insts_isGFX10Only,
  AMFBS_HasDot3Insts_isGFX10Only,
  AMFBS_HasDot3Insts_isGFX8GFX9,
  AMFBS_HasDot4Insts_isGFX8GFX9,
  AMFBS_HasDot5Insts_isGFX10Only,
  AMFBS_HasDot5Insts_isGFX11Only,
  AMFBS_HasDot5Insts_isGFX8GFX9,
  AMFBS_HasDot6Insts_isGFX10Only,
  AMFBS_HasDot6Insts_isGFX8GFX9,
  AMFBS_HasDot7Insts_HasVOP3PInsts,
  AMFBS_HasDot7Insts_isGFX10Only,
  AMFBS_HasDot7Insts_isGFX11Only,
  AMFBS_HasDot7Insts_isGFX12Only,
  AMFBS_HasDot8Insts_isGFX11Only,
  AMFBS_HasDot8Insts_isGFX12Only,
  AMFBS_HasDot9Insts_isGFX11Only,
  AMFBS_HasDot9Insts_isGFX12Only,
  AMFBS_HasDsSrc2Insts_isGFX10Only,
  AMFBS_HasDsSrc2Insts_isGFX6GFX7,
  AMFBS_HasDsSrc2Insts_isGFX8GFX9,
  AMFBS_HasExportInsts_isGFX12Only,
  AMFBS_HasF16BF16ToFP6BF6ConversionScaleInsts_isGFX9Only,
  AMFBS_HasF32ToF16BF16ConversionSRInsts_isGFX8GFX9,
  AMFBS_HasFP4ConversionScaleInsts_isGFX8GFX9,
  AMFBS_HasFP6BF6ConversionScaleInsts_isGFX9Only,
  AMFBS_HasFP8ConversionInsts_HasDPALU_DPP,
  AMFBS_HasFP8ConversionInsts_HasDPP,
  AMFBS_HasFP8ConversionInsts_HasSDWA9,
  AMFBS_HasFP8ConversionInsts_isGFX125xOnly,
  AMFBS_HasFP8ConversionInsts_isGFX8GFX9,
  AMFBS_HasFP8ConversionScaleInsts_isGFX8GFX9,
  AMFBS_HasFP8Insts_isGFX940Plus,
  AMFBS_HasFlatAddressSpace_isGFX10Only,
  AMFBS_HasFlatAddressSpace_isGFX11Only,
  AMFBS_HasFlatAddressSpace_isGFX12Only,
  AMFBS_HasFlatAddressSpace_isGFX7Only,
  AMFBS_HasFlatAddressSpace_isGFX8GFX9,
  AMFBS_HasFlatAtomicFaddF32Inst_isGFX11Only,
  AMFBS_HasFlatAtomicFaddF32Inst_isGFX12Only,
  AMFBS_HasFlatAtomicFaddF32Inst_isGFX940Plus,
  AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly,
  AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only,
  AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9,
  AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus,
  AMFBS_HasFlatGVSMode_isGFX125xOnly,
  AMFBS_HasFlatGVSMode_isGFX12Only,
  AMFBS_HasFlatGlobalInsts_isGFX10Only,
  AMFBS_HasFlatGlobalInsts_isGFX11Only,
  AMFBS_HasFlatGlobalInsts_isGFX12Only,
  AMFBS_HasFlatGlobalInsts_isGFX8GFX9,
  AMFBS_HasFlatGlobalInsts_isGFX940Plus,
  AMFBS_HasFlatScratchInsts_isGFX10Only,
  AMFBS_HasFlatScratchInsts_isGFX11Only,
  AMFBS_HasFlatScratchInsts_isGFX12Only,
  AMFBS_HasFlatScratchInsts_isGFX8GFX9,
  AMFBS_HasFlatScratchInsts_isGFX940Plus,
  AMFBS_HasFlatScratchSTMode_isGFX10Only,
  AMFBS_HasFlatScratchSTMode_isGFX11Only,
  AMFBS_HasFlatScratchSTMode_isGFX12Only,
  AMFBS_HasFlatScratchSTMode_isGFX940Plus,
  AMFBS_HasFlatScratchSVSMode_isGFX11Only,
  AMFBS_HasFlatScratchSVSMode_isGFX12Only,
  AMFBS_HasFlatScratchSVSMode_isGFX940Plus,
  AMFBS_HasFmaLegacy32_isGFX10Only,
  AMFBS_HasFmaLegacy32_isGFX11Only,
  AMFBS_HasFmaLegacy32_isGFX12Only,
  AMFBS_HasFmaMixBF16Insts_isGFX125xOnly,
  AMFBS_HasFmaMixInsts_HasVOP3PInsts,
  AMFBS_HasFmaMixInsts_isGFX10Only,
  AMFBS_HasFmaMixInsts_isGFX11Only,
  AMFBS_HasFmaMixInsts_isGFX12Only,
  AMFBS_HasFmaakFmamkF32Insts_isGFX10Only,
  AMFBS_HasFmaakFmamkF32Insts_isGFX11Only,
  AMFBS_HasFmaakFmamkF32Insts_isGFX12Only,
  AMFBS_HasFmaakFmamkF32Insts_isGFX8GFX9,
  AMFBS_HasFmaakFmamkF64Insts_isGFX125xOnly,
  AMFBS_HasFmacF64Inst_isGFX12Only,
  AMFBS_HasFmacLegacy32_isGFX10Only,
  AMFBS_HasFmacLegacy32_isGFX11Only,
  AMFBS_HasFormattedMUBUFInsts_isGFX10Only,
  AMFBS_HasFormattedMUBUFInsts_isGFX11Only,
  AMFBS_HasFormattedMUBUFInsts_isGFX12Only,
  AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7,
  AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A,
  AMFBS_HasFormattedMUBUFInsts_isGFX90APlus,
  AMFBS_HasGFX10_BEncoding_isGFX10Only,
  AMFBS_HasGFX10_BEncoding_isGFX11Only,
  AMFBS_HasGFX10_BEncoding_isGFX12Only,
  AMFBS_HasGFX950Insts_HasVOP3PInsts,
  AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A,
  AMFBS_HasGFX950Insts_isGFX90APlus,
  AMFBS_HasGFX950Insts_isGFX940Plus,
  AMFBS_HasGFX950Insts_isGFX9Only,
  AMFBS_HasGetWaveIdInst_isGFX10Only,
  AMFBS_HasIEEEMinimumMaximumInsts_isGFX11Only,
  AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only,
  AMFBS_HasImageInsts_isGFX10Only,
  AMFBS_HasImageInsts_isGFX11Only,
  AMFBS_HasImageInsts_isGFX12Plus,
  AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A,
  AMFBS_HasImageInsts_isGFX90APlus,
  AMFBS_HasLDSFPAtomicAddF32_isGFX10Only,
  AMFBS_HasLDSFPAtomicAddF32_isGFX11Only,
  AMFBS_HasLDSFPAtomicAddF32_isGFX12Plus,
  AMFBS_HasLDSFPAtomicAddF32_isGFX8GFX9,
  AMFBS_HasLDSFPAtomicAddF32_isGFX90APlus,
  AMFBS_HasLdsAtomicAddF64_isGFX12Plus,
  AMFBS_HasLdsAtomicAddF64_isGFX8GFX9,
  AMFBS_HasLdsAtomicAddF64_isGFX90APlus,
  AMFBS_HasLdsBarrierArriveAtomic_isGFX1250Plus,
  AMFBS_HasLerpInst_isGFX10Only,
  AMFBS_HasLerpInst_isGFX11Only,
  AMFBS_HasLerpInst_isGFX12Only,
  AMFBS_HasLerpInst_isGFX6GFX7,
  AMFBS_HasLerpInst_isGFX8GFX9,
  AMFBS_HasLshlAddU64Inst_isGFX125xOnly,
  AMFBS_HasLshlAddU64Inst_isGFX8GFX9,
  AMFBS_HasMAIInsts_isGFX940Plus,
  AMFBS_HasMTBUFInsts_HasUnpackedD16VMem,
  AMFBS_HasMTBUFInsts_isGFX10Only,
  AMFBS_HasMTBUFInsts_isGFX11Only,
  AMFBS_HasMTBUFInsts_isGFX12Only,
  AMFBS_HasMTBUFInsts_isGFX6GFX7,
  AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A,
  AMFBS_HasMTBUFInsts_isGFX90APlus,
  AMFBS_HasMadMacF32Insts_HasDPP,
  AMFBS_HasMadMacF32Insts_isGFX10Only,
  AMFBS_HasMadMacF32Insts_isGFX6GFX7,
  AMFBS_HasMadMacF32Insts_isGFX8GFX9,
  AMFBS_HasMadMixInsts_HasVOP3PInsts,
  AMFBS_HasMadU32Inst_isGFX125xOnly,
  AMFBS_HasMcastLoadInsts_isGFX125xOnly,
  AMFBS_HasMin3Max3PKF16_isGFX125xOnly,
  AMFBS_HasMinimum3Maximum3F16_isGFX12Only,
  AMFBS_HasMinimum3Maximum3F32_isGFX12Only,
  AMFBS_HasMinimum3Maximum3F32_isGFX8GFX9,
  AMFBS_HasMinimum3Maximum3PKF16_HasVOP3PInsts,
  AMFBS_HasMinimum3Maximum3PKF16_isGFX125xOnly,
  AMFBS_HasMovrel_isGFX10Only,
  AMFBS_HasMovrel_isGFX11Only,
  AMFBS_HasMovrel_isGFX12Only,
  AMFBS_HasMovrel_isGFX6GFX7,
  AMFBS_HasMovrel_isGFX8GFX9,
  AMFBS_HasNoSdstCMPX_isGFX10Only,
  AMFBS_HasNoSdstCMPX_isGFX11Only,
  AMFBS_HasNoSdstCMPX_isGFX12Only,
  AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A,
  AMFBS_HasPackedD16VMem_isGFX90APlus,
  AMFBS_HasPackedFP32Ops_HasVOP3PInsts,
  AMFBS_HasPackedFP32Ops_isGFX12Only,
  AMFBS_HasPermlane16Swap_isGFX125xOnly,
  AMFBS_HasPermlane16Swap_isGFX9Only,
  AMFBS_HasPermlane32Swap_isGFX9Only,
  AMFBS_HasPkAddMinMaxInsts_isGFX125xOnly,
  AMFBS_HasPkFmacF16Inst_isGFX10Only,
  AMFBS_HasPkFmacF16Inst_isGFX11Only,
  AMFBS_HasPkFmacF16Inst_isGFX12Only,
  AMFBS_HasPkFmacF16Inst_isGFX8GFX9,
  AMFBS_HasPkFmacF16Inst_isGFX9Only,
  AMFBS_HasPkMinMax3Insts_isGFX125xOnly,
  AMFBS_HasPkMovB32_HasVOP3PInsts,
  AMFBS_HasPrngInst_HasDPP,
  AMFBS_HasPrngInst_HasSDWA9,
  AMFBS_HasPrngInst_isGFX125xOnly,
  AMFBS_HasPrngInst_isGFX8GFX9,
  AMFBS_HasPseudoScalarTrans_isGFX12Only,
  AMFBS_HasQsadInsts_isGFX10Only,
  AMFBS_HasQsadInsts_isGFX11Only,
  AMFBS_HasQsadInsts_isGFX12Only,
  AMFBS_HasQsadInsts_isGFX7Only,
  AMFBS_HasQsadInsts_isGFX8GFX9,
  AMFBS_HasSALUFloatInsts_isGFX11Only,
  AMFBS_HasSALUFloatInsts_isGFX12Only,
  AMFBS_HasSGetShaderCyclesInst_isGFX12Only,
  AMFBS_HasSMemRealTime_isGFX10Only,
  AMFBS_HasSMemRealTime_isGFX8GFX9,
  AMFBS_HasSMemTimeInst_isGFX10Only,
  AMFBS_HasSMemTimeInst_isGFX6GFX7,
  AMFBS_HasSMemTimeInst_isGFX8GFX9,
  AMFBS_HasSWakeupBarrier_isGFX12Only,
  AMFBS_HasSadInsts_isGFX10Only,
  AMFBS_HasSadInsts_isGFX11Only,
  AMFBS_HasSadInsts_isGFX12Only,
  AMFBS_HasSadInsts_isGFX6GFX7,
  AMFBS_HasSadInsts_isGFX8GFX9,
  AMFBS_HasScalarAtomics_isGFX10Only,
  AMFBS_HasScalarAtomics_isGFX8GFX9,
  AMFBS_HasScalarAtomics_isGFX9Only,
  AMFBS_HasScalarFlatScratchInsts_isGFX10Only,
  AMFBS_HasScalarFlatScratchInsts_isGFX8GFX9,
  AMFBS_HasScalarFlatScratchInsts_isGFX9Only,
  AMFBS_HasScalarStores_isGFX10Only,
  AMFBS_HasScalarStores_isGFX8GFX9,
  AMFBS_HasScalarStores_isGFX9Only,
  AMFBS_HasSetPrioIncWgInst_isGFX12Only,
  AMFBS_HasTanhInsts_isGFX125xOnly,
  AMFBS_HasTensorCvtLutInsts_isGFX125xOnly,
  AMFBS_HasVGPRIndexMode_isGFX8GFX9,
  AMFBS_HasVINTERPEncoding_isGFX11Only,
  AMFBS_HasVINTERPEncoding_isGFX12Only,
  AMFBS_HasVmemPrefInsts_isGFX125xOnly,
  AMFBS_HasWaitXcnt_isGFX12Only,
  AMFBS_HasXF32Insts_isGFX940Plus,
  AMFBS_NotHasTrue16BitInsts_HasSDWA9,
  AMFBS_NotHasTrue16BitInsts_isGFX10Only,
  AMFBS_NotHasTrue16BitInsts_isGFX6GFX7,
  AMFBS_NotHasTrue16BitInsts_isGFX8GFX9,
  AMFBS_UseFakeTrue16Insts_isGFX11Only,
  AMFBS_UseFakeTrue16Insts_isGFX12Only,
  AMFBS_UseRealTrue16Insts_isGFX11Only,
  AMFBS_UseRealTrue16Insts_isGFX12Only,
  AMFBS_isGCN3ExcludingGFX90A_HasDPP,
  AMFBS_isGCN3ExcludingGFX90A_HasSDWA8,
  AMFBS_isGCN3ExcludingGFX90A_HasSDWA9,
  AMFBS_isGCN3ExcludingGFX90A_isGFX8GFX9,
  AMFBS_isGFX10Before1030_isGFX10Only,
  AMFBS_isGFX10GFX11_isGFX10Only,
  AMFBS_isGFX10GFX11_isGFX11Only,
  AMFBS_isGFX10Only_isWave32,
  AMFBS_isGFX10Only_isWave64,
  AMFBS_isGFX10Plus_isGFX10Only,
  AMFBS_isGFX10Plus_isGFX11Only,
  AMFBS_isGFX10Plus_isGFX12Only,
  AMFBS_isGFX11Only_UseFakeTrue16Insts,
  AMFBS_isGFX11Only_UseRealTrue16Insts,
  AMFBS_isGFX11Only_isWave32,
  AMFBS_isGFX11Only_isWave64,
  AMFBS_isGFX11Plus_isGFX11Only,
  AMFBS_isGFX11Plus_isGFX12Only,
  AMFBS_isGFX1250Plus_isGFX125xOnly,
  AMFBS_isGFX1250Plus_isGFX12Only,
  AMFBS_isGFX125xOnly_UseRealTrue16Insts,
  AMFBS_isGFX125xOnly_isWave32,
  AMFBS_isGFX12Not12_50_isWave32,
  AMFBS_isGFX12Only_UseFakeTrue16Insts,
  AMFBS_isGFX12Only_UseRealTrue16Insts,
  AMFBS_isGFX12Only_isWave32,
  AMFBS_isGFX12Only_isWave64,
  AMFBS_isGFX12Plus_isGFX12Only,
  AMFBS_isGFX12Plus_isWave32,
  AMFBS_isGFX12Plus_isWave64,
  AMFBS_isGFX12PlusNot12_50_isGFX12Only,
  AMFBS_isGFX12PlusNot12_50_isGFX12Plus,
  AMFBS_isGFX6GFX7_NotHasTrue16BitInsts,
  AMFBS_isGFX6GFX7_isWave32,
  AMFBS_isGFX6GFX7_isWave64,
  AMFBS_isGFX6GFX7GFX10_isGFX10Only,
  AMFBS_isGFX6GFX7GFX10_isGFX6GFX7,
  AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only,
  AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only,
  AMFBS_isGFX6GFX7GFX10Plus_isGFX12Only,
  AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7,
  AMFBS_isGFX6GFX7GFX8GFX9_isGFX6GFX7,
  AMFBS_isGFX6GFX7GFX8GFX9_isGFX8GFX9,
  AMFBS_isGFX7GFX10_isGFX10Only,
  AMFBS_isGFX7GFX10_isGFX7Only,
  AMFBS_isGFX7GFX10GFX11_isGFX10Only,
  AMFBS_isGFX7GFX10GFX11_isGFX11Only,
  AMFBS_isGFX7GFX10GFX11_isGFX12Only,
  AMFBS_isGFX7GFX10GFX11_isGFX7Only,
  AMFBS_isGFX7GFX8GFX9_HasSDWA8,
  AMFBS_isGFX7GFX8GFX9_HasSDWA9,
  AMFBS_isGFX7GFX8GFX9_isGFX7Only,
  AMFBS_isGFX7GFX8GFX9_isGFX8GFX9,
  AMFBS_isGFX7Plus_isGFX10Only,
  AMFBS_isGFX7Plus_isGFX11Only,
  AMFBS_isGFX7Plus_isGFX12Only,
  AMFBS_isGFX7Plus_isGFX12Plus,
  AMFBS_isGFX7Plus_isGFX6GFX7,
  AMFBS_isGFX7Plus_isGFX7Only,
  AMFBS_isGFX7Plus_isGFX8GFX9,
  AMFBS_isGFX7Plus_isGFX90APlus,
  AMFBS_isGFX8GFX9_HasDPP,
  AMFBS_isGFX8GFX9_HasSDWA8,
  AMFBS_isGFX8GFX9_HasSDWA9,
  AMFBS_isGFX8GFX9_isWave32,
  AMFBS_isGFX8GFX9_isWave64,
  AMFBS_isGFX8GFX9GFX10GFX11_isGFX10Only,
  AMFBS_isGFX8GFX9GFX10GFX11_isGFX11Only,
  AMFBS_isGFX8GFX9GFX10GFX11_isGFX8GFX9,
  AMFBS_isGFX8GFX9NotGFX90A_HasMAIInsts,
  AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts,
  AMFBS_isGFX8GFX9NotGFX940_isGFX8GFX9NotGFX90A,
  AMFBS_isGFX8GFX9NotGFX940_isGFX90APlus,
  AMFBS_isGFX8Only_isGFX8GFX9,
  AMFBS_isGFX8Plus_isGFX10Only,
  AMFBS_isGFX8Plus_isGFX11Only,
  AMFBS_isGFX8Plus_isGFX125xOnly,
  AMFBS_isGFX8Plus_isGFX12Not12_50,
  AMFBS_isGFX8Plus_isGFX12Only,
  AMFBS_isGFX8Plus_isGFX12Plus,
  AMFBS_isGFX8Plus_isGFX6GFX7,
  AMFBS_isGFX8Plus_isGFX8GFX9,
  AMFBS_isGFX8Plus_isGFX90APlus,
  AMFBS_isGFX8Plus_isGFX9Only,
  AMFBS_isGFX90AOnly_isGFX90APlus,
  AMFBS_isGFX90APlus_HasGFX950Insts,
  AMFBS_isGFX90APlus_isGFX8GFX9,
  AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A,
  AMFBS_isGFX90APlus_isGFX90AOnly,
  AMFBS_isGFX90APlus_isGFX940Plus,
  AMFBS_isGFX940orGFX1250_isGFX125xOnly,
  AMFBS_isGFX940orGFX1250_isGFX940Plus,
  AMFBS_isGFX9GFX10GFX11_isGFX10Only,
  AMFBS_isGFX9GFX10GFX11_isGFX11Only,
  AMFBS_isGFX9GFX10GFX11_isGFX8GFX9,
  AMFBS_isGFX9Only_HasDPP,
  AMFBS_isGFX9Only_HasFmacF64Inst,
  AMFBS_isGFX9Only_HasSDWA9,
  AMFBS_isGFX9Only_isGFX8GFX9,
  AMFBS_isGFX9Only_isWave32,
  AMFBS_isGFX9Only_isWave64,
  AMFBS_isGFX9Plus_HasSDWA8,
  AMFBS_isGFX9Plus_isGFX10Only,
  AMFBS_isGFX9Plus_isGFX11Only,
  AMFBS_isGFX9Plus_isGFX125xOnly,
  AMFBS_isGFX9Plus_isGFX12Only,
  AMFBS_isGFX9Plus_isGFX8GFX9,
  AMFBS_isNotGFX1250Plus_isGFX10Only,
  AMFBS_isNotGFX1250Plus_isGFX11Only,
  AMFBS_isNotGFX1250Plus_isGFX12Only,
  AMFBS_isNotGFX1250Plus_isGFX6GFX7,
  AMFBS_isNotGFX1250Plus_isGFX8GFX9,
  AMFBS_isNotGFX12Plus_isGFX10Only,
  AMFBS_isNotGFX12Plus_isGFX11Only,
  AMFBS_isNotGFX12Plus_isGFX6GFX7,
  AMFBS_isNotGFX12Plus_isGFX8GFX9,
  AMFBS_isNotGFX90APlus_isGFX10Only,
  AMFBS_isNotGFX90APlus_isGFX11Only,
  AMFBS_isNotGFX90APlus_isGFX6GFX7,
  AMFBS_isNotGFX90APlus_isGFX8GFX9,
  AMFBS_isNotGFX940Plus_isGFX6GFX7,
  AMFBS_isNotGFX940Plus_isGFX7Only,
  AMFBS_isNotGFX940Plus_isGFX8GFX9,
  AMFBS_Has16BitInsts_HasDPP_NotHasTrue16BitInsts,
  AMFBS_Has16BitInsts_HasNoSdstCMPX_isGFX10Only,
  AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts,
  AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts,
  AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts,
  AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts,
  AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts,
  AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts,
  AMFBS_HasBF16ConversionInsts_HasGFX950Insts_HasDPP,
  AMFBS_HasBF16ConversionInsts_HasGFX950Insts_HasSDWA9,
  AMFBS_HasBF16ConversionInsts_HasGFX950Insts_isGFX8GFX9,
  AMFBS_HasBF16ConversionInsts_isGFX1250Plus_isGFX125xOnly,
  AMFBS_HasBitOp3Insts_isGFX11Plus_isGFX125xOnly,
  AMFBS_HasBitOp3Insts_isGFX1250Plus_isGFX125xOnly,
  AMFBS_HasBitOp3Insts_isGFX940Plus_isGFX9Only,
  AMFBS_HasCvtPkNormVOP3Insts_isGFX10Only_NotHasTrue16BitInsts,
  AMFBS_HasCvtPkNormVOP3Insts_isGFX11Only_UseRealTrue16Insts,
  AMFBS_HasCvtPkNormVOP3Insts_isGFX12Only_UseRealTrue16Insts,
  AMFBS_HasCvtPkNormVOP3Insts_isGFX8GFX9_NotHasTrue16BitInsts,
  AMFBS_HasDPALU_DPP_HasAddSubU64Insts_isGFX125xOnly,
  AMFBS_HasDPALU_DPP_HasFmacF64Inst_isGFX12Only,
  AMFBS_HasDPALU_DPP_HasIEEEMinimumMaximumInsts_isGFX11Only,
  AMFBS_HasDPALU_DPP_HasIEEEMinimumMaximumInsts_isGFX12Only,
  AMFBS_HasDPALU_DPP_HasLshlAddU64Inst_isGFX125xOnly,
  AMFBS_HasDPALU_DPP_HasMadU32Inst_isGFX125xOnly,
  AMFBS_HasDPALU_DPP_isGFX1250Plus_isGFX125xOnly,
  AMFBS_HasDPALU_DPP_isGFX12Plus_isGFX12Only,
  AMFBS_HasDPALU_DPP_isGFX7Plus_isGFX12Only,
  AMFBS_HasDPALU_DPP_isGFX8Plus_isGFX125xOnly,
  AMFBS_HasDPALU_DPP_isGFX940orGFX1250_isGFX125xOnly,
  AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts,
  AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts,
  AMFBS_HasDPP16_isGFX11Only_isWave32,
  AMFBS_HasDPP16_isGFX11Only_isWave64,
  AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts,
  AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts,
  AMFBS_HasDPP16_isGFX12Only_isWave32,
  AMFBS_HasDPP16_isGFX12Only_isWave64,
  AMFBS_HasDot10Insts_isGFX11Plus_isGFX11Only,
  AMFBS_HasDot10Insts_isGFX11Plus_isGFX12Only,
  AMFBS_HasDot11Insts_isGFX11Plus_isGFX12Only,
  AMFBS_HasDot13Insts_isGFX9Only_HasDPP,
  AMFBS_HasDot3Insts_isGFX9Only_HasDPP,
  AMFBS_HasDot4Insts_isGFX9Only_HasDPP,
  AMFBS_HasDot5Insts_isGFX9Only_HasDPP,
  AMFBS_HasDot6Insts_isGFX9Only_HasDPP,
  AMFBS_HasDot9Insts_isGFX11Only_UseFakeTrue16Insts,
  AMFBS_HasDot9Insts_isGFX11Only_UseRealTrue16Insts,
  AMFBS_HasDot9Insts_isGFX12Only_UseFakeTrue16Insts,
  AMFBS_HasDot9Insts_isGFX12Only_UseRealTrue16Insts,
  AMFBS_HasDsSrc2Insts_HasLDSFPAtomicAddF32_isGFX10Only,
  AMFBS_HasDsSrc2Insts_HasLDSFPAtomicAddF32_isGFX8GFX9,
  AMFBS_HasExportInsts_isGFX11Plus_isGFX11Only,
  AMFBS_HasExportInsts_isGFX11Plus_isGFX12Only,
  AMFBS_HasExportInsts_isGFX12Plus_isGFX12Only,
  AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX11Only,
  AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX12Only,
  AMFBS_HasFP8ConversionInsts_isGFX12PlusNot12_50_isGFX11Only,
  AMFBS_HasFP8ConversionInsts_isGFX12PlusNot12_50_isGFX12Not12_50,
  AMFBS_HasFP8ConversionInsts_isGFX940Plus_isGFX8GFX9,
  AMFBS_HasFP8ConversionInsts_isGFX9Plus_isGFX11Only,
  AMFBS_HasFP8ConversionInsts_isGFX9Plus_isGFX12Only,
  AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly,
  AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only,
  AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only,
  AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only,
  AMFBS_HasFlatGVSMode_HasFlatAtomicFaddF32Inst_isGFX12Only,
  AMFBS_HasFlatGVSMode_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly,
  AMFBS_HasFlatGVSMode_HasVmemPrefInsts_isGFX125xOnly,
  AMFBS_HasFlatGVSMode_isGFX12Plus_isGFX12Only,
  AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only,
  AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only,
  AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only,
  AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only,
  AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A,
  AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus,
  AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX10Only,
  AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX11Only,
  AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX12Only,
  AMFBS_HasGFX950Insts_isGFX8GFX9_isWave64,
  AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only_UseRealTrue16Insts,
  AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only,
  AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only,
  AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus,
  AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A,
  AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus,
  AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only,
  AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only,
  AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus,
  AMFBS_HasImageInsts_isGFX11Plus_isGFX11Only,
  AMFBS_HasImageInsts_isGFX11Plus_isGFX12Plus,
  AMFBS_HasImageInsts_isGFX12Plus_isGFX12Only,
  AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7,
  AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A,
  AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only,
  AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only,
  AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only,
  AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A,
  AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus,
  AMFBS_HasMadMacF32Insts_isGFX6GFX7GFX10_isGFX10Only,
  AMFBS_HasMadMacF32Insts_isGFX6GFX7GFX10_isGFX6GFX7,
  AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32,
  AMFBS_HasMinimum3Maximum3F16_isGFX12Only_UseRealTrue16Insts,
  AMFBS_HasNoSdstCMPX_isGFX11Only_UseFakeTrue16Insts,
  AMFBS_HasNoSdstCMPX_isGFX11Only_UseRealTrue16Insts,
  AMFBS_HasNoSdstCMPX_isGFX12Only_UseFakeTrue16Insts,
  AMFBS_HasNoSdstCMPX_isGFX12Only_UseRealTrue16Insts,
  AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only,
  AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only,
  AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only,
  AMFBS_HasScalarStores_isGFX8Plus_isGFX10Only,
  AMFBS_HasScalarStores_isGFX8Plus_isGFX8GFX9,
  AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32,
  AMFBS_HasVINTERPEncoding_isGFX11Only_UseFakeTrue16Insts,
  AMFBS_HasVINTERPEncoding_isGFX11Only_UseRealTrue16Insts,
  AMFBS_HasVINTERPEncoding_isGFX12Only_UseFakeTrue16Insts,
  AMFBS_HasVINTERPEncoding_isGFX12Only_UseRealTrue16Insts,
  AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasSDWA9,
  AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only,
  AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9,
  AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly,
  AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX11Only,
  AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX12Only,
  AMFBS_UseFakeTrue16Insts_HasTanhInsts_isGFX125xOnly,
  AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only,
  AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only,
  AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly,
  AMFBS_UseFakeTrue16Insts_isGFX9Plus_isGFX11Only,
  AMFBS_UseFakeTrue16Insts_isGFX9Plus_isGFX12Only,
  AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly,
  AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX11Only,
  AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX12Only,
  AMFBS_UseRealTrue16Insts_HasTanhInsts_isGFX125xOnly,
  AMFBS_UseRealTrue16Insts_isGFX10Plus_isGFX11Only,
  AMFBS_UseRealTrue16Insts_isGFX10Plus_isGFX12Only,
  AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only,
  AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only,
  AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly,
  AMFBS_UseRealTrue16Insts_isGFX9Plus_isGFX11Only,
  AMFBS_UseRealTrue16Insts_isGFX9Plus_isGFX12Only,
  AMFBS_isGFX10Plus_isGFX10Only_NotHasTrue16BitInsts,
  AMFBS_isGFX10Plus_isGFX11Only_UseRealTrue16Insts,
  AMFBS_isGFX10Plus_isGFX12Only_UseRealTrue16Insts,
  AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts,
  AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts,
  AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts,
  AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts,
  AMFBS_isGFX11Plus_isGFX11Only_UseRealTrue16Insts,
  AMFBS_isGFX11Plus_isGFX12Only_UseRealTrue16Insts,
  AMFBS_isGFX1250Plus_isGFX125xOnly_UseRealTrue16Insts,
  AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32,
  AMFBS_isGFX1250Plus_isGFX12Only_isWave32,
  AMFBS_isGFX1250Plus_isGFX12Plus_isWave32,
  AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts,
  AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts,
  AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts,
  AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts,
  AMFBS_isGFX12Plus_isGFX125xOnly_isWave32,
  AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32,
  AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64,
  AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9,
  AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts_isGFX8GFX9,
  AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9,
  AMFBS_isGFX8Only_isGFX8GFX9_NotHasTrue16BitInsts,
  AMFBS_isGFX90APlus_HasFP8Insts_isGFX940Plus,
  AMFBS_isGFX90APlus_HasGFX950Insts_isGFX940Plus,
  AMFBS_isGFX90APlus_HasMAIInsts_isGFX940Plus,
  AMFBS_isGFX90APlus_HasXF32Insts_isGFX940Plus,
  AMFBS_isGFX9Only_HasFmacF64Inst_HasDPALU_DPP,
  AMFBS_isGFX9Plus_isGFX10Only_NotHasTrue16BitInsts,
  AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts,
  AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts,
  AMFBS_isGFX9Plus_isGFX8GFX9_NotHasTrue16BitInsts,
  AMFBS_isGFX9Plus_isGFX9Only_NotHasTrue16BitInsts,
  AMFBS_isNotGFX1250Plus_isGFX9Plus_isGFX11Only,
  AMFBS_isNotGFX1250Plus_isGFX9Plus_isGFX12Only,
  AMFBS_isNotGFX90APlus_Has16BitInsts_isGFX10Only,
  AMFBS_isNotGFX90APlus_Has16BitInsts_isGFX8GFX9,
  AMFBS_isNotGFX90APlus_Has16BitInsts_isGFX8Only,
  AMFBS_isNotGFX90APlus_Has16BitInsts_isGFX9Only,
  AMFBS_isNotGFX90APlus_isGFX8Plus_isGFX10Only,
  AMFBS_isNotGFX90APlus_isGFX8Plus_isGFX8GFX9,
  AMFBS_isNotGFX90APlus_isGFX9Plus_isGFX9Only,
  AMFBS_Has16BitInsts_HasNoSdstCMPX_isGFX10Only_NotHasTrue16BitInsts,
  AMFBS_HasBF16ConversionInsts_isGFX1250Plus_isGFX125xOnly_UseFakeTrue16Insts,
  AMFBS_HasBF16ConversionInsts_isGFX1250Plus_isGFX125xOnly_UseRealTrue16Insts,
  AMFBS_HasBitOp3Insts_isGFX1250Plus_isGFX125xOnly_UseFakeTrue16Insts,
  AMFBS_HasBitOp3Insts_isGFX1250Plus_isGFX125xOnly_UseRealTrue16Insts,
  AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts,
  AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts,
  AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts,
  AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts,
  AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts,
  AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts,
  AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts,
  AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts,
  AMFBS_HasFP8ConversionInsts_HasFP8E5M3Insts_isGFX12Plus_isGFX125xOnly,
  AMFBS_HasFP8ConversionInsts_HasFP8E5M3Insts_isGFX9Plus_isGFX125xOnly,
  AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX12Plus_isGFX11Only,
  AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX12Plus_isGFX12Not12_50,
  AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX9Plus_isGFX11Only,
  AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX9Plus_isGFX12Not12_50,
  AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX12Only_UseFakeTrue16Insts,
  AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX12Only_UseRealTrue16Insts,
  AMFBS_HasFP8ConversionInsts_isGFX9Plus_isGFX11Only_UseRealTrue16Insts,
  AMFBS_HasFP8ConversionInsts_isGFX9Plus_isGFX12Only_UseRealTrue16Insts,
  AMFBS_HasFP8ConversionInsts_isGFX9Plus_isGFX8GFX9_NotHasTrue16BitInsts,
  AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only,
  AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only,
  AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus,
  AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A,
  AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only,
  AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only,
  AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus,
  AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A,
  AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A,
  AMFBS_HasTransposeLoadF4F6Insts_isGFX1250Plus_isGFX12Plus_isWave32,
  AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasCvtNormInsts_HasSDWA9,
  AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasCvtNormInsts_isGFX10Only,
  AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasCvtNormInsts_isGFX8GFX9,
  AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX9Plus_HasSDWA9,
  AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX9Plus_isGFX10Only,
  AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX9Plus_isGFX8GFX9,
  AMFBS_HasFP8ConversionInsts_HasFP8E5M3Insts_isGFX9Plus_isGFX125xOnly_UseRealTrue16Insts,
  AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX9Plus_isGFX11Only_UseRealTrue16Insts,
  AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX9Plus_isGFX12Not12_50_UseRealTrue16Insts,
  AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX9Plus_isGFX8GFX9_NotHasTrue16BitInsts,
};

static constexpr FeatureBitset FeatureBitsets[] = {
  {}, // AMFBS_None
  {Feature_HasDPPBit, },
  {Feature_HasGFX950InstsBit, },
  {Feature_HasMAIInstsBit, },
  {Feature_HasSDWA8Bit, },
  {Feature_HasSDWA9Bit, },
  {Feature_HasUnpackedD16VMemBit, },
  {Feature_HasVOP3PInstsBit, },
  {Feature_isGFX10OnlyBit, },
  {Feature_isGFX10PlusBit, },
  {Feature_isGFX11OnlyBit, },
  {Feature_isGFX1250PlusBit, },
  {Feature_isGFX125xOnlyBit, },
  {Feature_isGFX12Not12_50Bit, },
  {Feature_isGFX12OnlyBit, },
  {Feature_isGFX12PlusBit, },
  {Feature_isGFX6Bit, },
  {Feature_isGFX6GFX7Bit, },
  {Feature_isGFX7OnlyBit, },
  {Feature_isGFX8GFX9Bit, },
  {Feature_isGFX8GFX9NotGFX90ABit, },
  {Feature_isGFX8OnlyBit, },
  {Feature_isGFX90AOnlyBit, },
  {Feature_isGFX90APlusBit, },
  {Feature_isGFX940PlusBit, },
  {Feature_isGFX9OnlyBit, },
  {Feature_Has1024AddressableVGPRsBit, Feature_isGFX12OnlyBit, },
  {Feature_Has16BitInstsBit, Feature_HasDPPBit, },
  {Feature_Has16BitInstsBit, Feature_HasSDWA8Bit, },
  {Feature_Has16BitInstsBit, Feature_HasSDWA9Bit, },
  {Feature_Has16BitInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_Has16BitInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_Has16BitInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_Has16BitInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_Has16BitInstsBit, Feature_isGFX8OnlyBit, },
  {Feature_Has16BitInstsBit, Feature_isGFX9OnlyBit, },
  {Feature_HasAddMinMaxInstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasAddNoCarryInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasAddNoCarryInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasAddNoCarryInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasAddNoCarryInstsBit, Feature_isGFX9OnlyBit, },
  {Feature_HasAddPC64InstBit, Feature_isGFX12OnlyBit, },
  {Feature_HasAddSubU64InstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasAshrPkInstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasAshrPkInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasAtomicBufferGlobalPkAddF16InstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasAtomicBufferGlobalPkAddF16InstsBit, Feature_isGFX8GFX9NotGFX90ABit, },
  {Feature_HasAtomicBufferGlobalPkAddF16InstsBit, Feature_isGFX8GFX9NotGFX940Bit, },
  {Feature_HasAtomicBufferGlobalPkAddF16InstsBit, Feature_isGFX90AOnlyBit, },
  {Feature_HasAtomicBufferGlobalPkAddF16InstsBit, Feature_isGFX940PlusBit, },
  {Feature_HasAtomicBufferGlobalPkAddF16NoRtnInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasAtomicBufferGlobalPkAddF16NoRtnInstsBit, Feature_isGFX8GFX9NotGFX90ABit, },
  {Feature_HasAtomicBufferGlobalPkAddF16NoRtnInstsBit, Feature_isGFX8GFX9NotGFX940Bit, },
  {Feature_HasAtomicBufferGlobalPkAddF16NoRtnInstsBit, Feature_isGFX90AOnlyBit, },
  {Feature_HasAtomicBufferGlobalPkAddF16NoRtnInstsBit, Feature_isGFX940PlusBit, },
  {Feature_HasAtomicBufferPkAddBF16InstBit, Feature_isGFX12OnlyBit, },
  {Feature_HasAtomicBufferPkAddBF16InstBit, Feature_isGFX8GFX9NotGFX90ABit, },
  {Feature_HasAtomicBufferPkAddBF16InstBit, Feature_isGFX90AOnlyBit, },
  {Feature_HasAtomicBufferPkAddBF16InstBit, Feature_isGFX940PlusBit, },
  {Feature_HasAtomicDsPkAdd16InstsBit, Feature_isGFX12PlusBit, },
  {Feature_HasAtomicDsPkAdd16InstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasAtomicDsPkAdd16InstsBit, Feature_isGFX90APlusBit, },
  {Feature_HasAtomicFMinFMaxF32GlobalInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasAtomicFMinFMaxF32GlobalInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasAtomicFMinFMaxF32GlobalInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasAtomicFMinFMaxF32GlobalInstsBit, Feature_isGFX6GFX7Bit, },
  {Feature_HasAtomicFMinFMaxF64FlatInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasAtomicFMinFMaxF64FlatInstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasAtomicFMinFMaxF64FlatInstsBit, Feature_isGFX7OnlyBit, },
  {Feature_HasAtomicFMinFMaxF64FlatInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasAtomicFMinFMaxF64FlatInstsBit, Feature_isGFX940PlusBit, },
  {Feature_HasAtomicFMinFMaxF64GlobalInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasAtomicFMinFMaxF64GlobalInstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasAtomicFMinFMaxF64GlobalInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasAtomicFMinFMaxF64GlobalInstsBit, Feature_isGFX6GFX7Bit, },
  {Feature_HasAtomicFMinFMaxF64GlobalInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasAtomicFMinFMaxF64GlobalInstsBit, Feature_isGFX940PlusBit, },
  {Feature_HasAtomicFaddNoRtnInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasAtomicFaddNoRtnInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasAtomicFaddNoRtnInstsBit, Feature_isGFX8GFX9NotGFX90ABit, },
  {Feature_HasAtomicFaddNoRtnInstsBit, Feature_isGFX8GFX9NotGFX940Bit, },
  {Feature_HasAtomicFaddNoRtnInstsBit, Feature_isGFX90AOnlyBit, },
  {Feature_HasAtomicFaddNoRtnInstsBit, Feature_isGFX940PlusBit, },
  {Feature_HasAtomicFaddRtnInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasAtomicFaddRtnInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasAtomicFaddRtnInstsBit, Feature_isGFX8GFX9NotGFX90ABit, },
  {Feature_HasAtomicFaddRtnInstsBit, Feature_isGFX8GFX9NotGFX940Bit, },
  {Feature_HasAtomicFaddRtnInstsBit, Feature_isGFX90AOnlyBit, },
  {Feature_HasAtomicFaddRtnInstsBit, Feature_isGFX940PlusBit, },
  {Feature_HasAtomicFlatPkAdd16InstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasAtomicFlatPkAdd16InstsBit, Feature_isGFX940PlusBit, },
  {Feature_HasAtomicGlobalPkAddBF16InstBit, Feature_isGFX12OnlyBit, },
  {Feature_HasAtomicGlobalPkAddBF16InstBit, Feature_isGFX940PlusBit, },
  {Feature_HasBF16ConversionInstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasBF16ConversionInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasBF16PackedInstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasBF8ConversionScaleInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasBitOp3InstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasBitOp3InstsBit, Feature_isGFX9OnlyBit, },
  {Feature_HasCubeInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasCubeInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasCubeInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasCubeInstsBit, Feature_isGFX6GFX7Bit, },
  {Feature_HasCubeInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasCvtNormInstsBit, Feature_HasSDWA8Bit, },
  {Feature_HasCvtPkF16F32InstBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasCvtPkF16F32InstBit, Feature_isGFX9OnlyBit, },
  {Feature_HasCvtPkNormVOP2InstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasCvtPkNormVOP2InstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasCvtPkNormVOP2InstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasCvtPkNormVOP2InstsBit, Feature_isGFX6GFX7Bit, },
  {Feature_HasCvtPkNormVOP2InstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasCvtPkNormVOP3InstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasCvtPkNormVOP3InstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasD16LoadStoreBit, Feature_isGFX10OnlyBit, },
  {Feature_HasD16LoadStoreBit, Feature_isGFX11OnlyBit, },
  {Feature_HasD16LoadStoreBit, Feature_isGFX12OnlyBit, },
  {Feature_HasD16LoadStoreBit, Feature_isGFX12PlusBit, },
  {Feature_HasD16LoadStoreBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasD16LoadStoreBit, Feature_isGFX8GFX9NotGFX90ABit, },
  {Feature_HasD16LoadStoreBit, Feature_isGFX90APlusBit, },
  {Feature_HasDLInstsBit, Feature_HasDPPBit, },
  {Feature_HasDLInstsBit, Feature_HasSDWA8Bit, },
  {Feature_HasDLInstsBit, Feature_HasSDWA9Bit, },
  {Feature_HasDLInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasDLInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasDLInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasDLInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasDPALU_DPPBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasDPALU_DPPBit, Feature_isGFX12OnlyBit, },
  {Feature_HasDPP16Bit, Feature_isGFX11OnlyBit, },
  {Feature_HasDPP16Bit, Feature_isGFX12OnlyBit, },
  {Feature_HasDSAddTidBit, Feature_isGFX10OnlyBit, },
  {Feature_HasDSAddTidBit, Feature_isGFX11OnlyBit, },
  {Feature_HasDSAddTidBit, Feature_isGFX12PlusBit, },
  {Feature_HasDSAddTidBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasDot10InstsBit, Feature_HasVOP3PInstsBit, },
  {Feature_HasDot10InstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasDot10InstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasDot10InstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasDot11InstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasDot12InstsBit, Feature_HasVOP3PInstsBit, },
  {Feature_HasDot12InstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasDot12InstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasDot13InstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasDot1InstsBit, Feature_HasVOP3PInstsBit, },
  {Feature_HasDot1InstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasDot2InstsBit, Feature_HasVOP3PInstsBit, },
  {Feature_HasDot2InstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasDot3InstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasDot3InstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasDot4InstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasDot5InstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasDot5InstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasDot5InstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasDot6InstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasDot6InstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasDot7InstsBit, Feature_HasVOP3PInstsBit, },
  {Feature_HasDot7InstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasDot7InstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasDot7InstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasDot8InstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasDot8InstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasDot9InstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasDot9InstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasDsSrc2InstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasDsSrc2InstsBit, Feature_isGFX6GFX7Bit, },
  {Feature_HasDsSrc2InstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasExportInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasF16BF16ToFP6BF6ConversionScaleInstsBit, Feature_isGFX9OnlyBit, },
  {Feature_HasF32ToF16BF16ConversionSRInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasFP4ConversionScaleInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasFP6BF6ConversionScaleInstsBit, Feature_isGFX9OnlyBit, },
  {Feature_HasFP8ConversionInstsBit, Feature_HasDPALU_DPPBit, },
  {Feature_HasFP8ConversionInstsBit, Feature_HasDPPBit, },
  {Feature_HasFP8ConversionInstsBit, Feature_HasSDWA9Bit, },
  {Feature_HasFP8ConversionInstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasFP8ConversionInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasFP8ConversionScaleInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasFP8InstsBit, Feature_isGFX940PlusBit, },
  {Feature_HasFlatAddressSpaceBit, Feature_isGFX10OnlyBit, },
  {Feature_HasFlatAddressSpaceBit, Feature_isGFX11OnlyBit, },
  {Feature_HasFlatAddressSpaceBit, Feature_isGFX12OnlyBit, },
  {Feature_HasFlatAddressSpaceBit, Feature_isGFX7OnlyBit, },
  {Feature_HasFlatAddressSpaceBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasFlatAtomicFaddF32InstBit, Feature_isGFX11OnlyBit, },
  {Feature_HasFlatAtomicFaddF32InstBit, Feature_isGFX12OnlyBit, },
  {Feature_HasFlatAtomicFaddF32InstBit, Feature_isGFX940PlusBit, },
  {Feature_HasFlatBufferGlobalAtomicFaddF64InstBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasFlatBufferGlobalAtomicFaddF64InstBit, Feature_isGFX12OnlyBit, },
  {Feature_HasFlatBufferGlobalAtomicFaddF64InstBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasFlatBufferGlobalAtomicFaddF64InstBit, Feature_isGFX940PlusBit, },
  {Feature_HasFlatGVSModeBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasFlatGVSModeBit, Feature_isGFX12OnlyBit, },
  {Feature_HasFlatGlobalInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasFlatGlobalInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasFlatGlobalInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasFlatGlobalInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasFlatGlobalInstsBit, Feature_isGFX940PlusBit, },
  {Feature_HasFlatScratchInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasFlatScratchInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasFlatScratchInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasFlatScratchInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasFlatScratchInstsBit, Feature_isGFX940PlusBit, },
  {Feature_HasFlatScratchSTModeBit, Feature_isGFX10OnlyBit, },
  {Feature_HasFlatScratchSTModeBit, Feature_isGFX11OnlyBit, },
  {Feature_HasFlatScratchSTModeBit, Feature_isGFX12OnlyBit, },
  {Feature_HasFlatScratchSTModeBit, Feature_isGFX940PlusBit, },
  {Feature_HasFlatScratchSVSModeBit, Feature_isGFX11OnlyBit, },
  {Feature_HasFlatScratchSVSModeBit, Feature_isGFX12OnlyBit, },
  {Feature_HasFlatScratchSVSModeBit, Feature_isGFX940PlusBit, },
  {Feature_HasFmaLegacy32Bit, Feature_isGFX10OnlyBit, },
  {Feature_HasFmaLegacy32Bit, Feature_isGFX11OnlyBit, },
  {Feature_HasFmaLegacy32Bit, Feature_isGFX12OnlyBit, },
  {Feature_HasFmaMixBF16InstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasFmaMixInstsBit, Feature_HasVOP3PInstsBit, },
  {Feature_HasFmaMixInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasFmaMixInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasFmaMixInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasFmaakFmamkF32InstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasFmaakFmamkF32InstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasFmaakFmamkF32InstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasFmaakFmamkF32InstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasFmaakFmamkF64InstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasFmacF64InstBit, Feature_isGFX12OnlyBit, },
  {Feature_HasFmacLegacy32Bit, Feature_isGFX10OnlyBit, },
  {Feature_HasFmacLegacy32Bit, Feature_isGFX11OnlyBit, },
  {Feature_HasFormattedMUBUFInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasFormattedMUBUFInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasFormattedMUBUFInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasFormattedMUBUFInstsBit, Feature_isGFX6GFX7Bit, },
  {Feature_HasFormattedMUBUFInstsBit, Feature_isGFX8GFX9NotGFX90ABit, },
  {Feature_HasFormattedMUBUFInstsBit, Feature_isGFX90APlusBit, },
  {Feature_HasGFX10_BEncodingBit, Feature_isGFX10OnlyBit, },
  {Feature_HasGFX10_BEncodingBit, Feature_isGFX11OnlyBit, },
  {Feature_HasGFX10_BEncodingBit, Feature_isGFX12OnlyBit, },
  {Feature_HasGFX950InstsBit, Feature_HasVOP3PInstsBit, },
  {Feature_HasGFX950InstsBit, Feature_isGFX8GFX9NotGFX90ABit, },
  {Feature_HasGFX950InstsBit, Feature_isGFX90APlusBit, },
  {Feature_HasGFX950InstsBit, Feature_isGFX940PlusBit, },
  {Feature_HasGFX950InstsBit, Feature_isGFX9OnlyBit, },
  {Feature_HasGetWaveIdInstBit, Feature_isGFX10OnlyBit, },
  {Feature_HasIEEEMinimumMaximumInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasIEEEMinimumMaximumInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasImageInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasImageInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasImageInstsBit, Feature_isGFX12PlusBit, },
  {Feature_HasImageInstsBit, Feature_isGFX6GFX7GFX8GFX9NotGFX90ABit, },
  {Feature_HasImageInstsBit, Feature_isGFX90APlusBit, },
  {Feature_HasLDSFPAtomicAddF32Bit, Feature_isGFX10OnlyBit, },
  {Feature_HasLDSFPAtomicAddF32Bit, Feature_isGFX11OnlyBit, },
  {Feature_HasLDSFPAtomicAddF32Bit, Feature_isGFX12PlusBit, },
  {Feature_HasLDSFPAtomicAddF32Bit, Feature_isGFX8GFX9Bit, },
  {Feature_HasLDSFPAtomicAddF32Bit, Feature_isGFX90APlusBit, },
  {Feature_HasLdsAtomicAddF64Bit, Feature_isGFX12PlusBit, },
  {Feature_HasLdsAtomicAddF64Bit, Feature_isGFX8GFX9Bit, },
  {Feature_HasLdsAtomicAddF64Bit, Feature_isGFX90APlusBit, },
  {Feature_HasLdsBarrierArriveAtomicBit, Feature_isGFX1250PlusBit, },
  {Feature_HasLerpInstBit, Feature_isGFX10OnlyBit, },
  {Feature_HasLerpInstBit, Feature_isGFX11OnlyBit, },
  {Feature_HasLerpInstBit, Feature_isGFX12OnlyBit, },
  {Feature_HasLerpInstBit, Feature_isGFX6GFX7Bit, },
  {Feature_HasLerpInstBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasLshlAddU64InstBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasLshlAddU64InstBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasMAIInstsBit, Feature_isGFX940PlusBit, },
  {Feature_HasMTBUFInstsBit, Feature_HasUnpackedD16VMemBit, },
  {Feature_HasMTBUFInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasMTBUFInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasMTBUFInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasMTBUFInstsBit, Feature_isGFX6GFX7Bit, },
  {Feature_HasMTBUFInstsBit, Feature_isGFX8GFX9NotGFX90ABit, },
  {Feature_HasMTBUFInstsBit, Feature_isGFX90APlusBit, },
  {Feature_HasMadMacF32InstsBit, Feature_HasDPPBit, },
  {Feature_HasMadMacF32InstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasMadMacF32InstsBit, Feature_isGFX6GFX7Bit, },
  {Feature_HasMadMacF32InstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasMadMixInstsBit, Feature_HasVOP3PInstsBit, },
  {Feature_HasMadU32InstBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasMcastLoadInstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasMin3Max3PKF16Bit, Feature_isGFX125xOnlyBit, },
  {Feature_HasMinimum3Maximum3F16Bit, Feature_isGFX12OnlyBit, },
  {Feature_HasMinimum3Maximum3F32Bit, Feature_isGFX12OnlyBit, },
  {Feature_HasMinimum3Maximum3F32Bit, Feature_isGFX8GFX9Bit, },
  {Feature_HasMinimum3Maximum3PKF16Bit, Feature_HasVOP3PInstsBit, },
  {Feature_HasMinimum3Maximum3PKF16Bit, Feature_isGFX125xOnlyBit, },
  {Feature_HasMovrelBit, Feature_isGFX10OnlyBit, },
  {Feature_HasMovrelBit, Feature_isGFX11OnlyBit, },
  {Feature_HasMovrelBit, Feature_isGFX12OnlyBit, },
  {Feature_HasMovrelBit, Feature_isGFX6GFX7Bit, },
  {Feature_HasMovrelBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasNoSdstCMPXBit, Feature_isGFX10OnlyBit, },
  {Feature_HasNoSdstCMPXBit, Feature_isGFX11OnlyBit, },
  {Feature_HasNoSdstCMPXBit, Feature_isGFX12OnlyBit, },
  {Feature_HasPackedD16VMemBit, Feature_isGFX8GFX9NotGFX90ABit, },
  {Feature_HasPackedD16VMemBit, Feature_isGFX90APlusBit, },
  {Feature_HasPackedFP32OpsBit, Feature_HasVOP3PInstsBit, },
  {Feature_HasPackedFP32OpsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasPermlane16SwapBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasPermlane16SwapBit, Feature_isGFX9OnlyBit, },
  {Feature_HasPermlane32SwapBit, Feature_isGFX9OnlyBit, },
  {Feature_HasPkAddMinMaxInstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasPkFmacF16InstBit, Feature_isGFX10OnlyBit, },
  {Feature_HasPkFmacF16InstBit, Feature_isGFX11OnlyBit, },
  {Feature_HasPkFmacF16InstBit, Feature_isGFX12OnlyBit, },
  {Feature_HasPkFmacF16InstBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasPkFmacF16InstBit, Feature_isGFX9OnlyBit, },
  {Feature_HasPkMinMax3InstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasPkMovB32Bit, Feature_HasVOP3PInstsBit, },
  {Feature_HasPrngInstBit, Feature_HasDPPBit, },
  {Feature_HasPrngInstBit, Feature_HasSDWA9Bit, },
  {Feature_HasPrngInstBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasPrngInstBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasPseudoScalarTransBit, Feature_isGFX12OnlyBit, },
  {Feature_HasQsadInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasQsadInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasQsadInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasQsadInstsBit, Feature_isGFX7OnlyBit, },
  {Feature_HasQsadInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasSALUFloatInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasSALUFloatInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasSGetShaderCyclesInstBit, Feature_isGFX12OnlyBit, },
  {Feature_HasSMemRealTimeBit, Feature_isGFX10OnlyBit, },
  {Feature_HasSMemRealTimeBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasSMemTimeInstBit, Feature_isGFX10OnlyBit, },
  {Feature_HasSMemTimeInstBit, Feature_isGFX6GFX7Bit, },
  {Feature_HasSMemTimeInstBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasSWakeupBarrierBit, Feature_isGFX12OnlyBit, },
  {Feature_HasSadInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasSadInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasSadInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasSadInstsBit, Feature_isGFX6GFX7Bit, },
  {Feature_HasSadInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasScalarAtomicsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasScalarAtomicsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasScalarAtomicsBit, Feature_isGFX9OnlyBit, },
  {Feature_HasScalarFlatScratchInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasScalarFlatScratchInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasScalarFlatScratchInstsBit, Feature_isGFX9OnlyBit, },
  {Feature_HasScalarStoresBit, Feature_isGFX10OnlyBit, },
  {Feature_HasScalarStoresBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasScalarStoresBit, Feature_isGFX9OnlyBit, },
  {Feature_HasSetPrioIncWgInstBit, Feature_isGFX12OnlyBit, },
  {Feature_HasTanhInstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasTensorCvtLutInstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasVGPRIndexModeBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasVINTERPEncodingBit, Feature_isGFX11OnlyBit, },
  {Feature_HasVINTERPEncodingBit, Feature_isGFX12OnlyBit, },
  {Feature_HasVmemPrefInstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasWaitXcntBit, Feature_isGFX12OnlyBit, },
  {Feature_HasXF32InstsBit, Feature_isGFX940PlusBit, },
  {Feature_NotHasTrue16BitInstsBit, Feature_HasSDWA9Bit, },
  {Feature_NotHasTrue16BitInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_NotHasTrue16BitInstsBit, Feature_isGFX6GFX7Bit, },
  {Feature_NotHasTrue16BitInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_UseFakeTrue16InstsBit, Feature_isGFX11OnlyBit, },
  {Feature_UseFakeTrue16InstsBit, Feature_isGFX12OnlyBit, },
  {Feature_UseRealTrue16InstsBit, Feature_isGFX11OnlyBit, },
  {Feature_UseRealTrue16InstsBit, Feature_isGFX12OnlyBit, },
  {Feature_isGCN3ExcludingGFX90ABit, Feature_HasDPPBit, },
  {Feature_isGCN3ExcludingGFX90ABit, Feature_HasSDWA8Bit, },
  {Feature_isGCN3ExcludingGFX90ABit, Feature_HasSDWA9Bit, },
  {Feature_isGCN3ExcludingGFX90ABit, Feature_isGFX8GFX9Bit, },
  {Feature_isGFX10Before1030Bit, Feature_isGFX10OnlyBit, },
  {Feature_isGFX10GFX11Bit, Feature_isGFX10OnlyBit, },
  {Feature_isGFX10GFX11Bit, Feature_isGFX11OnlyBit, },
  {Feature_isGFX10OnlyBit, Feature_isWave32Bit, },
  {Feature_isGFX10OnlyBit, Feature_isWave64Bit, },
  {Feature_isGFX10PlusBit, Feature_isGFX10OnlyBit, },
  {Feature_isGFX10PlusBit, Feature_isGFX11OnlyBit, },
  {Feature_isGFX10PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_isGFX11OnlyBit, Feature_UseFakeTrue16InstsBit, },
  {Feature_isGFX11OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_isGFX11OnlyBit, Feature_isWave32Bit, },
  {Feature_isGFX11OnlyBit, Feature_isWave64Bit, },
  {Feature_isGFX11PlusBit, Feature_isGFX11OnlyBit, },
  {Feature_isGFX11PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_isGFX1250PlusBit, Feature_isGFX125xOnlyBit, },
  {Feature_isGFX1250PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_isGFX125xOnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_isGFX125xOnlyBit, Feature_isWave32Bit, },
  {Feature_isGFX12Not12_50Bit, Feature_isWave32Bit, },
  {Feature_isGFX12OnlyBit, Feature_UseFakeTrue16InstsBit, },
  {Feature_isGFX12OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_isGFX12OnlyBit, Feature_isWave32Bit, },
  {Feature_isGFX12OnlyBit, Feature_isWave64Bit, },
  {Feature_isGFX12PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_isGFX12PlusBit, Feature_isWave32Bit, },
  {Feature_isGFX12PlusBit, Feature_isWave64Bit, },
  {Feature_isGFX12PlusNot12_50Bit, Feature_isGFX12OnlyBit, },
  {Feature_isGFX12PlusNot12_50Bit, Feature_isGFX12PlusBit, },
  {Feature_isGFX6GFX7Bit, Feature_NotHasTrue16BitInstsBit, },
  {Feature_isGFX6GFX7Bit, Feature_isWave32Bit, },
  {Feature_isGFX6GFX7Bit, Feature_isWave64Bit, },
  {Feature_isGFX6GFX7GFX10Bit, Feature_isGFX10OnlyBit, },
  {Feature_isGFX6GFX7GFX10Bit, Feature_isGFX6GFX7Bit, },
  {Feature_isGFX6GFX7GFX10PlusBit, Feature_isGFX10OnlyBit, },
  {Feature_isGFX6GFX7GFX10PlusBit, Feature_isGFX11OnlyBit, },
  {Feature_isGFX6GFX7GFX10PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_isGFX6GFX7GFX10PlusBit, Feature_isGFX6GFX7Bit, },
  {Feature_isGFX6GFX7GFX8GFX9Bit, Feature_isGFX6GFX7Bit, },
  {Feature_isGFX6GFX7GFX8GFX9Bit, Feature_isGFX8GFX9Bit, },
  {Feature_isGFX7GFX10Bit, Feature_isGFX10OnlyBit, },
  {Feature_isGFX7GFX10Bit, Feature_isGFX7OnlyBit, },
  {Feature_isGFX7GFX10GFX11Bit, Feature_isGFX10OnlyBit, },
  {Feature_isGFX7GFX10GFX11Bit, Feature_isGFX11OnlyBit, },
  {Feature_isGFX7GFX10GFX11Bit, Feature_isGFX12OnlyBit, },
  {Feature_isGFX7GFX10GFX11Bit, Feature_isGFX7OnlyBit, },
  {Feature_isGFX7GFX8GFX9Bit, Feature_HasSDWA8Bit, },
  {Feature_isGFX7GFX8GFX9Bit, Feature_HasSDWA9Bit, },
  {Feature_isGFX7GFX8GFX9Bit, Feature_isGFX7OnlyBit, },
  {Feature_isGFX7GFX8GFX9Bit, Feature_isGFX8GFX9Bit, },
  {Feature_isGFX7PlusBit, Feature_isGFX10OnlyBit, },
  {Feature_isGFX7PlusBit, Feature_isGFX11OnlyBit, },
  {Feature_isGFX7PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_isGFX7PlusBit, Feature_isGFX12PlusBit, },
  {Feature_isGFX7PlusBit, Feature_isGFX6GFX7Bit, },
  {Feature_isGFX7PlusBit, Feature_isGFX7OnlyBit, },
  {Feature_isGFX7PlusBit, Feature_isGFX8GFX9Bit, },
  {Feature_isGFX7PlusBit, Feature_isGFX90APlusBit, },
  {Feature_isGFX8GFX9Bit, Feature_HasDPPBit, },
  {Feature_isGFX8GFX9Bit, Feature_HasSDWA8Bit, },
  {Feature_isGFX8GFX9Bit, Feature_HasSDWA9Bit, },
  {Feature_isGFX8GFX9Bit, Feature_isWave32Bit, },
  {Feature_isGFX8GFX9Bit, Feature_isWave64Bit, },
  {Feature_isGFX8GFX9GFX10GFX11Bit, Feature_isGFX10OnlyBit, },
  {Feature_isGFX8GFX9GFX10GFX11Bit, Feature_isGFX11OnlyBit, },
  {Feature_isGFX8GFX9GFX10GFX11Bit, Feature_isGFX8GFX9Bit, },
  {Feature_isGFX8GFX9NotGFX90ABit, Feature_HasMAIInstsBit, },
  {Feature_isGFX8GFX9NotGFX940Bit, Feature_HasFlatScratchInstsBit, },
  {Feature_isGFX8GFX9NotGFX940Bit, Feature_isGFX8GFX9NotGFX90ABit, },
  {Feature_isGFX8GFX9NotGFX940Bit, Feature_isGFX90APlusBit, },
  {Feature_isGFX8OnlyBit, Feature_isGFX8GFX9Bit, },
  {Feature_isGFX8PlusBit, Feature_isGFX10OnlyBit, },
  {Feature_isGFX8PlusBit, Feature_isGFX11OnlyBit, },
  {Feature_isGFX8PlusBit, Feature_isGFX125xOnlyBit, },
  {Feature_isGFX8PlusBit, Feature_isGFX12Not12_50Bit, },
  {Feature_isGFX8PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_isGFX8PlusBit, Feature_isGFX12PlusBit, },
  {Feature_isGFX8PlusBit, Feature_isGFX6GFX7Bit, },
  {Feature_isGFX8PlusBit, Feature_isGFX8GFX9Bit, },
  {Feature_isGFX8PlusBit, Feature_isGFX90APlusBit, },
  {Feature_isGFX8PlusBit, Feature_isGFX9OnlyBit, },
  {Feature_isGFX90AOnlyBit, Feature_isGFX90APlusBit, },
  {Feature_isGFX90APlusBit, Feature_HasGFX950InstsBit, },
  {Feature_isGFX90APlusBit, Feature_isGFX8GFX9Bit, },
  {Feature_isGFX90APlusBit, Feature_isGFX8GFX9NotGFX90ABit, },
  {Feature_isGFX90APlusBit, Feature_isGFX90AOnlyBit, },
  {Feature_isGFX90APlusBit, Feature_isGFX940PlusBit, },
  {Feature_isGFX940orGFX1250Bit, Feature_isGFX125xOnlyBit, },
  {Feature_isGFX940orGFX1250Bit, Feature_isGFX940PlusBit, },
  {Feature_isGFX9GFX10GFX11Bit, Feature_isGFX10OnlyBit, },
  {Feature_isGFX9GFX10GFX11Bit, Feature_isGFX11OnlyBit, },
  {Feature_isGFX9GFX10GFX11Bit, Feature_isGFX8GFX9Bit, },
  {Feature_isGFX9OnlyBit, Feature_HasDPPBit, },
  {Feature_isGFX9OnlyBit, Feature_HasFmacF64InstBit, },
  {Feature_isGFX9OnlyBit, Feature_HasSDWA9Bit, },
  {Feature_isGFX9OnlyBit, Feature_isGFX8GFX9Bit, },
  {Feature_isGFX9OnlyBit, Feature_isWave32Bit, },
  {Feature_isGFX9OnlyBit, Feature_isWave64Bit, },
  {Feature_isGFX9PlusBit, Feature_HasSDWA8Bit, },
  {Feature_isGFX9PlusBit, Feature_isGFX10OnlyBit, },
  {Feature_isGFX9PlusBit, Feature_isGFX11OnlyBit, },
  {Feature_isGFX9PlusBit, Feature_isGFX125xOnlyBit, },
  {Feature_isGFX9PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_isGFX9PlusBit, Feature_isGFX8GFX9Bit, },
  {Feature_isNotGFX1250PlusBit, Feature_isGFX10OnlyBit, },
  {Feature_isNotGFX1250PlusBit, Feature_isGFX11OnlyBit, },
  {Feature_isNotGFX1250PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_isNotGFX1250PlusBit, Feature_isGFX6GFX7Bit, },
  {Feature_isNotGFX1250PlusBit, Feature_isGFX8GFX9Bit, },
  {Feature_isNotGFX12PlusBit, Feature_isGFX10OnlyBit, },
  {Feature_isNotGFX12PlusBit, Feature_isGFX11OnlyBit, },
  {Feature_isNotGFX12PlusBit, Feature_isGFX6GFX7Bit, },
  {Feature_isNotGFX12PlusBit, Feature_isGFX8GFX9Bit, },
  {Feature_isNotGFX90APlusBit, Feature_isGFX10OnlyBit, },
  {Feature_isNotGFX90APlusBit, Feature_isGFX11OnlyBit, },
  {Feature_isNotGFX90APlusBit, Feature_isGFX6GFX7Bit, },
  {Feature_isNotGFX90APlusBit, Feature_isGFX8GFX9Bit, },
  {Feature_isNotGFX940PlusBit, Feature_isGFX6GFX7Bit, },
  {Feature_isNotGFX940PlusBit, Feature_isGFX7OnlyBit, },
  {Feature_isNotGFX940PlusBit, Feature_isGFX8GFX9Bit, },
  {Feature_Has16BitInstsBit, Feature_HasDPPBit, Feature_NotHasTrue16BitInstsBit, },
  {Feature_Has16BitInstsBit, Feature_HasNoSdstCMPXBit, Feature_isGFX10OnlyBit, },
  {Feature_Has16BitInstsBit, Feature_isGFX10OnlyBit, Feature_NotHasTrue16BitInstsBit, },
  {Feature_Has16BitInstsBit, Feature_isGFX11OnlyBit, Feature_UseFakeTrue16InstsBit, },
  {Feature_Has16BitInstsBit, Feature_isGFX11OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_Has16BitInstsBit, Feature_isGFX12OnlyBit, Feature_UseFakeTrue16InstsBit, },
  {Feature_Has16BitInstsBit, Feature_isGFX12OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_Has16BitInstsBit, Feature_isGFX8GFX9Bit, Feature_NotHasTrue16BitInstsBit, },
  {Feature_HasBF16ConversionInstsBit, Feature_HasGFX950InstsBit, Feature_HasDPPBit, },
  {Feature_HasBF16ConversionInstsBit, Feature_HasGFX950InstsBit, Feature_HasSDWA9Bit, },
  {Feature_HasBF16ConversionInstsBit, Feature_HasGFX950InstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasBF16ConversionInstsBit, Feature_isGFX1250PlusBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasBitOp3InstsBit, Feature_isGFX11PlusBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasBitOp3InstsBit, Feature_isGFX1250PlusBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasBitOp3InstsBit, Feature_isGFX940PlusBit, Feature_isGFX9OnlyBit, },
  {Feature_HasCvtPkNormVOP3InstsBit, Feature_isGFX10OnlyBit, Feature_NotHasTrue16BitInstsBit, },
  {Feature_HasCvtPkNormVOP3InstsBit, Feature_isGFX11OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasCvtPkNormVOP3InstsBit, Feature_isGFX12OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasCvtPkNormVOP3InstsBit, Feature_isGFX8GFX9Bit, Feature_NotHasTrue16BitInstsBit, },
  {Feature_HasDPALU_DPPBit, Feature_HasAddSubU64InstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasDPALU_DPPBit, Feature_HasFmacF64InstBit, Feature_isGFX12OnlyBit, },
  {Feature_HasDPALU_DPPBit, Feature_HasIEEEMinimumMaximumInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasDPALU_DPPBit, Feature_HasIEEEMinimumMaximumInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasDPALU_DPPBit, Feature_HasLshlAddU64InstBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasDPALU_DPPBit, Feature_HasMadU32InstBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasDPALU_DPPBit, Feature_isGFX1250PlusBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasDPALU_DPPBit, Feature_isGFX12PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_HasDPALU_DPPBit, Feature_isGFX7PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_HasDPALU_DPPBit, Feature_isGFX8PlusBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasDPALU_DPPBit, Feature_isGFX940orGFX1250Bit, Feature_isGFX125xOnlyBit, },
  {Feature_HasDPP16Bit, Feature_isGFX11OnlyBit, Feature_UseFakeTrue16InstsBit, },
  {Feature_HasDPP16Bit, Feature_isGFX11OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasDPP16Bit, Feature_isGFX11OnlyBit, Feature_isWave32Bit, },
  {Feature_HasDPP16Bit, Feature_isGFX11OnlyBit, Feature_isWave64Bit, },
  {Feature_HasDPP16Bit, Feature_isGFX12OnlyBit, Feature_UseFakeTrue16InstsBit, },
  {Feature_HasDPP16Bit, Feature_isGFX12OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasDPP16Bit, Feature_isGFX12OnlyBit, Feature_isWave32Bit, },
  {Feature_HasDPP16Bit, Feature_isGFX12OnlyBit, Feature_isWave64Bit, },
  {Feature_HasDot10InstsBit, Feature_isGFX11PlusBit, Feature_isGFX11OnlyBit, },
  {Feature_HasDot10InstsBit, Feature_isGFX11PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_HasDot11InstsBit, Feature_isGFX11PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_HasDot13InstsBit, Feature_isGFX9OnlyBit, Feature_HasDPPBit, },
  {Feature_HasDot3InstsBit, Feature_isGFX9OnlyBit, Feature_HasDPPBit, },
  {Feature_HasDot4InstsBit, Feature_isGFX9OnlyBit, Feature_HasDPPBit, },
  {Feature_HasDot5InstsBit, Feature_isGFX9OnlyBit, Feature_HasDPPBit, },
  {Feature_HasDot6InstsBit, Feature_isGFX9OnlyBit, Feature_HasDPPBit, },
  {Feature_HasDot9InstsBit, Feature_isGFX11OnlyBit, Feature_UseFakeTrue16InstsBit, },
  {Feature_HasDot9InstsBit, Feature_isGFX11OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasDot9InstsBit, Feature_isGFX12OnlyBit, Feature_UseFakeTrue16InstsBit, },
  {Feature_HasDot9InstsBit, Feature_isGFX12OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasDsSrc2InstsBit, Feature_HasLDSFPAtomicAddF32Bit, Feature_isGFX10OnlyBit, },
  {Feature_HasDsSrc2InstsBit, Feature_HasLDSFPAtomicAddF32Bit, Feature_isGFX8GFX9Bit, },
  {Feature_HasExportInstsBit, Feature_isGFX11PlusBit, Feature_isGFX11OnlyBit, },
  {Feature_HasExportInstsBit, Feature_isGFX11PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_HasExportInstsBit, Feature_isGFX12PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_HasFP8ConversionInstsBit, Feature_isGFX12PlusBit, Feature_isGFX11OnlyBit, },
  {Feature_HasFP8ConversionInstsBit, Feature_isGFX12PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_HasFP8ConversionInstsBit, Feature_isGFX12PlusNot12_50Bit, Feature_isGFX11OnlyBit, },
  {Feature_HasFP8ConversionInstsBit, Feature_isGFX12PlusNot12_50Bit, Feature_isGFX12Not12_50Bit, },
  {Feature_HasFP8ConversionInstsBit, Feature_isGFX940PlusBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasFP8ConversionInstsBit, Feature_isGFX9PlusBit, Feature_isGFX11OnlyBit, },
  {Feature_HasFP8ConversionInstsBit, Feature_isGFX9PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_HasFlatGVSModeBit, Feature_HasAtomicFMinFMaxF64FlatInstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasFlatGVSModeBit, Feature_HasAtomicFlatPkAdd16InstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasFlatGVSModeBit, Feature_HasD16LoadStoreBit, Feature_isGFX12OnlyBit, },
  {Feature_HasFlatGVSModeBit, Feature_HasFlatAddressSpaceBit, Feature_isGFX12OnlyBit, },
  {Feature_HasFlatGVSModeBit, Feature_HasFlatAtomicFaddF32InstBit, Feature_isGFX12OnlyBit, },
  {Feature_HasFlatGVSModeBit, Feature_HasFlatBufferGlobalAtomicFaddF64InstBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasFlatGVSModeBit, Feature_HasVmemPrefInstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasFlatGVSModeBit, Feature_isGFX12PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_HasFlatGVSModeBit, Feature_isGFX7GFX10GFX11Bit, Feature_isGFX12OnlyBit, },
  {Feature_HasFormattedMUBUFInstsBit, Feature_HasD16LoadStoreBit, Feature_isGFX10OnlyBit, },
  {Feature_HasFormattedMUBUFInstsBit, Feature_HasD16LoadStoreBit, Feature_isGFX11OnlyBit, },
  {Feature_HasFormattedMUBUFInstsBit, Feature_HasD16LoadStoreBit, Feature_isGFX12OnlyBit, },
  {Feature_HasFormattedMUBUFInstsBit, Feature_HasD16LoadStoreBit, Feature_isGFX8GFX9NotGFX90ABit, },
  {Feature_HasFormattedMUBUFInstsBit, Feature_HasD16LoadStoreBit, Feature_isGFX90APlusBit, },
  {Feature_HasGFX10_BEncodingBit, Feature_HasFlatGlobalInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasGFX10_BEncodingBit, Feature_HasFlatGlobalInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasGFX10_BEncodingBit, Feature_HasFlatGlobalInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasGFX950InstsBit, Feature_isGFX8GFX9Bit, Feature_isWave64Bit, },
  {Feature_HasIEEEMinimumMaximumInstsBit, Feature_isGFX12OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasImageInstsBit, Feature_HasExtendedImageInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasImageInstsBit, Feature_HasExtendedImageInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasImageInstsBit, Feature_HasExtendedImageInstsBit, Feature_isGFX12PlusBit, },
  {Feature_HasImageInstsBit, Feature_HasExtendedImageInstsBit, Feature_isGFX6GFX7GFX8GFX9NotGFX90ABit, },
  {Feature_HasImageInstsBit, Feature_HasExtendedImageInstsBit, Feature_isGFX90APlusBit, },
  {Feature_HasImageInstsBit, Feature_HasGFX10_AEncodingBit, Feature_isGFX10OnlyBit, },
  {Feature_HasImageInstsBit, Feature_HasGFX10_AEncodingBit, Feature_isGFX11OnlyBit, },
  {Feature_HasImageInstsBit, Feature_HasGFX10_AEncodingBit, Feature_isGFX12PlusBit, },
  {Feature_HasImageInstsBit, Feature_isGFX11PlusBit, Feature_isGFX11OnlyBit, },
  {Feature_HasImageInstsBit, Feature_isGFX11PlusBit, Feature_isGFX12PlusBit, },
  {Feature_HasImageInstsBit, Feature_isGFX12PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_HasImageInstsBit, Feature_isGFX6GFX7GFX8GFX9NotGFX90ABit, Feature_isGFX6GFX7Bit, },
  {Feature_HasImageInstsBit, Feature_isGFX6GFX7GFX8GFX9NotGFX90ABit, Feature_isGFX8GFX9NotGFX90ABit, },
  {Feature_HasMTBUFInstsBit, Feature_HasPackedD16VMemBit, Feature_isGFX10OnlyBit, },
  {Feature_HasMTBUFInstsBit, Feature_HasPackedD16VMemBit, Feature_isGFX11OnlyBit, },
  {Feature_HasMTBUFInstsBit, Feature_HasPackedD16VMemBit, Feature_isGFX12OnlyBit, },
  {Feature_HasMTBUFInstsBit, Feature_HasPackedD16VMemBit, Feature_isGFX8GFX9NotGFX90ABit, },
  {Feature_HasMTBUFInstsBit, Feature_HasPackedD16VMemBit, Feature_isGFX90APlusBit, },
  {Feature_HasMadMacF32InstsBit, Feature_isGFX6GFX7GFX10Bit, Feature_isGFX10OnlyBit, },
  {Feature_HasMadMacF32InstsBit, Feature_isGFX6GFX7GFX10Bit, Feature_isGFX6GFX7Bit, },
  {Feature_HasMcastLoadInstsBit, Feature_isGFX125xOnlyBit, Feature_isWave32Bit, },
  {Feature_HasMinimum3Maximum3F16Bit, Feature_isGFX12OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasNoSdstCMPXBit, Feature_isGFX11OnlyBit, Feature_UseFakeTrue16InstsBit, },
  {Feature_HasNoSdstCMPXBit, Feature_isGFX11OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasNoSdstCMPXBit, Feature_isGFX12OnlyBit, Feature_UseFakeTrue16InstsBit, },
  {Feature_HasNoSdstCMPXBit, Feature_isGFX12OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasPackedD16VMemBit, Feature_HasFormattedMUBUFInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_HasPackedD16VMemBit, Feature_HasFormattedMUBUFInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_HasPackedD16VMemBit, Feature_HasFormattedMUBUFInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_HasScalarStoresBit, Feature_isGFX8PlusBit, Feature_isGFX10OnlyBit, },
  {Feature_HasScalarStoresBit, Feature_isGFX8PlusBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasTransposeLoadF4F6InstsBit, Feature_isGFX125xOnlyBit, Feature_isWave32Bit, },
  {Feature_HasVINTERPEncodingBit, Feature_isGFX11OnlyBit, Feature_UseFakeTrue16InstsBit, },
  {Feature_HasVINTERPEncodingBit, Feature_isGFX11OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasVINTERPEncodingBit, Feature_isGFX12OnlyBit, Feature_UseFakeTrue16InstsBit, },
  {Feature_HasVINTERPEncodingBit, Feature_isGFX12OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_NotHasTrue16BitInstsBit, Feature_Has16BitInstsBit, Feature_HasSDWA9Bit, },
  {Feature_NotHasTrue16BitInstsBit, Feature_Has16BitInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_NotHasTrue16BitInstsBit, Feature_Has16BitInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_UseFakeTrue16InstsBit, Feature_HasBF16TransInstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_UseFakeTrue16InstsBit, Feature_HasCvtNormInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_UseFakeTrue16InstsBit, Feature_HasCvtNormInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_UseFakeTrue16InstsBit, Feature_HasTanhInstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_UseFakeTrue16InstsBit, Feature_isGFX11PlusBit, Feature_isGFX11OnlyBit, },
  {Feature_UseFakeTrue16InstsBit, Feature_isGFX11PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_UseFakeTrue16InstsBit, Feature_isGFX1250PlusBit, Feature_isGFX125xOnlyBit, },
  {Feature_UseFakeTrue16InstsBit, Feature_isGFX9PlusBit, Feature_isGFX11OnlyBit, },
  {Feature_UseFakeTrue16InstsBit, Feature_isGFX9PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_UseRealTrue16InstsBit, Feature_HasBF16TransInstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_UseRealTrue16InstsBit, Feature_HasCvtNormInstsBit, Feature_isGFX11OnlyBit, },
  {Feature_UseRealTrue16InstsBit, Feature_HasCvtNormInstsBit, Feature_isGFX12OnlyBit, },
  {Feature_UseRealTrue16InstsBit, Feature_HasTanhInstsBit, Feature_isGFX125xOnlyBit, },
  {Feature_UseRealTrue16InstsBit, Feature_isGFX10PlusBit, Feature_isGFX11OnlyBit, },
  {Feature_UseRealTrue16InstsBit, Feature_isGFX10PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_UseRealTrue16InstsBit, Feature_isGFX11PlusBit, Feature_isGFX11OnlyBit, },
  {Feature_UseRealTrue16InstsBit, Feature_isGFX11PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_UseRealTrue16InstsBit, Feature_isGFX1250PlusBit, Feature_isGFX125xOnlyBit, },
  {Feature_UseRealTrue16InstsBit, Feature_isGFX9PlusBit, Feature_isGFX11OnlyBit, },
  {Feature_UseRealTrue16InstsBit, Feature_isGFX9PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_isGFX10PlusBit, Feature_isGFX10OnlyBit, Feature_NotHasTrue16BitInstsBit, },
  {Feature_isGFX10PlusBit, Feature_isGFX11OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_isGFX10PlusBit, Feature_isGFX12OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_isGFX11OnlyBit, Feature_isWave32Bit, Feature_UseFakeTrue16InstsBit, },
  {Feature_isGFX11OnlyBit, Feature_isWave32Bit, Feature_UseRealTrue16InstsBit, },
  {Feature_isGFX11OnlyBit, Feature_isWave64Bit, Feature_UseFakeTrue16InstsBit, },
  {Feature_isGFX11OnlyBit, Feature_isWave64Bit, Feature_UseRealTrue16InstsBit, },
  {Feature_isGFX11PlusBit, Feature_isGFX11OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_isGFX11PlusBit, Feature_isGFX12OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_isGFX1250PlusBit, Feature_isGFX125xOnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_isGFX1250PlusBit, Feature_isGFX125xOnlyBit, Feature_isWave32Bit, },
  {Feature_isGFX1250PlusBit, Feature_isGFX12OnlyBit, Feature_isWave32Bit, },
  {Feature_isGFX1250PlusBit, Feature_isGFX12PlusBit, Feature_isWave32Bit, },
  {Feature_isGFX12OnlyBit, Feature_isWave32Bit, Feature_UseFakeTrue16InstsBit, },
  {Feature_isGFX12OnlyBit, Feature_isWave32Bit, Feature_UseRealTrue16InstsBit, },
  {Feature_isGFX12OnlyBit, Feature_isWave64Bit, Feature_UseFakeTrue16InstsBit, },
  {Feature_isGFX12OnlyBit, Feature_isWave64Bit, Feature_UseRealTrue16InstsBit, },
  {Feature_isGFX12PlusBit, Feature_isGFX125xOnlyBit, Feature_isWave32Bit, },
  {Feature_isGFX12PlusBit, Feature_isGFX12Not12_50Bit, Feature_isWave32Bit, },
  {Feature_isGFX12PlusNot12_50Bit, Feature_isGFX12OnlyBit, Feature_isWave64Bit, },
  {Feature_isGFX8GFX9NotGFX940Bit, Feature_HasFlatGlobalInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_isGFX8GFX9NotGFX940Bit, Feature_HasFlatScratchInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_isGFX8GFX9NotGFX940Bit, Feature_HasGFX950InstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_isGFX8OnlyBit, Feature_isGFX8GFX9Bit, Feature_NotHasTrue16BitInstsBit, },
  {Feature_isGFX90APlusBit, Feature_HasFP8InstsBit, Feature_isGFX940PlusBit, },
  {Feature_isGFX90APlusBit, Feature_HasGFX950InstsBit, Feature_isGFX940PlusBit, },
  {Feature_isGFX90APlusBit, Feature_HasMAIInstsBit, Feature_isGFX940PlusBit, },
  {Feature_isGFX90APlusBit, Feature_HasXF32InstsBit, Feature_isGFX940PlusBit, },
  {Feature_isGFX9OnlyBit, Feature_HasFmacF64InstBit, Feature_HasDPALU_DPPBit, },
  {Feature_isGFX9PlusBit, Feature_isGFX10OnlyBit, Feature_NotHasTrue16BitInstsBit, },
  {Feature_isGFX9PlusBit, Feature_isGFX11OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_isGFX9PlusBit, Feature_isGFX12OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_isGFX9PlusBit, Feature_isGFX8GFX9Bit, Feature_NotHasTrue16BitInstsBit, },
  {Feature_isGFX9PlusBit, Feature_isGFX9OnlyBit, Feature_NotHasTrue16BitInstsBit, },
  {Feature_isNotGFX1250PlusBit, Feature_isGFX9PlusBit, Feature_isGFX11OnlyBit, },
  {Feature_isNotGFX1250PlusBit, Feature_isGFX9PlusBit, Feature_isGFX12OnlyBit, },
  {Feature_isNotGFX90APlusBit, Feature_Has16BitInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_isNotGFX90APlusBit, Feature_Has16BitInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_isNotGFX90APlusBit, Feature_Has16BitInstsBit, Feature_isGFX8OnlyBit, },
  {Feature_isNotGFX90APlusBit, Feature_Has16BitInstsBit, Feature_isGFX9OnlyBit, },
  {Feature_isNotGFX90APlusBit, Feature_isGFX8PlusBit, Feature_isGFX10OnlyBit, },
  {Feature_isNotGFX90APlusBit, Feature_isGFX8PlusBit, Feature_isGFX8GFX9Bit, },
  {Feature_isNotGFX90APlusBit, Feature_isGFX9PlusBit, Feature_isGFX9OnlyBit, },
  {Feature_Has16BitInstsBit, Feature_HasNoSdstCMPXBit, Feature_isGFX10OnlyBit, Feature_NotHasTrue16BitInstsBit, },
  {Feature_HasBF16ConversionInstsBit, Feature_isGFX1250PlusBit, Feature_isGFX125xOnlyBit, Feature_UseFakeTrue16InstsBit, },
  {Feature_HasBF16ConversionInstsBit, Feature_isGFX1250PlusBit, Feature_isGFX125xOnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasBitOp3InstsBit, Feature_isGFX1250PlusBit, Feature_isGFX125xOnlyBit, Feature_UseFakeTrue16InstsBit, },
  {Feature_HasBitOp3InstsBit, Feature_isGFX1250PlusBit, Feature_isGFX125xOnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasDPP16Bit, Feature_isGFX11OnlyBit, Feature_isWave32Bit, Feature_UseFakeTrue16InstsBit, },
  {Feature_HasDPP16Bit, Feature_isGFX11OnlyBit, Feature_isWave32Bit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasDPP16Bit, Feature_isGFX11OnlyBit, Feature_isWave64Bit, Feature_UseFakeTrue16InstsBit, },
  {Feature_HasDPP16Bit, Feature_isGFX11OnlyBit, Feature_isWave64Bit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasDPP16Bit, Feature_isGFX12OnlyBit, Feature_isWave32Bit, Feature_UseFakeTrue16InstsBit, },
  {Feature_HasDPP16Bit, Feature_isGFX12OnlyBit, Feature_isWave32Bit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasDPP16Bit, Feature_isGFX12OnlyBit, Feature_isWave64Bit, Feature_UseFakeTrue16InstsBit, },
  {Feature_HasDPP16Bit, Feature_isGFX12OnlyBit, Feature_isWave64Bit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasFP8ConversionInstsBit, Feature_HasFP8E5M3InstsBit, Feature_isGFX12PlusBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasFP8ConversionInstsBit, Feature_HasFP8E5M3InstsBit, Feature_isGFX9PlusBit, Feature_isGFX125xOnlyBit, },
  {Feature_HasFP8ConversionInstsBit, Feature_NotHasFP8E5M3InstsBit, Feature_isGFX12PlusBit, Feature_isGFX11OnlyBit, },
  {Feature_HasFP8ConversionInstsBit, Feature_NotHasFP8E5M3InstsBit, Feature_isGFX12PlusBit, Feature_isGFX12Not12_50Bit, },
  {Feature_HasFP8ConversionInstsBit, Feature_NotHasFP8E5M3InstsBit, Feature_isGFX9PlusBit, Feature_isGFX11OnlyBit, },
  {Feature_HasFP8ConversionInstsBit, Feature_NotHasFP8E5M3InstsBit, Feature_isGFX9PlusBit, Feature_isGFX12Not12_50Bit, },
  {Feature_HasFP8ConversionInstsBit, Feature_isGFX12PlusBit, Feature_isGFX12OnlyBit, Feature_UseFakeTrue16InstsBit, },
  {Feature_HasFP8ConversionInstsBit, Feature_isGFX12PlusBit, Feature_isGFX12OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasFP8ConversionInstsBit, Feature_isGFX9PlusBit, Feature_isGFX11OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasFP8ConversionInstsBit, Feature_isGFX9PlusBit, Feature_isGFX12OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasFP8ConversionInstsBit, Feature_isGFX9PlusBit, Feature_isGFX8GFX9Bit, Feature_NotHasTrue16BitInstsBit, },
  {Feature_HasImageInstsBit, Feature_HasExtendedImageInstsBit, Feature_HasG16Bit, Feature_isGFX10OnlyBit, },
  {Feature_HasImageInstsBit, Feature_HasExtendedImageInstsBit, Feature_HasG16Bit, Feature_isGFX11OnlyBit, },
  {Feature_HasImageInstsBit, Feature_HasExtendedImageInstsBit, Feature_HasG16Bit, Feature_isGFX12PlusBit, },
  {Feature_HasImageInstsBit, Feature_HasExtendedImageInstsBit, Feature_HasG16Bit, Feature_isGFX6GFX7GFX8GFX9NotGFX90ABit, },
  {Feature_HasImageInstsBit, Feature_HasExtendedImageInstsBit, Feature_isGFX9PlusBit, Feature_isGFX10OnlyBit, },
  {Feature_HasImageInstsBit, Feature_HasExtendedImageInstsBit, Feature_isGFX9PlusBit, Feature_isGFX11OnlyBit, },
  {Feature_HasImageInstsBit, Feature_HasExtendedImageInstsBit, Feature_isGFX9PlusBit, Feature_isGFX12PlusBit, },
  {Feature_HasImageInstsBit, Feature_HasExtendedImageInstsBit, Feature_isGFX9PlusBit, Feature_isGFX6GFX7GFX8GFX9NotGFX90ABit, },
  {Feature_HasImageInstsBit, Feature_HasGFX10_AEncodingBit, Feature_isGFX10OnlyBit, Feature_isGFX6GFX7GFX8GFX9NotGFX90ABit, },
  {Feature_HasTransposeLoadF4F6InstsBit, Feature_isGFX1250PlusBit, Feature_isGFX12PlusBit, Feature_isWave32Bit, },
  {Feature_NotHasTrue16BitInstsBit, Feature_Has16BitInstsBit, Feature_HasCvtNormInstsBit, Feature_HasSDWA9Bit, },
  {Feature_NotHasTrue16BitInstsBit, Feature_Has16BitInstsBit, Feature_HasCvtNormInstsBit, Feature_isGFX10OnlyBit, },
  {Feature_NotHasTrue16BitInstsBit, Feature_Has16BitInstsBit, Feature_HasCvtNormInstsBit, Feature_isGFX8GFX9Bit, },
  {Feature_NotHasTrue16BitInstsBit, Feature_Has16BitInstsBit, Feature_isGFX9PlusBit, Feature_HasSDWA9Bit, },
  {Feature_NotHasTrue16BitInstsBit, Feature_Has16BitInstsBit, Feature_isGFX9PlusBit, Feature_isGFX10OnlyBit, },
  {Feature_NotHasTrue16BitInstsBit, Feature_Has16BitInstsBit, Feature_isGFX9PlusBit, Feature_isGFX8GFX9Bit, },
  {Feature_HasFP8ConversionInstsBit, Feature_HasFP8E5M3InstsBit, Feature_isGFX9PlusBit, Feature_isGFX125xOnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasFP8ConversionInstsBit, Feature_NotHasFP8E5M3InstsBit, Feature_isGFX9PlusBit, Feature_isGFX11OnlyBit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasFP8ConversionInstsBit, Feature_NotHasFP8E5M3InstsBit, Feature_isGFX9PlusBit, Feature_isGFX12Not12_50Bit, Feature_UseRealTrue16InstsBit, },
  {Feature_HasFP8ConversionInstsBit, Feature_NotHasFP8E5M3InstsBit, Feature_isGFX9PlusBit, Feature_isGFX8GFX9Bit, Feature_NotHasTrue16BitInstsBit, },
};

namespace {
  struct MatchEntry {
    uint16_t Mnemonic;
    uint16_t Opcode;
    uint16_t ConvertFn;
    uint16_t RequiredFeaturesIdx;
    uint16_t Classes[26];
    StringRef getMnemonic() const {
      return StringRef(MnemonicTable + Mnemonic + 1,
                       MnemonicTable[Mnemonic]);
    }
  };

  // Predicate for searching for an opcode.
  struct LessOpcode {
    bool operator()(const MatchEntry &LHS, StringRef RHS) {
      return LHS.getMnemonic() < RHS;
    }
    bool operator()(StringRef LHS, const MatchEntry &RHS) {
      return LHS < RHS.getMnemonic();
    }
    bool operator()(const MatchEntry &LHS, const MatchEntry &RHS) {
      return LHS.getMnemonic() < RHS.getMnemonic();
    }
  };
} // end anonymous namespace

static const MatchEntry MatchTable0[] = {
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 0 /* buffer_atomic_add */, AMDGPU::BUFFER_ATOMIC_ADD_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_OFFSET_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_OFFSET_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_IDXEN_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_IDXEN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_OFFEN_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_OFFEN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_BOTHEN_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_BOTHEN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 18 /* buffer_atomic_add_f32 */, AMDGPU::BUFFER_ATOMIC_ADD_F32_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_OFFSET_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_OFFSET_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_IDXEN_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_IDXEN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_OFFEN_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_OFFEN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_BOTHEN_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_BOTHEN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 40 /* buffer_atomic_add_f64 */, AMDGPU::BUFFER_ATOMIC_ADD_F64_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 62 /* buffer_atomic_add_u32 */, AMDGPU::BUFFER_ATOMIC_ADD_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 62 /* buffer_atomic_add_u32 */, AMDGPU::BUFFER_ATOMIC_ADD_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 62 /* buffer_atomic_add_u32 */, AMDGPU::BUFFER_ATOMIC_ADD_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 62 /* buffer_atomic_add_u32 */, AMDGPU::BUFFER_ATOMIC_ADD_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 62 /* buffer_atomic_add_u32 */, AMDGPU::BUFFER_ATOMIC_ADD_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 62 /* buffer_atomic_add_u32 */, AMDGPU::BUFFER_ATOMIC_ADD_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 62 /* buffer_atomic_add_u32 */, AMDGPU::BUFFER_ATOMIC_ADD_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 62 /* buffer_atomic_add_u32 */, AMDGPU::BUFFER_ATOMIC_ADD_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 62 /* buffer_atomic_add_u32 */, AMDGPU::BUFFER_ATOMIC_ADD_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 62 /* buffer_atomic_add_u32 */, AMDGPU::BUFFER_ATOMIC_ADD_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 62 /* buffer_atomic_add_u32 */, AMDGPU::BUFFER_ATOMIC_ADD_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 62 /* buffer_atomic_add_u32 */, AMDGPU::BUFFER_ATOMIC_ADD_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 62 /* buffer_atomic_add_u32 */, AMDGPU::BUFFER_ATOMIC_ADD_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 62 /* buffer_atomic_add_u32 */, AMDGPU::BUFFER_ATOMIC_ADD_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 62 /* buffer_atomic_add_u32 */, AMDGPU::BUFFER_ATOMIC_ADD_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 62 /* buffer_atomic_add_u32 */, AMDGPU::BUFFER_ATOMIC_ADD_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 84 /* buffer_atomic_add_u64 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 84 /* buffer_atomic_add_u64 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 84 /* buffer_atomic_add_u64 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 84 /* buffer_atomic_add_u64 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 84 /* buffer_atomic_add_u64 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 84 /* buffer_atomic_add_u64 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 84 /* buffer_atomic_add_u64 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 84 /* buffer_atomic_add_u64 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 84 /* buffer_atomic_add_u64 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 84 /* buffer_atomic_add_u64 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 84 /* buffer_atomic_add_u64 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 84 /* buffer_atomic_add_u64 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 84 /* buffer_atomic_add_u64 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 84 /* buffer_atomic_add_u64 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 84 /* buffer_atomic_add_u64 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 84 /* buffer_atomic_add_u64 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 106 /* buffer_atomic_add_x2 */, AMDGPU::BUFFER_ATOMIC_ADD_X2_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 127 /* buffer_atomic_and */, AMDGPU::BUFFER_ATOMIC_AND_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 145 /* buffer_atomic_and_b32 */, AMDGPU::BUFFER_ATOMIC_AND_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 145 /* buffer_atomic_and_b32 */, AMDGPU::BUFFER_ATOMIC_AND_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 145 /* buffer_atomic_and_b32 */, AMDGPU::BUFFER_ATOMIC_AND_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 145 /* buffer_atomic_and_b32 */, AMDGPU::BUFFER_ATOMIC_AND_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 145 /* buffer_atomic_and_b32 */, AMDGPU::BUFFER_ATOMIC_AND_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 145 /* buffer_atomic_and_b32 */, AMDGPU::BUFFER_ATOMIC_AND_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 145 /* buffer_atomic_and_b32 */, AMDGPU::BUFFER_ATOMIC_AND_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 145 /* buffer_atomic_and_b32 */, AMDGPU::BUFFER_ATOMIC_AND_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 145 /* buffer_atomic_and_b32 */, AMDGPU::BUFFER_ATOMIC_AND_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 145 /* buffer_atomic_and_b32 */, AMDGPU::BUFFER_ATOMIC_AND_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 145 /* buffer_atomic_and_b32 */, AMDGPU::BUFFER_ATOMIC_AND_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 145 /* buffer_atomic_and_b32 */, AMDGPU::BUFFER_ATOMIC_AND_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 145 /* buffer_atomic_and_b32 */, AMDGPU::BUFFER_ATOMIC_AND_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 145 /* buffer_atomic_and_b32 */, AMDGPU::BUFFER_ATOMIC_AND_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 145 /* buffer_atomic_and_b32 */, AMDGPU::BUFFER_ATOMIC_AND_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 145 /* buffer_atomic_and_b32 */, AMDGPU::BUFFER_ATOMIC_AND_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 167 /* buffer_atomic_and_b64 */, AMDGPU::BUFFER_ATOMIC_AND_X2_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 167 /* buffer_atomic_and_b64 */, AMDGPU::BUFFER_ATOMIC_AND_X2_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 167 /* buffer_atomic_and_b64 */, AMDGPU::BUFFER_ATOMIC_AND_X2_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 167 /* buffer_atomic_and_b64 */, AMDGPU::BUFFER_ATOMIC_AND_X2_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 167 /* buffer_atomic_and_b64 */, AMDGPU::BUFFER_ATOMIC_AND_X2_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 167 /* buffer_atomic_and_b64 */, AMDGPU::BUFFER_ATOMIC_AND_X2_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 167 /* buffer_atomic_and_b64 */, AMDGPU::BUFFER_ATOMIC_AND_X2_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 167 /* buffer_atomic_and_b64 */, AMDGPU::BUFFER_ATOMIC_AND_X2_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 167 /* buffer_atomic_and_b64 */, AMDGPU::BUFFER_ATOMIC_AND_X2_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 167 /* buffer_atomic_and_b64 */, AMDGPU::BUFFER_ATOMIC_AND_X2_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 167 /* buffer_atomic_and_b64 */, AMDGPU::BUFFER_ATOMIC_AND_X2_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 167 /* buffer_atomic_and_b64 */, AMDGPU::BUFFER_ATOMIC_AND_X2_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 167 /* buffer_atomic_and_b64 */, AMDGPU::BUFFER_ATOMIC_AND_X2_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 167 /* buffer_atomic_and_b64 */, AMDGPU::BUFFER_ATOMIC_AND_X2_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 167 /* buffer_atomic_and_b64 */, AMDGPU::BUFFER_ATOMIC_AND_X2_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 167 /* buffer_atomic_and_b64 */, AMDGPU::BUFFER_ATOMIC_AND_X2_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 189 /* buffer_atomic_and_x2 */, AMDGPU::BUFFER_ATOMIC_AND_X2_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 210 /* buffer_atomic_cmpswap */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 232 /* buffer_atomic_cmpswap_b32 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 232 /* buffer_atomic_cmpswap_b32 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 232 /* buffer_atomic_cmpswap_b32 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 232 /* buffer_atomic_cmpswap_b32 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 232 /* buffer_atomic_cmpswap_b32 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 232 /* buffer_atomic_cmpswap_b32 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 232 /* buffer_atomic_cmpswap_b32 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 232 /* buffer_atomic_cmpswap_b32 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 232 /* buffer_atomic_cmpswap_b32 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 232 /* buffer_atomic_cmpswap_b32 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 232 /* buffer_atomic_cmpswap_b32 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 232 /* buffer_atomic_cmpswap_b32 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 232 /* buffer_atomic_cmpswap_b32 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 232 /* buffer_atomic_cmpswap_b32 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 232 /* buffer_atomic_cmpswap_b32 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 232 /* buffer_atomic_cmpswap_b32 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 258 /* buffer_atomic_cmpswap_b64 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 258 /* buffer_atomic_cmpswap_b64 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 258 /* buffer_atomic_cmpswap_b64 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 258 /* buffer_atomic_cmpswap_b64 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 258 /* buffer_atomic_cmpswap_b64 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 258 /* buffer_atomic_cmpswap_b64 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 258 /* buffer_atomic_cmpswap_b64 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 258 /* buffer_atomic_cmpswap_b64 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 258 /* buffer_atomic_cmpswap_b64 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 258 /* buffer_atomic_cmpswap_b64 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 258 /* buffer_atomic_cmpswap_b64 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 258 /* buffer_atomic_cmpswap_b64 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 258 /* buffer_atomic_cmpswap_b64 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 258 /* buffer_atomic_cmpswap_b64 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 258 /* buffer_atomic_cmpswap_b64 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 258 /* buffer_atomic_cmpswap_b64 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 284 /* buffer_atomic_cmpswap_f32 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 284 /* buffer_atomic_cmpswap_f32 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 284 /* buffer_atomic_cmpswap_f32 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 284 /* buffer_atomic_cmpswap_f32 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 284 /* buffer_atomic_cmpswap_f32 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 284 /* buffer_atomic_cmpswap_f32 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 284 /* buffer_atomic_cmpswap_f32 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 284 /* buffer_atomic_cmpswap_f32 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 310 /* buffer_atomic_cmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_CMPSWAP_X2_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 335 /* buffer_atomic_cond_sub_u32 */, AMDGPU::BUFFER_ATOMIC_COND_SUB_U32_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 335 /* buffer_atomic_cond_sub_u32 */, AMDGPU::BUFFER_ATOMIC_COND_SUB_U32_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 335 /* buffer_atomic_cond_sub_u32 */, AMDGPU::BUFFER_ATOMIC_COND_SUB_U32_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 335 /* buffer_atomic_cond_sub_u32 */, AMDGPU::BUFFER_ATOMIC_COND_SUB_U32_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 335 /* buffer_atomic_cond_sub_u32 */, AMDGPU::BUFFER_ATOMIC_COND_SUB_U32_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 335 /* buffer_atomic_cond_sub_u32 */, AMDGPU::BUFFER_ATOMIC_COND_SUB_U32_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 335 /* buffer_atomic_cond_sub_u32 */, AMDGPU::BUFFER_ATOMIC_COND_SUB_U32_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 335 /* buffer_atomic_cond_sub_u32 */, AMDGPU::BUFFER_ATOMIC_COND_SUB_U32_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 362 /* buffer_atomic_csub */, AMDGPU::BUFFER_ATOMIC_CSUB_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX10Only, { MCK_VGPR_32, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 362 /* buffer_atomic_csub */, AMDGPU::BUFFER_ATOMIC_CSUB_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX10Only, { MCK_VGPR_32, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 362 /* buffer_atomic_csub */, AMDGPU::BUFFER_ATOMIC_CSUB_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 362 /* buffer_atomic_csub */, AMDGPU::BUFFER_ATOMIC_CSUB_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 362 /* buffer_atomic_csub */, AMDGPU::BUFFER_ATOMIC_CSUB_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 362 /* buffer_atomic_csub */, AMDGPU::BUFFER_ATOMIC_CSUB_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 362 /* buffer_atomic_csub */, AMDGPU::BUFFER_ATOMIC_CSUB_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 362 /* buffer_atomic_csub */, AMDGPU::BUFFER_ATOMIC_CSUB_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 381 /* buffer_atomic_csub_u32 */, AMDGPU::BUFFER_ATOMIC_CSUB_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX11Only, { MCK_VGPR_32, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 381 /* buffer_atomic_csub_u32 */, AMDGPU::BUFFER_ATOMIC_CSUB_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX11Only, { MCK_VGPR_32, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 381 /* buffer_atomic_csub_u32 */, AMDGPU::BUFFER_ATOMIC_CSUB_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 381 /* buffer_atomic_csub_u32 */, AMDGPU::BUFFER_ATOMIC_CSUB_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 381 /* buffer_atomic_csub_u32 */, AMDGPU::BUFFER_ATOMIC_CSUB_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 381 /* buffer_atomic_csub_u32 */, AMDGPU::BUFFER_ATOMIC_CSUB_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 381 /* buffer_atomic_csub_u32 */, AMDGPU::BUFFER_ATOMIC_CSUB_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 381 /* buffer_atomic_csub_u32 */, AMDGPU::BUFFER_ATOMIC_CSUB_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 404 /* buffer_atomic_dec */, AMDGPU::BUFFER_ATOMIC_DEC_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 422 /* buffer_atomic_dec_u32 */, AMDGPU::BUFFER_ATOMIC_DEC_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 422 /* buffer_atomic_dec_u32 */, AMDGPU::BUFFER_ATOMIC_DEC_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 422 /* buffer_atomic_dec_u32 */, AMDGPU::BUFFER_ATOMIC_DEC_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 422 /* buffer_atomic_dec_u32 */, AMDGPU::BUFFER_ATOMIC_DEC_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 422 /* buffer_atomic_dec_u32 */, AMDGPU::BUFFER_ATOMIC_DEC_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 422 /* buffer_atomic_dec_u32 */, AMDGPU::BUFFER_ATOMIC_DEC_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 422 /* buffer_atomic_dec_u32 */, AMDGPU::BUFFER_ATOMIC_DEC_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 422 /* buffer_atomic_dec_u32 */, AMDGPU::BUFFER_ATOMIC_DEC_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 422 /* buffer_atomic_dec_u32 */, AMDGPU::BUFFER_ATOMIC_DEC_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 422 /* buffer_atomic_dec_u32 */, AMDGPU::BUFFER_ATOMIC_DEC_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 422 /* buffer_atomic_dec_u32 */, AMDGPU::BUFFER_ATOMIC_DEC_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 422 /* buffer_atomic_dec_u32 */, AMDGPU::BUFFER_ATOMIC_DEC_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 422 /* buffer_atomic_dec_u32 */, AMDGPU::BUFFER_ATOMIC_DEC_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 422 /* buffer_atomic_dec_u32 */, AMDGPU::BUFFER_ATOMIC_DEC_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 422 /* buffer_atomic_dec_u32 */, AMDGPU::BUFFER_ATOMIC_DEC_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 422 /* buffer_atomic_dec_u32 */, AMDGPU::BUFFER_ATOMIC_DEC_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 444 /* buffer_atomic_dec_u64 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 444 /* buffer_atomic_dec_u64 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 444 /* buffer_atomic_dec_u64 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 444 /* buffer_atomic_dec_u64 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 444 /* buffer_atomic_dec_u64 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 444 /* buffer_atomic_dec_u64 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 444 /* buffer_atomic_dec_u64 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 444 /* buffer_atomic_dec_u64 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 444 /* buffer_atomic_dec_u64 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 444 /* buffer_atomic_dec_u64 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 444 /* buffer_atomic_dec_u64 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 444 /* buffer_atomic_dec_u64 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 444 /* buffer_atomic_dec_u64 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 444 /* buffer_atomic_dec_u64 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 444 /* buffer_atomic_dec_u64 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 444 /* buffer_atomic_dec_u64 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 466 /* buffer_atomic_dec_x2 */, AMDGPU::BUFFER_ATOMIC_DEC_X2_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 487 /* buffer_atomic_fcmpswap */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 487 /* buffer_atomic_fcmpswap */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 487 /* buffer_atomic_fcmpswap */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 487 /* buffer_atomic_fcmpswap */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 487 /* buffer_atomic_fcmpswap */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 487 /* buffer_atomic_fcmpswap */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 487 /* buffer_atomic_fcmpswap */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 487 /* buffer_atomic_fcmpswap */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 487 /* buffer_atomic_fcmpswap */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 487 /* buffer_atomic_fcmpswap */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 487 /* buffer_atomic_fcmpswap */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 487 /* buffer_atomic_fcmpswap */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 487 /* buffer_atomic_fcmpswap */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 487 /* buffer_atomic_fcmpswap */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 487 /* buffer_atomic_fcmpswap */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 487 /* buffer_atomic_fcmpswap */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 487 /* buffer_atomic_fcmpswap */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 487 /* buffer_atomic_fcmpswap */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 510 /* buffer_atomic_fcmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_X2_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10_isGFX10Only, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 510 /* buffer_atomic_fcmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_X2_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 510 /* buffer_atomic_fcmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_X2_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10_isGFX10Only, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 510 /* buffer_atomic_fcmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_X2_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 510 /* buffer_atomic_fcmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_X2_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10_isGFX10Only, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 510 /* buffer_atomic_fcmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_X2_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 510 /* buffer_atomic_fcmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_X2_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10_isGFX10Only, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 510 /* buffer_atomic_fcmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_X2_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 510 /* buffer_atomic_fcmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_X2_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10_isGFX10Only, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 510 /* buffer_atomic_fcmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_X2_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 510 /* buffer_atomic_fcmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_X2_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10_isGFX10Only, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 510 /* buffer_atomic_fcmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_X2_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 510 /* buffer_atomic_fcmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_X2_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 510 /* buffer_atomic_fcmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_X2_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 510 /* buffer_atomic_fcmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_X2_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10_isGFX10Only, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 510 /* buffer_atomic_fcmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_X2_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 510 /* buffer_atomic_fcmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_X2_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10_isGFX10Only, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 510 /* buffer_atomic_fcmpswap_x2 */, AMDGPU::BUFFER_ATOMIC_FCMPSWAP_X2_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 536 /* buffer_atomic_fmax */, AMDGPU::BUFFER_ATOMIC_FMAX_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 536 /* buffer_atomic_fmax */, AMDGPU::BUFFER_ATOMIC_FMAX_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 536 /* buffer_atomic_fmax */, AMDGPU::BUFFER_ATOMIC_FMAX_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 536 /* buffer_atomic_fmax */, AMDGPU::BUFFER_ATOMIC_FMAX_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 536 /* buffer_atomic_fmax */, AMDGPU::BUFFER_ATOMIC_FMAX_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 536 /* buffer_atomic_fmax */, AMDGPU::BUFFER_ATOMIC_FMAX_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 536 /* buffer_atomic_fmax */, AMDGPU::BUFFER_ATOMIC_FMAX_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 536 /* buffer_atomic_fmax */, AMDGPU::BUFFER_ATOMIC_FMAX_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 536 /* buffer_atomic_fmax */, AMDGPU::BUFFER_ATOMIC_FMAX_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 536 /* buffer_atomic_fmax */, AMDGPU::BUFFER_ATOMIC_FMAX_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 536 /* buffer_atomic_fmax */, AMDGPU::BUFFER_ATOMIC_FMAX_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 536 /* buffer_atomic_fmax */, AMDGPU::BUFFER_ATOMIC_FMAX_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 536 /* buffer_atomic_fmax */, AMDGPU::BUFFER_ATOMIC_FMAX_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 536 /* buffer_atomic_fmax */, AMDGPU::BUFFER_ATOMIC_FMAX_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 536 /* buffer_atomic_fmax */, AMDGPU::BUFFER_ATOMIC_FMAX_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 536 /* buffer_atomic_fmax */, AMDGPU::BUFFER_ATOMIC_FMAX_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 536 /* buffer_atomic_fmax */, AMDGPU::BUFFER_ATOMIC_FMAX_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 536 /* buffer_atomic_fmax */, AMDGPU::BUFFER_ATOMIC_FMAX_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 555 /* buffer_atomic_fmax_x2 */, AMDGPU::BUFFER_ATOMIC_FMAX_X2_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 555 /* buffer_atomic_fmax_x2 */, AMDGPU::BUFFER_ATOMIC_FMAX_X2_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 555 /* buffer_atomic_fmax_x2 */, AMDGPU::BUFFER_ATOMIC_FMAX_X2_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 555 /* buffer_atomic_fmax_x2 */, AMDGPU::BUFFER_ATOMIC_FMAX_X2_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 555 /* buffer_atomic_fmax_x2 */, AMDGPU::BUFFER_ATOMIC_FMAX_X2_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 555 /* buffer_atomic_fmax_x2 */, AMDGPU::BUFFER_ATOMIC_FMAX_X2_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 555 /* buffer_atomic_fmax_x2 */, AMDGPU::BUFFER_ATOMIC_FMAX_X2_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 555 /* buffer_atomic_fmax_x2 */, AMDGPU::BUFFER_ATOMIC_FMAX_X2_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 555 /* buffer_atomic_fmax_x2 */, AMDGPU::BUFFER_ATOMIC_FMAX_X2_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 555 /* buffer_atomic_fmax_x2 */, AMDGPU::BUFFER_ATOMIC_FMAX_X2_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 555 /* buffer_atomic_fmax_x2 */, AMDGPU::BUFFER_ATOMIC_FMAX_X2_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 555 /* buffer_atomic_fmax_x2 */, AMDGPU::BUFFER_ATOMIC_FMAX_X2_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 555 /* buffer_atomic_fmax_x2 */, AMDGPU::BUFFER_ATOMIC_FMAX_X2_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 555 /* buffer_atomic_fmax_x2 */, AMDGPU::BUFFER_ATOMIC_FMAX_X2_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 555 /* buffer_atomic_fmax_x2 */, AMDGPU::BUFFER_ATOMIC_FMAX_X2_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 555 /* buffer_atomic_fmax_x2 */, AMDGPU::BUFFER_ATOMIC_FMAX_X2_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 555 /* buffer_atomic_fmax_x2 */, AMDGPU::BUFFER_ATOMIC_FMAX_X2_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 555 /* buffer_atomic_fmax_x2 */, AMDGPU::BUFFER_ATOMIC_FMAX_X2_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 577 /* buffer_atomic_fmin */, AMDGPU::BUFFER_ATOMIC_FMIN_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 577 /* buffer_atomic_fmin */, AMDGPU::BUFFER_ATOMIC_FMIN_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 577 /* buffer_atomic_fmin */, AMDGPU::BUFFER_ATOMIC_FMIN_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 577 /* buffer_atomic_fmin */, AMDGPU::BUFFER_ATOMIC_FMIN_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 577 /* buffer_atomic_fmin */, AMDGPU::BUFFER_ATOMIC_FMIN_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 577 /* buffer_atomic_fmin */, AMDGPU::BUFFER_ATOMIC_FMIN_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 577 /* buffer_atomic_fmin */, AMDGPU::BUFFER_ATOMIC_FMIN_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 577 /* buffer_atomic_fmin */, AMDGPU::BUFFER_ATOMIC_FMIN_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 577 /* buffer_atomic_fmin */, AMDGPU::BUFFER_ATOMIC_FMIN_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 577 /* buffer_atomic_fmin */, AMDGPU::BUFFER_ATOMIC_FMIN_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 577 /* buffer_atomic_fmin */, AMDGPU::BUFFER_ATOMIC_FMIN_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 577 /* buffer_atomic_fmin */, AMDGPU::BUFFER_ATOMIC_FMIN_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 577 /* buffer_atomic_fmin */, AMDGPU::BUFFER_ATOMIC_FMIN_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 577 /* buffer_atomic_fmin */, AMDGPU::BUFFER_ATOMIC_FMIN_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 577 /* buffer_atomic_fmin */, AMDGPU::BUFFER_ATOMIC_FMIN_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 577 /* buffer_atomic_fmin */, AMDGPU::BUFFER_ATOMIC_FMIN_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 577 /* buffer_atomic_fmin */, AMDGPU::BUFFER_ATOMIC_FMIN_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 577 /* buffer_atomic_fmin */, AMDGPU::BUFFER_ATOMIC_FMIN_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 596 /* buffer_atomic_fmin_x2 */, AMDGPU::BUFFER_ATOMIC_FMIN_X2_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 596 /* buffer_atomic_fmin_x2 */, AMDGPU::BUFFER_ATOMIC_FMIN_X2_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 596 /* buffer_atomic_fmin_x2 */, AMDGPU::BUFFER_ATOMIC_FMIN_X2_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 596 /* buffer_atomic_fmin_x2 */, AMDGPU::BUFFER_ATOMIC_FMIN_X2_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 596 /* buffer_atomic_fmin_x2 */, AMDGPU::BUFFER_ATOMIC_FMIN_X2_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 596 /* buffer_atomic_fmin_x2 */, AMDGPU::BUFFER_ATOMIC_FMIN_X2_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 596 /* buffer_atomic_fmin_x2 */, AMDGPU::BUFFER_ATOMIC_FMIN_X2_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 596 /* buffer_atomic_fmin_x2 */, AMDGPU::BUFFER_ATOMIC_FMIN_X2_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 596 /* buffer_atomic_fmin_x2 */, AMDGPU::BUFFER_ATOMIC_FMIN_X2_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 596 /* buffer_atomic_fmin_x2 */, AMDGPU::BUFFER_ATOMIC_FMIN_X2_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 596 /* buffer_atomic_fmin_x2 */, AMDGPU::BUFFER_ATOMIC_FMIN_X2_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 596 /* buffer_atomic_fmin_x2 */, AMDGPU::BUFFER_ATOMIC_FMIN_X2_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 596 /* buffer_atomic_fmin_x2 */, AMDGPU::BUFFER_ATOMIC_FMIN_X2_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 596 /* buffer_atomic_fmin_x2 */, AMDGPU::BUFFER_ATOMIC_FMIN_X2_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 596 /* buffer_atomic_fmin_x2 */, AMDGPU::BUFFER_ATOMIC_FMIN_X2_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 596 /* buffer_atomic_fmin_x2 */, AMDGPU::BUFFER_ATOMIC_FMIN_X2_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 596 /* buffer_atomic_fmin_x2 */, AMDGPU::BUFFER_ATOMIC_FMIN_X2_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 596 /* buffer_atomic_fmin_x2 */, AMDGPU::BUFFER_ATOMIC_FMIN_X2_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 618 /* buffer_atomic_inc */, AMDGPU::BUFFER_ATOMIC_INC_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 636 /* buffer_atomic_inc_u32 */, AMDGPU::BUFFER_ATOMIC_INC_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 636 /* buffer_atomic_inc_u32 */, AMDGPU::BUFFER_ATOMIC_INC_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 636 /* buffer_atomic_inc_u32 */, AMDGPU::BUFFER_ATOMIC_INC_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 636 /* buffer_atomic_inc_u32 */, AMDGPU::BUFFER_ATOMIC_INC_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 636 /* buffer_atomic_inc_u32 */, AMDGPU::BUFFER_ATOMIC_INC_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 636 /* buffer_atomic_inc_u32 */, AMDGPU::BUFFER_ATOMIC_INC_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 636 /* buffer_atomic_inc_u32 */, AMDGPU::BUFFER_ATOMIC_INC_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 636 /* buffer_atomic_inc_u32 */, AMDGPU::BUFFER_ATOMIC_INC_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 636 /* buffer_atomic_inc_u32 */, AMDGPU::BUFFER_ATOMIC_INC_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 636 /* buffer_atomic_inc_u32 */, AMDGPU::BUFFER_ATOMIC_INC_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 636 /* buffer_atomic_inc_u32 */, AMDGPU::BUFFER_ATOMIC_INC_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 636 /* buffer_atomic_inc_u32 */, AMDGPU::BUFFER_ATOMIC_INC_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 636 /* buffer_atomic_inc_u32 */, AMDGPU::BUFFER_ATOMIC_INC_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 636 /* buffer_atomic_inc_u32 */, AMDGPU::BUFFER_ATOMIC_INC_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 636 /* buffer_atomic_inc_u32 */, AMDGPU::BUFFER_ATOMIC_INC_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 636 /* buffer_atomic_inc_u32 */, AMDGPU::BUFFER_ATOMIC_INC_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 658 /* buffer_atomic_inc_u64 */, AMDGPU::BUFFER_ATOMIC_INC_X2_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 658 /* buffer_atomic_inc_u64 */, AMDGPU::BUFFER_ATOMIC_INC_X2_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 658 /* buffer_atomic_inc_u64 */, AMDGPU::BUFFER_ATOMIC_INC_X2_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 658 /* buffer_atomic_inc_u64 */, AMDGPU::BUFFER_ATOMIC_INC_X2_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 658 /* buffer_atomic_inc_u64 */, AMDGPU::BUFFER_ATOMIC_INC_X2_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 658 /* buffer_atomic_inc_u64 */, AMDGPU::BUFFER_ATOMIC_INC_X2_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 658 /* buffer_atomic_inc_u64 */, AMDGPU::BUFFER_ATOMIC_INC_X2_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 658 /* buffer_atomic_inc_u64 */, AMDGPU::BUFFER_ATOMIC_INC_X2_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 658 /* buffer_atomic_inc_u64 */, AMDGPU::BUFFER_ATOMIC_INC_X2_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 658 /* buffer_atomic_inc_u64 */, AMDGPU::BUFFER_ATOMIC_INC_X2_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 658 /* buffer_atomic_inc_u64 */, AMDGPU::BUFFER_ATOMIC_INC_X2_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 658 /* buffer_atomic_inc_u64 */, AMDGPU::BUFFER_ATOMIC_INC_X2_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 658 /* buffer_atomic_inc_u64 */, AMDGPU::BUFFER_ATOMIC_INC_X2_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 658 /* buffer_atomic_inc_u64 */, AMDGPU::BUFFER_ATOMIC_INC_X2_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 658 /* buffer_atomic_inc_u64 */, AMDGPU::BUFFER_ATOMIC_INC_X2_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 658 /* buffer_atomic_inc_u64 */, AMDGPU::BUFFER_ATOMIC_INC_X2_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 680 /* buffer_atomic_inc_x2 */, AMDGPU::BUFFER_ATOMIC_INC_X2_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 701 /* buffer_atomic_max_f32 */, AMDGPU::BUFFER_ATOMIC_FMAX_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 701 /* buffer_atomic_max_f32 */, AMDGPU::BUFFER_ATOMIC_FMAX_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 701 /* buffer_atomic_max_f32 */, AMDGPU::BUFFER_ATOMIC_FMAX_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 701 /* buffer_atomic_max_f32 */, AMDGPU::BUFFER_ATOMIC_FMAX_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 701 /* buffer_atomic_max_f32 */, AMDGPU::BUFFER_ATOMIC_FMAX_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 701 /* buffer_atomic_max_f32 */, AMDGPU::BUFFER_ATOMIC_FMAX_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 701 /* buffer_atomic_max_f32 */, AMDGPU::BUFFER_ATOMIC_FMAX_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 701 /* buffer_atomic_max_f32 */, AMDGPU::BUFFER_ATOMIC_FMAX_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_OFFSET_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_OFFSET_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_IDXEN_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_IDXEN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_OFFEN_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_OFFEN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_BOTHEN_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_BOTHEN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 723 /* buffer_atomic_max_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 745 /* buffer_atomic_max_i32 */, AMDGPU::BUFFER_ATOMIC_SMAX_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 745 /* buffer_atomic_max_i32 */, AMDGPU::BUFFER_ATOMIC_SMAX_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 745 /* buffer_atomic_max_i32 */, AMDGPU::BUFFER_ATOMIC_SMAX_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 745 /* buffer_atomic_max_i32 */, AMDGPU::BUFFER_ATOMIC_SMAX_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 745 /* buffer_atomic_max_i32 */, AMDGPU::BUFFER_ATOMIC_SMAX_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 745 /* buffer_atomic_max_i32 */, AMDGPU::BUFFER_ATOMIC_SMAX_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 745 /* buffer_atomic_max_i32 */, AMDGPU::BUFFER_ATOMIC_SMAX_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 745 /* buffer_atomic_max_i32 */, AMDGPU::BUFFER_ATOMIC_SMAX_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 745 /* buffer_atomic_max_i32 */, AMDGPU::BUFFER_ATOMIC_SMAX_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 745 /* buffer_atomic_max_i32 */, AMDGPU::BUFFER_ATOMIC_SMAX_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 745 /* buffer_atomic_max_i32 */, AMDGPU::BUFFER_ATOMIC_SMAX_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 745 /* buffer_atomic_max_i32 */, AMDGPU::BUFFER_ATOMIC_SMAX_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 745 /* buffer_atomic_max_i32 */, AMDGPU::BUFFER_ATOMIC_SMAX_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 745 /* buffer_atomic_max_i32 */, AMDGPU::BUFFER_ATOMIC_SMAX_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 745 /* buffer_atomic_max_i32 */, AMDGPU::BUFFER_ATOMIC_SMAX_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 745 /* buffer_atomic_max_i32 */, AMDGPU::BUFFER_ATOMIC_SMAX_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 767 /* buffer_atomic_max_i64 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 767 /* buffer_atomic_max_i64 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 767 /* buffer_atomic_max_i64 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 767 /* buffer_atomic_max_i64 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 767 /* buffer_atomic_max_i64 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 767 /* buffer_atomic_max_i64 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 767 /* buffer_atomic_max_i64 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 767 /* buffer_atomic_max_i64 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 767 /* buffer_atomic_max_i64 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 767 /* buffer_atomic_max_i64 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 767 /* buffer_atomic_max_i64 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 767 /* buffer_atomic_max_i64 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 767 /* buffer_atomic_max_i64 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 767 /* buffer_atomic_max_i64 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 767 /* buffer_atomic_max_i64 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 767 /* buffer_atomic_max_i64 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 789 /* buffer_atomic_max_num_f32 */, AMDGPU::BUFFER_ATOMIC_FMAX_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 789 /* buffer_atomic_max_num_f32 */, AMDGPU::BUFFER_ATOMIC_FMAX_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 789 /* buffer_atomic_max_num_f32 */, AMDGPU::BUFFER_ATOMIC_FMAX_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 789 /* buffer_atomic_max_num_f32 */, AMDGPU::BUFFER_ATOMIC_FMAX_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 789 /* buffer_atomic_max_num_f32 */, AMDGPU::BUFFER_ATOMIC_FMAX_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 789 /* buffer_atomic_max_num_f32 */, AMDGPU::BUFFER_ATOMIC_FMAX_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 789 /* buffer_atomic_max_num_f32 */, AMDGPU::BUFFER_ATOMIC_FMAX_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 789 /* buffer_atomic_max_num_f32 */, AMDGPU::BUFFER_ATOMIC_FMAX_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 815 /* buffer_atomic_max_num_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 815 /* buffer_atomic_max_num_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 815 /* buffer_atomic_max_num_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 815 /* buffer_atomic_max_num_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 815 /* buffer_atomic_max_num_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 815 /* buffer_atomic_max_num_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 815 /* buffer_atomic_max_num_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 815 /* buffer_atomic_max_num_f64 */, AMDGPU::BUFFER_ATOMIC_MAX_F64_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 841 /* buffer_atomic_max_u32 */, AMDGPU::BUFFER_ATOMIC_UMAX_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 841 /* buffer_atomic_max_u32 */, AMDGPU::BUFFER_ATOMIC_UMAX_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 841 /* buffer_atomic_max_u32 */, AMDGPU::BUFFER_ATOMIC_UMAX_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 841 /* buffer_atomic_max_u32 */, AMDGPU::BUFFER_ATOMIC_UMAX_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 841 /* buffer_atomic_max_u32 */, AMDGPU::BUFFER_ATOMIC_UMAX_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 841 /* buffer_atomic_max_u32 */, AMDGPU::BUFFER_ATOMIC_UMAX_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 841 /* buffer_atomic_max_u32 */, AMDGPU::BUFFER_ATOMIC_UMAX_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 841 /* buffer_atomic_max_u32 */, AMDGPU::BUFFER_ATOMIC_UMAX_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 841 /* buffer_atomic_max_u32 */, AMDGPU::BUFFER_ATOMIC_UMAX_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 841 /* buffer_atomic_max_u32 */, AMDGPU::BUFFER_ATOMIC_UMAX_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 841 /* buffer_atomic_max_u32 */, AMDGPU::BUFFER_ATOMIC_UMAX_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 841 /* buffer_atomic_max_u32 */, AMDGPU::BUFFER_ATOMIC_UMAX_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 841 /* buffer_atomic_max_u32 */, AMDGPU::BUFFER_ATOMIC_UMAX_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 841 /* buffer_atomic_max_u32 */, AMDGPU::BUFFER_ATOMIC_UMAX_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 841 /* buffer_atomic_max_u32 */, AMDGPU::BUFFER_ATOMIC_UMAX_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 841 /* buffer_atomic_max_u32 */, AMDGPU::BUFFER_ATOMIC_UMAX_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 863 /* buffer_atomic_max_u64 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 863 /* buffer_atomic_max_u64 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 863 /* buffer_atomic_max_u64 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 863 /* buffer_atomic_max_u64 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 863 /* buffer_atomic_max_u64 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 863 /* buffer_atomic_max_u64 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 863 /* buffer_atomic_max_u64 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 863 /* buffer_atomic_max_u64 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 863 /* buffer_atomic_max_u64 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 863 /* buffer_atomic_max_u64 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 863 /* buffer_atomic_max_u64 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 863 /* buffer_atomic_max_u64 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 863 /* buffer_atomic_max_u64 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 863 /* buffer_atomic_max_u64 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 863 /* buffer_atomic_max_u64 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 863 /* buffer_atomic_max_u64 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 885 /* buffer_atomic_min_f32 */, AMDGPU::BUFFER_ATOMIC_FMIN_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 885 /* buffer_atomic_min_f32 */, AMDGPU::BUFFER_ATOMIC_FMIN_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 885 /* buffer_atomic_min_f32 */, AMDGPU::BUFFER_ATOMIC_FMIN_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 885 /* buffer_atomic_min_f32 */, AMDGPU::BUFFER_ATOMIC_FMIN_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 885 /* buffer_atomic_min_f32 */, AMDGPU::BUFFER_ATOMIC_FMIN_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 885 /* buffer_atomic_min_f32 */, AMDGPU::BUFFER_ATOMIC_FMIN_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 885 /* buffer_atomic_min_f32 */, AMDGPU::BUFFER_ATOMIC_FMIN_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 885 /* buffer_atomic_min_f32 */, AMDGPU::BUFFER_ATOMIC_FMIN_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_OFFSET_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_OFFSET_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_IDXEN_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_IDXEN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_OFFEN_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_OFFEN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_BOTHEN_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_BOTHEN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 907 /* buffer_atomic_min_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 929 /* buffer_atomic_min_i32 */, AMDGPU::BUFFER_ATOMIC_SMIN_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 929 /* buffer_atomic_min_i32 */, AMDGPU::BUFFER_ATOMIC_SMIN_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 929 /* buffer_atomic_min_i32 */, AMDGPU::BUFFER_ATOMIC_SMIN_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 929 /* buffer_atomic_min_i32 */, AMDGPU::BUFFER_ATOMIC_SMIN_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 929 /* buffer_atomic_min_i32 */, AMDGPU::BUFFER_ATOMIC_SMIN_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 929 /* buffer_atomic_min_i32 */, AMDGPU::BUFFER_ATOMIC_SMIN_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 929 /* buffer_atomic_min_i32 */, AMDGPU::BUFFER_ATOMIC_SMIN_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 929 /* buffer_atomic_min_i32 */, AMDGPU::BUFFER_ATOMIC_SMIN_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 929 /* buffer_atomic_min_i32 */, AMDGPU::BUFFER_ATOMIC_SMIN_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 929 /* buffer_atomic_min_i32 */, AMDGPU::BUFFER_ATOMIC_SMIN_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 929 /* buffer_atomic_min_i32 */, AMDGPU::BUFFER_ATOMIC_SMIN_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 929 /* buffer_atomic_min_i32 */, AMDGPU::BUFFER_ATOMIC_SMIN_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 929 /* buffer_atomic_min_i32 */, AMDGPU::BUFFER_ATOMIC_SMIN_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 929 /* buffer_atomic_min_i32 */, AMDGPU::BUFFER_ATOMIC_SMIN_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 929 /* buffer_atomic_min_i32 */, AMDGPU::BUFFER_ATOMIC_SMIN_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 929 /* buffer_atomic_min_i32 */, AMDGPU::BUFFER_ATOMIC_SMIN_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 951 /* buffer_atomic_min_i64 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 951 /* buffer_atomic_min_i64 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 951 /* buffer_atomic_min_i64 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 951 /* buffer_atomic_min_i64 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 951 /* buffer_atomic_min_i64 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 951 /* buffer_atomic_min_i64 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 951 /* buffer_atomic_min_i64 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 951 /* buffer_atomic_min_i64 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 951 /* buffer_atomic_min_i64 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 951 /* buffer_atomic_min_i64 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 951 /* buffer_atomic_min_i64 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 951 /* buffer_atomic_min_i64 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 951 /* buffer_atomic_min_i64 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 951 /* buffer_atomic_min_i64 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 951 /* buffer_atomic_min_i64 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 951 /* buffer_atomic_min_i64 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 973 /* buffer_atomic_min_num_f32 */, AMDGPU::BUFFER_ATOMIC_FMIN_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 973 /* buffer_atomic_min_num_f32 */, AMDGPU::BUFFER_ATOMIC_FMIN_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 973 /* buffer_atomic_min_num_f32 */, AMDGPU::BUFFER_ATOMIC_FMIN_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 973 /* buffer_atomic_min_num_f32 */, AMDGPU::BUFFER_ATOMIC_FMIN_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 973 /* buffer_atomic_min_num_f32 */, AMDGPU::BUFFER_ATOMIC_FMIN_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 973 /* buffer_atomic_min_num_f32 */, AMDGPU::BUFFER_ATOMIC_FMIN_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 973 /* buffer_atomic_min_num_f32 */, AMDGPU::BUFFER_ATOMIC_FMIN_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 973 /* buffer_atomic_min_num_f32 */, AMDGPU::BUFFER_ATOMIC_FMIN_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 999 /* buffer_atomic_min_num_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 999 /* buffer_atomic_min_num_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 999 /* buffer_atomic_min_num_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 999 /* buffer_atomic_min_num_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 999 /* buffer_atomic_min_num_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 999 /* buffer_atomic_min_num_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 999 /* buffer_atomic_min_num_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 999 /* buffer_atomic_min_num_f64 */, AMDGPU::BUFFER_ATOMIC_MIN_F64_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1025 /* buffer_atomic_min_u32 */, AMDGPU::BUFFER_ATOMIC_UMIN_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 1025 /* buffer_atomic_min_u32 */, AMDGPU::BUFFER_ATOMIC_UMIN_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1025 /* buffer_atomic_min_u32 */, AMDGPU::BUFFER_ATOMIC_UMIN_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1025 /* buffer_atomic_min_u32 */, AMDGPU::BUFFER_ATOMIC_UMIN_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1025 /* buffer_atomic_min_u32 */, AMDGPU::BUFFER_ATOMIC_UMIN_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1025 /* buffer_atomic_min_u32 */, AMDGPU::BUFFER_ATOMIC_UMIN_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1025 /* buffer_atomic_min_u32 */, AMDGPU::BUFFER_ATOMIC_UMIN_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1025 /* buffer_atomic_min_u32 */, AMDGPU::BUFFER_ATOMIC_UMIN_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1025 /* buffer_atomic_min_u32 */, AMDGPU::BUFFER_ATOMIC_UMIN_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1025 /* buffer_atomic_min_u32 */, AMDGPU::BUFFER_ATOMIC_UMIN_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1025 /* buffer_atomic_min_u32 */, AMDGPU::BUFFER_ATOMIC_UMIN_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1025 /* buffer_atomic_min_u32 */, AMDGPU::BUFFER_ATOMIC_UMIN_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1025 /* buffer_atomic_min_u32 */, AMDGPU::BUFFER_ATOMIC_UMIN_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1025 /* buffer_atomic_min_u32 */, AMDGPU::BUFFER_ATOMIC_UMIN_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1025 /* buffer_atomic_min_u32 */, AMDGPU::BUFFER_ATOMIC_UMIN_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1025 /* buffer_atomic_min_u32 */, AMDGPU::BUFFER_ATOMIC_UMIN_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1047 /* buffer_atomic_min_u64 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 1047 /* buffer_atomic_min_u64 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1047 /* buffer_atomic_min_u64 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1047 /* buffer_atomic_min_u64 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1047 /* buffer_atomic_min_u64 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1047 /* buffer_atomic_min_u64 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1047 /* buffer_atomic_min_u64 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1047 /* buffer_atomic_min_u64 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1047 /* buffer_atomic_min_u64 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1047 /* buffer_atomic_min_u64 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1047 /* buffer_atomic_min_u64 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1047 /* buffer_atomic_min_u64 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1047 /* buffer_atomic_min_u64 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1047 /* buffer_atomic_min_u64 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1047 /* buffer_atomic_min_u64 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1047 /* buffer_atomic_min_u64 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1069 /* buffer_atomic_or */, AMDGPU::BUFFER_ATOMIC_OR_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1086 /* buffer_atomic_or_b32 */, AMDGPU::BUFFER_ATOMIC_OR_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 1086 /* buffer_atomic_or_b32 */, AMDGPU::BUFFER_ATOMIC_OR_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1086 /* buffer_atomic_or_b32 */, AMDGPU::BUFFER_ATOMIC_OR_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1086 /* buffer_atomic_or_b32 */, AMDGPU::BUFFER_ATOMIC_OR_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1086 /* buffer_atomic_or_b32 */, AMDGPU::BUFFER_ATOMIC_OR_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1086 /* buffer_atomic_or_b32 */, AMDGPU::BUFFER_ATOMIC_OR_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1086 /* buffer_atomic_or_b32 */, AMDGPU::BUFFER_ATOMIC_OR_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1086 /* buffer_atomic_or_b32 */, AMDGPU::BUFFER_ATOMIC_OR_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1086 /* buffer_atomic_or_b32 */, AMDGPU::BUFFER_ATOMIC_OR_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1086 /* buffer_atomic_or_b32 */, AMDGPU::BUFFER_ATOMIC_OR_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1086 /* buffer_atomic_or_b32 */, AMDGPU::BUFFER_ATOMIC_OR_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1086 /* buffer_atomic_or_b32 */, AMDGPU::BUFFER_ATOMIC_OR_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1086 /* buffer_atomic_or_b32 */, AMDGPU::BUFFER_ATOMIC_OR_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1086 /* buffer_atomic_or_b32 */, AMDGPU::BUFFER_ATOMIC_OR_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1086 /* buffer_atomic_or_b32 */, AMDGPU::BUFFER_ATOMIC_OR_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1086 /* buffer_atomic_or_b32 */, AMDGPU::BUFFER_ATOMIC_OR_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1107 /* buffer_atomic_or_b64 */, AMDGPU::BUFFER_ATOMIC_OR_X2_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 1107 /* buffer_atomic_or_b64 */, AMDGPU::BUFFER_ATOMIC_OR_X2_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1107 /* buffer_atomic_or_b64 */, AMDGPU::BUFFER_ATOMIC_OR_X2_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1107 /* buffer_atomic_or_b64 */, AMDGPU::BUFFER_ATOMIC_OR_X2_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1107 /* buffer_atomic_or_b64 */, AMDGPU::BUFFER_ATOMIC_OR_X2_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1107 /* buffer_atomic_or_b64 */, AMDGPU::BUFFER_ATOMIC_OR_X2_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1107 /* buffer_atomic_or_b64 */, AMDGPU::BUFFER_ATOMIC_OR_X2_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1107 /* buffer_atomic_or_b64 */, AMDGPU::BUFFER_ATOMIC_OR_X2_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1107 /* buffer_atomic_or_b64 */, AMDGPU::BUFFER_ATOMIC_OR_X2_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1107 /* buffer_atomic_or_b64 */, AMDGPU::BUFFER_ATOMIC_OR_X2_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1107 /* buffer_atomic_or_b64 */, AMDGPU::BUFFER_ATOMIC_OR_X2_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1107 /* buffer_atomic_or_b64 */, AMDGPU::BUFFER_ATOMIC_OR_X2_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1107 /* buffer_atomic_or_b64 */, AMDGPU::BUFFER_ATOMIC_OR_X2_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1107 /* buffer_atomic_or_b64 */, AMDGPU::BUFFER_ATOMIC_OR_X2_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1107 /* buffer_atomic_or_b64 */, AMDGPU::BUFFER_ATOMIC_OR_X2_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1107 /* buffer_atomic_or_b64 */, AMDGPU::BUFFER_ATOMIC_OR_X2_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1128 /* buffer_atomic_or_x2 */, AMDGPU::BUFFER_ATOMIC_OR_X2_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_OFFSET_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_OFFSET_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_IDXEN_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_IDXEN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_OFFEN_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_OFFEN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_BOTHEN_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_BOTHEN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1148 /* buffer_atomic_pk_add_bf16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_BF16_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_OFFSET_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_OFFSET_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_IDXEN_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_IDXEN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_OFFEN_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_OFFEN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_BOTHEN_RTN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_BOTHEN_gfx940, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1174 /* buffer_atomic_pk_add_f16 */, AMDGPU::BUFFER_ATOMIC_PK_ADD_F16_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1199 /* buffer_atomic_smax */, AMDGPU::BUFFER_ATOMIC_SMAX_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1218 /* buffer_atomic_smax_x2 */, AMDGPU::BUFFER_ATOMIC_SMAX_X2_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1240 /* buffer_atomic_smin */, AMDGPU::BUFFER_ATOMIC_SMIN_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1259 /* buffer_atomic_smin_x2 */, AMDGPU::BUFFER_ATOMIC_SMIN_X2_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1281 /* buffer_atomic_sub */, AMDGPU::BUFFER_ATOMIC_SUB_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, AMDGPU::BUFFER_ATOMIC_CSUB_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX12Only, { MCK_VGPR_32, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, AMDGPU::BUFFER_ATOMIC_CSUB_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX12Only, { MCK_VGPR_32, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, AMDGPU::BUFFER_ATOMIC_CSUB_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, AMDGPU::BUFFER_ATOMIC_CSUB_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, AMDGPU::BUFFER_ATOMIC_CSUB_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, AMDGPU::BUFFER_ATOMIC_CSUB_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, AMDGPU::BUFFER_ATOMIC_CSUB_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, AMDGPU::BUFFER_ATOMIC_CSUB_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_HasGFX10_BEncoding_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1327 /* buffer_atomic_sub_u32 */, AMDGPU::BUFFER_ATOMIC_SUB_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 1327 /* buffer_atomic_sub_u32 */, AMDGPU::BUFFER_ATOMIC_SUB_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1327 /* buffer_atomic_sub_u32 */, AMDGPU::BUFFER_ATOMIC_SUB_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1327 /* buffer_atomic_sub_u32 */, AMDGPU::BUFFER_ATOMIC_SUB_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1327 /* buffer_atomic_sub_u32 */, AMDGPU::BUFFER_ATOMIC_SUB_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1327 /* buffer_atomic_sub_u32 */, AMDGPU::BUFFER_ATOMIC_SUB_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1327 /* buffer_atomic_sub_u32 */, AMDGPU::BUFFER_ATOMIC_SUB_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1327 /* buffer_atomic_sub_u32 */, AMDGPU::BUFFER_ATOMIC_SUB_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1327 /* buffer_atomic_sub_u32 */, AMDGPU::BUFFER_ATOMIC_SUB_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1327 /* buffer_atomic_sub_u32 */, AMDGPU::BUFFER_ATOMIC_SUB_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1327 /* buffer_atomic_sub_u32 */, AMDGPU::BUFFER_ATOMIC_SUB_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1327 /* buffer_atomic_sub_u32 */, AMDGPU::BUFFER_ATOMIC_SUB_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1327 /* buffer_atomic_sub_u32 */, AMDGPU::BUFFER_ATOMIC_SUB_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1327 /* buffer_atomic_sub_u32 */, AMDGPU::BUFFER_ATOMIC_SUB_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1327 /* buffer_atomic_sub_u32 */, AMDGPU::BUFFER_ATOMIC_SUB_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1327 /* buffer_atomic_sub_u32 */, AMDGPU::BUFFER_ATOMIC_SUB_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1349 /* buffer_atomic_sub_u64 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 1349 /* buffer_atomic_sub_u64 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1349 /* buffer_atomic_sub_u64 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1349 /* buffer_atomic_sub_u64 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1349 /* buffer_atomic_sub_u64 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1349 /* buffer_atomic_sub_u64 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1349 /* buffer_atomic_sub_u64 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1349 /* buffer_atomic_sub_u64 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1349 /* buffer_atomic_sub_u64 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1349 /* buffer_atomic_sub_u64 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1349 /* buffer_atomic_sub_u64 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1349 /* buffer_atomic_sub_u64 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1349 /* buffer_atomic_sub_u64 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1349 /* buffer_atomic_sub_u64 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1349 /* buffer_atomic_sub_u64 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1349 /* buffer_atomic_sub_u64 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1371 /* buffer_atomic_sub_x2 */, AMDGPU::BUFFER_ATOMIC_SUB_X2_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1392 /* buffer_atomic_swap */, AMDGPU::BUFFER_ATOMIC_SWAP_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1411 /* buffer_atomic_swap_b32 */, AMDGPU::BUFFER_ATOMIC_SWAP_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 1411 /* buffer_atomic_swap_b32 */, AMDGPU::BUFFER_ATOMIC_SWAP_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1411 /* buffer_atomic_swap_b32 */, AMDGPU::BUFFER_ATOMIC_SWAP_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1411 /* buffer_atomic_swap_b32 */, AMDGPU::BUFFER_ATOMIC_SWAP_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1411 /* buffer_atomic_swap_b32 */, AMDGPU::BUFFER_ATOMIC_SWAP_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1411 /* buffer_atomic_swap_b32 */, AMDGPU::BUFFER_ATOMIC_SWAP_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1411 /* buffer_atomic_swap_b32 */, AMDGPU::BUFFER_ATOMIC_SWAP_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1411 /* buffer_atomic_swap_b32 */, AMDGPU::BUFFER_ATOMIC_SWAP_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1411 /* buffer_atomic_swap_b32 */, AMDGPU::BUFFER_ATOMIC_SWAP_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1411 /* buffer_atomic_swap_b32 */, AMDGPU::BUFFER_ATOMIC_SWAP_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1411 /* buffer_atomic_swap_b32 */, AMDGPU::BUFFER_ATOMIC_SWAP_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1411 /* buffer_atomic_swap_b32 */, AMDGPU::BUFFER_ATOMIC_SWAP_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1411 /* buffer_atomic_swap_b32 */, AMDGPU::BUFFER_ATOMIC_SWAP_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1411 /* buffer_atomic_swap_b32 */, AMDGPU::BUFFER_ATOMIC_SWAP_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1411 /* buffer_atomic_swap_b32 */, AMDGPU::BUFFER_ATOMIC_SWAP_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1411 /* buffer_atomic_swap_b32 */, AMDGPU::BUFFER_ATOMIC_SWAP_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1434 /* buffer_atomic_swap_b64 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 1434 /* buffer_atomic_swap_b64 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1434 /* buffer_atomic_swap_b64 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1434 /* buffer_atomic_swap_b64 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1434 /* buffer_atomic_swap_b64 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1434 /* buffer_atomic_swap_b64 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1434 /* buffer_atomic_swap_b64 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1434 /* buffer_atomic_swap_b64 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1434 /* buffer_atomic_swap_b64 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1434 /* buffer_atomic_swap_b64 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1434 /* buffer_atomic_swap_b64 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1434 /* buffer_atomic_swap_b64 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1434 /* buffer_atomic_swap_b64 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1434 /* buffer_atomic_swap_b64 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1434 /* buffer_atomic_swap_b64 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1434 /* buffer_atomic_swap_b64 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1457 /* buffer_atomic_swap_x2 */, AMDGPU::BUFFER_ATOMIC_SWAP_X2_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1479 /* buffer_atomic_umax */, AMDGPU::BUFFER_ATOMIC_UMAX_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1498 /* buffer_atomic_umax_x2 */, AMDGPU::BUFFER_ATOMIC_UMAX_X2_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1520 /* buffer_atomic_umin */, AMDGPU::BUFFER_ATOMIC_UMIN_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1539 /* buffer_atomic_umin_x2 */, AMDGPU::BUFFER_ATOMIC_UMIN_X2_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1561 /* buffer_atomic_xor */, AMDGPU::BUFFER_ATOMIC_XOR_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1579 /* buffer_atomic_xor_b32 */, AMDGPU::BUFFER_ATOMIC_XOR_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 1579 /* buffer_atomic_xor_b32 */, AMDGPU::BUFFER_ATOMIC_XOR_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1579 /* buffer_atomic_xor_b32 */, AMDGPU::BUFFER_ATOMIC_XOR_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1579 /* buffer_atomic_xor_b32 */, AMDGPU::BUFFER_ATOMIC_XOR_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1579 /* buffer_atomic_xor_b32 */, AMDGPU::BUFFER_ATOMIC_XOR_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1579 /* buffer_atomic_xor_b32 */, AMDGPU::BUFFER_ATOMIC_XOR_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1579 /* buffer_atomic_xor_b32 */, AMDGPU::BUFFER_ATOMIC_XOR_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1579 /* buffer_atomic_xor_b32 */, AMDGPU::BUFFER_ATOMIC_XOR_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1579 /* buffer_atomic_xor_b32 */, AMDGPU::BUFFER_ATOMIC_XOR_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1579 /* buffer_atomic_xor_b32 */, AMDGPU::BUFFER_ATOMIC_XOR_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1579 /* buffer_atomic_xor_b32 */, AMDGPU::BUFFER_ATOMIC_XOR_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1579 /* buffer_atomic_xor_b32 */, AMDGPU::BUFFER_ATOMIC_XOR_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1579 /* buffer_atomic_xor_b32 */, AMDGPU::BUFFER_ATOMIC_XOR_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1579 /* buffer_atomic_xor_b32 */, AMDGPU::BUFFER_ATOMIC_XOR_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1579 /* buffer_atomic_xor_b32 */, AMDGPU::BUFFER_ATOMIC_XOR_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1579 /* buffer_atomic_xor_b32 */, AMDGPU::BUFFER_ATOMIC_XOR_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1601 /* buffer_atomic_xor_b64 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_VBUFFER_OFFSET_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_GLC }, },
  { 1601 /* buffer_atomic_xor_b64 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1601 /* buffer_atomic_xor_b64 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_OFFSET_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1601 /* buffer_atomic_xor_b64 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_OFFSET_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1601 /* buffer_atomic_xor_b64 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_VBUFFER_IDXEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1601 /* buffer_atomic_xor_b64 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1601 /* buffer_atomic_xor_b64 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_VBUFFER_OFFEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1601 /* buffer_atomic_xor_b64 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1601 /* buffer_atomic_xor_b64 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_IDXEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1601 /* buffer_atomic_xor_b64 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_IDXEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1601 /* buffer_atomic_xor_b64 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_OFFEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1601 /* buffer_atomic_xor_b64 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_OFFEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1601 /* buffer_atomic_xor_b64 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_VBUFFER_BOTHEN_RTN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1601 /* buffer_atomic_xor_b64 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1601 /* buffer_atomic_xor_b64 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_BOTHEN_RTN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1601 /* buffer_atomic_xor_b64 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_BOTHEN_gfx11, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_OFFSET_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_OFFSET_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_OFFSET_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_OFFSET_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_GLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_OFFSET_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_OFFSET_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_OFFSET_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_IDXEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_IDXEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_IDXEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_IDXEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_GLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_IDXEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_IDXEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_IDXEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_OFFEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_OFFEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_OFFEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_OFFEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_OFFEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_OFFEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_OFFEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_ADDR64_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_GLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_BOTHEN_RTN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_BOTHEN_RTN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_BOTHEN_RTN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_BOTHEN_RTN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_GLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_BOTHEN_gfx10, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_BOTHEN_gfx90a, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1623 /* buffer_atomic_xor_x2 */, AMDGPU::BUFFER_ATOMIC_XOR_X2_BOTHEN_vi, ConvertCustom_cvtMubufAtomic, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol_NonGLC }, },
  { 1644 /* buffer_gl0_inv */, AMDGPU::BUFFER_GL0_INV_gfx10, Convert_NoOperands, AMFBS_isGFX10Only, {  }, },
  { 1644 /* buffer_gl0_inv */, AMDGPU::BUFFER_GL0_INV_gfx11, Convert_NoOperands, AMFBS_isGFX11Only, {  }, },
  { 1659 /* buffer_gl1_inv */, AMDGPU::BUFFER_GL1_INV_gfx10, Convert_NoOperands, AMFBS_isGFX10Only, {  }, },
  { 1659 /* buffer_gl1_inv */, AMDGPU::BUFFER_GL1_INV_gfx11, Convert_NoOperands, AMFBS_isGFX11Only, {  }, },
  { 1674 /* buffer_inv */, AMDGPU::BUFFER_INV_gfx940, Convert__CPol1_0, AMFBS_isGFX940Plus, { MCK_CPol }, },
  { 1685 /* buffer_invl2 */, AMDGPU::BUFFER_INVL2_gfx90a, Convert_NoOperands, AMFBS_isGFX90AOnly_isGFX90APlus, {  }, },
  { 1698 /* buffer_load_b128 */, AMDGPU::BUFFER_LOAD_DWORDX4_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 1698 /* buffer_load_b128 */, AMDGPU::BUFFER_LOAD_DWORDX4_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 1698 /* buffer_load_b128 */, AMDGPU::BUFFER_LOAD_DWORDX4_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1698 /* buffer_load_b128 */, AMDGPU::BUFFER_LOAD_DWORDX4_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1698 /* buffer_load_b128 */, AMDGPU::BUFFER_LOAD_DWORDX4_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1698 /* buffer_load_b128 */, AMDGPU::BUFFER_LOAD_DWORDX4_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1698 /* buffer_load_b128 */, AMDGPU::BUFFER_LOAD_DWORDX4_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1698 /* buffer_load_b128 */, AMDGPU::BUFFER_LOAD_DWORDX4_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1698 /* buffer_load_b128 */, AMDGPU::BUFFER_LOAD_DWORDX4_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1698 /* buffer_load_b128 */, AMDGPU::BUFFER_LOAD_DWORDX4_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1698 /* buffer_load_b128 */, AMDGPU::BUFFER_LOAD_DWORDX4_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1698 /* buffer_load_b128 */, AMDGPU::BUFFER_LOAD_DWORDX4_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1698 /* buffer_load_b128 */, AMDGPU::BUFFER_LOAD_DWORDX4_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1698 /* buffer_load_b128 */, AMDGPU::BUFFER_LOAD_DWORDX4_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1698 /* buffer_load_b128 */, AMDGPU::BUFFER_LOAD_DWORDX4_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1698 /* buffer_load_b128 */, AMDGPU::BUFFER_LOAD_DWORDX4_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1715 /* buffer_load_b32 */, AMDGPU::BUFFER_LOAD_DWORD_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 1715 /* buffer_load_b32 */, AMDGPU::BUFFER_LOAD_DWORD_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 1715 /* buffer_load_b32 */, AMDGPU::BUFFER_LOAD_DWORD_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1715 /* buffer_load_b32 */, AMDGPU::BUFFER_LOAD_DWORD_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1715 /* buffer_load_b32 */, AMDGPU::BUFFER_LOAD_DWORD_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1715 /* buffer_load_b32 */, AMDGPU::BUFFER_LOAD_DWORD_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1715 /* buffer_load_b32 */, AMDGPU::BUFFER_LOAD_DWORD_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1715 /* buffer_load_b32 */, AMDGPU::BUFFER_LOAD_DWORD_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1715 /* buffer_load_b32 */, AMDGPU::BUFFER_LOAD_DWORD_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1715 /* buffer_load_b32 */, AMDGPU::BUFFER_LOAD_DWORD_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1715 /* buffer_load_b32 */, AMDGPU::BUFFER_LOAD_DWORD_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1715 /* buffer_load_b32 */, AMDGPU::BUFFER_LOAD_DWORD_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1715 /* buffer_load_b32 */, AMDGPU::BUFFER_LOAD_DWORD_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1715 /* buffer_load_b32 */, AMDGPU::BUFFER_LOAD_DWORD_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1715 /* buffer_load_b32 */, AMDGPU::BUFFER_LOAD_DWORD_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1715 /* buffer_load_b32 */, AMDGPU::BUFFER_LOAD_DWORD_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1731 /* buffer_load_b64 */, AMDGPU::BUFFER_LOAD_DWORDX2_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 1731 /* buffer_load_b64 */, AMDGPU::BUFFER_LOAD_DWORDX2_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 1731 /* buffer_load_b64 */, AMDGPU::BUFFER_LOAD_DWORDX2_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1731 /* buffer_load_b64 */, AMDGPU::BUFFER_LOAD_DWORDX2_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1731 /* buffer_load_b64 */, AMDGPU::BUFFER_LOAD_DWORDX2_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1731 /* buffer_load_b64 */, AMDGPU::BUFFER_LOAD_DWORDX2_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1731 /* buffer_load_b64 */, AMDGPU::BUFFER_LOAD_DWORDX2_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1731 /* buffer_load_b64 */, AMDGPU::BUFFER_LOAD_DWORDX2_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1731 /* buffer_load_b64 */, AMDGPU::BUFFER_LOAD_DWORDX2_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1731 /* buffer_load_b64 */, AMDGPU::BUFFER_LOAD_DWORDX2_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1731 /* buffer_load_b64 */, AMDGPU::BUFFER_LOAD_DWORDX2_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1731 /* buffer_load_b64 */, AMDGPU::BUFFER_LOAD_DWORDX2_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1731 /* buffer_load_b64 */, AMDGPU::BUFFER_LOAD_DWORDX2_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1731 /* buffer_load_b64 */, AMDGPU::BUFFER_LOAD_DWORDX2_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1731 /* buffer_load_b64 */, AMDGPU::BUFFER_LOAD_DWORDX2_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1731 /* buffer_load_b64 */, AMDGPU::BUFFER_LOAD_DWORDX2_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1747 /* buffer_load_b96 */, AMDGPU::BUFFER_LOAD_DWORDX3_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 1747 /* buffer_load_b96 */, AMDGPU::BUFFER_LOAD_DWORDX3_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 1747 /* buffer_load_b96 */, AMDGPU::BUFFER_LOAD_DWORDX3_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1747 /* buffer_load_b96 */, AMDGPU::BUFFER_LOAD_DWORDX3_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1747 /* buffer_load_b96 */, AMDGPU::BUFFER_LOAD_DWORDX3_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1747 /* buffer_load_b96 */, AMDGPU::BUFFER_LOAD_DWORDX3_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1747 /* buffer_load_b96 */, AMDGPU::BUFFER_LOAD_DWORDX3_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1747 /* buffer_load_b96 */, AMDGPU::BUFFER_LOAD_DWORDX3_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1747 /* buffer_load_b96 */, AMDGPU::BUFFER_LOAD_DWORDX3_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1747 /* buffer_load_b96 */, AMDGPU::BUFFER_LOAD_DWORDX3_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1747 /* buffer_load_b96 */, AMDGPU::BUFFER_LOAD_DWORDX3_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1747 /* buffer_load_b96 */, AMDGPU::BUFFER_LOAD_DWORDX3_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1747 /* buffer_load_b96 */, AMDGPU::BUFFER_LOAD_DWORDX3_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1747 /* buffer_load_b96 */, AMDGPU::BUFFER_LOAD_DWORDX3_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1747 /* buffer_load_b96 */, AMDGPU::BUFFER_LOAD_DWORDX3_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1747 /* buffer_load_b96 */, AMDGPU::BUFFER_LOAD_DWORDX3_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1763 /* buffer_load_d16_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 1763 /* buffer_load_d16_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 1763 /* buffer_load_d16_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1763 /* buffer_load_d16_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1763 /* buffer_load_d16_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1763 /* buffer_load_d16_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1763 /* buffer_load_d16_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1763 /* buffer_load_d16_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1763 /* buffer_load_d16_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1763 /* buffer_load_d16_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1763 /* buffer_load_d16_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1763 /* buffer_load_d16_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1763 /* buffer_load_d16_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1763 /* buffer_load_d16_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1763 /* buffer_load_d16_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1763 /* buffer_load_d16_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1783 /* buffer_load_d16_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 1783 /* buffer_load_d16_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 1783 /* buffer_load_d16_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1783 /* buffer_load_d16_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1783 /* buffer_load_d16_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1783 /* buffer_load_d16_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1783 /* buffer_load_d16_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1783 /* buffer_load_d16_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1783 /* buffer_load_d16_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1783 /* buffer_load_d16_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1783 /* buffer_load_d16_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1783 /* buffer_load_d16_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1783 /* buffer_load_d16_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1783 /* buffer_load_d16_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1783 /* buffer_load_d16_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1783 /* buffer_load_d16_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1808 /* buffer_load_d16_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 1808 /* buffer_load_d16_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 1808 /* buffer_load_d16_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1808 /* buffer_load_d16_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1808 /* buffer_load_d16_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1808 /* buffer_load_d16_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1808 /* buffer_load_d16_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1808 /* buffer_load_d16_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1808 /* buffer_load_d16_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1808 /* buffer_load_d16_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1808 /* buffer_load_d16_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1808 /* buffer_load_d16_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1808 /* buffer_load_d16_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1808 /* buffer_load_d16_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1808 /* buffer_load_d16_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1808 /* buffer_load_d16_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1834 /* buffer_load_d16_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 1834 /* buffer_load_d16_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 1834 /* buffer_load_d16_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1834 /* buffer_load_d16_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1834 /* buffer_load_d16_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1834 /* buffer_load_d16_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1834 /* buffer_load_d16_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1834 /* buffer_load_d16_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1834 /* buffer_load_d16_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1834 /* buffer_load_d16_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1834 /* buffer_load_d16_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1834 /* buffer_load_d16_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1834 /* buffer_load_d16_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1834 /* buffer_load_d16_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1834 /* buffer_load_d16_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1834 /* buffer_load_d16_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1861 /* buffer_load_d16_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 1861 /* buffer_load_d16_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 1861 /* buffer_load_d16_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1861 /* buffer_load_d16_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1861 /* buffer_load_d16_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1861 /* buffer_load_d16_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1861 /* buffer_load_d16_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1861 /* buffer_load_d16_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1861 /* buffer_load_d16_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1861 /* buffer_load_d16_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1861 /* buffer_load_d16_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1861 /* buffer_load_d16_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1861 /* buffer_load_d16_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1861 /* buffer_load_d16_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1861 /* buffer_load_d16_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1861 /* buffer_load_d16_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1889 /* buffer_load_d16_hi_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 1889 /* buffer_load_d16_hi_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 1889 /* buffer_load_d16_hi_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1889 /* buffer_load_d16_hi_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1889 /* buffer_load_d16_hi_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1889 /* buffer_load_d16_hi_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1889 /* buffer_load_d16_hi_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1889 /* buffer_load_d16_hi_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1889 /* buffer_load_d16_hi_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1889 /* buffer_load_d16_hi_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1889 /* buffer_load_d16_hi_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1889 /* buffer_load_d16_hi_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1889 /* buffer_load_d16_hi_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1889 /* buffer_load_d16_hi_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1889 /* buffer_load_d16_hi_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1889 /* buffer_load_d16_hi_b16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1912 /* buffer_load_d16_hi_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 1912 /* buffer_load_d16_hi_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 1912 /* buffer_load_d16_hi_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1912 /* buffer_load_d16_hi_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1912 /* buffer_load_d16_hi_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1912 /* buffer_load_d16_hi_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1912 /* buffer_load_d16_hi_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1912 /* buffer_load_d16_hi_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1912 /* buffer_load_d16_hi_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1912 /* buffer_load_d16_hi_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1912 /* buffer_load_d16_hi_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1912 /* buffer_load_d16_hi_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1912 /* buffer_load_d16_hi_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1912 /* buffer_load_d16_hi_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1912 /* buffer_load_d16_hi_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1912 /* buffer_load_d16_hi_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1940 /* buffer_load_d16_hi_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 1940 /* buffer_load_d16_hi_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 1940 /* buffer_load_d16_hi_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1940 /* buffer_load_d16_hi_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1940 /* buffer_load_d16_hi_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1940 /* buffer_load_d16_hi_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1940 /* buffer_load_d16_hi_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1940 /* buffer_load_d16_hi_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1940 /* buffer_load_d16_hi_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1940 /* buffer_load_d16_hi_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1940 /* buffer_load_d16_hi_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1940 /* buffer_load_d16_hi_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1940 /* buffer_load_d16_hi_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1940 /* buffer_load_d16_hi_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1940 /* buffer_load_d16_hi_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1940 /* buffer_load_d16_hi_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1962 /* buffer_load_d16_hi_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 1962 /* buffer_load_d16_hi_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 1962 /* buffer_load_d16_hi_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1962 /* buffer_load_d16_hi_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1962 /* buffer_load_d16_hi_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1962 /* buffer_load_d16_hi_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1962 /* buffer_load_d16_hi_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1962 /* buffer_load_d16_hi_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1962 /* buffer_load_d16_hi_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1962 /* buffer_load_d16_hi_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1962 /* buffer_load_d16_hi_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1962 /* buffer_load_d16_hi_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1962 /* buffer_load_d16_hi_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1962 /* buffer_load_d16_hi_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1962 /* buffer_load_d16_hi_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1962 /* buffer_load_d16_hi_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1984 /* buffer_load_d16_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 1984 /* buffer_load_d16_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 1984 /* buffer_load_d16_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1984 /* buffer_load_d16_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1984 /* buffer_load_d16_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 1984 /* buffer_load_d16_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1984 /* buffer_load_d16_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1984 /* buffer_load_d16_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1984 /* buffer_load_d16_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1984 /* buffer_load_d16_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 1984 /* buffer_load_d16_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1984 /* buffer_load_d16_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1984 /* buffer_load_d16_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1984 /* buffer_load_d16_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1984 /* buffer_load_d16_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 1984 /* buffer_load_d16_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2003 /* buffer_load_d16_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 2003 /* buffer_load_d16_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2003 /* buffer_load_d16_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2003 /* buffer_load_d16_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2003 /* buffer_load_d16_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2003 /* buffer_load_d16_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2003 /* buffer_load_d16_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2003 /* buffer_load_d16_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2003 /* buffer_load_d16_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2003 /* buffer_load_d16_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2003 /* buffer_load_d16_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2003 /* buffer_load_d16_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2003 /* buffer_load_d16_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2003 /* buffer_load_d16_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2003 /* buffer_load_d16_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2003 /* buffer_load_d16_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_LDS_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_LDS_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_LDS_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_LDS_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_LDS_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_LDS_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_LDS_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_LDS_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_LDS_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_LDS_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_LDS_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_LDS_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_TFE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_LDS_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_TFE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_TFE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_TFE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_LDS_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_LDS_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_LDS_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_LDS_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_TFE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2022 /* buffer_load_dword */, AMDGPU::BUFFER_LOAD_DWORD_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_TFE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_TFE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_TFE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_TFE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_TFE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2040 /* buffer_load_dwordx2 */, AMDGPU::BUFFER_LOAD_DWORDX2_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_LDS_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasGFX950Insts_isGFX90APlus, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_LDS_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_LDS_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasGFX950Insts_isGFX90APlus, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_LDS_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_LDS_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasGFX950Insts_isGFX90APlus, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_LDS_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_TFE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_TFE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_TFE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_TFE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_LDS_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasGFX950Insts_isGFX90APlus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_LDS_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_TFE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2060 /* buffer_load_dwordx3 */, AMDGPU::BUFFER_LOAD_DWORDX3_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_LDS_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasGFX950Insts_isGFX90APlus, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_LDS_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_LDS_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasGFX950Insts_isGFX90APlus, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_LDS_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_LDS_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasGFX950Insts_isGFX90APlus, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_LDS_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_TFE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_TFE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_TFE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_TFE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_LDS_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasGFX950Insts_isGFX90APlus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_LDS_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_TFE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2080 /* buffer_load_dwordx4 */, AMDGPU::BUFFER_LOAD_DWORDX4_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2100 /* buffer_load_format_d16_hi_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2100 /* buffer_load_format_d16_hi_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2100 /* buffer_load_format_d16_hi_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2100 /* buffer_load_format_d16_hi_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2100 /* buffer_load_format_d16_hi_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2100 /* buffer_load_format_d16_hi_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2100 /* buffer_load_format_d16_hi_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2100 /* buffer_load_format_d16_hi_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2100 /* buffer_load_format_d16_hi_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2100 /* buffer_load_format_d16_hi_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2100 /* buffer_load_format_d16_hi_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2100 /* buffer_load_format_d16_hi_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2100 /* buffer_load_format_d16_hi_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2100 /* buffer_load_format_d16_hi_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2100 /* buffer_load_format_d16_hi_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2100 /* buffer_load_format_d16_hi_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2100 /* buffer_load_format_d16_hi_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2100 /* buffer_load_format_d16_hi_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2100 /* buffer_load_format_d16_hi_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2100 /* buffer_load_format_d16_hi_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_HI_X_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_gfx80_OFFSET_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_gfx80_IDXEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_gfx80_OFFEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_gfx80_TFE_OFFSET_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_gfx80_BOTHEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_gfx80_TFE_IDXEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_gfx80_TFE_OFFEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2128 /* buffer_load_format_d16_x */, AMDGPU::BUFFER_LOAD_FORMAT_D16_X_gfx80_TFE_BOTHEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_gfx80_OFFSET_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_gfx80_IDXEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_gfx80_OFFEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_gfx80_TFE_OFFSET_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_gfx80_BOTHEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_gfx80_TFE_IDXEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_gfx80_TFE_OFFEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2153 /* buffer_load_format_d16_xy */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XY_gfx80_TFE_BOTHEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_gfx80_OFFSET_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_gfx80_IDXEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_gfx80_OFFEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_gfx80_TFE_OFFSET_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_gfx80_BOTHEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_gfx80_TFE_IDXEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_gfx80_TFE_OFFEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2179 /* buffer_load_format_d16_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZ_gfx80_TFE_BOTHEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_gfx80_OFFSET_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_gfx80_IDXEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_gfx80_OFFEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_gfx80_TFE_OFFSET_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_gfx80_BOTHEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_gfx80_TFE_IDXEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_gfx80_TFE_OFFEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2206 /* buffer_load_format_d16_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_D16_XYZW_gfx80_TFE_BOTHEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_LDS_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_LDS_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_LDS_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_LDS_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_LDS_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_LDS_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_LDS_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_LDS_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_LDS_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_LDS_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_LDS_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_LDS_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_TFE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_LDS_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_TFE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_TFE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_TFE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_LDS_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_LDS_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_LDS_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_LDS_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_TFE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2234 /* buffer_load_format_x */, AMDGPU::BUFFER_LOAD_FORMAT_X_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_TFE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_TFE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_TFE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_TFE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_TFE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2255 /* buffer_load_format_xy */, AMDGPU::BUFFER_LOAD_FORMAT_XY_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_TFE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_TFE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_TFE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_TFE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_TFE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2277 /* buffer_load_format_xyz */, AMDGPU::BUFFER_LOAD_FORMAT_XYZ_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_TFE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_TFE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_TFE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_TFE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_TFE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2300 /* buffer_load_format_xyzw */, AMDGPU::BUFFER_LOAD_FORMAT_XYZW_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2324 /* buffer_load_i16 */, AMDGPU::BUFFER_LOAD_SSHORT_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 2324 /* buffer_load_i16 */, AMDGPU::BUFFER_LOAD_SSHORT_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2324 /* buffer_load_i16 */, AMDGPU::BUFFER_LOAD_SSHORT_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2324 /* buffer_load_i16 */, AMDGPU::BUFFER_LOAD_SSHORT_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2324 /* buffer_load_i16 */, AMDGPU::BUFFER_LOAD_SSHORT_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2324 /* buffer_load_i16 */, AMDGPU::BUFFER_LOAD_SSHORT_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2324 /* buffer_load_i16 */, AMDGPU::BUFFER_LOAD_SSHORT_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2324 /* buffer_load_i16 */, AMDGPU::BUFFER_LOAD_SSHORT_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2324 /* buffer_load_i16 */, AMDGPU::BUFFER_LOAD_SSHORT_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2324 /* buffer_load_i16 */, AMDGPU::BUFFER_LOAD_SSHORT_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2324 /* buffer_load_i16 */, AMDGPU::BUFFER_LOAD_SSHORT_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2324 /* buffer_load_i16 */, AMDGPU::BUFFER_LOAD_SSHORT_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2324 /* buffer_load_i16 */, AMDGPU::BUFFER_LOAD_SSHORT_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2324 /* buffer_load_i16 */, AMDGPU::BUFFER_LOAD_SSHORT_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2324 /* buffer_load_i16 */, AMDGPU::BUFFER_LOAD_SSHORT_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2324 /* buffer_load_i16 */, AMDGPU::BUFFER_LOAD_SSHORT_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2340 /* buffer_load_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 2340 /* buffer_load_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2340 /* buffer_load_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2340 /* buffer_load_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2340 /* buffer_load_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2340 /* buffer_load_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2340 /* buffer_load_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2340 /* buffer_load_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2340 /* buffer_load_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2340 /* buffer_load_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2340 /* buffer_load_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2340 /* buffer_load_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2340 /* buffer_load_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2340 /* buffer_load_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2340 /* buffer_load_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2340 /* buffer_load_i8 */, AMDGPU::BUFFER_LOAD_SBYTE_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_LDS_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_LDS_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_LDS_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_LDS_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_LDS_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_LDS_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_LDS_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_LDS_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_LDS_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_LDS_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_LDS_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_LDS_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_TFE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_LDS_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_TFE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_TFE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_TFE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_LDS_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_LDS_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_LDS_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_LDS_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_TFE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2355 /* buffer_load_sbyte */, AMDGPU::BUFFER_LOAD_SBYTE_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2373 /* buffer_load_sbyte_d16 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2373 /* buffer_load_sbyte_d16 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2373 /* buffer_load_sbyte_d16 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2373 /* buffer_load_sbyte_d16 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2373 /* buffer_load_sbyte_d16 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2373 /* buffer_load_sbyte_d16 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2373 /* buffer_load_sbyte_d16 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2373 /* buffer_load_sbyte_d16 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2373 /* buffer_load_sbyte_d16 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2373 /* buffer_load_sbyte_d16 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2373 /* buffer_load_sbyte_d16 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2373 /* buffer_load_sbyte_d16 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2373 /* buffer_load_sbyte_d16 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2373 /* buffer_load_sbyte_d16 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2373 /* buffer_load_sbyte_d16 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2373 /* buffer_load_sbyte_d16 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2373 /* buffer_load_sbyte_d16 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2373 /* buffer_load_sbyte_d16 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2373 /* buffer_load_sbyte_d16 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2373 /* buffer_load_sbyte_d16 */, AMDGPU::BUFFER_LOAD_SBYTE_D16_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2395 /* buffer_load_sbyte_d16_hi */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2395 /* buffer_load_sbyte_d16_hi */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2395 /* buffer_load_sbyte_d16_hi */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2395 /* buffer_load_sbyte_d16_hi */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2395 /* buffer_load_sbyte_d16_hi */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2395 /* buffer_load_sbyte_d16_hi */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2395 /* buffer_load_sbyte_d16_hi */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2395 /* buffer_load_sbyte_d16_hi */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2395 /* buffer_load_sbyte_d16_hi */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2395 /* buffer_load_sbyte_d16_hi */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2395 /* buffer_load_sbyte_d16_hi */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2395 /* buffer_load_sbyte_d16_hi */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2395 /* buffer_load_sbyte_d16_hi */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2395 /* buffer_load_sbyte_d16_hi */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2395 /* buffer_load_sbyte_d16_hi */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2395 /* buffer_load_sbyte_d16_hi */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2395 /* buffer_load_sbyte_d16_hi */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2395 /* buffer_load_sbyte_d16_hi */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2395 /* buffer_load_sbyte_d16_hi */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2395 /* buffer_load_sbyte_d16_hi */, AMDGPU::BUFFER_LOAD_SBYTE_D16_HI_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2420 /* buffer_load_short_d16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2420 /* buffer_load_short_d16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2420 /* buffer_load_short_d16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2420 /* buffer_load_short_d16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2420 /* buffer_load_short_d16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2420 /* buffer_load_short_d16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2420 /* buffer_load_short_d16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2420 /* buffer_load_short_d16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2420 /* buffer_load_short_d16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2420 /* buffer_load_short_d16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2420 /* buffer_load_short_d16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2420 /* buffer_load_short_d16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2420 /* buffer_load_short_d16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2420 /* buffer_load_short_d16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2420 /* buffer_load_short_d16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2420 /* buffer_load_short_d16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2420 /* buffer_load_short_d16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2420 /* buffer_load_short_d16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2420 /* buffer_load_short_d16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2420 /* buffer_load_short_d16 */, AMDGPU::BUFFER_LOAD_SHORT_D16_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2442 /* buffer_load_short_d16_hi */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2442 /* buffer_load_short_d16_hi */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2442 /* buffer_load_short_d16_hi */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2442 /* buffer_load_short_d16_hi */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2442 /* buffer_load_short_d16_hi */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2442 /* buffer_load_short_d16_hi */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2442 /* buffer_load_short_d16_hi */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2442 /* buffer_load_short_d16_hi */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2442 /* buffer_load_short_d16_hi */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2442 /* buffer_load_short_d16_hi */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2442 /* buffer_load_short_d16_hi */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2442 /* buffer_load_short_d16_hi */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2442 /* buffer_load_short_d16_hi */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2442 /* buffer_load_short_d16_hi */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2442 /* buffer_load_short_d16_hi */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2442 /* buffer_load_short_d16_hi */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2442 /* buffer_load_short_d16_hi */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2442 /* buffer_load_short_d16_hi */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2442 /* buffer_load_short_d16_hi */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2442 /* buffer_load_short_d16_hi */, AMDGPU::BUFFER_LOAD_SHORT_D16_HI_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_LDS_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_LDS_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_LDS_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_LDS_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_LDS_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_LDS_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_LDS_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_LDS_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_LDS_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_LDS_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_LDS_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_LDS_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_TFE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_LDS_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_TFE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_TFE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_TFE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_LDS_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_LDS_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_LDS_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_LDS_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_TFE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2467 /* buffer_load_sshort */, AMDGPU::BUFFER_LOAD_SSHORT_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2486 /* buffer_load_u16 */, AMDGPU::BUFFER_LOAD_USHORT_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 2486 /* buffer_load_u16 */, AMDGPU::BUFFER_LOAD_USHORT_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2486 /* buffer_load_u16 */, AMDGPU::BUFFER_LOAD_USHORT_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2486 /* buffer_load_u16 */, AMDGPU::BUFFER_LOAD_USHORT_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2486 /* buffer_load_u16 */, AMDGPU::BUFFER_LOAD_USHORT_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2486 /* buffer_load_u16 */, AMDGPU::BUFFER_LOAD_USHORT_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2486 /* buffer_load_u16 */, AMDGPU::BUFFER_LOAD_USHORT_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2486 /* buffer_load_u16 */, AMDGPU::BUFFER_LOAD_USHORT_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2486 /* buffer_load_u16 */, AMDGPU::BUFFER_LOAD_USHORT_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2486 /* buffer_load_u16 */, AMDGPU::BUFFER_LOAD_USHORT_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2486 /* buffer_load_u16 */, AMDGPU::BUFFER_LOAD_USHORT_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2486 /* buffer_load_u16 */, AMDGPU::BUFFER_LOAD_USHORT_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2486 /* buffer_load_u16 */, AMDGPU::BUFFER_LOAD_USHORT_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2486 /* buffer_load_u16 */, AMDGPU::BUFFER_LOAD_USHORT_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2486 /* buffer_load_u16 */, AMDGPU::BUFFER_LOAD_USHORT_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2486 /* buffer_load_u16 */, AMDGPU::BUFFER_LOAD_USHORT_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2502 /* buffer_load_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 2502 /* buffer_load_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2502 /* buffer_load_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2502 /* buffer_load_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2502 /* buffer_load_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2502 /* buffer_load_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2502 /* buffer_load_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2502 /* buffer_load_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2502 /* buffer_load_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2502 /* buffer_load_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2502 /* buffer_load_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2502 /* buffer_load_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2502 /* buffer_load_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2502 /* buffer_load_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2502 /* buffer_load_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2502 /* buffer_load_u8 */, AMDGPU::BUFFER_LOAD_UBYTE_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_LDS_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_LDS_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_LDS_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_LDS_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_LDS_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_LDS_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_LDS_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_LDS_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_LDS_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_LDS_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_LDS_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_LDS_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_TFE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_LDS_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_TFE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_TFE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_TFE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_LDS_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_LDS_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_LDS_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_LDS_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_TFE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2517 /* buffer_load_ubyte */, AMDGPU::BUFFER_LOAD_UBYTE_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2535 /* buffer_load_ubyte_d16 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2535 /* buffer_load_ubyte_d16 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2535 /* buffer_load_ubyte_d16 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2535 /* buffer_load_ubyte_d16 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2535 /* buffer_load_ubyte_d16 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2535 /* buffer_load_ubyte_d16 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2535 /* buffer_load_ubyte_d16 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2535 /* buffer_load_ubyte_d16 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2535 /* buffer_load_ubyte_d16 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2535 /* buffer_load_ubyte_d16 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2535 /* buffer_load_ubyte_d16 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2535 /* buffer_load_ubyte_d16 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2535 /* buffer_load_ubyte_d16 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2535 /* buffer_load_ubyte_d16 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2535 /* buffer_load_ubyte_d16 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2535 /* buffer_load_ubyte_d16 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2535 /* buffer_load_ubyte_d16 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2535 /* buffer_load_ubyte_d16 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2535 /* buffer_load_ubyte_d16 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2535 /* buffer_load_ubyte_d16 */, AMDGPU::BUFFER_LOAD_UBYTE_D16_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2557 /* buffer_load_ubyte_d16_hi */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2557 /* buffer_load_ubyte_d16_hi */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2557 /* buffer_load_ubyte_d16_hi */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2557 /* buffer_load_ubyte_d16_hi */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2557 /* buffer_load_ubyte_d16_hi */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2557 /* buffer_load_ubyte_d16_hi */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2557 /* buffer_load_ubyte_d16_hi */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2557 /* buffer_load_ubyte_d16_hi */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2557 /* buffer_load_ubyte_d16_hi */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2557 /* buffer_load_ubyte_d16_hi */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2557 /* buffer_load_ubyte_d16_hi */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2557 /* buffer_load_ubyte_d16_hi */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2557 /* buffer_load_ubyte_d16_hi */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2557 /* buffer_load_ubyte_d16_hi */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2557 /* buffer_load_ubyte_d16_hi */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2557 /* buffer_load_ubyte_d16_hi */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2557 /* buffer_load_ubyte_d16_hi */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2557 /* buffer_load_ubyte_d16_hi */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2557 /* buffer_load_ubyte_d16_hi */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2557 /* buffer_load_ubyte_d16_hi */, AMDGPU::BUFFER_LOAD_UBYTE_D16_HI_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_LDS_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_LDS_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_LDS_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_LDS_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_LDS_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_LDS_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_LDS_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_LDS_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_LDS_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_LDS_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_LDS_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_LDS_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_TFE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_LDS_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_TFE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_TFE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_TFE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_LDS_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_LDS_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_LDS_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_LDS_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_lds }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_TFE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2582 /* buffer_load_ushort */, AMDGPU::BUFFER_LOAD_USHORT_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2601 /* buffer_store_b128 */, AMDGPU::BUFFER_STORE_DWORDX4_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 2601 /* buffer_store_b128 */, AMDGPU::BUFFER_STORE_DWORDX4_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2601 /* buffer_store_b128 */, AMDGPU::BUFFER_STORE_DWORDX4_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2601 /* buffer_store_b128 */, AMDGPU::BUFFER_STORE_DWORDX4_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2601 /* buffer_store_b128 */, AMDGPU::BUFFER_STORE_DWORDX4_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2601 /* buffer_store_b128 */, AMDGPU::BUFFER_STORE_DWORDX4_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2601 /* buffer_store_b128 */, AMDGPU::BUFFER_STORE_DWORDX4_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2601 /* buffer_store_b128 */, AMDGPU::BUFFER_STORE_DWORDX4_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2601 /* buffer_store_b128 */, AMDGPU::BUFFER_STORE_DWORDX4_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2601 /* buffer_store_b128 */, AMDGPU::BUFFER_STORE_DWORDX4_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2601 /* buffer_store_b128 */, AMDGPU::BUFFER_STORE_DWORDX4_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2601 /* buffer_store_b128 */, AMDGPU::BUFFER_STORE_DWORDX4_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2601 /* buffer_store_b128 */, AMDGPU::BUFFER_STORE_DWORDX4_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2601 /* buffer_store_b128 */, AMDGPU::BUFFER_STORE_DWORDX4_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2601 /* buffer_store_b128 */, AMDGPU::BUFFER_STORE_DWORDX4_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2601 /* buffer_store_b128 */, AMDGPU::BUFFER_STORE_DWORDX4_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2619 /* buffer_store_b16 */, AMDGPU::BUFFER_STORE_SHORT_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 2619 /* buffer_store_b16 */, AMDGPU::BUFFER_STORE_SHORT_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2619 /* buffer_store_b16 */, AMDGPU::BUFFER_STORE_SHORT_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2619 /* buffer_store_b16 */, AMDGPU::BUFFER_STORE_SHORT_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2619 /* buffer_store_b16 */, AMDGPU::BUFFER_STORE_SHORT_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2619 /* buffer_store_b16 */, AMDGPU::BUFFER_STORE_SHORT_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2619 /* buffer_store_b16 */, AMDGPU::BUFFER_STORE_SHORT_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2619 /* buffer_store_b16 */, AMDGPU::BUFFER_STORE_SHORT_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2619 /* buffer_store_b16 */, AMDGPU::BUFFER_STORE_SHORT_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2619 /* buffer_store_b16 */, AMDGPU::BUFFER_STORE_SHORT_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2619 /* buffer_store_b16 */, AMDGPU::BUFFER_STORE_SHORT_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2619 /* buffer_store_b16 */, AMDGPU::BUFFER_STORE_SHORT_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2619 /* buffer_store_b16 */, AMDGPU::BUFFER_STORE_SHORT_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2619 /* buffer_store_b16 */, AMDGPU::BUFFER_STORE_SHORT_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2619 /* buffer_store_b16 */, AMDGPU::BUFFER_STORE_SHORT_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2619 /* buffer_store_b16 */, AMDGPU::BUFFER_STORE_SHORT_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2636 /* buffer_store_b32 */, AMDGPU::BUFFER_STORE_DWORD_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 2636 /* buffer_store_b32 */, AMDGPU::BUFFER_STORE_DWORD_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2636 /* buffer_store_b32 */, AMDGPU::BUFFER_STORE_DWORD_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2636 /* buffer_store_b32 */, AMDGPU::BUFFER_STORE_DWORD_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2636 /* buffer_store_b32 */, AMDGPU::BUFFER_STORE_DWORD_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2636 /* buffer_store_b32 */, AMDGPU::BUFFER_STORE_DWORD_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2636 /* buffer_store_b32 */, AMDGPU::BUFFER_STORE_DWORD_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2636 /* buffer_store_b32 */, AMDGPU::BUFFER_STORE_DWORD_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2636 /* buffer_store_b32 */, AMDGPU::BUFFER_STORE_DWORD_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2636 /* buffer_store_b32 */, AMDGPU::BUFFER_STORE_DWORD_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2636 /* buffer_store_b32 */, AMDGPU::BUFFER_STORE_DWORD_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2636 /* buffer_store_b32 */, AMDGPU::BUFFER_STORE_DWORD_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2636 /* buffer_store_b32 */, AMDGPU::BUFFER_STORE_DWORD_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2636 /* buffer_store_b32 */, AMDGPU::BUFFER_STORE_DWORD_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2636 /* buffer_store_b32 */, AMDGPU::BUFFER_STORE_DWORD_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2636 /* buffer_store_b32 */, AMDGPU::BUFFER_STORE_DWORD_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2653 /* buffer_store_b64 */, AMDGPU::BUFFER_STORE_DWORDX2_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 2653 /* buffer_store_b64 */, AMDGPU::BUFFER_STORE_DWORDX2_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2653 /* buffer_store_b64 */, AMDGPU::BUFFER_STORE_DWORDX2_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2653 /* buffer_store_b64 */, AMDGPU::BUFFER_STORE_DWORDX2_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2653 /* buffer_store_b64 */, AMDGPU::BUFFER_STORE_DWORDX2_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2653 /* buffer_store_b64 */, AMDGPU::BUFFER_STORE_DWORDX2_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2653 /* buffer_store_b64 */, AMDGPU::BUFFER_STORE_DWORDX2_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2653 /* buffer_store_b64 */, AMDGPU::BUFFER_STORE_DWORDX2_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2653 /* buffer_store_b64 */, AMDGPU::BUFFER_STORE_DWORDX2_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2653 /* buffer_store_b64 */, AMDGPU::BUFFER_STORE_DWORDX2_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2653 /* buffer_store_b64 */, AMDGPU::BUFFER_STORE_DWORDX2_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2653 /* buffer_store_b64 */, AMDGPU::BUFFER_STORE_DWORDX2_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2653 /* buffer_store_b64 */, AMDGPU::BUFFER_STORE_DWORDX2_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2653 /* buffer_store_b64 */, AMDGPU::BUFFER_STORE_DWORDX2_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2653 /* buffer_store_b64 */, AMDGPU::BUFFER_STORE_DWORDX2_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2653 /* buffer_store_b64 */, AMDGPU::BUFFER_STORE_DWORDX2_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2670 /* buffer_store_b8 */, AMDGPU::BUFFER_STORE_BYTE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 2670 /* buffer_store_b8 */, AMDGPU::BUFFER_STORE_BYTE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2670 /* buffer_store_b8 */, AMDGPU::BUFFER_STORE_BYTE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2670 /* buffer_store_b8 */, AMDGPU::BUFFER_STORE_BYTE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2670 /* buffer_store_b8 */, AMDGPU::BUFFER_STORE_BYTE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2670 /* buffer_store_b8 */, AMDGPU::BUFFER_STORE_BYTE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2670 /* buffer_store_b8 */, AMDGPU::BUFFER_STORE_BYTE_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2670 /* buffer_store_b8 */, AMDGPU::BUFFER_STORE_BYTE_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2670 /* buffer_store_b8 */, AMDGPU::BUFFER_STORE_BYTE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2670 /* buffer_store_b8 */, AMDGPU::BUFFER_STORE_BYTE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2670 /* buffer_store_b8 */, AMDGPU::BUFFER_STORE_BYTE_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2670 /* buffer_store_b8 */, AMDGPU::BUFFER_STORE_BYTE_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2670 /* buffer_store_b8 */, AMDGPU::BUFFER_STORE_BYTE_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2670 /* buffer_store_b8 */, AMDGPU::BUFFER_STORE_BYTE_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2670 /* buffer_store_b8 */, AMDGPU::BUFFER_STORE_BYTE_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2670 /* buffer_store_b8 */, AMDGPU::BUFFER_STORE_BYTE_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2686 /* buffer_store_b96 */, AMDGPU::BUFFER_STORE_DWORDX3_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 2686 /* buffer_store_b96 */, AMDGPU::BUFFER_STORE_DWORDX3_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2686 /* buffer_store_b96 */, AMDGPU::BUFFER_STORE_DWORDX3_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2686 /* buffer_store_b96 */, AMDGPU::BUFFER_STORE_DWORDX3_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2686 /* buffer_store_b96 */, AMDGPU::BUFFER_STORE_DWORDX3_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2686 /* buffer_store_b96 */, AMDGPU::BUFFER_STORE_DWORDX3_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2686 /* buffer_store_b96 */, AMDGPU::BUFFER_STORE_DWORDX3_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2686 /* buffer_store_b96 */, AMDGPU::BUFFER_STORE_DWORDX3_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2686 /* buffer_store_b96 */, AMDGPU::BUFFER_STORE_DWORDX3_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2686 /* buffer_store_b96 */, AMDGPU::BUFFER_STORE_DWORDX3_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2686 /* buffer_store_b96 */, AMDGPU::BUFFER_STORE_DWORDX3_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2686 /* buffer_store_b96 */, AMDGPU::BUFFER_STORE_DWORDX3_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2686 /* buffer_store_b96 */, AMDGPU::BUFFER_STORE_DWORDX3_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2686 /* buffer_store_b96 */, AMDGPU::BUFFER_STORE_DWORDX3_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2686 /* buffer_store_b96 */, AMDGPU::BUFFER_STORE_DWORDX3_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2686 /* buffer_store_b96 */, AMDGPU::BUFFER_STORE_DWORDX3_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_TFE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_TFE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_TFE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_TFE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_TFE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2703 /* buffer_store_byte */, AMDGPU::BUFFER_STORE_BYTE_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2721 /* buffer_store_byte_d16_hi */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2721 /* buffer_store_byte_d16_hi */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2721 /* buffer_store_byte_d16_hi */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2721 /* buffer_store_byte_d16_hi */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2721 /* buffer_store_byte_d16_hi */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2721 /* buffer_store_byte_d16_hi */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2721 /* buffer_store_byte_d16_hi */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2721 /* buffer_store_byte_d16_hi */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2721 /* buffer_store_byte_d16_hi */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2721 /* buffer_store_byte_d16_hi */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2721 /* buffer_store_byte_d16_hi */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2721 /* buffer_store_byte_d16_hi */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2721 /* buffer_store_byte_d16_hi */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2721 /* buffer_store_byte_d16_hi */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2721 /* buffer_store_byte_d16_hi */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2721 /* buffer_store_byte_d16_hi */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2721 /* buffer_store_byte_d16_hi */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2721 /* buffer_store_byte_d16_hi */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2721 /* buffer_store_byte_d16_hi */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2721 /* buffer_store_byte_d16_hi */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2746 /* buffer_store_d16_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 2746 /* buffer_store_d16_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2746 /* buffer_store_d16_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2746 /* buffer_store_d16_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2746 /* buffer_store_d16_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2746 /* buffer_store_d16_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2746 /* buffer_store_d16_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2746 /* buffer_store_d16_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2746 /* buffer_store_d16_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2746 /* buffer_store_d16_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2746 /* buffer_store_d16_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2746 /* buffer_store_d16_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2746 /* buffer_store_d16_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2746 /* buffer_store_d16_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2746 /* buffer_store_d16_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2746 /* buffer_store_d16_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2772 /* buffer_store_d16_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 2772 /* buffer_store_d16_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2772 /* buffer_store_d16_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2772 /* buffer_store_d16_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2772 /* buffer_store_d16_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2772 /* buffer_store_d16_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2772 /* buffer_store_d16_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2772 /* buffer_store_d16_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2772 /* buffer_store_d16_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2772 /* buffer_store_d16_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2772 /* buffer_store_d16_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2772 /* buffer_store_d16_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2772 /* buffer_store_d16_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2772 /* buffer_store_d16_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2772 /* buffer_store_d16_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2772 /* buffer_store_d16_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2799 /* buffer_store_d16_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 2799 /* buffer_store_d16_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2799 /* buffer_store_d16_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2799 /* buffer_store_d16_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2799 /* buffer_store_d16_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2799 /* buffer_store_d16_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2799 /* buffer_store_d16_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2799 /* buffer_store_d16_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2799 /* buffer_store_d16_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2799 /* buffer_store_d16_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2799 /* buffer_store_d16_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2799 /* buffer_store_d16_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2799 /* buffer_store_d16_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2799 /* buffer_store_d16_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2799 /* buffer_store_d16_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2799 /* buffer_store_d16_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2827 /* buffer_store_d16_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 2827 /* buffer_store_d16_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2827 /* buffer_store_d16_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2827 /* buffer_store_d16_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2827 /* buffer_store_d16_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2827 /* buffer_store_d16_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2827 /* buffer_store_d16_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2827 /* buffer_store_d16_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2827 /* buffer_store_d16_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2827 /* buffer_store_d16_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2827 /* buffer_store_d16_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2827 /* buffer_store_d16_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2827 /* buffer_store_d16_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2827 /* buffer_store_d16_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2827 /* buffer_store_d16_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2827 /* buffer_store_d16_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2856 /* buffer_store_d16_hi_b16 */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 2856 /* buffer_store_d16_hi_b16 */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2856 /* buffer_store_d16_hi_b16 */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2856 /* buffer_store_d16_hi_b16 */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2856 /* buffer_store_d16_hi_b16 */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2856 /* buffer_store_d16_hi_b16 */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2856 /* buffer_store_d16_hi_b16 */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2856 /* buffer_store_d16_hi_b16 */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2856 /* buffer_store_d16_hi_b16 */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2856 /* buffer_store_d16_hi_b16 */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2856 /* buffer_store_d16_hi_b16 */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2856 /* buffer_store_d16_hi_b16 */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2856 /* buffer_store_d16_hi_b16 */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2856 /* buffer_store_d16_hi_b16 */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2856 /* buffer_store_d16_hi_b16 */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2856 /* buffer_store_d16_hi_b16 */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2880 /* buffer_store_d16_hi_b8 */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 2880 /* buffer_store_d16_hi_b8 */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2880 /* buffer_store_d16_hi_b8 */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2880 /* buffer_store_d16_hi_b8 */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2880 /* buffer_store_d16_hi_b8 */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2880 /* buffer_store_d16_hi_b8 */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2880 /* buffer_store_d16_hi_b8 */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2880 /* buffer_store_d16_hi_b8 */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2880 /* buffer_store_d16_hi_b8 */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2880 /* buffer_store_d16_hi_b8 */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2880 /* buffer_store_d16_hi_b8 */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2880 /* buffer_store_d16_hi_b8 */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2880 /* buffer_store_d16_hi_b8 */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2880 /* buffer_store_d16_hi_b8 */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2880 /* buffer_store_d16_hi_b8 */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2880 /* buffer_store_d16_hi_b8 */, AMDGPU::BUFFER_STORE_BYTE_D16_HI_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2903 /* buffer_store_d16_hi_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 2903 /* buffer_store_d16_hi_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2903 /* buffer_store_d16_hi_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2903 /* buffer_store_d16_hi_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2903 /* buffer_store_d16_hi_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2903 /* buffer_store_d16_hi_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2903 /* buffer_store_d16_hi_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2903 /* buffer_store_d16_hi_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2903 /* buffer_store_d16_hi_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2903 /* buffer_store_d16_hi_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2903 /* buffer_store_d16_hi_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2903 /* buffer_store_d16_hi_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2903 /* buffer_store_d16_hi_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2903 /* buffer_store_d16_hi_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2903 /* buffer_store_d16_hi_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2903 /* buffer_store_d16_hi_format_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_TFE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_TFE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_TFE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_TFE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_TFE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2932 /* buffer_store_dword */, AMDGPU::BUFFER_STORE_DWORD_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_TFE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_TFE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_TFE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_TFE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_TFE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2951 /* buffer_store_dwordx2 */, AMDGPU::BUFFER_STORE_DWORDX2_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_TFE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_TFE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_TFE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_TFE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_TFE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2972 /* buffer_store_dwordx3 */, AMDGPU::BUFFER_STORE_DWORDX3_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_TFE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_TFE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_TFE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_TFE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_TFE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 2993 /* buffer_store_dwordx4 */, AMDGPU::BUFFER_STORE_DWORDX4_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3014 /* buffer_store_format_d16_hi_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3014 /* buffer_store_format_d16_hi_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3014 /* buffer_store_format_d16_hi_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3014 /* buffer_store_format_d16_hi_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3014 /* buffer_store_format_d16_hi_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3014 /* buffer_store_format_d16_hi_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3014 /* buffer_store_format_d16_hi_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3014 /* buffer_store_format_d16_hi_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3014 /* buffer_store_format_d16_hi_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3014 /* buffer_store_format_d16_hi_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3014 /* buffer_store_format_d16_hi_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3014 /* buffer_store_format_d16_hi_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3014 /* buffer_store_format_d16_hi_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3014 /* buffer_store_format_d16_hi_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3014 /* buffer_store_format_d16_hi_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3014 /* buffer_store_format_d16_hi_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3014 /* buffer_store_format_d16_hi_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3014 /* buffer_store_format_d16_hi_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3014 /* buffer_store_format_d16_hi_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3014 /* buffer_store_format_d16_hi_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_HI_X_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_gfx80_OFFSET_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_gfx80_IDXEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_gfx80_OFFEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_gfx80_TFE_OFFSET_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_gfx80_BOTHEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_gfx80_TFE_IDXEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_gfx80_TFE_OFFEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3043 /* buffer_store_format_d16_x */, AMDGPU::BUFFER_STORE_FORMAT_D16_X_gfx80_TFE_BOTHEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_gfx80_OFFSET_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_gfx80_IDXEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_gfx80_OFFEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_gfx80_TFE_OFFSET_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_gfx80_BOTHEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_gfx80_TFE_IDXEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_gfx80_TFE_OFFEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3069 /* buffer_store_format_d16_xy */, AMDGPU::BUFFER_STORE_FORMAT_D16_XY_gfx80_TFE_BOTHEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_gfx80_OFFSET_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_gfx80_IDXEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_gfx80_OFFEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_gfx80_TFE_OFFSET_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_gfx80_BOTHEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_gfx80_TFE_IDXEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_gfx80_TFE_OFFEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3096 /* buffer_store_format_d16_xyz */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZ_gfx80_TFE_BOTHEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_gfx80_OFFSET_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_gfx80_IDXEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_gfx80_OFFEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_gfx80_TFE_OFFSET_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_gfx80_BOTHEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_gfx80_TFE_IDXEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_gfx80_TFE_OFFEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3124 /* buffer_store_format_d16_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_D16_XYZW_gfx80_TFE_BOTHEN_gfx80, ConvertCustom_cvtMubuf, AMFBS_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_TFE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_TFE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_TFE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_TFE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_TFE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3153 /* buffer_store_format_x */, AMDGPU::BUFFER_STORE_FORMAT_X_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_TFE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_TFE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_TFE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_TFE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_TFE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3175 /* buffer_store_format_xy */, AMDGPU::BUFFER_STORE_FORMAT_XY_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_TFE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_TFE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_TFE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_TFE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_TFE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3198 /* buffer_store_format_xyz */, AMDGPU::BUFFER_STORE_FORMAT_XYZ_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_TFE_VBUFFER_OFFSET_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_TFE_OFFSET_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_TFE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_TFE_VBUFFER_IDXEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_TFE_VBUFFER_OFFEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_TFE_IDXEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_TFE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_TFE_OFFEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_TFE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_TFE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_TFE_VBUFFER_BOTHEN_gfx12, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_TFE_BOTHEN_gfx11, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_TFE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3222 /* buffer_store_format_xyzw */, AMDGPU::BUFFER_STORE_FORMAT_XYZW_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3247 /* buffer_store_lds_dword */, AMDGPU::BUFFER_STORE_LDS_DWORD_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX940_isGFX90APlus, { MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_lds, MCK_CPol }, },
  { 3247 /* buffer_store_lds_dword */, AMDGPU::BUFFER_STORE_LDS_DWORD_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX940_isGFX8GFX9NotGFX90A, { MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_lds, MCK_CPol }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_TFE_OFFSET_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_TFE_IDXEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_TFE_OFFEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_TFE_ADDR64_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_TFE_BOTHEN_gfx6_gfx7, ConvertCustom_cvtMubuf, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3270 /* buffer_store_short */, AMDGPU::BUFFER_STORE_SHORT_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3289 /* buffer_store_short_d16_hi */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3289 /* buffer_store_short_d16_hi */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_OFFSET_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3289 /* buffer_store_short_d16_hi */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 3289 /* buffer_store_short_d16_hi */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3289 /* buffer_store_short_d16_hi */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_IDXEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3289 /* buffer_store_short_d16_hi */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 3289 /* buffer_store_short_d16_hi */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3289 /* buffer_store_short_d16_hi */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_OFFEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3289 /* buffer_store_short_d16_hi */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3289 /* buffer_store_short_d16_hi */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_TFE_OFFSET_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3289 /* buffer_store_short_d16_hi */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_TFE_OFFSET_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3289 /* buffer_store_short_d16_hi */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3289 /* buffer_store_short_d16_hi */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_BOTHEN_gfx90a, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3289 /* buffer_store_short_d16_hi */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 3289 /* buffer_store_short_d16_hi */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_TFE_IDXEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3289 /* buffer_store_short_d16_hi */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_TFE_IDXEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3289 /* buffer_store_short_d16_hi */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_TFE_OFFEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3289 /* buffer_store_short_d16_hi */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_TFE_OFFEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3289 /* buffer_store_short_d16_hi */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_TFE_BOTHEN_gfx10, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3289 /* buffer_store_short_d16_hi */, AMDGPU::BUFFER_STORE_SHORT_D16_HI_TFE_BOTHEN_vi, ConvertCustom_cvtMubuf, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_128_XNULL, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol, MCK_tfe }, },
  { 3315 /* buffer_wbinvl1 */, AMDGPU::BUFFER_WBINVL1_gfx6_gfx7, Convert_NoOperands, AMFBS_isNotGFX940Plus_isGFX6GFX7, {  }, },
  { 3315 /* buffer_wbinvl1 */, AMDGPU::BUFFER_WBINVL1_vi, Convert_NoOperands, AMFBS_isNotGFX940Plus_isGFX8GFX9, {  }, },
  { 3330 /* buffer_wbinvl1_sc */, AMDGPU::BUFFER_WBINVL1_SC_gfx6, Convert_NoOperands, AMFBS_isGFX6, {  }, },
  { 3348 /* buffer_wbinvl1_vol */, AMDGPU::BUFFER_WBINVL1_VOL_gfx7, Convert_NoOperands, AMFBS_isNotGFX940Plus_isGFX7Only, {  }, },
  { 3348 /* buffer_wbinvl1_vol */, AMDGPU::BUFFER_WBINVL1_VOL_vi, Convert_NoOperands, AMFBS_isNotGFX940Plus_isGFX8GFX9, {  }, },
  { 3367 /* buffer_wbl2 */, AMDGPU::BUFFER_WBL2_gfx90a, Convert__imm_95_0, AMFBS_isGFX90AOnly, {  }, },
  { 3367 /* buffer_wbl2 */, AMDGPU::BUFFER_WBL2_gfx940, Convert__CPol1_0, AMFBS_isGFX940Plus, { MCK_CPol }, },
  { 3379 /* cluster_load_async_to_lds_b128 */, AMDGPU::CLUSTER_LOAD_ASYNC_TO_LDS_B128_SADDR_gfx1250, Convert__Reg1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 3379 /* cluster_load_async_to_lds_b128 */, AMDGPU::CLUSTER_LOAD_ASYNC_TO_LDS_B128_gfx1250, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 3410 /* cluster_load_async_to_lds_b32 */, AMDGPU::CLUSTER_LOAD_ASYNC_TO_LDS_B32_SADDR_gfx1250, Convert__Reg1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 3410 /* cluster_load_async_to_lds_b32 */, AMDGPU::CLUSTER_LOAD_ASYNC_TO_LDS_B32_gfx1250, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 3440 /* cluster_load_async_to_lds_b64 */, AMDGPU::CLUSTER_LOAD_ASYNC_TO_LDS_B64_SADDR_gfx1250, Convert__Reg1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 3440 /* cluster_load_async_to_lds_b64 */, AMDGPU::CLUSTER_LOAD_ASYNC_TO_LDS_B64_gfx1250, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 3470 /* cluster_load_async_to_lds_b8 */, AMDGPU::CLUSTER_LOAD_ASYNC_TO_LDS_B8_SADDR_gfx1250, Convert__Reg1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 3470 /* cluster_load_async_to_lds_b8 */, AMDGPU::CLUSTER_LOAD_ASYNC_TO_LDS_B8_gfx1250, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 3499 /* cluster_load_b128 */, AMDGPU::CLUSTER_LOAD_B128_SADDR_gfx1250, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 3499 /* cluster_load_b128 */, AMDGPU::CLUSTER_LOAD_B128_gfx1250, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 3517 /* cluster_load_b32 */, AMDGPU::CLUSTER_LOAD_B32_SADDR_gfx1250, Convert__Reg1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 3517 /* cluster_load_b32 */, AMDGPU::CLUSTER_LOAD_B32_gfx1250, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 3534 /* cluster_load_b64 */, AMDGPU::CLUSTER_LOAD_B64_SADDR_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 3534 /* cluster_load_b64 */, AMDGPU::CLUSTER_LOAD_B64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 3551 /* ds_add_f32 */, AMDGPU::DS_ADD_F32_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_HasLDSFPAtomicAddF32_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 3551 /* ds_add_f32 */, AMDGPU::DS_ADD_F32_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_HasLDSFPAtomicAddF32_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 3551 /* ds_add_f32 */, AMDGPU::DS_ADD_F32_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_HasLDSFPAtomicAddF32_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 3551 /* ds_add_f32 */, AMDGPU::DS_ADD_F32_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_HasLDSFPAtomicAddF32_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 3551 /* ds_add_f32 */, AMDGPU::DS_ADD_F32_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_HasLDSFPAtomicAddF32_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 3562 /* ds_add_f64 */, AMDGPU::DS_ADD_F64_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_HasLdsAtomicAddF64_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3562 /* ds_add_f64 */, AMDGPU::DS_ADD_F64_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_HasLdsAtomicAddF64_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3573 /* ds_add_gs_reg_rtn */, AMDGPU::DS_ADD_GS_REG_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Offset1_2, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_gds }, },
  { 3591 /* ds_add_rtn_f32 */, AMDGPU::DS_ADD_RTN_F32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_HasLDSFPAtomicAddF32_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 3591 /* ds_add_rtn_f32 */, AMDGPU::DS_ADD_RTN_F32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_HasLDSFPAtomicAddF32_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3591 /* ds_add_rtn_f32 */, AMDGPU::DS_ADD_RTN_F32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_HasLDSFPAtomicAddF32_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3591 /* ds_add_rtn_f32 */, AMDGPU::DS_ADD_RTN_F32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_HasLDSFPAtomicAddF32_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3591 /* ds_add_rtn_f32 */, AMDGPU::DS_ADD_RTN_F32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_HasLDSFPAtomicAddF32_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3591 /* ds_add_rtn_f32 */, AMDGPU::DS_ADD_RTN_F32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_HasLDSFPAtomicAddF32_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3606 /* ds_add_rtn_f64 */, AMDGPU::DS_ADD_RTN_F64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_HasLdsAtomicAddF64_isGFX90APlus, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 3606 /* ds_add_rtn_f64 */, AMDGPU::DS_ADD_RTN_F64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_HasLdsAtomicAddF64_isGFX12Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3606 /* ds_add_rtn_f64 */, AMDGPU::DS_ADD_RTN_F64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_HasLdsAtomicAddF64_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3621 /* ds_add_rtn_u32 */, AMDGPU::DS_ADD_RTN_U32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 3621 /* ds_add_rtn_u32 */, AMDGPU::DS_ADD_RTN_U32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3621 /* ds_add_rtn_u32 */, AMDGPU::DS_ADD_RTN_U32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3621 /* ds_add_rtn_u32 */, AMDGPU::DS_ADD_RTN_U32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3621 /* ds_add_rtn_u32 */, AMDGPU::DS_ADD_RTN_U32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3621 /* ds_add_rtn_u32 */, AMDGPU::DS_ADD_RTN_U32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3621 /* ds_add_rtn_u32 */, AMDGPU::DS_ADD_RTN_U32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3636 /* ds_add_rtn_u64 */, AMDGPU::DS_ADD_RTN_U64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 3636 /* ds_add_rtn_u64 */, AMDGPU::DS_ADD_RTN_U64_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3636 /* ds_add_rtn_u64 */, AMDGPU::DS_ADD_RTN_U64_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3636 /* ds_add_rtn_u64 */, AMDGPU::DS_ADD_RTN_U64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3636 /* ds_add_rtn_u64 */, AMDGPU::DS_ADD_RTN_U64_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3636 /* ds_add_rtn_u64 */, AMDGPU::DS_ADD_RTN_U64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3636 /* ds_add_rtn_u64 */, AMDGPU::DS_ADD_RTN_U64_vi_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3651 /* ds_add_src2_f32 */, AMDGPU::DS_ADD_SRC2_F32_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_HasLDSFPAtomicAddF32_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3651 /* ds_add_src2_f32 */, AMDGPU::DS_ADD_SRC2_F32_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_HasLDSFPAtomicAddF32_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3667 /* ds_add_src2_u32 */, AMDGPU::DS_ADD_SRC2_U32_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3667 /* ds_add_src2_u32 */, AMDGPU::DS_ADD_SRC2_U32_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3667 /* ds_add_src2_u32 */, AMDGPU::DS_ADD_SRC2_U32_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3683 /* ds_add_src2_u64 */, AMDGPU::DS_ADD_SRC2_U64_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3683 /* ds_add_src2_u64 */, AMDGPU::DS_ADD_SRC2_U64_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3683 /* ds_add_src2_u64 */, AMDGPU::DS_ADD_SRC2_U64_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3699 /* ds_add_u32 */, AMDGPU::DS_ADD_U32_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 3699 /* ds_add_u32 */, AMDGPU::DS_ADD_U32_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 3699 /* ds_add_u32 */, AMDGPU::DS_ADD_U32_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 3699 /* ds_add_u32 */, AMDGPU::DS_ADD_U32_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 3699 /* ds_add_u32 */, AMDGPU::DS_ADD_U32_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 3699 /* ds_add_u32 */, AMDGPU::DS_ADD_U32_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 3710 /* ds_add_u64 */, AMDGPU::DS_ADD_U64_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3710 /* ds_add_u64 */, AMDGPU::DS_ADD_U64_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3710 /* ds_add_u64 */, AMDGPU::DS_ADD_U64_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3710 /* ds_add_u64 */, AMDGPU::DS_ADD_U64_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3710 /* ds_add_u64 */, AMDGPU::DS_ADD_U64_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3710 /* ds_add_u64 */, AMDGPU::DS_ADD_U64_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3721 /* ds_and_b32 */, AMDGPU::DS_AND_B32_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 3721 /* ds_and_b32 */, AMDGPU::DS_AND_B32_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 3721 /* ds_and_b32 */, AMDGPU::DS_AND_B32_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 3721 /* ds_and_b32 */, AMDGPU::DS_AND_B32_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 3721 /* ds_and_b32 */, AMDGPU::DS_AND_B32_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 3721 /* ds_and_b32 */, AMDGPU::DS_AND_B32_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 3732 /* ds_and_b64 */, AMDGPU::DS_AND_B64_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3732 /* ds_and_b64 */, AMDGPU::DS_AND_B64_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3732 /* ds_and_b64 */, AMDGPU::DS_AND_B64_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3732 /* ds_and_b64 */, AMDGPU::DS_AND_B64_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3732 /* ds_and_b64 */, AMDGPU::DS_AND_B64_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3732 /* ds_and_b64 */, AMDGPU::DS_AND_B64_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3743 /* ds_and_rtn_b32 */, AMDGPU::DS_AND_RTN_B32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 3743 /* ds_and_rtn_b32 */, AMDGPU::DS_AND_RTN_B32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3743 /* ds_and_rtn_b32 */, AMDGPU::DS_AND_RTN_B32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3743 /* ds_and_rtn_b32 */, AMDGPU::DS_AND_RTN_B32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3743 /* ds_and_rtn_b32 */, AMDGPU::DS_AND_RTN_B32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3743 /* ds_and_rtn_b32 */, AMDGPU::DS_AND_RTN_B32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3743 /* ds_and_rtn_b32 */, AMDGPU::DS_AND_RTN_B32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3758 /* ds_and_rtn_b64 */, AMDGPU::DS_AND_RTN_B64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 3758 /* ds_and_rtn_b64 */, AMDGPU::DS_AND_RTN_B64_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3758 /* ds_and_rtn_b64 */, AMDGPU::DS_AND_RTN_B64_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3758 /* ds_and_rtn_b64 */, AMDGPU::DS_AND_RTN_B64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3758 /* ds_and_rtn_b64 */, AMDGPU::DS_AND_RTN_B64_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3758 /* ds_and_rtn_b64 */, AMDGPU::DS_AND_RTN_B64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3758 /* ds_and_rtn_b64 */, AMDGPU::DS_AND_RTN_B64_vi_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3773 /* ds_and_src2_b32 */, AMDGPU::DS_AND_SRC2_B32_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3773 /* ds_and_src2_b32 */, AMDGPU::DS_AND_SRC2_B32_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3773 /* ds_and_src2_b32 */, AMDGPU::DS_AND_SRC2_B32_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3789 /* ds_and_src2_b64 */, AMDGPU::DS_AND_SRC2_B64_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3789 /* ds_and_src2_b64 */, AMDGPU::DS_AND_SRC2_B64_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3789 /* ds_and_src2_b64 */, AMDGPU::DS_AND_SRC2_B64_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3805 /* ds_append */, AMDGPU::DS_APPEND_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Offset1_1__GDS1_2, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 3805 /* ds_append */, AMDGPU::DS_APPEND_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Offset1_1__GDS1_2, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 3805 /* ds_append */, AMDGPU::DS_APPEND_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Offset1_1__GDS1_2, AMFBS_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 3805 /* ds_append */, AMDGPU::DS_APPEND_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Offset1_1__GDS1_2, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 3805 /* ds_append */, AMDGPU::DS_APPEND_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Offset1_1__GDS1_2, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 3815 /* ds_atomic_async_barrier_arrive_b64 */, AMDGPU::DS_ATOMIC_ASYNC_BARRIER_ARRIVE_B64_gfx12, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasLdsBarrierArriveAtomic_isGFX1250Plus, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 3850 /* ds_atomic_barrier_arrive_rtn_b64 */, AMDGPU::DS_ATOMIC_BARRIER_ARRIVE_RTN_B64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_HasLdsBarrierArriveAtomic_isGFX1250Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 3883 /* ds_bpermute_b32 */, AMDGPU::DS_BPERMUTE_B32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3, AMFBS_isGFX8Plus_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_Offset }, },
  { 3883 /* ds_bpermute_b32 */, AMDGPU::DS_BPERMUTE_B32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3, AMFBS_isGFX8Plus_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset }, },
  { 3883 /* ds_bpermute_b32 */, AMDGPU::DS_BPERMUTE_B32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3, AMFBS_isGFX8Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset }, },
  { 3883 /* ds_bpermute_b32 */, AMDGPU::DS_BPERMUTE_B32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3, AMFBS_isGFX8Plus_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset }, },
  { 3883 /* ds_bpermute_b32 */, AMDGPU::DS_BPERMUTE_B32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3, AMFBS_isGFX8Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset }, },
  { 3899 /* ds_bpermute_fi_b32 */, AMDGPU::DS_BPERMUTE_FI_B32_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__RegByHwMode_AV_LdSt_32_Target1_2__Offset1_3, AMFBS_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset }, },
  { 3918 /* ds_bvh_stack_push4_pop1_rtn_b32 */, AMDGPU::DS_BVH_STACK_RTN_B32_gfx12, Convert__Reg1_0__Reg1_1__Tie1_1_1__Reg1_2__RegByHwMode_VReg_128_AlignTarget1_3__Offset1_4, AMFBS_HasImageInsts_isGFX11Plus_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_Offset }, },
  { 3950 /* ds_bvh_stack_push8_pop1_rtn_b32 */, AMDGPU::DS_BVH_STACK_PUSH8_POP1_RTN_B32_gfx12, Convert__Reg1_0__Reg1_1__Tie1_1_1__Reg1_2__RegByHwMode_VReg_256_AlignTarget1_3__Offset1_4, AMFBS_HasImageInsts_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_Offset }, },
  { 3982 /* ds_bvh_stack_push8_pop2_rtn_b64 */, AMDGPU::DS_BVH_STACK_PUSH8_POP2_RTN_B64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Tie1_1_1__Reg1_2__RegByHwMode_VReg_256_AlignTarget1_3__Offset1_4, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_Offset }, },
  { 4014 /* ds_bvh_stack_rtn_b32 */, AMDGPU::DS_BVH_STACK_RTN_B32_gfx11, Convert__Reg1_0__Reg1_1__Tie1_1_1__Reg1_2__RegByHwMode_VReg_128_AlignTarget1_3__Offset1_4, AMFBS_HasImageInsts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_Offset }, },
  { 4035 /* ds_cmpst_b32 */, AMDGPU::DS_CMPST_B32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_VGPR_32, MCK_AGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 4035 /* ds_cmpst_b32 */, AMDGPU::DS_CMPST_B32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4035 /* ds_cmpst_b32 */, AMDGPU::DS_CMPST_B32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4035 /* ds_cmpst_b32 */, AMDGPU::DS_CMPST_B32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4035 /* ds_cmpst_b32 */, AMDGPU::DS_CMPST_B32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4048 /* ds_cmpst_b64 */, AMDGPU::DS_CMPST_B64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_VGPR_32, MCK_AReg_64, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 4048 /* ds_cmpst_b64 */, AMDGPU::DS_CMPST_B64_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4048 /* ds_cmpst_b64 */, AMDGPU::DS_CMPST_B64_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4048 /* ds_cmpst_b64 */, AMDGPU::DS_CMPST_B64_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4048 /* ds_cmpst_b64 */, AMDGPU::DS_CMPST_B64_vi_gfx9, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4061 /* ds_cmpst_f32 */, AMDGPU::DS_CMPST_F32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_VGPR_32, MCK_AGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 4061 /* ds_cmpst_f32 */, AMDGPU::DS_CMPST_F32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4061 /* ds_cmpst_f32 */, AMDGPU::DS_CMPST_F32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4061 /* ds_cmpst_f32 */, AMDGPU::DS_CMPST_F32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4061 /* ds_cmpst_f32 */, AMDGPU::DS_CMPST_F32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4074 /* ds_cmpst_f64 */, AMDGPU::DS_CMPST_F64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_VGPR_32, MCK_AReg_64, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 4074 /* ds_cmpst_f64 */, AMDGPU::DS_CMPST_F64_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4074 /* ds_cmpst_f64 */, AMDGPU::DS_CMPST_F64_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4074 /* ds_cmpst_f64 */, AMDGPU::DS_CMPST_F64_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4074 /* ds_cmpst_f64 */, AMDGPU::DS_CMPST_F64_vi_gfx9, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4087 /* ds_cmpst_rtn_b32 */, AMDGPU::DS_CMPST_RTN_B32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 4087 /* ds_cmpst_rtn_b32 */, AMDGPU::DS_CMPST_RTN_B32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4087 /* ds_cmpst_rtn_b32 */, AMDGPU::DS_CMPST_RTN_B32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4087 /* ds_cmpst_rtn_b32 */, AMDGPU::DS_CMPST_RTN_B32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4087 /* ds_cmpst_rtn_b32 */, AMDGPU::DS_CMPST_RTN_B32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4104 /* ds_cmpst_rtn_b64 */, AMDGPU::DS_CMPST_RTN_B64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX90APlus, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 4104 /* ds_cmpst_rtn_b64 */, AMDGPU::DS_CMPST_RTN_B64_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset1_4__GDS1_5, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4104 /* ds_cmpst_rtn_b64 */, AMDGPU::DS_CMPST_RTN_B64_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset1_4__GDS1_5, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4104 /* ds_cmpst_rtn_b64 */, AMDGPU::DS_CMPST_RTN_B64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset1_4__GDS1_5, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4104 /* ds_cmpst_rtn_b64 */, AMDGPU::DS_CMPST_RTN_B64_vi_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset1_4__GDS1_5, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4121 /* ds_cmpst_rtn_f32 */, AMDGPU::DS_CMPST_RTN_F32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 4121 /* ds_cmpst_rtn_f32 */, AMDGPU::DS_CMPST_RTN_F32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4121 /* ds_cmpst_rtn_f32 */, AMDGPU::DS_CMPST_RTN_F32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4121 /* ds_cmpst_rtn_f32 */, AMDGPU::DS_CMPST_RTN_F32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4121 /* ds_cmpst_rtn_f32 */, AMDGPU::DS_CMPST_RTN_F32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4138 /* ds_cmpst_rtn_f64 */, AMDGPU::DS_CMPST_RTN_F64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX90APlus, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 4138 /* ds_cmpst_rtn_f64 */, AMDGPU::DS_CMPST_RTN_F64_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset1_4__GDS1_5, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4138 /* ds_cmpst_rtn_f64 */, AMDGPU::DS_CMPST_RTN_F64_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset1_4__GDS1_5, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4138 /* ds_cmpst_rtn_f64 */, AMDGPU::DS_CMPST_RTN_F64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset1_4__GDS1_5, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4138 /* ds_cmpst_rtn_f64 */, AMDGPU::DS_CMPST_RTN_F64_vi_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset1_4__GDS1_5, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4155 /* ds_cmpstore_b32 */, AMDGPU::DS_CMPSTORE_B32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4155 /* ds_cmpstore_b32 */, AMDGPU::DS_CMPSTORE_B32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4171 /* ds_cmpstore_b64 */, AMDGPU::DS_CMPSTORE_B64_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4171 /* ds_cmpstore_b64 */, AMDGPU::DS_CMPSTORE_B64_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4187 /* ds_cmpstore_f32 */, AMDGPU::DS_CMPSTORE_F32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4203 /* ds_cmpstore_f64 */, AMDGPU::DS_CMPSTORE_F64_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4219 /* ds_cmpstore_rtn_b32 */, AMDGPU::DS_CMPSTORE_RTN_B32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4219 /* ds_cmpstore_rtn_b32 */, AMDGPU::DS_CMPSTORE_RTN_B32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4239 /* ds_cmpstore_rtn_b64 */, AMDGPU::DS_CMPSTORE_RTN_B64_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset1_4__GDS1_5, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4239 /* ds_cmpstore_rtn_b64 */, AMDGPU::DS_CMPSTORE_RTN_B64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset1_4__GDS1_5, AMFBS_isGFX12Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4259 /* ds_cmpstore_rtn_f32 */, AMDGPU::DS_CMPSTORE_RTN_F32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4279 /* ds_cmpstore_rtn_f64 */, AMDGPU::DS_CMPSTORE_RTN_F64_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset1_4__GDS1_5, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4299 /* ds_cond_sub_rtn_u32 */, AMDGPU::DS_COND_SUB_RTN_U32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4319 /* ds_cond_sub_u32 */, AMDGPU::DS_COND_SUB_U32_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 4335 /* ds_condxchg32_rtn_b64 */, AMDGPU::DS_CONDXCHG32_RTN_B64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX7Plus_isGFX90APlus, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 4335 /* ds_condxchg32_rtn_b64 */, AMDGPU::DS_CONDXCHG32_RTN_B64_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX7Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4335 /* ds_condxchg32_rtn_b64 */, AMDGPU::DS_CONDXCHG32_RTN_B64_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX7Plus_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4335 /* ds_condxchg32_rtn_b64 */, AMDGPU::DS_CONDXCHG32_RTN_B64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX7Plus_isGFX12Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4335 /* ds_condxchg32_rtn_b64 */, AMDGPU::DS_CONDXCHG32_RTN_B64_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX7Plus_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4335 /* ds_condxchg32_rtn_b64 */, AMDGPU::DS_CONDXCHG32_RTN_B64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4335 /* ds_condxchg32_rtn_b64 */, AMDGPU::DS_CONDXCHG32_RTN_B64_vi_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4357 /* ds_consume */, AMDGPU::DS_CONSUME_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Offset1_1__GDS1_2, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 4357 /* ds_consume */, AMDGPU::DS_CONSUME_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Offset1_1__GDS1_2, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 4357 /* ds_consume */, AMDGPU::DS_CONSUME_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Offset1_1__GDS1_2, AMFBS_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 4357 /* ds_consume */, AMDGPU::DS_CONSUME_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Offset1_1__GDS1_2, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 4357 /* ds_consume */, AMDGPU::DS_CONSUME_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Offset1_1__GDS1_2, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 4368 /* ds_dec_rtn_u32 */, AMDGPU::DS_DEC_RTN_U32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 4368 /* ds_dec_rtn_u32 */, AMDGPU::DS_DEC_RTN_U32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4368 /* ds_dec_rtn_u32 */, AMDGPU::DS_DEC_RTN_U32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4368 /* ds_dec_rtn_u32 */, AMDGPU::DS_DEC_RTN_U32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4368 /* ds_dec_rtn_u32 */, AMDGPU::DS_DEC_RTN_U32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4368 /* ds_dec_rtn_u32 */, AMDGPU::DS_DEC_RTN_U32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4368 /* ds_dec_rtn_u32 */, AMDGPU::DS_DEC_RTN_U32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4383 /* ds_dec_rtn_u64 */, AMDGPU::DS_DEC_RTN_U64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 4383 /* ds_dec_rtn_u64 */, AMDGPU::DS_DEC_RTN_U64_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4383 /* ds_dec_rtn_u64 */, AMDGPU::DS_DEC_RTN_U64_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4383 /* ds_dec_rtn_u64 */, AMDGPU::DS_DEC_RTN_U64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4383 /* ds_dec_rtn_u64 */, AMDGPU::DS_DEC_RTN_U64_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4383 /* ds_dec_rtn_u64 */, AMDGPU::DS_DEC_RTN_U64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4383 /* ds_dec_rtn_u64 */, AMDGPU::DS_DEC_RTN_U64_vi_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4398 /* ds_dec_src2_u32 */, AMDGPU::DS_DEC_SRC2_U32_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4398 /* ds_dec_src2_u32 */, AMDGPU::DS_DEC_SRC2_U32_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4398 /* ds_dec_src2_u32 */, AMDGPU::DS_DEC_SRC2_U32_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4414 /* ds_dec_src2_u64 */, AMDGPU::DS_DEC_SRC2_U64_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4414 /* ds_dec_src2_u64 */, AMDGPU::DS_DEC_SRC2_U64_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4414 /* ds_dec_src2_u64 */, AMDGPU::DS_DEC_SRC2_U64_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4430 /* ds_dec_u32 */, AMDGPU::DS_DEC_U32_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 4430 /* ds_dec_u32 */, AMDGPU::DS_DEC_U32_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 4430 /* ds_dec_u32 */, AMDGPU::DS_DEC_U32_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 4430 /* ds_dec_u32 */, AMDGPU::DS_DEC_U32_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 4430 /* ds_dec_u32 */, AMDGPU::DS_DEC_U32_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 4430 /* ds_dec_u32 */, AMDGPU::DS_DEC_U32_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 4441 /* ds_dec_u64 */, AMDGPU::DS_DEC_U64_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4441 /* ds_dec_u64 */, AMDGPU::DS_DEC_U64_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4441 /* ds_dec_u64 */, AMDGPU::DS_DEC_U64_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4441 /* ds_dec_u64 */, AMDGPU::DS_DEC_U64_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4441 /* ds_dec_u64 */, AMDGPU::DS_DEC_U64_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4441 /* ds_dec_u64 */, AMDGPU::DS_DEC_U64_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4452 /* ds_direct_load */, AMDGPU::DS_DIRECT_LOAD_gfx12, Convert__Reg1_0__WaitVAVDst1_1__WaitVMVSrc1_2, AMFBS_isGFX12PlusNot12_50_isGFX12Plus, { MCK_VGPR_32, MCK_WaitVAVDst, MCK_WaitVMVSrc }, },
  { 4467 /* ds_gws_barrier */, AMDGPU::DS_GWS_BARRIER_gfx10, Convert__AV_LdSt_32_Align2_RegOp1_0__Offset1_1, AMFBS_isGFX10Only, { MCK_AV_LdSt_32_Align2_RegOp, MCK_Offset, MCK_gds }, },
  { 4467 /* ds_gws_barrier */, AMDGPU::DS_GWS_BARRIER_gfx11, Convert__AV_LdSt_32_Align2_RegOp1_0__Offset1_1, AMFBS_isGFX11Only, { MCK_AV_LdSt_32_Align2_RegOp, MCK_Offset, MCK_gds }, },
  { 4467 /* ds_gws_barrier */, AMDGPU::DS_GWS_BARRIER_gfx6_gfx7, Convert__AV_LdSt_32_Align2_RegOp1_0__Offset1_1, AMFBS_isGFX6GFX7, { MCK_AV_LdSt_32_Align2_RegOp, MCK_Offset, MCK_gds }, },
  { 4467 /* ds_gws_barrier */, AMDGPU::DS_GWS_BARRIER_vi, Convert__AV_LdSt_32_Align2_RegOp1_0__Offset1_1, AMFBS_isGFX8GFX9, { MCK_AV_LdSt_32_Align2_RegOp, MCK_Offset, MCK_gds }, },
  { 4482 /* ds_gws_init */, AMDGPU::DS_GWS_INIT_gfx10, Convert__AV_LdSt_32_Align2_RegOp1_0__Offset1_1, AMFBS_isGFX10Only, { MCK_AV_LdSt_32_Align2_RegOp, MCK_Offset, MCK_gds }, },
  { 4482 /* ds_gws_init */, AMDGPU::DS_GWS_INIT_gfx11, Convert__AV_LdSt_32_Align2_RegOp1_0__Offset1_1, AMFBS_isGFX11Only, { MCK_AV_LdSt_32_Align2_RegOp, MCK_Offset, MCK_gds }, },
  { 4482 /* ds_gws_init */, AMDGPU::DS_GWS_INIT_gfx6_gfx7, Convert__AV_LdSt_32_Align2_RegOp1_0__Offset1_1, AMFBS_isGFX6GFX7, { MCK_AV_LdSt_32_Align2_RegOp, MCK_Offset, MCK_gds }, },
  { 4482 /* ds_gws_init */, AMDGPU::DS_GWS_INIT_vi, Convert__AV_LdSt_32_Align2_RegOp1_0__Offset1_1, AMFBS_isGFX8GFX9, { MCK_AV_LdSt_32_Align2_RegOp, MCK_Offset, MCK_gds }, },
  { 4494 /* ds_gws_sema_br */, AMDGPU::DS_GWS_SEMA_BR_gfx10, Convert__AV_LdSt_32_Align2_RegOp1_0__Offset1_1, AMFBS_isGFX10Only, { MCK_AV_LdSt_32_Align2_RegOp, MCK_Offset, MCK_gds }, },
  { 4494 /* ds_gws_sema_br */, AMDGPU::DS_GWS_SEMA_BR_gfx11, Convert__AV_LdSt_32_Align2_RegOp1_0__Offset1_1, AMFBS_isGFX11Only, { MCK_AV_LdSt_32_Align2_RegOp, MCK_Offset, MCK_gds }, },
  { 4494 /* ds_gws_sema_br */, AMDGPU::DS_GWS_SEMA_BR_gfx6_gfx7, Convert__AV_LdSt_32_Align2_RegOp1_0__Offset1_1, AMFBS_isGFX6GFX7, { MCK_AV_LdSt_32_Align2_RegOp, MCK_Offset, MCK_gds }, },
  { 4494 /* ds_gws_sema_br */, AMDGPU::DS_GWS_SEMA_BR_vi, Convert__AV_LdSt_32_Align2_RegOp1_0__Offset1_1, AMFBS_isGFX8GFX9, { MCK_AV_LdSt_32_Align2_RegOp, MCK_Offset, MCK_gds }, },
  { 4509 /* ds_gws_sema_p */, AMDGPU::DS_GWS_SEMA_P_gfx10, Convert__Offset1_0, AMFBS_isGFX10Only, { MCK_Offset, MCK_gds }, },
  { 4509 /* ds_gws_sema_p */, AMDGPU::DS_GWS_SEMA_P_gfx11, Convert__Offset1_0, AMFBS_isGFX11Only, { MCK_Offset, MCK_gds }, },
  { 4509 /* ds_gws_sema_p */, AMDGPU::DS_GWS_SEMA_P_gfx6_gfx7, Convert__Offset1_0, AMFBS_isGFX6GFX7, { MCK_Offset, MCK_gds }, },
  { 4509 /* ds_gws_sema_p */, AMDGPU::DS_GWS_SEMA_P_vi, Convert__Offset1_0, AMFBS_isGFX8GFX9, { MCK_Offset, MCK_gds }, },
  { 4523 /* ds_gws_sema_release_all */, AMDGPU::DS_GWS_SEMA_RELEASE_ALL_gfx10, Convert__Offset1_0, AMFBS_isGFX7Plus_isGFX10Only, { MCK_Offset, MCK_gds }, },
  { 4523 /* ds_gws_sema_release_all */, AMDGPU::DS_GWS_SEMA_RELEASE_ALL_gfx11, Convert__Offset1_0, AMFBS_isGFX7Plus_isGFX11Only, { MCK_Offset, MCK_gds }, },
  { 4523 /* ds_gws_sema_release_all */, AMDGPU::DS_GWS_SEMA_RELEASE_ALL_gfx7, Convert__Offset1_0, AMFBS_isGFX7Plus_isGFX7Only, { MCK_Offset, MCK_gds }, },
  { 4523 /* ds_gws_sema_release_all */, AMDGPU::DS_GWS_SEMA_RELEASE_ALL_vi, Convert__Offset1_0, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_Offset, MCK_gds }, },
  { 4547 /* ds_gws_sema_v */, AMDGPU::DS_GWS_SEMA_V_gfx10, Convert__Offset1_0, AMFBS_isGFX10Only, { MCK_Offset, MCK_gds }, },
  { 4547 /* ds_gws_sema_v */, AMDGPU::DS_GWS_SEMA_V_gfx11, Convert__Offset1_0, AMFBS_isGFX11Only, { MCK_Offset, MCK_gds }, },
  { 4547 /* ds_gws_sema_v */, AMDGPU::DS_GWS_SEMA_V_gfx6_gfx7, Convert__Offset1_0, AMFBS_isGFX6GFX7, { MCK_Offset, MCK_gds }, },
  { 4547 /* ds_gws_sema_v */, AMDGPU::DS_GWS_SEMA_V_vi, Convert__Offset1_0, AMFBS_isGFX8GFX9, { MCK_Offset, MCK_gds }, },
  { 4561 /* ds_inc_rtn_u32 */, AMDGPU::DS_INC_RTN_U32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 4561 /* ds_inc_rtn_u32 */, AMDGPU::DS_INC_RTN_U32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4561 /* ds_inc_rtn_u32 */, AMDGPU::DS_INC_RTN_U32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4561 /* ds_inc_rtn_u32 */, AMDGPU::DS_INC_RTN_U32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4561 /* ds_inc_rtn_u32 */, AMDGPU::DS_INC_RTN_U32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4561 /* ds_inc_rtn_u32 */, AMDGPU::DS_INC_RTN_U32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4561 /* ds_inc_rtn_u32 */, AMDGPU::DS_INC_RTN_U32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4576 /* ds_inc_rtn_u64 */, AMDGPU::DS_INC_RTN_U64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 4576 /* ds_inc_rtn_u64 */, AMDGPU::DS_INC_RTN_U64_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4576 /* ds_inc_rtn_u64 */, AMDGPU::DS_INC_RTN_U64_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4576 /* ds_inc_rtn_u64 */, AMDGPU::DS_INC_RTN_U64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4576 /* ds_inc_rtn_u64 */, AMDGPU::DS_INC_RTN_U64_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4576 /* ds_inc_rtn_u64 */, AMDGPU::DS_INC_RTN_U64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4576 /* ds_inc_rtn_u64 */, AMDGPU::DS_INC_RTN_U64_vi_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4591 /* ds_inc_src2_u32 */, AMDGPU::DS_INC_SRC2_U32_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4591 /* ds_inc_src2_u32 */, AMDGPU::DS_INC_SRC2_U32_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4591 /* ds_inc_src2_u32 */, AMDGPU::DS_INC_SRC2_U32_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4607 /* ds_inc_src2_u64 */, AMDGPU::DS_INC_SRC2_U64_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4607 /* ds_inc_src2_u64 */, AMDGPU::DS_INC_SRC2_U64_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4607 /* ds_inc_src2_u64 */, AMDGPU::DS_INC_SRC2_U64_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4623 /* ds_inc_u32 */, AMDGPU::DS_INC_U32_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 4623 /* ds_inc_u32 */, AMDGPU::DS_INC_U32_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 4623 /* ds_inc_u32 */, AMDGPU::DS_INC_U32_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 4623 /* ds_inc_u32 */, AMDGPU::DS_INC_U32_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 4623 /* ds_inc_u32 */, AMDGPU::DS_INC_U32_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 4623 /* ds_inc_u32 */, AMDGPU::DS_INC_U32_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 4634 /* ds_inc_u64 */, AMDGPU::DS_INC_U64_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4634 /* ds_inc_u64 */, AMDGPU::DS_INC_U64_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4634 /* ds_inc_u64 */, AMDGPU::DS_INC_U64_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4634 /* ds_inc_u64 */, AMDGPU::DS_INC_U64_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4634 /* ds_inc_u64 */, AMDGPU::DS_INC_U64_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4634 /* ds_inc_u64 */, AMDGPU::DS_INC_U64_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 4645 /* ds_load_2addr_b32 */, AMDGPU::DS_READ2_B32_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 4645 /* ds_load_2addr_b32 */, AMDGPU::DS_READ2_B32_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 4663 /* ds_load_2addr_b64 */, AMDGPU::DS_READ2_B64_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 4663 /* ds_load_2addr_b64 */, AMDGPU::DS_READ2_B64_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 4681 /* ds_load_2addr_stride64_b32 */, AMDGPU::DS_READ2ST64_B32_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 4681 /* ds_load_2addr_stride64_b32 */, AMDGPU::DS_READ2ST64_B32_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 4708 /* ds_load_2addr_stride64_b64 */, AMDGPU::DS_READ2ST64_B64_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 4708 /* ds_load_2addr_stride64_b64 */, AMDGPU::DS_READ2ST64_B64_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 4735 /* ds_load_addtid_b32 */, AMDGPU::DS_READ_ADDTID_B32_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Offset1_1__GDS1_2, AMFBS_HasDSAddTid_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 4735 /* ds_load_addtid_b32 */, AMDGPU::DS_READ_ADDTID_B32_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Offset1_1__GDS1_2, AMFBS_HasDSAddTid_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 4754 /* ds_load_b128 */, AMDGPU::DS_READ_B128_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4754 /* ds_load_b128 */, AMDGPU::DS_READ_B128_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4767 /* ds_load_b32 */, AMDGPU::DS_READ_B32_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4767 /* ds_load_b32 */, AMDGPU::DS_READ_B32_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4779 /* ds_load_b64 */, AMDGPU::DS_READ_B64_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4779 /* ds_load_b64 */, AMDGPU::DS_READ_B64_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4791 /* ds_load_b96 */, AMDGPU::DS_READ_B96_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4791 /* ds_load_b96 */, AMDGPU::DS_READ_B96_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4803 /* ds_load_i16 */, AMDGPU::DS_READ_I16_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4803 /* ds_load_i16 */, AMDGPU::DS_READ_I16_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4815 /* ds_load_i8 */, AMDGPU::DS_READ_I8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4815 /* ds_load_i8 */, AMDGPU::DS_READ_I8_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4826 /* ds_load_i8_d16 */, AMDGPU::DS_READ_I8_D16_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4826 /* ds_load_i8_d16 */, AMDGPU::DS_READ_I8_D16_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4841 /* ds_load_i8_d16_hi */, AMDGPU::DS_READ_I8_D16_HI_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4841 /* ds_load_i8_d16_hi */, AMDGPU::DS_READ_I8_D16_HI_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4859 /* ds_load_tr16_b128 */, AMDGPU::DS_LOAD_TR16_B128_gfx12, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX1250Plus_isGFX12Plus_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4877 /* ds_load_tr4_b64 */, AMDGPU::DS_LOAD_TR4_B64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_HasTransposeLoadF4F6Insts_isGFX1250Plus_isGFX12Plus_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4893 /* ds_load_tr6_b96 */, AMDGPU::DS_LOAD_TR6_B96_gfx12, Convert__Reg1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_HasTransposeLoadF4F6Insts_isGFX1250Plus_isGFX12Plus_isWave32, { MCK_VReg_96, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4909 /* ds_load_tr8_b64 */, AMDGPU::DS_LOAD_TR8_B64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX1250Plus_isGFX12Plus_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4925 /* ds_load_u16 */, AMDGPU::DS_READ_U16_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4925 /* ds_load_u16 */, AMDGPU::DS_READ_U16_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4937 /* ds_load_u16_d16 */, AMDGPU::DS_READ_U16_D16_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4937 /* ds_load_u16_d16 */, AMDGPU::DS_READ_U16_D16_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4953 /* ds_load_u16_d16_hi */, AMDGPU::DS_READ_U16_D16_HI_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4953 /* ds_load_u16_d16_hi */, AMDGPU::DS_READ_U16_D16_HI_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4972 /* ds_load_u8 */, AMDGPU::DS_READ_U8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4972 /* ds_load_u8 */, AMDGPU::DS_READ_U8_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4983 /* ds_load_u8_d16 */, AMDGPU::DS_READ_U8_D16_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4983 /* ds_load_u8_d16 */, AMDGPU::DS_READ_U8_D16_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4998 /* ds_load_u8_d16_hi */, AMDGPU::DS_READ_U8_D16_HI_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 4998 /* ds_load_u8_d16_hi */, AMDGPU::DS_READ_U8_D16_HI_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5016 /* ds_max_f32 */, AMDGPU::DS_MAX_F32_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5016 /* ds_max_f32 */, AMDGPU::DS_MAX_F32_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5016 /* ds_max_f32 */, AMDGPU::DS_MAX_F32_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5016 /* ds_max_f32 */, AMDGPU::DS_MAX_F32_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5016 /* ds_max_f32 */, AMDGPU::DS_MAX_F32_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5027 /* ds_max_f64 */, AMDGPU::DS_MAX_F64_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5027 /* ds_max_f64 */, AMDGPU::DS_MAX_F64_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5027 /* ds_max_f64 */, AMDGPU::DS_MAX_F64_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5027 /* ds_max_f64 */, AMDGPU::DS_MAX_F64_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5027 /* ds_max_f64 */, AMDGPU::DS_MAX_F64_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5038 /* ds_max_i32 */, AMDGPU::DS_MAX_I32_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5038 /* ds_max_i32 */, AMDGPU::DS_MAX_I32_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5038 /* ds_max_i32 */, AMDGPU::DS_MAX_I32_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5038 /* ds_max_i32 */, AMDGPU::DS_MAX_I32_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5038 /* ds_max_i32 */, AMDGPU::DS_MAX_I32_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5038 /* ds_max_i32 */, AMDGPU::DS_MAX_I32_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5049 /* ds_max_i64 */, AMDGPU::DS_MAX_I64_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5049 /* ds_max_i64 */, AMDGPU::DS_MAX_I64_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5049 /* ds_max_i64 */, AMDGPU::DS_MAX_I64_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5049 /* ds_max_i64 */, AMDGPU::DS_MAX_I64_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5049 /* ds_max_i64 */, AMDGPU::DS_MAX_I64_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5049 /* ds_max_i64 */, AMDGPU::DS_MAX_I64_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5060 /* ds_max_num_f32 */, AMDGPU::DS_MAX_F32_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5075 /* ds_max_num_f64 */, AMDGPU::DS_MAX_F64_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5090 /* ds_max_num_rtn_f32 */, AMDGPU::DS_MAX_RTN_F32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5109 /* ds_max_num_rtn_f64 */, AMDGPU::DS_MAX_RTN_F64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5128 /* ds_max_rtn_f32 */, AMDGPU::DS_MAX_RTN_F32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 5128 /* ds_max_rtn_f32 */, AMDGPU::DS_MAX_RTN_F32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5128 /* ds_max_rtn_f32 */, AMDGPU::DS_MAX_RTN_F32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5128 /* ds_max_rtn_f32 */, AMDGPU::DS_MAX_RTN_F32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5128 /* ds_max_rtn_f32 */, AMDGPU::DS_MAX_RTN_F32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5128 /* ds_max_rtn_f32 */, AMDGPU::DS_MAX_RTN_F32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5143 /* ds_max_rtn_f64 */, AMDGPU::DS_MAX_RTN_F64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 5143 /* ds_max_rtn_f64 */, AMDGPU::DS_MAX_RTN_F64_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5143 /* ds_max_rtn_f64 */, AMDGPU::DS_MAX_RTN_F64_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5143 /* ds_max_rtn_f64 */, AMDGPU::DS_MAX_RTN_F64_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5143 /* ds_max_rtn_f64 */, AMDGPU::DS_MAX_RTN_F64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5143 /* ds_max_rtn_f64 */, AMDGPU::DS_MAX_RTN_F64_vi_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5158 /* ds_max_rtn_i32 */, AMDGPU::DS_MAX_RTN_I32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 5158 /* ds_max_rtn_i32 */, AMDGPU::DS_MAX_RTN_I32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5158 /* ds_max_rtn_i32 */, AMDGPU::DS_MAX_RTN_I32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5158 /* ds_max_rtn_i32 */, AMDGPU::DS_MAX_RTN_I32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5158 /* ds_max_rtn_i32 */, AMDGPU::DS_MAX_RTN_I32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5158 /* ds_max_rtn_i32 */, AMDGPU::DS_MAX_RTN_I32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5158 /* ds_max_rtn_i32 */, AMDGPU::DS_MAX_RTN_I32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5173 /* ds_max_rtn_i64 */, AMDGPU::DS_MAX_RTN_I64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 5173 /* ds_max_rtn_i64 */, AMDGPU::DS_MAX_RTN_I64_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5173 /* ds_max_rtn_i64 */, AMDGPU::DS_MAX_RTN_I64_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5173 /* ds_max_rtn_i64 */, AMDGPU::DS_MAX_RTN_I64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5173 /* ds_max_rtn_i64 */, AMDGPU::DS_MAX_RTN_I64_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5173 /* ds_max_rtn_i64 */, AMDGPU::DS_MAX_RTN_I64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5173 /* ds_max_rtn_i64 */, AMDGPU::DS_MAX_RTN_I64_vi_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5188 /* ds_max_rtn_u32 */, AMDGPU::DS_MAX_RTN_U32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 5188 /* ds_max_rtn_u32 */, AMDGPU::DS_MAX_RTN_U32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5188 /* ds_max_rtn_u32 */, AMDGPU::DS_MAX_RTN_U32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5188 /* ds_max_rtn_u32 */, AMDGPU::DS_MAX_RTN_U32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5188 /* ds_max_rtn_u32 */, AMDGPU::DS_MAX_RTN_U32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5188 /* ds_max_rtn_u32 */, AMDGPU::DS_MAX_RTN_U32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5188 /* ds_max_rtn_u32 */, AMDGPU::DS_MAX_RTN_U32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5203 /* ds_max_rtn_u64 */, AMDGPU::DS_MAX_RTN_U64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 5203 /* ds_max_rtn_u64 */, AMDGPU::DS_MAX_RTN_U64_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5203 /* ds_max_rtn_u64 */, AMDGPU::DS_MAX_RTN_U64_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5203 /* ds_max_rtn_u64 */, AMDGPU::DS_MAX_RTN_U64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5203 /* ds_max_rtn_u64 */, AMDGPU::DS_MAX_RTN_U64_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5203 /* ds_max_rtn_u64 */, AMDGPU::DS_MAX_RTN_U64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5203 /* ds_max_rtn_u64 */, AMDGPU::DS_MAX_RTN_U64_vi_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5218 /* ds_max_src2_f32 */, AMDGPU::DS_MAX_SRC2_F32_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5218 /* ds_max_src2_f32 */, AMDGPU::DS_MAX_SRC2_F32_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5218 /* ds_max_src2_f32 */, AMDGPU::DS_MAX_SRC2_F32_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5234 /* ds_max_src2_f64 */, AMDGPU::DS_MAX_SRC2_F64_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5234 /* ds_max_src2_f64 */, AMDGPU::DS_MAX_SRC2_F64_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5234 /* ds_max_src2_f64 */, AMDGPU::DS_MAX_SRC2_F64_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5250 /* ds_max_src2_i32 */, AMDGPU::DS_MAX_SRC2_I32_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5250 /* ds_max_src2_i32 */, AMDGPU::DS_MAX_SRC2_I32_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5250 /* ds_max_src2_i32 */, AMDGPU::DS_MAX_SRC2_I32_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5266 /* ds_max_src2_i64 */, AMDGPU::DS_MAX_SRC2_I64_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5266 /* ds_max_src2_i64 */, AMDGPU::DS_MAX_SRC2_I64_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5266 /* ds_max_src2_i64 */, AMDGPU::DS_MAX_SRC2_I64_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5282 /* ds_max_src2_u32 */, AMDGPU::DS_MAX_SRC2_U32_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5282 /* ds_max_src2_u32 */, AMDGPU::DS_MAX_SRC2_U32_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5282 /* ds_max_src2_u32 */, AMDGPU::DS_MAX_SRC2_U32_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5298 /* ds_max_src2_u64 */, AMDGPU::DS_MAX_SRC2_U64_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5298 /* ds_max_src2_u64 */, AMDGPU::DS_MAX_SRC2_U64_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5298 /* ds_max_src2_u64 */, AMDGPU::DS_MAX_SRC2_U64_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5314 /* ds_max_u32 */, AMDGPU::DS_MAX_U32_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5314 /* ds_max_u32 */, AMDGPU::DS_MAX_U32_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5314 /* ds_max_u32 */, AMDGPU::DS_MAX_U32_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5314 /* ds_max_u32 */, AMDGPU::DS_MAX_U32_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5314 /* ds_max_u32 */, AMDGPU::DS_MAX_U32_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5314 /* ds_max_u32 */, AMDGPU::DS_MAX_U32_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5325 /* ds_max_u64 */, AMDGPU::DS_MAX_U64_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5325 /* ds_max_u64 */, AMDGPU::DS_MAX_U64_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5325 /* ds_max_u64 */, AMDGPU::DS_MAX_U64_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5325 /* ds_max_u64 */, AMDGPU::DS_MAX_U64_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5325 /* ds_max_u64 */, AMDGPU::DS_MAX_U64_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5325 /* ds_max_u64 */, AMDGPU::DS_MAX_U64_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5336 /* ds_min_f32 */, AMDGPU::DS_MIN_F32_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5336 /* ds_min_f32 */, AMDGPU::DS_MIN_F32_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5336 /* ds_min_f32 */, AMDGPU::DS_MIN_F32_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5336 /* ds_min_f32 */, AMDGPU::DS_MIN_F32_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5336 /* ds_min_f32 */, AMDGPU::DS_MIN_F32_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5347 /* ds_min_f64 */, AMDGPU::DS_MIN_F64_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5347 /* ds_min_f64 */, AMDGPU::DS_MIN_F64_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5347 /* ds_min_f64 */, AMDGPU::DS_MIN_F64_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5347 /* ds_min_f64 */, AMDGPU::DS_MIN_F64_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5347 /* ds_min_f64 */, AMDGPU::DS_MIN_F64_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5358 /* ds_min_i32 */, AMDGPU::DS_MIN_I32_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5358 /* ds_min_i32 */, AMDGPU::DS_MIN_I32_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5358 /* ds_min_i32 */, AMDGPU::DS_MIN_I32_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5358 /* ds_min_i32 */, AMDGPU::DS_MIN_I32_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5358 /* ds_min_i32 */, AMDGPU::DS_MIN_I32_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5358 /* ds_min_i32 */, AMDGPU::DS_MIN_I32_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5369 /* ds_min_i64 */, AMDGPU::DS_MIN_I64_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5369 /* ds_min_i64 */, AMDGPU::DS_MIN_I64_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5369 /* ds_min_i64 */, AMDGPU::DS_MIN_I64_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5369 /* ds_min_i64 */, AMDGPU::DS_MIN_I64_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5369 /* ds_min_i64 */, AMDGPU::DS_MIN_I64_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5369 /* ds_min_i64 */, AMDGPU::DS_MIN_I64_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5380 /* ds_min_num_f32 */, AMDGPU::DS_MIN_F32_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5395 /* ds_min_num_f64 */, AMDGPU::DS_MIN_F64_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5410 /* ds_min_num_rtn_f32 */, AMDGPU::DS_MIN_RTN_F32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5429 /* ds_min_num_rtn_f64 */, AMDGPU::DS_MIN_RTN_F64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5448 /* ds_min_rtn_f32 */, AMDGPU::DS_MIN_RTN_F32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 5448 /* ds_min_rtn_f32 */, AMDGPU::DS_MIN_RTN_F32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5448 /* ds_min_rtn_f32 */, AMDGPU::DS_MIN_RTN_F32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5448 /* ds_min_rtn_f32 */, AMDGPU::DS_MIN_RTN_F32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5448 /* ds_min_rtn_f32 */, AMDGPU::DS_MIN_RTN_F32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5448 /* ds_min_rtn_f32 */, AMDGPU::DS_MIN_RTN_F32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5463 /* ds_min_rtn_f64 */, AMDGPU::DS_MIN_RTN_F64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 5463 /* ds_min_rtn_f64 */, AMDGPU::DS_MIN_RTN_F64_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5463 /* ds_min_rtn_f64 */, AMDGPU::DS_MIN_RTN_F64_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5463 /* ds_min_rtn_f64 */, AMDGPU::DS_MIN_RTN_F64_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5463 /* ds_min_rtn_f64 */, AMDGPU::DS_MIN_RTN_F64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5463 /* ds_min_rtn_f64 */, AMDGPU::DS_MIN_RTN_F64_vi_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5478 /* ds_min_rtn_i32 */, AMDGPU::DS_MIN_RTN_I32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 5478 /* ds_min_rtn_i32 */, AMDGPU::DS_MIN_RTN_I32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5478 /* ds_min_rtn_i32 */, AMDGPU::DS_MIN_RTN_I32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5478 /* ds_min_rtn_i32 */, AMDGPU::DS_MIN_RTN_I32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5478 /* ds_min_rtn_i32 */, AMDGPU::DS_MIN_RTN_I32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5478 /* ds_min_rtn_i32 */, AMDGPU::DS_MIN_RTN_I32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5478 /* ds_min_rtn_i32 */, AMDGPU::DS_MIN_RTN_I32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5493 /* ds_min_rtn_i64 */, AMDGPU::DS_MIN_RTN_I64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 5493 /* ds_min_rtn_i64 */, AMDGPU::DS_MIN_RTN_I64_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5493 /* ds_min_rtn_i64 */, AMDGPU::DS_MIN_RTN_I64_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5493 /* ds_min_rtn_i64 */, AMDGPU::DS_MIN_RTN_I64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5493 /* ds_min_rtn_i64 */, AMDGPU::DS_MIN_RTN_I64_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5493 /* ds_min_rtn_i64 */, AMDGPU::DS_MIN_RTN_I64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5493 /* ds_min_rtn_i64 */, AMDGPU::DS_MIN_RTN_I64_vi_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5508 /* ds_min_rtn_u32 */, AMDGPU::DS_MIN_RTN_U32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 5508 /* ds_min_rtn_u32 */, AMDGPU::DS_MIN_RTN_U32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5508 /* ds_min_rtn_u32 */, AMDGPU::DS_MIN_RTN_U32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5508 /* ds_min_rtn_u32 */, AMDGPU::DS_MIN_RTN_U32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5508 /* ds_min_rtn_u32 */, AMDGPU::DS_MIN_RTN_U32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5508 /* ds_min_rtn_u32 */, AMDGPU::DS_MIN_RTN_U32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5508 /* ds_min_rtn_u32 */, AMDGPU::DS_MIN_RTN_U32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5523 /* ds_min_rtn_u64 */, AMDGPU::DS_MIN_RTN_U64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 5523 /* ds_min_rtn_u64 */, AMDGPU::DS_MIN_RTN_U64_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5523 /* ds_min_rtn_u64 */, AMDGPU::DS_MIN_RTN_U64_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5523 /* ds_min_rtn_u64 */, AMDGPU::DS_MIN_RTN_U64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5523 /* ds_min_rtn_u64 */, AMDGPU::DS_MIN_RTN_U64_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5523 /* ds_min_rtn_u64 */, AMDGPU::DS_MIN_RTN_U64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5523 /* ds_min_rtn_u64 */, AMDGPU::DS_MIN_RTN_U64_vi_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5538 /* ds_min_src2_f32 */, AMDGPU::DS_MIN_SRC2_F32_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5538 /* ds_min_src2_f32 */, AMDGPU::DS_MIN_SRC2_F32_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5538 /* ds_min_src2_f32 */, AMDGPU::DS_MIN_SRC2_F32_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5554 /* ds_min_src2_f64 */, AMDGPU::DS_MIN_SRC2_F64_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5554 /* ds_min_src2_f64 */, AMDGPU::DS_MIN_SRC2_F64_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5554 /* ds_min_src2_f64 */, AMDGPU::DS_MIN_SRC2_F64_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5570 /* ds_min_src2_i32 */, AMDGPU::DS_MIN_SRC2_I32_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5570 /* ds_min_src2_i32 */, AMDGPU::DS_MIN_SRC2_I32_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5570 /* ds_min_src2_i32 */, AMDGPU::DS_MIN_SRC2_I32_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5586 /* ds_min_src2_i64 */, AMDGPU::DS_MIN_SRC2_I64_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5586 /* ds_min_src2_i64 */, AMDGPU::DS_MIN_SRC2_I64_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5586 /* ds_min_src2_i64 */, AMDGPU::DS_MIN_SRC2_I64_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5602 /* ds_min_src2_u32 */, AMDGPU::DS_MIN_SRC2_U32_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5602 /* ds_min_src2_u32 */, AMDGPU::DS_MIN_SRC2_U32_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5602 /* ds_min_src2_u32 */, AMDGPU::DS_MIN_SRC2_U32_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5618 /* ds_min_src2_u64 */, AMDGPU::DS_MIN_SRC2_U64_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5618 /* ds_min_src2_u64 */, AMDGPU::DS_MIN_SRC2_U64_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5618 /* ds_min_src2_u64 */, AMDGPU::DS_MIN_SRC2_U64_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5634 /* ds_min_u32 */, AMDGPU::DS_MIN_U32_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5634 /* ds_min_u32 */, AMDGPU::DS_MIN_U32_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5634 /* ds_min_u32 */, AMDGPU::DS_MIN_U32_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5634 /* ds_min_u32 */, AMDGPU::DS_MIN_U32_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5634 /* ds_min_u32 */, AMDGPU::DS_MIN_U32_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5634 /* ds_min_u32 */, AMDGPU::DS_MIN_U32_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5645 /* ds_min_u64 */, AMDGPU::DS_MIN_U64_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5645 /* ds_min_u64 */, AMDGPU::DS_MIN_U64_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5645 /* ds_min_u64 */, AMDGPU::DS_MIN_U64_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5645 /* ds_min_u64 */, AMDGPU::DS_MIN_U64_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5645 /* ds_min_u64 */, AMDGPU::DS_MIN_U64_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5645 /* ds_min_u64 */, AMDGPU::DS_MIN_U64_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5656 /* ds_mskor_b32 */, AMDGPU::DS_MSKOR_B32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_VGPR_32, MCK_AGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 5656 /* ds_mskor_b32 */, AMDGPU::DS_MSKOR_B32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5656 /* ds_mskor_b32 */, AMDGPU::DS_MSKOR_B32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5656 /* ds_mskor_b32 */, AMDGPU::DS_MSKOR_B32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5656 /* ds_mskor_b32 */, AMDGPU::DS_MSKOR_B32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5656 /* ds_mskor_b32 */, AMDGPU::DS_MSKOR_B32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5656 /* ds_mskor_b32 */, AMDGPU::DS_MSKOR_B32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5669 /* ds_mskor_b64 */, AMDGPU::DS_MSKOR_B64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_VGPR_32, MCK_AReg_64, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 5669 /* ds_mskor_b64 */, AMDGPU::DS_MSKOR_B64_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5669 /* ds_mskor_b64 */, AMDGPU::DS_MSKOR_B64_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5669 /* ds_mskor_b64 */, AMDGPU::DS_MSKOR_B64_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5669 /* ds_mskor_b64 */, AMDGPU::DS_MSKOR_B64_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5669 /* ds_mskor_b64 */, AMDGPU::DS_MSKOR_B64_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5669 /* ds_mskor_b64 */, AMDGPU::DS_MSKOR_B64_vi_gfx9, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5682 /* ds_mskor_rtn_b32 */, AMDGPU::DS_MSKOR_RTN_B32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 5682 /* ds_mskor_rtn_b32 */, AMDGPU::DS_MSKOR_RTN_B32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5682 /* ds_mskor_rtn_b32 */, AMDGPU::DS_MSKOR_RTN_B32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5682 /* ds_mskor_rtn_b32 */, AMDGPU::DS_MSKOR_RTN_B32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5682 /* ds_mskor_rtn_b32 */, AMDGPU::DS_MSKOR_RTN_B32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5682 /* ds_mskor_rtn_b32 */, AMDGPU::DS_MSKOR_RTN_B32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5682 /* ds_mskor_rtn_b32 */, AMDGPU::DS_MSKOR_RTN_B32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5699 /* ds_mskor_rtn_b64 */, AMDGPU::DS_MSKOR_RTN_B64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX90APlus, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 5699 /* ds_mskor_rtn_b64 */, AMDGPU::DS_MSKOR_RTN_B64_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset1_4__GDS1_5, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5699 /* ds_mskor_rtn_b64 */, AMDGPU::DS_MSKOR_RTN_B64_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset1_4__GDS1_5, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5699 /* ds_mskor_rtn_b64 */, AMDGPU::DS_MSKOR_RTN_B64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset1_4__GDS1_5, AMFBS_isGFX12Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5699 /* ds_mskor_rtn_b64 */, AMDGPU::DS_MSKOR_RTN_B64_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset1_4__GDS1_5, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5699 /* ds_mskor_rtn_b64 */, AMDGPU::DS_MSKOR_RTN_B64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset1_4__GDS1_5, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5699 /* ds_mskor_rtn_b64 */, AMDGPU::DS_MSKOR_RTN_B64_vi_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset1_4__GDS1_5, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5716 /* ds_nop */, AMDGPU::DS_NOP_gfx10, Convert_NoOperands, AMFBS_isGFX7Plus_isGFX10Only, {  }, },
  { 5716 /* ds_nop */, AMDGPU::DS_NOP_gfx11, Convert_NoOperands, AMFBS_isGFX7Plus_isGFX11Only, {  }, },
  { 5716 /* ds_nop */, AMDGPU::DS_NOP_gfx12, Convert_NoOperands, AMFBS_isGFX7Plus_isGFX12Plus, {  }, },
  { 5716 /* ds_nop */, AMDGPU::DS_NOP_gfx6_gfx7, Convert_NoOperands, AMFBS_isGFX7Plus_isGFX6GFX7, {  }, },
  { 5716 /* ds_nop */, AMDGPU::DS_NOP_vi, Convert_NoOperands, AMFBS_isGFX7Plus_isGFX8GFX9, {  }, },
  { 5723 /* ds_or_b32 */, AMDGPU::DS_OR_B32_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5723 /* ds_or_b32 */, AMDGPU::DS_OR_B32_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5723 /* ds_or_b32 */, AMDGPU::DS_OR_B32_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5723 /* ds_or_b32 */, AMDGPU::DS_OR_B32_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5723 /* ds_or_b32 */, AMDGPU::DS_OR_B32_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5723 /* ds_or_b32 */, AMDGPU::DS_OR_B32_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5733 /* ds_or_b64 */, AMDGPU::DS_OR_B64_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5733 /* ds_or_b64 */, AMDGPU::DS_OR_B64_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5733 /* ds_or_b64 */, AMDGPU::DS_OR_B64_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5733 /* ds_or_b64 */, AMDGPU::DS_OR_B64_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5733 /* ds_or_b64 */, AMDGPU::DS_OR_B64_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5733 /* ds_or_b64 */, AMDGPU::DS_OR_B64_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5743 /* ds_or_rtn_b32 */, AMDGPU::DS_OR_RTN_B32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 5743 /* ds_or_rtn_b32 */, AMDGPU::DS_OR_RTN_B32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5743 /* ds_or_rtn_b32 */, AMDGPU::DS_OR_RTN_B32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5743 /* ds_or_rtn_b32 */, AMDGPU::DS_OR_RTN_B32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5743 /* ds_or_rtn_b32 */, AMDGPU::DS_OR_RTN_B32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5743 /* ds_or_rtn_b32 */, AMDGPU::DS_OR_RTN_B32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5743 /* ds_or_rtn_b32 */, AMDGPU::DS_OR_RTN_B32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5757 /* ds_or_rtn_b64 */, AMDGPU::DS_OR_RTN_B64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 5757 /* ds_or_rtn_b64 */, AMDGPU::DS_OR_RTN_B64_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5757 /* ds_or_rtn_b64 */, AMDGPU::DS_OR_RTN_B64_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5757 /* ds_or_rtn_b64 */, AMDGPU::DS_OR_RTN_B64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5757 /* ds_or_rtn_b64 */, AMDGPU::DS_OR_RTN_B64_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5757 /* ds_or_rtn_b64 */, AMDGPU::DS_OR_RTN_B64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5757 /* ds_or_rtn_b64 */, AMDGPU::DS_OR_RTN_B64_vi_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 5771 /* ds_or_src2_b32 */, AMDGPU::DS_OR_SRC2_B32_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5771 /* ds_or_src2_b32 */, AMDGPU::DS_OR_SRC2_B32_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5771 /* ds_or_src2_b32 */, AMDGPU::DS_OR_SRC2_B32_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5786 /* ds_or_src2_b64 */, AMDGPU::DS_OR_SRC2_B64_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5786 /* ds_or_src2_b64 */, AMDGPU::DS_OR_SRC2_B64_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5786 /* ds_or_src2_b64 */, AMDGPU::DS_OR_SRC2_B64_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5801 /* ds_ordered_count */, AMDGPU::DS_ORDERED_COUNT_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2, AMFBS_isNotGFX90APlus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_gds }, },
  { 5801 /* ds_ordered_count */, AMDGPU::DS_ORDERED_COUNT_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2, AMFBS_isNotGFX90APlus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_gds }, },
  { 5801 /* ds_ordered_count */, AMDGPU::DS_ORDERED_COUNT_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2, AMFBS_isNotGFX90APlus_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_gds }, },
  { 5801 /* ds_ordered_count */, AMDGPU::DS_ORDERED_COUNT_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2, AMFBS_isNotGFX90APlus_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_gds }, },
  { 5818 /* ds_param_load */, AMDGPU::DS_PARAM_LOAD_gfx12, Convert__Reg1_0__InterpAttr1_1__InterpAttrChan1_2__WaitVAVDst1_3__WaitVMVSrc1_4, AMFBS_isGFX12PlusNot12_50_isGFX12Plus, { MCK_VGPR_32, MCK_InterpAttr, MCK_InterpAttrChan, MCK_WaitVAVDst, MCK_WaitVMVSrc }, },
  { 5832 /* ds_permute_b32 */, AMDGPU::DS_PERMUTE_B32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3, AMFBS_isGFX8Plus_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_Offset }, },
  { 5832 /* ds_permute_b32 */, AMDGPU::DS_PERMUTE_B32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3, AMFBS_isGFX8Plus_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset }, },
  { 5832 /* ds_permute_b32 */, AMDGPU::DS_PERMUTE_B32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3, AMFBS_isGFX8Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset }, },
  { 5832 /* ds_permute_b32 */, AMDGPU::DS_PERMUTE_B32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3, AMFBS_isGFX8Plus_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset }, },
  { 5832 /* ds_permute_b32 */, AMDGPU::DS_PERMUTE_B32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3, AMFBS_isGFX8Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset }, },
  { 5847 /* ds_pk_add_bf16 */, AMDGPU::DS_PK_ADD_BF16_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_HasAtomicDsPkAdd16Insts_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5847 /* ds_pk_add_bf16 */, AMDGPU::DS_PK_ADD_BF16_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_HasAtomicDsPkAdd16Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5862 /* ds_pk_add_f16 */, AMDGPU::DS_PK_ADD_F16_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_HasAtomicDsPkAdd16Insts_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5862 /* ds_pk_add_f16 */, AMDGPU::DS_PK_ADD_F16_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_HasAtomicDsPkAdd16Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5876 /* ds_pk_add_rtn_bf16 */, AMDGPU::DS_PK_ADD_RTN_BF16_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_HasAtomicDsPkAdd16Insts_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 5876 /* ds_pk_add_rtn_bf16 */, AMDGPU::DS_PK_ADD_RTN_BF16_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_HasAtomicDsPkAdd16Insts_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5876 /* ds_pk_add_rtn_bf16 */, AMDGPU::DS_PK_ADD_RTN_BF16_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_HasAtomicDsPkAdd16Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5895 /* ds_pk_add_rtn_f16 */, AMDGPU::DS_PK_ADD_RTN_F16_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_HasAtomicDsPkAdd16Insts_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 5895 /* ds_pk_add_rtn_f16 */, AMDGPU::DS_PK_ADD_RTN_F16_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_HasAtomicDsPkAdd16Insts_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5895 /* ds_pk_add_rtn_f16 */, AMDGPU::DS_PK_ADD_RTN_F16_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_HasAtomicDsPkAdd16Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5913 /* ds_read2_b32 */, AMDGPU::DS_READ2_B32_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 5913 /* ds_read2_b32 */, AMDGPU::DS_READ2_B32_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 5913 /* ds_read2_b32 */, AMDGPU::DS_READ2_B32_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 5913 /* ds_read2_b32 */, AMDGPU::DS_READ2_B32_vi_gfx9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 5926 /* ds_read2_b64 */, AMDGPU::DS_READ2_B64_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 5926 /* ds_read2_b64 */, AMDGPU::DS_READ2_B64_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 5926 /* ds_read2_b64 */, AMDGPU::DS_READ2_B64_vi, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 5926 /* ds_read2_b64 */, AMDGPU::DS_READ2_B64_vi_gfx9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 5939 /* ds_read2st64_b32 */, AMDGPU::DS_READ2ST64_B32_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 5939 /* ds_read2st64_b32 */, AMDGPU::DS_READ2ST64_B32_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 5939 /* ds_read2st64_b32 */, AMDGPU::DS_READ2ST64_B32_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 5939 /* ds_read2st64_b32 */, AMDGPU::DS_READ2ST64_B32_vi_gfx9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 5956 /* ds_read2st64_b64 */, AMDGPU::DS_READ2ST64_B64_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 5956 /* ds_read2st64_b64 */, AMDGPU::DS_READ2ST64_B64_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 5956 /* ds_read2st64_b64 */, AMDGPU::DS_READ2ST64_B64_vi, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 5956 /* ds_read2st64_b64 */, AMDGPU::DS_READ2ST64_B64_vi_gfx9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Offset01_2__Offset11_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 5973 /* ds_read_addtid_b32 */, AMDGPU::DS_READ_ADDTID_B32_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Offset1_1__GDS1_2, AMFBS_HasDSAddTid_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5973 /* ds_read_addtid_b32 */, AMDGPU::DS_READ_ADDTID_B32_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Offset1_1__GDS1_2, AMFBS_HasDSAddTid_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 5992 /* ds_read_b128 */, AMDGPU::DS_READ_B128_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5992 /* ds_read_b128 */, AMDGPU::DS_READ_B128_gfx7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX7Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5992 /* ds_read_b128 */, AMDGPU::DS_READ_B128_vi, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 5992 /* ds_read_b128 */, AMDGPU::DS_READ_B128_vi_gfx9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6005 /* ds_read_b32 */, AMDGPU::DS_READ_B32_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6005 /* ds_read_b32 */, AMDGPU::DS_READ_B32_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6005 /* ds_read_b32 */, AMDGPU::DS_READ_B32_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6005 /* ds_read_b32 */, AMDGPU::DS_READ_B32_vi_gfx9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6017 /* ds_read_b64 */, AMDGPU::DS_READ_B64_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6017 /* ds_read_b64 */, AMDGPU::DS_READ_B64_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6017 /* ds_read_b64 */, AMDGPU::DS_READ_B64_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6017 /* ds_read_b64 */, AMDGPU::DS_READ_B64_vi_gfx9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6029 /* ds_read_b64_tr_b16 */, AMDGPU::DS_READ_B64_TR_B16_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_HasGFX950Insts_isGFX8GFX9_isWave64, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6048 /* ds_read_b64_tr_b4 */, AMDGPU::DS_READ_B64_TR_B4_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_HasGFX950Insts_isGFX8GFX9_isWave64, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6066 /* ds_read_b64_tr_b8 */, AMDGPU::DS_READ_B64_TR_B8_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_HasGFX950Insts_isGFX8GFX9_isWave64, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6084 /* ds_read_b96 */, AMDGPU::DS_READ_B96_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6084 /* ds_read_b96 */, AMDGPU::DS_READ_B96_gfx7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX7Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6084 /* ds_read_b96 */, AMDGPU::DS_READ_B96_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6084 /* ds_read_b96 */, AMDGPU::DS_READ_B96_vi_gfx9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6096 /* ds_read_b96_tr_b6 */, AMDGPU::DS_READ_B96_TR_B6_vi, Convert__RegByHwMode_AV_LdSt_96_Align11_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_HasGFX950Insts_isGFX8GFX9_isWave64, { MCK_RegByHwMode_AV_LdSt_96_Align1, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6114 /* ds_read_i16 */, AMDGPU::DS_READ_I16_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6114 /* ds_read_i16 */, AMDGPU::DS_READ_I16_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6114 /* ds_read_i16 */, AMDGPU::DS_READ_I16_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6114 /* ds_read_i16 */, AMDGPU::DS_READ_I16_vi_gfx9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6126 /* ds_read_i8 */, AMDGPU::DS_READ_I8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6126 /* ds_read_i8 */, AMDGPU::DS_READ_I8_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6126 /* ds_read_i8 */, AMDGPU::DS_READ_I8_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6126 /* ds_read_i8 */, AMDGPU::DS_READ_I8_vi_gfx9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6137 /* ds_read_i8_d16 */, AMDGPU::DS_READ_I8_D16_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6137 /* ds_read_i8_d16 */, AMDGPU::DS_READ_I8_D16_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6152 /* ds_read_i8_d16_hi */, AMDGPU::DS_READ_I8_D16_HI_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6152 /* ds_read_i8_d16_hi */, AMDGPU::DS_READ_I8_D16_HI_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6170 /* ds_read_u16 */, AMDGPU::DS_READ_U16_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6170 /* ds_read_u16 */, AMDGPU::DS_READ_U16_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6170 /* ds_read_u16 */, AMDGPU::DS_READ_U16_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6170 /* ds_read_u16 */, AMDGPU::DS_READ_U16_vi_gfx9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6182 /* ds_read_u16_d16 */, AMDGPU::DS_READ_U16_D16_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6182 /* ds_read_u16_d16 */, AMDGPU::DS_READ_U16_D16_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6198 /* ds_read_u16_d16_hi */, AMDGPU::DS_READ_U16_D16_HI_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6198 /* ds_read_u16_d16_hi */, AMDGPU::DS_READ_U16_D16_HI_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6217 /* ds_read_u8 */, AMDGPU::DS_READ_U8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6217 /* ds_read_u8 */, AMDGPU::DS_READ_U8_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6217 /* ds_read_u8 */, AMDGPU::DS_READ_U8_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6217 /* ds_read_u8 */, AMDGPU::DS_READ_U8_vi_gfx9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6228 /* ds_read_u8_d16 */, AMDGPU::DS_READ_U8_D16_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6228 /* ds_read_u8_d16 */, AMDGPU::DS_READ_U8_D16_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6243 /* ds_read_u8_d16_hi */, AMDGPU::DS_READ_U8_D16_HI_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6243 /* ds_read_u8_d16_hi */, AMDGPU::DS_READ_U8_D16_HI_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Offset1_2__GDS1_3__Tie0_1_1, AMFBS_HasD16LoadStore_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6261 /* ds_rsub_rtn_u32 */, AMDGPU::DS_RSUB_RTN_U32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 6261 /* ds_rsub_rtn_u32 */, AMDGPU::DS_RSUB_RTN_U32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6261 /* ds_rsub_rtn_u32 */, AMDGPU::DS_RSUB_RTN_U32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6261 /* ds_rsub_rtn_u32 */, AMDGPU::DS_RSUB_RTN_U32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6261 /* ds_rsub_rtn_u32 */, AMDGPU::DS_RSUB_RTN_U32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6261 /* ds_rsub_rtn_u32 */, AMDGPU::DS_RSUB_RTN_U32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6261 /* ds_rsub_rtn_u32 */, AMDGPU::DS_RSUB_RTN_U32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6277 /* ds_rsub_rtn_u64 */, AMDGPU::DS_RSUB_RTN_U64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 6277 /* ds_rsub_rtn_u64 */, AMDGPU::DS_RSUB_RTN_U64_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6277 /* ds_rsub_rtn_u64 */, AMDGPU::DS_RSUB_RTN_U64_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6277 /* ds_rsub_rtn_u64 */, AMDGPU::DS_RSUB_RTN_U64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6277 /* ds_rsub_rtn_u64 */, AMDGPU::DS_RSUB_RTN_U64_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6277 /* ds_rsub_rtn_u64 */, AMDGPU::DS_RSUB_RTN_U64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6277 /* ds_rsub_rtn_u64 */, AMDGPU::DS_RSUB_RTN_U64_vi_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6293 /* ds_rsub_src2_u32 */, AMDGPU::DS_RSUB_SRC2_U32_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6293 /* ds_rsub_src2_u32 */, AMDGPU::DS_RSUB_SRC2_U32_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6293 /* ds_rsub_src2_u32 */, AMDGPU::DS_RSUB_SRC2_U32_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6310 /* ds_rsub_src2_u64 */, AMDGPU::DS_RSUB_SRC2_U64_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6310 /* ds_rsub_src2_u64 */, AMDGPU::DS_RSUB_SRC2_U64_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6310 /* ds_rsub_src2_u64 */, AMDGPU::DS_RSUB_SRC2_U64_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6327 /* ds_rsub_u32 */, AMDGPU::DS_RSUB_U32_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6327 /* ds_rsub_u32 */, AMDGPU::DS_RSUB_U32_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6327 /* ds_rsub_u32 */, AMDGPU::DS_RSUB_U32_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6327 /* ds_rsub_u32 */, AMDGPU::DS_RSUB_U32_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6327 /* ds_rsub_u32 */, AMDGPU::DS_RSUB_U32_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6327 /* ds_rsub_u32 */, AMDGPU::DS_RSUB_U32_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6339 /* ds_rsub_u64 */, AMDGPU::DS_RSUB_U64_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6339 /* ds_rsub_u64 */, AMDGPU::DS_RSUB_U64_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6339 /* ds_rsub_u64 */, AMDGPU::DS_RSUB_U64_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6339 /* ds_rsub_u64 */, AMDGPU::DS_RSUB_U64_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6339 /* ds_rsub_u64 */, AMDGPU::DS_RSUB_U64_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6339 /* ds_rsub_u64 */, AMDGPU::DS_RSUB_U64_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6351 /* ds_store_2addr_b32 */, AMDGPU::DS_WRITE2_B32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6351 /* ds_store_2addr_b32 */, AMDGPU::DS_WRITE2_B32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6370 /* ds_store_2addr_b64 */, AMDGPU::DS_WRITE2_B64_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6370 /* ds_store_2addr_b64 */, AMDGPU::DS_WRITE2_B64_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6389 /* ds_store_2addr_stride64_b32 */, AMDGPU::DS_WRITE2ST64_B32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6389 /* ds_store_2addr_stride64_b32 */, AMDGPU::DS_WRITE2ST64_B32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6417 /* ds_store_2addr_stride64_b64 */, AMDGPU::DS_WRITE2ST64_B64_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6417 /* ds_store_2addr_stride64_b64 */, AMDGPU::DS_WRITE2ST64_B64_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6445 /* ds_store_addtid_b32 */, AMDGPU::DS_WRITE_ADDTID_B32_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Offset1_1__GDS1_2, AMFBS_HasDSAddTid_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6445 /* ds_store_addtid_b32 */, AMDGPU::DS_WRITE_ADDTID_B32_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Offset1_1__GDS1_2, AMFBS_HasDSAddTid_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6465 /* ds_store_b128 */, AMDGPU::DS_WRITE_B128_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6465 /* ds_store_b128 */, AMDGPU::DS_WRITE_B128_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6479 /* ds_store_b16 */, AMDGPU::DS_WRITE_B16_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6479 /* ds_store_b16 */, AMDGPU::DS_WRITE_B16_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6492 /* ds_store_b16_d16_hi */, AMDGPU::DS_WRITE_B16_D16_HI_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6492 /* ds_store_b16_d16_hi */, AMDGPU::DS_WRITE_B16_D16_HI_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_HasD16LoadStore_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6512 /* ds_store_b32 */, AMDGPU::DS_WRITE_B32_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6512 /* ds_store_b32 */, AMDGPU::DS_WRITE_B32_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6525 /* ds_store_b64 */, AMDGPU::DS_WRITE_B64_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6525 /* ds_store_b64 */, AMDGPU::DS_WRITE_B64_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6538 /* ds_store_b8 */, AMDGPU::DS_WRITE_B8_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6538 /* ds_store_b8 */, AMDGPU::DS_WRITE_B8_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6550 /* ds_store_b8_d16_hi */, AMDGPU::DS_WRITE_B8_D16_HI_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6550 /* ds_store_b8_d16_hi */, AMDGPU::DS_WRITE_B8_D16_HI_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_HasD16LoadStore_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6569 /* ds_store_b96 */, AMDGPU::DS_WRITE_B96_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6569 /* ds_store_b96 */, AMDGPU::DS_WRITE_B96_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6582 /* ds_storexchg_2addr_rtn_b32 */, AMDGPU::DS_WRXCHG2_RTN_B32_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6582 /* ds_storexchg_2addr_rtn_b32 */, AMDGPU::DS_WRXCHG2_RTN_B32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX12Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6609 /* ds_storexchg_2addr_rtn_b64 */, AMDGPU::DS_WRXCHG2_RTN_B64_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6609 /* ds_storexchg_2addr_rtn_b64 */, AMDGPU::DS_WRXCHG2_RTN_B64_gfx12, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX12Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6636 /* ds_storexchg_2addr_stride64_rtn_b32 */, AMDGPU::DS_WRXCHG2ST64_RTN_B32_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6636 /* ds_storexchg_2addr_stride64_rtn_b32 */, AMDGPU::DS_WRXCHG2ST64_RTN_B32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX12Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6672 /* ds_storexchg_2addr_stride64_rtn_b64 */, AMDGPU::DS_WRXCHG2ST64_RTN_B64_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6672 /* ds_storexchg_2addr_stride64_rtn_b64 */, AMDGPU::DS_WRXCHG2ST64_RTN_B64_gfx12, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX12Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6708 /* ds_storexchg_rtn_b32 */, AMDGPU::DS_WRXCHG_RTN_B32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6708 /* ds_storexchg_rtn_b32 */, AMDGPU::DS_WRXCHG_RTN_B32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6729 /* ds_storexchg_rtn_b64 */, AMDGPU::DS_WRXCHG_RTN_B64_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6729 /* ds_storexchg_rtn_b64 */, AMDGPU::DS_WRXCHG_RTN_B64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6750 /* ds_sub_clamp_rtn_u32 */, AMDGPU::DS_SUB_CLAMP_RTN_U32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6771 /* ds_sub_clamp_u32 */, AMDGPU::DS_SUB_CLAMP_U32_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6788 /* ds_sub_gs_reg_rtn */, AMDGPU::DS_SUB_GS_REG_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Offset1_2, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_Offset, MCK_gds }, },
  { 6806 /* ds_sub_rtn_u32 */, AMDGPU::DS_SUB_RTN_U32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 6806 /* ds_sub_rtn_u32 */, AMDGPU::DS_SUB_RTN_U32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6806 /* ds_sub_rtn_u32 */, AMDGPU::DS_SUB_RTN_U32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6806 /* ds_sub_rtn_u32 */, AMDGPU::DS_SUB_RTN_U32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6806 /* ds_sub_rtn_u32 */, AMDGPU::DS_SUB_RTN_U32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6806 /* ds_sub_rtn_u32 */, AMDGPU::DS_SUB_RTN_U32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6806 /* ds_sub_rtn_u32 */, AMDGPU::DS_SUB_RTN_U32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6821 /* ds_sub_rtn_u64 */, AMDGPU::DS_SUB_RTN_U64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 6821 /* ds_sub_rtn_u64 */, AMDGPU::DS_SUB_RTN_U64_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6821 /* ds_sub_rtn_u64 */, AMDGPU::DS_SUB_RTN_U64_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6821 /* ds_sub_rtn_u64 */, AMDGPU::DS_SUB_RTN_U64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6821 /* ds_sub_rtn_u64 */, AMDGPU::DS_SUB_RTN_U64_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6821 /* ds_sub_rtn_u64 */, AMDGPU::DS_SUB_RTN_U64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6821 /* ds_sub_rtn_u64 */, AMDGPU::DS_SUB_RTN_U64_vi_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6836 /* ds_sub_src2_u32 */, AMDGPU::DS_SUB_SRC2_U32_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6836 /* ds_sub_src2_u32 */, AMDGPU::DS_SUB_SRC2_U32_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6836 /* ds_sub_src2_u32 */, AMDGPU::DS_SUB_SRC2_U32_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6852 /* ds_sub_src2_u64 */, AMDGPU::DS_SUB_SRC2_U64_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6852 /* ds_sub_src2_u64 */, AMDGPU::DS_SUB_SRC2_U64_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6852 /* ds_sub_src2_u64 */, AMDGPU::DS_SUB_SRC2_U64_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6868 /* ds_sub_u32 */, AMDGPU::DS_SUB_U32_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6868 /* ds_sub_u32 */, AMDGPU::DS_SUB_U32_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6868 /* ds_sub_u32 */, AMDGPU::DS_SUB_U32_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6868 /* ds_sub_u32 */, AMDGPU::DS_SUB_U32_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6868 /* ds_sub_u32 */, AMDGPU::DS_SUB_U32_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6868 /* ds_sub_u32 */, AMDGPU::DS_SUB_U32_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6879 /* ds_sub_u64 */, AMDGPU::DS_SUB_U64_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6879 /* ds_sub_u64 */, AMDGPU::DS_SUB_U64_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6879 /* ds_sub_u64 */, AMDGPU::DS_SUB_U64_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6879 /* ds_sub_u64 */, AMDGPU::DS_SUB_U64_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6879 /* ds_sub_u64 */, AMDGPU::DS_SUB_U64_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6879 /* ds_sub_u64 */, AMDGPU::DS_SUB_U64_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 6890 /* ds_swizzle_b32 */, AMDGPU::DS_SWIZZLE_B32_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Swizzle1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Swizzle, MCK_GDS }, },
  { 6890 /* ds_swizzle_b32 */, AMDGPU::DS_SWIZZLE_B32_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Swizzle1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Swizzle, MCK_GDS }, },
  { 6890 /* ds_swizzle_b32 */, AMDGPU::DS_SWIZZLE_B32_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Swizzle1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Swizzle, MCK_GDS }, },
  { 6890 /* ds_swizzle_b32 */, AMDGPU::DS_SWIZZLE_B32_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Swizzle1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Swizzle, MCK_GDS }, },
  { 6890 /* ds_swizzle_b32 */, AMDGPU::DS_SWIZZLE_B32_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Swizzle1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_Swizzle, MCK_GDS }, },
  { 6905 /* ds_wrap_rtn_b32 */, AMDGPU::DS_WRAP_RTN_B32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX7Plus_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 6905 /* ds_wrap_rtn_b32 */, AMDGPU::DS_WRAP_RTN_B32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX7Plus_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6905 /* ds_wrap_rtn_b32 */, AMDGPU::DS_WRAP_RTN_B32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX7Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6905 /* ds_wrap_rtn_b32 */, AMDGPU::DS_WRAP_RTN_B32_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX7Plus_isGFX7Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6905 /* ds_wrap_rtn_b32 */, AMDGPU::DS_WRAP_RTN_B32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6905 /* ds_wrap_rtn_b32 */, AMDGPU::DS_WRAP_RTN_B32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset1_4__GDS1_5, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 6921 /* ds_write2_b32 */, AMDGPU::DS_WRITE2_B32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX90APlus, { MCK_VGPR_32, MCK_AGPR_32, MCK_AGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6921 /* ds_write2_b32 */, AMDGPU::DS_WRITE2_B32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6921 /* ds_write2_b32 */, AMDGPU::DS_WRITE2_B32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6921 /* ds_write2_b32 */, AMDGPU::DS_WRITE2_B32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6921 /* ds_write2_b32 */, AMDGPU::DS_WRITE2_B32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6935 /* ds_write2_b64 */, AMDGPU::DS_WRITE2_B64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX90APlus, { MCK_VGPR_32, MCK_AReg_64, MCK_AReg_64, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6935 /* ds_write2_b64 */, AMDGPU::DS_WRITE2_B64_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6935 /* ds_write2_b64 */, AMDGPU::DS_WRITE2_B64_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6935 /* ds_write2_b64 */, AMDGPU::DS_WRITE2_B64_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6935 /* ds_write2_b64 */, AMDGPU::DS_WRITE2_B64_vi_gfx9, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6949 /* ds_write2st64_b32 */, AMDGPU::DS_WRITE2ST64_B32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX90APlus, { MCK_VGPR_32, MCK_AGPR_32, MCK_AGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6949 /* ds_write2st64_b32 */, AMDGPU::DS_WRITE2ST64_B32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6949 /* ds_write2st64_b32 */, AMDGPU::DS_WRITE2ST64_B32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6949 /* ds_write2st64_b32 */, AMDGPU::DS_WRITE2ST64_B32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6949 /* ds_write2st64_b32 */, AMDGPU::DS_WRITE2ST64_B32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6967 /* ds_write2st64_b64 */, AMDGPU::DS_WRITE2ST64_B64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX90APlus, { MCK_VGPR_32, MCK_AReg_64, MCK_AReg_64, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6967 /* ds_write2st64_b64 */, AMDGPU::DS_WRITE2ST64_B64_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6967 /* ds_write2st64_b64 */, AMDGPU::DS_WRITE2ST64_B64_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6967 /* ds_write2st64_b64 */, AMDGPU::DS_WRITE2ST64_B64_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6967 /* ds_write2st64_b64 */, AMDGPU::DS_WRITE2ST64_B64_vi_gfx9, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset01_3__Offset11_4__GDS1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 6985 /* ds_write_addtid_b32 */, AMDGPU::DS_WRITE_ADDTID_B32_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Offset1_1__GDS1_2, AMFBS_HasDSAddTid_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 6985 /* ds_write_addtid_b32 */, AMDGPU::DS_WRITE_ADDTID_B32_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Offset1_1__GDS1_2, AMFBS_HasDSAddTid_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7005 /* ds_write_b128 */, AMDGPU::DS_WRITE_B128_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7005 /* ds_write_b128 */, AMDGPU::DS_WRITE_B128_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX7Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7005 /* ds_write_b128 */, AMDGPU::DS_WRITE_B128_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7005 /* ds_write_b128 */, AMDGPU::DS_WRITE_B128_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7019 /* ds_write_b16 */, AMDGPU::DS_WRITE_B16_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7019 /* ds_write_b16 */, AMDGPU::DS_WRITE_B16_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7019 /* ds_write_b16 */, AMDGPU::DS_WRITE_B16_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7019 /* ds_write_b16 */, AMDGPU::DS_WRITE_B16_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7032 /* ds_write_b16_d16_hi */, AMDGPU::DS_WRITE_B16_D16_HI_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7032 /* ds_write_b16_d16_hi */, AMDGPU::DS_WRITE_B16_D16_HI_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_HasD16LoadStore_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7052 /* ds_write_b32 */, AMDGPU::DS_WRITE_B32_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7052 /* ds_write_b32 */, AMDGPU::DS_WRITE_B32_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7052 /* ds_write_b32 */, AMDGPU::DS_WRITE_B32_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7052 /* ds_write_b32 */, AMDGPU::DS_WRITE_B32_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7065 /* ds_write_b64 */, AMDGPU::DS_WRITE_B64_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7065 /* ds_write_b64 */, AMDGPU::DS_WRITE_B64_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7065 /* ds_write_b64 */, AMDGPU::DS_WRITE_B64_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7065 /* ds_write_b64 */, AMDGPU::DS_WRITE_B64_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7078 /* ds_write_b8 */, AMDGPU::DS_WRITE_B8_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7078 /* ds_write_b8 */, AMDGPU::DS_WRITE_B8_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7078 /* ds_write_b8 */, AMDGPU::DS_WRITE_B8_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7078 /* ds_write_b8 */, AMDGPU::DS_WRITE_B8_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7090 /* ds_write_b8_d16_hi */, AMDGPU::DS_WRITE_B8_D16_HI_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7090 /* ds_write_b8_d16_hi */, AMDGPU::DS_WRITE_B8_D16_HI_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_HasD16LoadStore_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7109 /* ds_write_b96 */, AMDGPU::DS_WRITE_B96_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7109 /* ds_write_b96 */, AMDGPU::DS_WRITE_B96_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX7Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7109 /* ds_write_b96 */, AMDGPU::DS_WRITE_B96_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7109 /* ds_write_b96 */, AMDGPU::DS_WRITE_B96_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7122 /* ds_write_src2_b32 */, AMDGPU::DS_WRITE_SRC2_B32_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 7122 /* ds_write_src2_b32 */, AMDGPU::DS_WRITE_SRC2_B32_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 7122 /* ds_write_src2_b32 */, AMDGPU::DS_WRITE_SRC2_B32_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 7140 /* ds_write_src2_b64 */, AMDGPU::DS_WRITE_SRC2_B64_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 7140 /* ds_write_src2_b64 */, AMDGPU::DS_WRITE_SRC2_B64_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 7140 /* ds_write_src2_b64 */, AMDGPU::DS_WRITE_SRC2_B64_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 7158 /* ds_wrxchg2_rtn_b32 */, AMDGPU::DS_WRXCHG2_RTN_B32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX90APlus, { MCK_AReg_64, MCK_VGPR_32, MCK_AGPR_32, MCK_AGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 7158 /* ds_wrxchg2_rtn_b32 */, AMDGPU::DS_WRXCHG2_RTN_B32_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 7158 /* ds_wrxchg2_rtn_b32 */, AMDGPU::DS_WRXCHG2_RTN_B32_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 7158 /* ds_wrxchg2_rtn_b32 */, AMDGPU::DS_WRXCHG2_RTN_B32_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 7158 /* ds_wrxchg2_rtn_b32 */, AMDGPU::DS_WRXCHG2_RTN_B32_vi_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 7177 /* ds_wrxchg2_rtn_b64 */, AMDGPU::DS_WRXCHG2_RTN_B64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX90APlus, { MCK_AReg_128, MCK_VGPR_32, MCK_AReg_64, MCK_AReg_64, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 7177 /* ds_wrxchg2_rtn_b64 */, AMDGPU::DS_WRXCHG2_RTN_B64_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 7177 /* ds_wrxchg2_rtn_b64 */, AMDGPU::DS_WRXCHG2_RTN_B64_gfx6_gfx7, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 7177 /* ds_wrxchg2_rtn_b64 */, AMDGPU::DS_WRXCHG2_RTN_B64_vi, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 7177 /* ds_wrxchg2_rtn_b64 */, AMDGPU::DS_WRXCHG2_RTN_B64_vi_gfx9, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, AMDGPU::DS_WRXCHG2ST64_RTN_B32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX90APlus, { MCK_AReg_64, MCK_VGPR_32, MCK_AGPR_32, MCK_AGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, AMDGPU::DS_WRXCHG2ST64_RTN_B32_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, AMDGPU::DS_WRXCHG2ST64_RTN_B32_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, AMDGPU::DS_WRXCHG2ST64_RTN_B32_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, AMDGPU::DS_WRXCHG2ST64_RTN_B32_vi_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, AMDGPU::DS_WRXCHG2ST64_RTN_B64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX90APlus, { MCK_AReg_128, MCK_VGPR_32, MCK_AReg_64, MCK_AReg_64, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, AMDGPU::DS_WRXCHG2ST64_RTN_B64_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, AMDGPU::DS_WRXCHG2ST64_RTN_B64_gfx6_gfx7, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, AMDGPU::DS_WRXCHG2ST64_RTN_B64_vi, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, AMDGPU::DS_WRXCHG2ST64_RTN_B64_vi_gfx9, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Offset01_4__Offset11_5__GDS1_6, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset0, MCK_Offset1, MCK_GDS }, },
  { 7242 /* ds_wrxchg_rtn_b32 */, AMDGPU::DS_WRXCHG_RTN_B32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 7242 /* ds_wrxchg_rtn_b32 */, AMDGPU::DS_WRXCHG_RTN_B32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 7242 /* ds_wrxchg_rtn_b32 */, AMDGPU::DS_WRXCHG_RTN_B32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 7242 /* ds_wrxchg_rtn_b32 */, AMDGPU::DS_WRXCHG_RTN_B32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 7242 /* ds_wrxchg_rtn_b32 */, AMDGPU::DS_WRXCHG_RTN_B32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 7260 /* ds_wrxchg_rtn_b64 */, AMDGPU::DS_WRXCHG_RTN_B64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 7260 /* ds_wrxchg_rtn_b64 */, AMDGPU::DS_WRXCHG_RTN_B64_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7260 /* ds_wrxchg_rtn_b64 */, AMDGPU::DS_WRXCHG_RTN_B64_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7260 /* ds_wrxchg_rtn_b64 */, AMDGPU::DS_WRXCHG_RTN_B64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7260 /* ds_wrxchg_rtn_b64 */, AMDGPU::DS_WRXCHG_RTN_B64_vi_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7278 /* ds_xor_b32 */, AMDGPU::DS_XOR_B32_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7278 /* ds_xor_b32 */, AMDGPU::DS_XOR_B32_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7278 /* ds_xor_b32 */, AMDGPU::DS_XOR_B32_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7278 /* ds_xor_b32 */, AMDGPU::DS_XOR_B32_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7278 /* ds_xor_b32 */, AMDGPU::DS_XOR_B32_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7278 /* ds_xor_b32 */, AMDGPU::DS_XOR_B32_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_Offset, MCK_GDS }, },
  { 7289 /* ds_xor_b64 */, AMDGPU::DS_XOR_B64_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7289 /* ds_xor_b64 */, AMDGPU::DS_XOR_B64_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7289 /* ds_xor_b64 */, AMDGPU::DS_XOR_B64_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7289 /* ds_xor_b64 */, AMDGPU::DS_XOR_B64_gfx6_gfx7, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7289 /* ds_xor_b64 */, AMDGPU::DS_XOR_B64_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7289 /* ds_xor_b64 */, AMDGPU::DS_XOR_B64_vi_gfx9, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Offset1_2__GDS1_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7300 /* ds_xor_rtn_b32 */, AMDGPU::DS_XOR_RTN_B32_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_Offset, MCK_GDS }, },
  { 7300 /* ds_xor_rtn_b32 */, AMDGPU::DS_XOR_RTN_B32_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 7300 /* ds_xor_rtn_b32 */, AMDGPU::DS_XOR_RTN_B32_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 7300 /* ds_xor_rtn_b32 */, AMDGPU::DS_XOR_RTN_B32_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 7300 /* ds_xor_rtn_b32 */, AMDGPU::DS_XOR_RTN_B32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 7300 /* ds_xor_rtn_b32 */, AMDGPU::DS_XOR_RTN_B32_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 7300 /* ds_xor_rtn_b32 */, AMDGPU::DS_XOR_RTN_B32_vi_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 7315 /* ds_xor_rtn_b64 */, AMDGPU::DS_XOR_RTN_B64_vi_agpr, Convert__Reg1_0__Reg1_1__Reg1_2__Offset1_3__GDS1_4, AMFBS_isGFX90APlus, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_Offset, MCK_GDS }, },
  { 7315 /* ds_xor_rtn_b64 */, AMDGPU::DS_XOR_RTN_B64_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7315 /* ds_xor_rtn_b64 */, AMDGPU::DS_XOR_RTN_B64_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7315 /* ds_xor_rtn_b64 */, AMDGPU::DS_XOR_RTN_B64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX12Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7315 /* ds_xor_rtn_b64 */, AMDGPU::DS_XOR_RTN_B64_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7315 /* ds_xor_rtn_b64 */, AMDGPU::DS_XOR_RTN_B64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7315 /* ds_xor_rtn_b64 */, AMDGPU::DS_XOR_RTN_B64_vi_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Offset1_3__GDS1_4, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_Offset, MCK_GDS }, },
  { 7330 /* ds_xor_src2_b32 */, AMDGPU::DS_XOR_SRC2_B32_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 7330 /* ds_xor_src2_b32 */, AMDGPU::DS_XOR_SRC2_B32_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 7330 /* ds_xor_src2_b32 */, AMDGPU::DS_XOR_SRC2_B32_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 7346 /* ds_xor_src2_b64 */, AMDGPU::DS_XOR_SRC2_B64_gfx10, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX10Only, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 7346 /* ds_xor_src2_b64 */, AMDGPU::DS_XOR_SRC2_B64_gfx6_gfx7, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 7346 /* ds_xor_src2_b64 */, AMDGPU::DS_XOR_SRC2_B64_vi, Convert__Reg1_0__Offset1_1__GDS1_2, AMFBS_HasDsSrc2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_Offset, MCK_GDS }, },
  { 7362 /* exp */, AMDGPU::EXP_gfx11, ConvertCustom_cvtExp, AMFBS_isGFX11Only, { MCK_ExpTgt, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff }, },
  { 7362 /* exp */, AMDGPU::EXP_DONE_gfx11, ConvertCustom_cvtExp, AMFBS_isGFX11Only, { MCK_ExpTgt, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_done }, },
  { 7362 /* exp */, AMDGPU::EXP_ROW_gfx11, ConvertCustom_cvtExp, AMFBS_isGFX11Only, { MCK_ExpTgt, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_row_95_en }, },
  { 7362 /* exp */, AMDGPU::EXP_ROW_DONE_gfx11, ConvertCustom_cvtExp, AMFBS_isGFX11Only, { MCK_ExpTgt, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_done, MCK_row_95_en }, },
  { 7362 /* exp */, AMDGPU::EXP_vi, ConvertCustom_cvtExp, AMFBS_isNotGFX90APlus_isGFX8GFX9, { MCK_ExpTgt, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_ExpCompr, MCK_ExpVM }, },
  { 7362 /* exp */, AMDGPU::EXP_gfx10, ConvertCustom_cvtExp, AMFBS_isGFX10Only, { MCK_ExpTgt, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_ExpCompr, MCK_ExpVM }, },
  { 7362 /* exp */, AMDGPU::EXP_si, ConvertCustom_cvtExp, AMFBS_isGFX6GFX7, { MCK_ExpTgt, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_ExpCompr, MCK_ExpVM }, },
  { 7362 /* exp */, AMDGPU::EXP_DONE_vi, ConvertCustom_cvtExp, AMFBS_isNotGFX90APlus_isGFX8GFX9, { MCK_ExpTgt, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_done, MCK_ExpCompr, MCK_ExpVM }, },
  { 7362 /* exp */, AMDGPU::EXP_DONE_gfx10, ConvertCustom_cvtExp, AMFBS_isGFX10Only, { MCK_ExpTgt, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_done, MCK_ExpCompr, MCK_ExpVM }, },
  { 7362 /* exp */, AMDGPU::EXP_DONE_si, ConvertCustom_cvtExp, AMFBS_isGFX6GFX7, { MCK_ExpTgt, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_done, MCK_ExpCompr, MCK_ExpVM }, },
  { 7366 /* export */, AMDGPU::EXP_gfx12, ConvertCustom_cvtExp, AMFBS_HasExportInsts_isGFX12Only, { MCK_ExpTgt, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff }, },
  { 7366 /* export */, AMDGPU::EXP_DONE_gfx12, ConvertCustom_cvtExp, AMFBS_HasExportInsts_isGFX12Only, { MCK_ExpTgt, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_done }, },
  { 7366 /* export */, AMDGPU::EXP_ROW_gfx12, ConvertCustom_cvtExp, AMFBS_HasExportInsts_isGFX12Only, { MCK_ExpTgt, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_row_95_en }, },
  { 7366 /* export */, AMDGPU::EXP_ROW_DONE_gfx12, ConvertCustom_cvtExp, AMFBS_HasExportInsts_isGFX12Only, { MCK_ExpTgt, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_VReg32OrOff, MCK_done, MCK_row_95_en }, },
  { 7373 /* flat_atomic_add */, AMDGPU::FLAT_ATOMIC_ADD_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7373 /* flat_atomic_add */, AMDGPU::FLAT_ATOMIC_ADD_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7373 /* flat_atomic_add */, AMDGPU::FLAT_ATOMIC_ADD_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7373 /* flat_atomic_add */, AMDGPU::FLAT_ATOMIC_ADD_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7373 /* flat_atomic_add */, AMDGPU::FLAT_ATOMIC_ADD_RTN_ci, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7373 /* flat_atomic_add */, AMDGPU::FLAT_ATOMIC_ADD_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7373 /* flat_atomic_add */, AMDGPU::FLAT_ATOMIC_ADD_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7389 /* flat_atomic_add_f32 */, AMDGPU::FLAT_ATOMIC_ADD_F32_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAtomicFaddF32Inst_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7389 /* flat_atomic_add_f32 */, AMDGPU::FLAT_ATOMIC_ADD_F32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAtomicFaddF32Inst_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7389 /* flat_atomic_add_f32 */, AMDGPU::FLAT_ATOMIC_ADD_F32_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAtomicFaddF32Inst_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7389 /* flat_atomic_add_f32 */, AMDGPU::FLAT_ATOMIC_ADD_F32_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAtomicFaddF32Inst_isGFX940Plus, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7389 /* flat_atomic_add_f32 */, AMDGPU::FLAT_ATOMIC_ADD_F32_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAtomicFaddF32Inst_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7389 /* flat_atomic_add_f32 */, AMDGPU::FLAT_ATOMIC_ADD_F32_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAtomicFaddF32Inst_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7389 /* flat_atomic_add_f32 */, AMDGPU::FLAT_ATOMIC_ADD_F32_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAtomicFaddF32Inst_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7389 /* flat_atomic_add_f32 */, AMDGPU::FLAT_ATOMIC_ADD_F32_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAtomicFaddF32Inst_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7389 /* flat_atomic_add_f32 */, AMDGPU::FLAT_ATOMIC_ADD_F32_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAtomicFaddF32Inst_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7409 /* flat_atomic_add_f64 */, AMDGPU::FLAT_ATOMIC_ADD_F64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7409 /* flat_atomic_add_f64 */, AMDGPU::FLAT_ATOMIC_ADD_F64_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7409 /* flat_atomic_add_f64 */, AMDGPU::FLAT_ATOMIC_ADD_F64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7409 /* flat_atomic_add_f64 */, AMDGPU::FLAT_ATOMIC_ADD_F64_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7409 /* flat_atomic_add_f64 */, AMDGPU::FLAT_ATOMIC_ADD_F64_SADDR_gfx1250, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7409 /* flat_atomic_add_f64 */, AMDGPU::FLAT_ATOMIC_ADD_F64_RTN_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7409 /* flat_atomic_add_f64 */, AMDGPU::FLAT_ATOMIC_ADD_F64_RTN_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7409 /* flat_atomic_add_f64 */, AMDGPU::FLAT_ATOMIC_ADD_F64_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7409 /* flat_atomic_add_f64 */, AMDGPU::FLAT_ATOMIC_ADD_F64_SADDR_RTN_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7429 /* flat_atomic_add_u32 */, AMDGPU::FLAT_ATOMIC_ADD_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7429 /* flat_atomic_add_u32 */, AMDGPU::FLAT_ATOMIC_ADD_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7429 /* flat_atomic_add_u32 */, AMDGPU::FLAT_ATOMIC_ADD_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7429 /* flat_atomic_add_u32 */, AMDGPU::FLAT_ATOMIC_ADD_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7429 /* flat_atomic_add_u32 */, AMDGPU::FLAT_ATOMIC_ADD_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7429 /* flat_atomic_add_u32 */, AMDGPU::FLAT_ATOMIC_ADD_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7449 /* flat_atomic_add_u64 */, AMDGPU::FLAT_ATOMIC_ADD_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7449 /* flat_atomic_add_u64 */, AMDGPU::FLAT_ATOMIC_ADD_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7449 /* flat_atomic_add_u64 */, AMDGPU::FLAT_ATOMIC_ADD_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7449 /* flat_atomic_add_u64 */, AMDGPU::FLAT_ATOMIC_ADD_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7449 /* flat_atomic_add_u64 */, AMDGPU::FLAT_ATOMIC_ADD_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7449 /* flat_atomic_add_u64 */, AMDGPU::FLAT_ATOMIC_ADD_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7469 /* flat_atomic_add_x2 */, AMDGPU::FLAT_ATOMIC_ADD_X2_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7469 /* flat_atomic_add_x2 */, AMDGPU::FLAT_ATOMIC_ADD_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7469 /* flat_atomic_add_x2 */, AMDGPU::FLAT_ATOMIC_ADD_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7469 /* flat_atomic_add_x2 */, AMDGPU::FLAT_ATOMIC_ADD_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7469 /* flat_atomic_add_x2 */, AMDGPU::FLAT_ATOMIC_ADD_X2_RTN_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7469 /* flat_atomic_add_x2 */, AMDGPU::FLAT_ATOMIC_ADD_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7469 /* flat_atomic_add_x2 */, AMDGPU::FLAT_ATOMIC_ADD_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7488 /* flat_atomic_and */, AMDGPU::FLAT_ATOMIC_AND_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7488 /* flat_atomic_and */, AMDGPU::FLAT_ATOMIC_AND_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7488 /* flat_atomic_and */, AMDGPU::FLAT_ATOMIC_AND_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7488 /* flat_atomic_and */, AMDGPU::FLAT_ATOMIC_AND_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7488 /* flat_atomic_and */, AMDGPU::FLAT_ATOMIC_AND_RTN_ci, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7488 /* flat_atomic_and */, AMDGPU::FLAT_ATOMIC_AND_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7488 /* flat_atomic_and */, AMDGPU::FLAT_ATOMIC_AND_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7504 /* flat_atomic_and_b32 */, AMDGPU::FLAT_ATOMIC_AND_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7504 /* flat_atomic_and_b32 */, AMDGPU::FLAT_ATOMIC_AND_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7504 /* flat_atomic_and_b32 */, AMDGPU::FLAT_ATOMIC_AND_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7504 /* flat_atomic_and_b32 */, AMDGPU::FLAT_ATOMIC_AND_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7504 /* flat_atomic_and_b32 */, AMDGPU::FLAT_ATOMIC_AND_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7504 /* flat_atomic_and_b32 */, AMDGPU::FLAT_ATOMIC_AND_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7524 /* flat_atomic_and_b64 */, AMDGPU::FLAT_ATOMIC_AND_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7524 /* flat_atomic_and_b64 */, AMDGPU::FLAT_ATOMIC_AND_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7524 /* flat_atomic_and_b64 */, AMDGPU::FLAT_ATOMIC_AND_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7524 /* flat_atomic_and_b64 */, AMDGPU::FLAT_ATOMIC_AND_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7524 /* flat_atomic_and_b64 */, AMDGPU::FLAT_ATOMIC_AND_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7524 /* flat_atomic_and_b64 */, AMDGPU::FLAT_ATOMIC_AND_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7544 /* flat_atomic_and_x2 */, AMDGPU::FLAT_ATOMIC_AND_X2_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7544 /* flat_atomic_and_x2 */, AMDGPU::FLAT_ATOMIC_AND_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7544 /* flat_atomic_and_x2 */, AMDGPU::FLAT_ATOMIC_AND_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7544 /* flat_atomic_and_x2 */, AMDGPU::FLAT_ATOMIC_AND_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7544 /* flat_atomic_and_x2 */, AMDGPU::FLAT_ATOMIC_AND_X2_RTN_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7544 /* flat_atomic_and_x2 */, AMDGPU::FLAT_ATOMIC_AND_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7544 /* flat_atomic_and_x2 */, AMDGPU::FLAT_ATOMIC_AND_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7563 /* flat_atomic_cmpswap */, AMDGPU::FLAT_ATOMIC_CMPSWAP_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7563 /* flat_atomic_cmpswap */, AMDGPU::FLAT_ATOMIC_CMPSWAP_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7563 /* flat_atomic_cmpswap */, AMDGPU::FLAT_ATOMIC_CMPSWAP_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7563 /* flat_atomic_cmpswap */, AMDGPU::FLAT_ATOMIC_CMPSWAP_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7563 /* flat_atomic_cmpswap */, AMDGPU::FLAT_ATOMIC_CMPSWAP_RTN_ci, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7563 /* flat_atomic_cmpswap */, AMDGPU::FLAT_ATOMIC_CMPSWAP_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7563 /* flat_atomic_cmpswap */, AMDGPU::FLAT_ATOMIC_CMPSWAP_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7583 /* flat_atomic_cmpswap_b32 */, AMDGPU::FLAT_ATOMIC_CMPSWAP_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7583 /* flat_atomic_cmpswap_b32 */, AMDGPU::FLAT_ATOMIC_CMPSWAP_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7583 /* flat_atomic_cmpswap_b32 */, AMDGPU::FLAT_ATOMIC_CMPSWAP_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7583 /* flat_atomic_cmpswap_b32 */, AMDGPU::FLAT_ATOMIC_CMPSWAP_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7583 /* flat_atomic_cmpswap_b32 */, AMDGPU::FLAT_ATOMIC_CMPSWAP_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7583 /* flat_atomic_cmpswap_b32 */, AMDGPU::FLAT_ATOMIC_CMPSWAP_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7607 /* flat_atomic_cmpswap_b64 */, AMDGPU::FLAT_ATOMIC_CMPSWAP_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7607 /* flat_atomic_cmpswap_b64 */, AMDGPU::FLAT_ATOMIC_CMPSWAP_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7607 /* flat_atomic_cmpswap_b64 */, AMDGPU::FLAT_ATOMIC_CMPSWAP_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7607 /* flat_atomic_cmpswap_b64 */, AMDGPU::FLAT_ATOMIC_CMPSWAP_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_128_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7607 /* flat_atomic_cmpswap_b64 */, AMDGPU::FLAT_ATOMIC_CMPSWAP_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_128_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7607 /* flat_atomic_cmpswap_b64 */, AMDGPU::FLAT_ATOMIC_CMPSWAP_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_128_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7631 /* flat_atomic_cmpswap_f32 */, AMDGPU::FLAT_ATOMIC_FCMPSWAP_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX7GFX10GFX11_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7631 /* flat_atomic_cmpswap_f32 */, AMDGPU::FLAT_ATOMIC_FCMPSWAP_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX7GFX10GFX11_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7655 /* flat_atomic_cmpswap_x2 */, AMDGPU::FLAT_ATOMIC_CMPSWAP_X2_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7655 /* flat_atomic_cmpswap_x2 */, AMDGPU::FLAT_ATOMIC_CMPSWAP_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7655 /* flat_atomic_cmpswap_x2 */, AMDGPU::FLAT_ATOMIC_CMPSWAP_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7655 /* flat_atomic_cmpswap_x2 */, AMDGPU::FLAT_ATOMIC_CMPSWAP_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_128, MCK_FlatOffset, MCK_CPol }, },
  { 7655 /* flat_atomic_cmpswap_x2 */, AMDGPU::FLAT_ATOMIC_CMPSWAP_X2_RTN_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_128_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7655 /* flat_atomic_cmpswap_x2 */, AMDGPU::FLAT_ATOMIC_CMPSWAP_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_128_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7655 /* flat_atomic_cmpswap_x2 */, AMDGPU::FLAT_ATOMIC_CMPSWAP_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_128_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7678 /* flat_atomic_cond_sub_u32 */, AMDGPU::FLAT_ATOMIC_COND_SUB_U32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7678 /* flat_atomic_cond_sub_u32 */, AMDGPU::FLAT_ATOMIC_COND_SUB_U32_SADDR_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7678 /* flat_atomic_cond_sub_u32 */, AMDGPU::FLAT_ATOMIC_COND_SUB_U32_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7678 /* flat_atomic_cond_sub_u32 */, AMDGPU::FLAT_ATOMIC_COND_SUB_U32_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7703 /* flat_atomic_dec */, AMDGPU::FLAT_ATOMIC_DEC_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7703 /* flat_atomic_dec */, AMDGPU::FLAT_ATOMIC_DEC_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7703 /* flat_atomic_dec */, AMDGPU::FLAT_ATOMIC_DEC_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7703 /* flat_atomic_dec */, AMDGPU::FLAT_ATOMIC_DEC_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7703 /* flat_atomic_dec */, AMDGPU::FLAT_ATOMIC_DEC_RTN_ci, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7703 /* flat_atomic_dec */, AMDGPU::FLAT_ATOMIC_DEC_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7703 /* flat_atomic_dec */, AMDGPU::FLAT_ATOMIC_DEC_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7719 /* flat_atomic_dec_u32 */, AMDGPU::FLAT_ATOMIC_DEC_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7719 /* flat_atomic_dec_u32 */, AMDGPU::FLAT_ATOMIC_DEC_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7719 /* flat_atomic_dec_u32 */, AMDGPU::FLAT_ATOMIC_DEC_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7719 /* flat_atomic_dec_u32 */, AMDGPU::FLAT_ATOMIC_DEC_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7719 /* flat_atomic_dec_u32 */, AMDGPU::FLAT_ATOMIC_DEC_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7719 /* flat_atomic_dec_u32 */, AMDGPU::FLAT_ATOMIC_DEC_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7739 /* flat_atomic_dec_u64 */, AMDGPU::FLAT_ATOMIC_DEC_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7739 /* flat_atomic_dec_u64 */, AMDGPU::FLAT_ATOMIC_DEC_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7739 /* flat_atomic_dec_u64 */, AMDGPU::FLAT_ATOMIC_DEC_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7739 /* flat_atomic_dec_u64 */, AMDGPU::FLAT_ATOMIC_DEC_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7739 /* flat_atomic_dec_u64 */, AMDGPU::FLAT_ATOMIC_DEC_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7739 /* flat_atomic_dec_u64 */, AMDGPU::FLAT_ATOMIC_DEC_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7759 /* flat_atomic_dec_x2 */, AMDGPU::FLAT_ATOMIC_DEC_X2_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7759 /* flat_atomic_dec_x2 */, AMDGPU::FLAT_ATOMIC_DEC_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7759 /* flat_atomic_dec_x2 */, AMDGPU::FLAT_ATOMIC_DEC_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7759 /* flat_atomic_dec_x2 */, AMDGPU::FLAT_ATOMIC_DEC_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7759 /* flat_atomic_dec_x2 */, AMDGPU::FLAT_ATOMIC_DEC_X2_RTN_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7759 /* flat_atomic_dec_x2 */, AMDGPU::FLAT_ATOMIC_DEC_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7759 /* flat_atomic_dec_x2 */, AMDGPU::FLAT_ATOMIC_DEC_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7778 /* flat_atomic_fcmpswap */, AMDGPU::FLAT_ATOMIC_FCMPSWAP_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX7GFX10GFX11_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7778 /* flat_atomic_fcmpswap */, AMDGPU::FLAT_ATOMIC_FCMPSWAP_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX7GFX10GFX11_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7778 /* flat_atomic_fcmpswap */, AMDGPU::FLAT_ATOMIC_FCMPSWAP_RTN_ci, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX7GFX10GFX11_isGFX7Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7778 /* flat_atomic_fcmpswap */, AMDGPU::FLAT_ATOMIC_FCMPSWAP_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX7GFX10GFX11_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7799 /* flat_atomic_fcmpswap_x2 */, AMDGPU::FLAT_ATOMIC_FCMPSWAP_X2_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX7GFX10_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7799 /* flat_atomic_fcmpswap_x2 */, AMDGPU::FLAT_ATOMIC_FCMPSWAP_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX7GFX10_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7799 /* flat_atomic_fcmpswap_x2 */, AMDGPU::FLAT_ATOMIC_FCMPSWAP_X2_RTN_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_128_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX7GFX10_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7799 /* flat_atomic_fcmpswap_x2 */, AMDGPU::FLAT_ATOMIC_FCMPSWAP_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_128_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX7GFX10_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7823 /* flat_atomic_fmax */, AMDGPU::FLAT_ATOMIC_FMAX_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX7GFX10GFX11_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7823 /* flat_atomic_fmax */, AMDGPU::FLAT_ATOMIC_FMAX_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX7GFX10GFX11_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7823 /* flat_atomic_fmax */, AMDGPU::FLAT_ATOMIC_FMAX_RTN_ci, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX7GFX10GFX11_isGFX7Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7823 /* flat_atomic_fmax */, AMDGPU::FLAT_ATOMIC_FMAX_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX7GFX10GFX11_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7840 /* flat_atomic_fmax_x2 */, AMDGPU::FLAT_ATOMIC_FMAX_X2_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7840 /* flat_atomic_fmax_x2 */, AMDGPU::FLAT_ATOMIC_FMAX_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7840 /* flat_atomic_fmax_x2 */, AMDGPU::FLAT_ATOMIC_FMAX_X2_RTN_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7840 /* flat_atomic_fmax_x2 */, AMDGPU::FLAT_ATOMIC_FMAX_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7860 /* flat_atomic_fmin */, AMDGPU::FLAT_ATOMIC_FMIN_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX7GFX10GFX11_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7860 /* flat_atomic_fmin */, AMDGPU::FLAT_ATOMIC_FMIN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX7GFX10GFX11_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7860 /* flat_atomic_fmin */, AMDGPU::FLAT_ATOMIC_FMIN_RTN_ci, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX7GFX10GFX11_isGFX7Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7860 /* flat_atomic_fmin */, AMDGPU::FLAT_ATOMIC_FMIN_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX7GFX10GFX11_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7877 /* flat_atomic_fmin_x2 */, AMDGPU::FLAT_ATOMIC_FMIN_X2_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7877 /* flat_atomic_fmin_x2 */, AMDGPU::FLAT_ATOMIC_FMIN_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7877 /* flat_atomic_fmin_x2 */, AMDGPU::FLAT_ATOMIC_FMIN_X2_RTN_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7877 /* flat_atomic_fmin_x2 */, AMDGPU::FLAT_ATOMIC_FMIN_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7897 /* flat_atomic_inc */, AMDGPU::FLAT_ATOMIC_INC_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7897 /* flat_atomic_inc */, AMDGPU::FLAT_ATOMIC_INC_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7897 /* flat_atomic_inc */, AMDGPU::FLAT_ATOMIC_INC_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7897 /* flat_atomic_inc */, AMDGPU::FLAT_ATOMIC_INC_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7897 /* flat_atomic_inc */, AMDGPU::FLAT_ATOMIC_INC_RTN_ci, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7897 /* flat_atomic_inc */, AMDGPU::FLAT_ATOMIC_INC_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7897 /* flat_atomic_inc */, AMDGPU::FLAT_ATOMIC_INC_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7913 /* flat_atomic_inc_u32 */, AMDGPU::FLAT_ATOMIC_INC_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7913 /* flat_atomic_inc_u32 */, AMDGPU::FLAT_ATOMIC_INC_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7913 /* flat_atomic_inc_u32 */, AMDGPU::FLAT_ATOMIC_INC_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7913 /* flat_atomic_inc_u32 */, AMDGPU::FLAT_ATOMIC_INC_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7913 /* flat_atomic_inc_u32 */, AMDGPU::FLAT_ATOMIC_INC_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7913 /* flat_atomic_inc_u32 */, AMDGPU::FLAT_ATOMIC_INC_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7933 /* flat_atomic_inc_u64 */, AMDGPU::FLAT_ATOMIC_INC_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7933 /* flat_atomic_inc_u64 */, AMDGPU::FLAT_ATOMIC_INC_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7933 /* flat_atomic_inc_u64 */, AMDGPU::FLAT_ATOMIC_INC_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7933 /* flat_atomic_inc_u64 */, AMDGPU::FLAT_ATOMIC_INC_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7933 /* flat_atomic_inc_u64 */, AMDGPU::FLAT_ATOMIC_INC_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7933 /* flat_atomic_inc_u64 */, AMDGPU::FLAT_ATOMIC_INC_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7953 /* flat_atomic_inc_x2 */, AMDGPU::FLAT_ATOMIC_INC_X2_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7953 /* flat_atomic_inc_x2 */, AMDGPU::FLAT_ATOMIC_INC_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7953 /* flat_atomic_inc_x2 */, AMDGPU::FLAT_ATOMIC_INC_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7953 /* flat_atomic_inc_x2 */, AMDGPU::FLAT_ATOMIC_INC_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7953 /* flat_atomic_inc_x2 */, AMDGPU::FLAT_ATOMIC_INC_X2_RTN_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7953 /* flat_atomic_inc_x2 */, AMDGPU::FLAT_ATOMIC_INC_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7953 /* flat_atomic_inc_x2 */, AMDGPU::FLAT_ATOMIC_INC_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7972 /* flat_atomic_max_f32 */, AMDGPU::FLAT_ATOMIC_FMAX_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX7GFX10GFX11_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 7972 /* flat_atomic_max_f32 */, AMDGPU::FLAT_ATOMIC_FMAX_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX7GFX10GFX11_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 7992 /* flat_atomic_max_f64 */, AMDGPU::FLAT_ATOMIC_MAX_F64_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7992 /* flat_atomic_max_f64 */, AMDGPU::FLAT_ATOMIC_MAX_F64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7992 /* flat_atomic_max_f64 */, AMDGPU::FLAT_ATOMIC_MAX_F64_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 7992 /* flat_atomic_max_f64 */, AMDGPU::FLAT_ATOMIC_MAX_F64_RTN_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 7992 /* flat_atomic_max_f64 */, AMDGPU::FLAT_ATOMIC_MAX_F64_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8012 /* flat_atomic_max_i32 */, AMDGPU::FLAT_ATOMIC_SMAX_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8012 /* flat_atomic_max_i32 */, AMDGPU::FLAT_ATOMIC_SMAX_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8012 /* flat_atomic_max_i32 */, AMDGPU::FLAT_ATOMIC_SMAX_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8012 /* flat_atomic_max_i32 */, AMDGPU::FLAT_ATOMIC_SMAX_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8012 /* flat_atomic_max_i32 */, AMDGPU::FLAT_ATOMIC_SMAX_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8012 /* flat_atomic_max_i32 */, AMDGPU::FLAT_ATOMIC_SMAX_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8032 /* flat_atomic_max_i64 */, AMDGPU::FLAT_ATOMIC_SMAX_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8032 /* flat_atomic_max_i64 */, AMDGPU::FLAT_ATOMIC_SMAX_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8032 /* flat_atomic_max_i64 */, AMDGPU::FLAT_ATOMIC_SMAX_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8032 /* flat_atomic_max_i64 */, AMDGPU::FLAT_ATOMIC_SMAX_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8032 /* flat_atomic_max_i64 */, AMDGPU::FLAT_ATOMIC_SMAX_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8032 /* flat_atomic_max_i64 */, AMDGPU::FLAT_ATOMIC_SMAX_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8052 /* flat_atomic_max_num_f32 */, AMDGPU::FLAT_ATOMIC_FMAX_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX7GFX10GFX11_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8052 /* flat_atomic_max_num_f32 */, AMDGPU::FLAT_ATOMIC_FMAX_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8052 /* flat_atomic_max_num_f32 */, AMDGPU::FLAT_ATOMIC_FMAX_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX7GFX10GFX11_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8052 /* flat_atomic_max_num_f32 */, AMDGPU::FLAT_ATOMIC_FMAX_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8076 /* flat_atomic_max_num_f64 */, AMDGPU::FLAT_ATOMIC_MAX_F64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8076 /* flat_atomic_max_num_f64 */, AMDGPU::FLAT_ATOMIC_MAX_F64_SADDR_gfx1250, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8076 /* flat_atomic_max_num_f64 */, AMDGPU::FLAT_ATOMIC_MAX_F64_RTN_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8076 /* flat_atomic_max_num_f64 */, AMDGPU::FLAT_ATOMIC_MAX_F64_SADDR_RTN_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8100 /* flat_atomic_max_u32 */, AMDGPU::FLAT_ATOMIC_UMAX_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8100 /* flat_atomic_max_u32 */, AMDGPU::FLAT_ATOMIC_UMAX_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8100 /* flat_atomic_max_u32 */, AMDGPU::FLAT_ATOMIC_UMAX_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8100 /* flat_atomic_max_u32 */, AMDGPU::FLAT_ATOMIC_UMAX_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8100 /* flat_atomic_max_u32 */, AMDGPU::FLAT_ATOMIC_UMAX_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8100 /* flat_atomic_max_u32 */, AMDGPU::FLAT_ATOMIC_UMAX_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8120 /* flat_atomic_max_u64 */, AMDGPU::FLAT_ATOMIC_UMAX_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8120 /* flat_atomic_max_u64 */, AMDGPU::FLAT_ATOMIC_UMAX_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8120 /* flat_atomic_max_u64 */, AMDGPU::FLAT_ATOMIC_UMAX_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8120 /* flat_atomic_max_u64 */, AMDGPU::FLAT_ATOMIC_UMAX_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8120 /* flat_atomic_max_u64 */, AMDGPU::FLAT_ATOMIC_UMAX_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8120 /* flat_atomic_max_u64 */, AMDGPU::FLAT_ATOMIC_UMAX_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8140 /* flat_atomic_min_f32 */, AMDGPU::FLAT_ATOMIC_FMIN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX7GFX10GFX11_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8140 /* flat_atomic_min_f32 */, AMDGPU::FLAT_ATOMIC_FMIN_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX7GFX10GFX11_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8160 /* flat_atomic_min_f64 */, AMDGPU::FLAT_ATOMIC_MIN_F64_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8160 /* flat_atomic_min_f64 */, AMDGPU::FLAT_ATOMIC_MIN_F64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8160 /* flat_atomic_min_f64 */, AMDGPU::FLAT_ATOMIC_MIN_F64_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8160 /* flat_atomic_min_f64 */, AMDGPU::FLAT_ATOMIC_MIN_F64_RTN_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8160 /* flat_atomic_min_f64 */, AMDGPU::FLAT_ATOMIC_MIN_F64_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8180 /* flat_atomic_min_i32 */, AMDGPU::FLAT_ATOMIC_SMIN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8180 /* flat_atomic_min_i32 */, AMDGPU::FLAT_ATOMIC_SMIN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8180 /* flat_atomic_min_i32 */, AMDGPU::FLAT_ATOMIC_SMIN_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8180 /* flat_atomic_min_i32 */, AMDGPU::FLAT_ATOMIC_SMIN_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8180 /* flat_atomic_min_i32 */, AMDGPU::FLAT_ATOMIC_SMIN_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8180 /* flat_atomic_min_i32 */, AMDGPU::FLAT_ATOMIC_SMIN_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8200 /* flat_atomic_min_i64 */, AMDGPU::FLAT_ATOMIC_SMIN_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8200 /* flat_atomic_min_i64 */, AMDGPU::FLAT_ATOMIC_SMIN_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8200 /* flat_atomic_min_i64 */, AMDGPU::FLAT_ATOMIC_SMIN_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8200 /* flat_atomic_min_i64 */, AMDGPU::FLAT_ATOMIC_SMIN_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8200 /* flat_atomic_min_i64 */, AMDGPU::FLAT_ATOMIC_SMIN_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8200 /* flat_atomic_min_i64 */, AMDGPU::FLAT_ATOMIC_SMIN_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8220 /* flat_atomic_min_num_f32 */, AMDGPU::FLAT_ATOMIC_FMIN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX7GFX10GFX11_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8220 /* flat_atomic_min_num_f32 */, AMDGPU::FLAT_ATOMIC_FMIN_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8220 /* flat_atomic_min_num_f32 */, AMDGPU::FLAT_ATOMIC_FMIN_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX7GFX10GFX11_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8220 /* flat_atomic_min_num_f32 */, AMDGPU::FLAT_ATOMIC_FMIN_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8244 /* flat_atomic_min_num_f64 */, AMDGPU::FLAT_ATOMIC_MIN_F64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8244 /* flat_atomic_min_num_f64 */, AMDGPU::FLAT_ATOMIC_MIN_F64_SADDR_gfx1250, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8244 /* flat_atomic_min_num_f64 */, AMDGPU::FLAT_ATOMIC_MIN_F64_RTN_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8244 /* flat_atomic_min_num_f64 */, AMDGPU::FLAT_ATOMIC_MIN_F64_SADDR_RTN_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8268 /* flat_atomic_min_u32 */, AMDGPU::FLAT_ATOMIC_UMIN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8268 /* flat_atomic_min_u32 */, AMDGPU::FLAT_ATOMIC_UMIN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8268 /* flat_atomic_min_u32 */, AMDGPU::FLAT_ATOMIC_UMIN_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8268 /* flat_atomic_min_u32 */, AMDGPU::FLAT_ATOMIC_UMIN_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8268 /* flat_atomic_min_u32 */, AMDGPU::FLAT_ATOMIC_UMIN_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8268 /* flat_atomic_min_u32 */, AMDGPU::FLAT_ATOMIC_UMIN_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8288 /* flat_atomic_min_u64 */, AMDGPU::FLAT_ATOMIC_UMIN_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8288 /* flat_atomic_min_u64 */, AMDGPU::FLAT_ATOMIC_UMIN_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8288 /* flat_atomic_min_u64 */, AMDGPU::FLAT_ATOMIC_UMIN_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8288 /* flat_atomic_min_u64 */, AMDGPU::FLAT_ATOMIC_UMIN_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8288 /* flat_atomic_min_u64 */, AMDGPU::FLAT_ATOMIC_UMIN_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8288 /* flat_atomic_min_u64 */, AMDGPU::FLAT_ATOMIC_UMIN_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8308 /* flat_atomic_or */, AMDGPU::FLAT_ATOMIC_OR_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8308 /* flat_atomic_or */, AMDGPU::FLAT_ATOMIC_OR_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8308 /* flat_atomic_or */, AMDGPU::FLAT_ATOMIC_OR_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8308 /* flat_atomic_or */, AMDGPU::FLAT_ATOMIC_OR_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8308 /* flat_atomic_or */, AMDGPU::FLAT_ATOMIC_OR_RTN_ci, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8308 /* flat_atomic_or */, AMDGPU::FLAT_ATOMIC_OR_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8308 /* flat_atomic_or */, AMDGPU::FLAT_ATOMIC_OR_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8323 /* flat_atomic_or_b32 */, AMDGPU::FLAT_ATOMIC_OR_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8323 /* flat_atomic_or_b32 */, AMDGPU::FLAT_ATOMIC_OR_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8323 /* flat_atomic_or_b32 */, AMDGPU::FLAT_ATOMIC_OR_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8323 /* flat_atomic_or_b32 */, AMDGPU::FLAT_ATOMIC_OR_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8323 /* flat_atomic_or_b32 */, AMDGPU::FLAT_ATOMIC_OR_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8323 /* flat_atomic_or_b32 */, AMDGPU::FLAT_ATOMIC_OR_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8342 /* flat_atomic_or_b64 */, AMDGPU::FLAT_ATOMIC_OR_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8342 /* flat_atomic_or_b64 */, AMDGPU::FLAT_ATOMIC_OR_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8342 /* flat_atomic_or_b64 */, AMDGPU::FLAT_ATOMIC_OR_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8342 /* flat_atomic_or_b64 */, AMDGPU::FLAT_ATOMIC_OR_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8342 /* flat_atomic_or_b64 */, AMDGPU::FLAT_ATOMIC_OR_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8342 /* flat_atomic_or_b64 */, AMDGPU::FLAT_ATOMIC_OR_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8361 /* flat_atomic_or_x2 */, AMDGPU::FLAT_ATOMIC_OR_X2_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8361 /* flat_atomic_or_x2 */, AMDGPU::FLAT_ATOMIC_OR_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8361 /* flat_atomic_or_x2 */, AMDGPU::FLAT_ATOMIC_OR_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8361 /* flat_atomic_or_x2 */, AMDGPU::FLAT_ATOMIC_OR_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8361 /* flat_atomic_or_x2 */, AMDGPU::FLAT_ATOMIC_OR_X2_RTN_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8361 /* flat_atomic_or_x2 */, AMDGPU::FLAT_ATOMIC_OR_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8361 /* flat_atomic_or_x2 */, AMDGPU::FLAT_ATOMIC_OR_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8379 /* flat_atomic_pk_add_bf16 */, AMDGPU::FLAT_ATOMIC_PK_ADD_BF16_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8379 /* flat_atomic_pk_add_bf16 */, AMDGPU::FLAT_ATOMIC_PK_ADD_BF16_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8379 /* flat_atomic_pk_add_bf16 */, AMDGPU::FLAT_ATOMIC_PK_ADD_BF16_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8379 /* flat_atomic_pk_add_bf16 */, AMDGPU::FLAT_ATOMIC_PK_ADD_BF16_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8379 /* flat_atomic_pk_add_bf16 */, AMDGPU::FLAT_ATOMIC_PK_ADD_BF16_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8379 /* flat_atomic_pk_add_bf16 */, AMDGPU::FLAT_ATOMIC_PK_ADD_BF16_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8379 /* flat_atomic_pk_add_bf16 */, AMDGPU::FLAT_ATOMIC_PK_ADD_BF16_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8403 /* flat_atomic_pk_add_f16 */, AMDGPU::FLAT_ATOMIC_PK_ADD_F16_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8403 /* flat_atomic_pk_add_f16 */, AMDGPU::FLAT_ATOMIC_PK_ADD_F16_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8403 /* flat_atomic_pk_add_f16 */, AMDGPU::FLAT_ATOMIC_PK_ADD_F16_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8403 /* flat_atomic_pk_add_f16 */, AMDGPU::FLAT_ATOMIC_PK_ADD_F16_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8403 /* flat_atomic_pk_add_f16 */, AMDGPU::FLAT_ATOMIC_PK_ADD_F16_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8403 /* flat_atomic_pk_add_f16 */, AMDGPU::FLAT_ATOMIC_PK_ADD_F16_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8403 /* flat_atomic_pk_add_f16 */, AMDGPU::FLAT_ATOMIC_PK_ADD_F16_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8426 /* flat_atomic_smax */, AMDGPU::FLAT_ATOMIC_SMAX_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8426 /* flat_atomic_smax */, AMDGPU::FLAT_ATOMIC_SMAX_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8426 /* flat_atomic_smax */, AMDGPU::FLAT_ATOMIC_SMAX_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8426 /* flat_atomic_smax */, AMDGPU::FLAT_ATOMIC_SMAX_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8426 /* flat_atomic_smax */, AMDGPU::FLAT_ATOMIC_SMAX_RTN_ci, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8426 /* flat_atomic_smax */, AMDGPU::FLAT_ATOMIC_SMAX_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8426 /* flat_atomic_smax */, AMDGPU::FLAT_ATOMIC_SMAX_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8443 /* flat_atomic_smax_x2 */, AMDGPU::FLAT_ATOMIC_SMAX_X2_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8443 /* flat_atomic_smax_x2 */, AMDGPU::FLAT_ATOMIC_SMAX_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8443 /* flat_atomic_smax_x2 */, AMDGPU::FLAT_ATOMIC_SMAX_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8443 /* flat_atomic_smax_x2 */, AMDGPU::FLAT_ATOMIC_SMAX_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8443 /* flat_atomic_smax_x2 */, AMDGPU::FLAT_ATOMIC_SMAX_X2_RTN_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8443 /* flat_atomic_smax_x2 */, AMDGPU::FLAT_ATOMIC_SMAX_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8443 /* flat_atomic_smax_x2 */, AMDGPU::FLAT_ATOMIC_SMAX_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8463 /* flat_atomic_smin */, AMDGPU::FLAT_ATOMIC_SMIN_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8463 /* flat_atomic_smin */, AMDGPU::FLAT_ATOMIC_SMIN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8463 /* flat_atomic_smin */, AMDGPU::FLAT_ATOMIC_SMIN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8463 /* flat_atomic_smin */, AMDGPU::FLAT_ATOMIC_SMIN_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8463 /* flat_atomic_smin */, AMDGPU::FLAT_ATOMIC_SMIN_RTN_ci, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8463 /* flat_atomic_smin */, AMDGPU::FLAT_ATOMIC_SMIN_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8463 /* flat_atomic_smin */, AMDGPU::FLAT_ATOMIC_SMIN_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8480 /* flat_atomic_smin_x2 */, AMDGPU::FLAT_ATOMIC_SMIN_X2_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8480 /* flat_atomic_smin_x2 */, AMDGPU::FLAT_ATOMIC_SMIN_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8480 /* flat_atomic_smin_x2 */, AMDGPU::FLAT_ATOMIC_SMIN_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8480 /* flat_atomic_smin_x2 */, AMDGPU::FLAT_ATOMIC_SMIN_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8480 /* flat_atomic_smin_x2 */, AMDGPU::FLAT_ATOMIC_SMIN_X2_RTN_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8480 /* flat_atomic_smin_x2 */, AMDGPU::FLAT_ATOMIC_SMIN_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8480 /* flat_atomic_smin_x2 */, AMDGPU::FLAT_ATOMIC_SMIN_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8500 /* flat_atomic_sub */, AMDGPU::FLAT_ATOMIC_SUB_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8500 /* flat_atomic_sub */, AMDGPU::FLAT_ATOMIC_SUB_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8500 /* flat_atomic_sub */, AMDGPU::FLAT_ATOMIC_SUB_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8500 /* flat_atomic_sub */, AMDGPU::FLAT_ATOMIC_SUB_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8500 /* flat_atomic_sub */, AMDGPU::FLAT_ATOMIC_SUB_RTN_ci, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8500 /* flat_atomic_sub */, AMDGPU::FLAT_ATOMIC_SUB_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8500 /* flat_atomic_sub */, AMDGPU::FLAT_ATOMIC_SUB_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8516 /* flat_atomic_sub_clamp_u32 */, AMDGPU::FLAT_ATOMIC_CSUB_U32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8516 /* flat_atomic_sub_clamp_u32 */, AMDGPU::FLAT_ATOMIC_CSUB_U32_SADDR_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8516 /* flat_atomic_sub_clamp_u32 */, AMDGPU::FLAT_ATOMIC_CSUB_U32_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8516 /* flat_atomic_sub_clamp_u32 */, AMDGPU::FLAT_ATOMIC_CSUB_U32_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8542 /* flat_atomic_sub_u32 */, AMDGPU::FLAT_ATOMIC_SUB_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8542 /* flat_atomic_sub_u32 */, AMDGPU::FLAT_ATOMIC_SUB_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8542 /* flat_atomic_sub_u32 */, AMDGPU::FLAT_ATOMIC_SUB_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8542 /* flat_atomic_sub_u32 */, AMDGPU::FLAT_ATOMIC_SUB_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8542 /* flat_atomic_sub_u32 */, AMDGPU::FLAT_ATOMIC_SUB_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8542 /* flat_atomic_sub_u32 */, AMDGPU::FLAT_ATOMIC_SUB_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8562 /* flat_atomic_sub_u64 */, AMDGPU::FLAT_ATOMIC_SUB_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8562 /* flat_atomic_sub_u64 */, AMDGPU::FLAT_ATOMIC_SUB_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8562 /* flat_atomic_sub_u64 */, AMDGPU::FLAT_ATOMIC_SUB_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8562 /* flat_atomic_sub_u64 */, AMDGPU::FLAT_ATOMIC_SUB_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8562 /* flat_atomic_sub_u64 */, AMDGPU::FLAT_ATOMIC_SUB_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8562 /* flat_atomic_sub_u64 */, AMDGPU::FLAT_ATOMIC_SUB_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8582 /* flat_atomic_sub_x2 */, AMDGPU::FLAT_ATOMIC_SUB_X2_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8582 /* flat_atomic_sub_x2 */, AMDGPU::FLAT_ATOMIC_SUB_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8582 /* flat_atomic_sub_x2 */, AMDGPU::FLAT_ATOMIC_SUB_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8582 /* flat_atomic_sub_x2 */, AMDGPU::FLAT_ATOMIC_SUB_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8582 /* flat_atomic_sub_x2 */, AMDGPU::FLAT_ATOMIC_SUB_X2_RTN_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8582 /* flat_atomic_sub_x2 */, AMDGPU::FLAT_ATOMIC_SUB_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8582 /* flat_atomic_sub_x2 */, AMDGPU::FLAT_ATOMIC_SUB_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8601 /* flat_atomic_swap */, AMDGPU::FLAT_ATOMIC_SWAP_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8601 /* flat_atomic_swap */, AMDGPU::FLAT_ATOMIC_SWAP_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8601 /* flat_atomic_swap */, AMDGPU::FLAT_ATOMIC_SWAP_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8601 /* flat_atomic_swap */, AMDGPU::FLAT_ATOMIC_SWAP_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8601 /* flat_atomic_swap */, AMDGPU::FLAT_ATOMIC_SWAP_RTN_ci, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8601 /* flat_atomic_swap */, AMDGPU::FLAT_ATOMIC_SWAP_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8601 /* flat_atomic_swap */, AMDGPU::FLAT_ATOMIC_SWAP_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8618 /* flat_atomic_swap_b32 */, AMDGPU::FLAT_ATOMIC_SWAP_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8618 /* flat_atomic_swap_b32 */, AMDGPU::FLAT_ATOMIC_SWAP_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8618 /* flat_atomic_swap_b32 */, AMDGPU::FLAT_ATOMIC_SWAP_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8618 /* flat_atomic_swap_b32 */, AMDGPU::FLAT_ATOMIC_SWAP_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8618 /* flat_atomic_swap_b32 */, AMDGPU::FLAT_ATOMIC_SWAP_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8618 /* flat_atomic_swap_b32 */, AMDGPU::FLAT_ATOMIC_SWAP_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8639 /* flat_atomic_swap_b64 */, AMDGPU::FLAT_ATOMIC_SWAP_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8639 /* flat_atomic_swap_b64 */, AMDGPU::FLAT_ATOMIC_SWAP_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8639 /* flat_atomic_swap_b64 */, AMDGPU::FLAT_ATOMIC_SWAP_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8639 /* flat_atomic_swap_b64 */, AMDGPU::FLAT_ATOMIC_SWAP_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8639 /* flat_atomic_swap_b64 */, AMDGPU::FLAT_ATOMIC_SWAP_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8639 /* flat_atomic_swap_b64 */, AMDGPU::FLAT_ATOMIC_SWAP_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8660 /* flat_atomic_swap_x2 */, AMDGPU::FLAT_ATOMIC_SWAP_X2_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8660 /* flat_atomic_swap_x2 */, AMDGPU::FLAT_ATOMIC_SWAP_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8660 /* flat_atomic_swap_x2 */, AMDGPU::FLAT_ATOMIC_SWAP_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8660 /* flat_atomic_swap_x2 */, AMDGPU::FLAT_ATOMIC_SWAP_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8660 /* flat_atomic_swap_x2 */, AMDGPU::FLAT_ATOMIC_SWAP_X2_RTN_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8660 /* flat_atomic_swap_x2 */, AMDGPU::FLAT_ATOMIC_SWAP_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8660 /* flat_atomic_swap_x2 */, AMDGPU::FLAT_ATOMIC_SWAP_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8680 /* flat_atomic_umax */, AMDGPU::FLAT_ATOMIC_UMAX_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8680 /* flat_atomic_umax */, AMDGPU::FLAT_ATOMIC_UMAX_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8680 /* flat_atomic_umax */, AMDGPU::FLAT_ATOMIC_UMAX_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8680 /* flat_atomic_umax */, AMDGPU::FLAT_ATOMIC_UMAX_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8680 /* flat_atomic_umax */, AMDGPU::FLAT_ATOMIC_UMAX_RTN_ci, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8680 /* flat_atomic_umax */, AMDGPU::FLAT_ATOMIC_UMAX_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8680 /* flat_atomic_umax */, AMDGPU::FLAT_ATOMIC_UMAX_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8697 /* flat_atomic_umax_x2 */, AMDGPU::FLAT_ATOMIC_UMAX_X2_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8697 /* flat_atomic_umax_x2 */, AMDGPU::FLAT_ATOMIC_UMAX_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8697 /* flat_atomic_umax_x2 */, AMDGPU::FLAT_ATOMIC_UMAX_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8697 /* flat_atomic_umax_x2 */, AMDGPU::FLAT_ATOMIC_UMAX_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8697 /* flat_atomic_umax_x2 */, AMDGPU::FLAT_ATOMIC_UMAX_X2_RTN_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8697 /* flat_atomic_umax_x2 */, AMDGPU::FLAT_ATOMIC_UMAX_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8697 /* flat_atomic_umax_x2 */, AMDGPU::FLAT_ATOMIC_UMAX_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8717 /* flat_atomic_umin */, AMDGPU::FLAT_ATOMIC_UMIN_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8717 /* flat_atomic_umin */, AMDGPU::FLAT_ATOMIC_UMIN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8717 /* flat_atomic_umin */, AMDGPU::FLAT_ATOMIC_UMIN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8717 /* flat_atomic_umin */, AMDGPU::FLAT_ATOMIC_UMIN_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8717 /* flat_atomic_umin */, AMDGPU::FLAT_ATOMIC_UMIN_RTN_ci, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8717 /* flat_atomic_umin */, AMDGPU::FLAT_ATOMIC_UMIN_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8717 /* flat_atomic_umin */, AMDGPU::FLAT_ATOMIC_UMIN_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8734 /* flat_atomic_umin_x2 */, AMDGPU::FLAT_ATOMIC_UMIN_X2_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8734 /* flat_atomic_umin_x2 */, AMDGPU::FLAT_ATOMIC_UMIN_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8734 /* flat_atomic_umin_x2 */, AMDGPU::FLAT_ATOMIC_UMIN_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8734 /* flat_atomic_umin_x2 */, AMDGPU::FLAT_ATOMIC_UMIN_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8734 /* flat_atomic_umin_x2 */, AMDGPU::FLAT_ATOMIC_UMIN_X2_RTN_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8734 /* flat_atomic_umin_x2 */, AMDGPU::FLAT_ATOMIC_UMIN_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8734 /* flat_atomic_umin_x2 */, AMDGPU::FLAT_ATOMIC_UMIN_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8754 /* flat_atomic_xor */, AMDGPU::FLAT_ATOMIC_XOR_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8754 /* flat_atomic_xor */, AMDGPU::FLAT_ATOMIC_XOR_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8754 /* flat_atomic_xor */, AMDGPU::FLAT_ATOMIC_XOR_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8754 /* flat_atomic_xor */, AMDGPU::FLAT_ATOMIC_XOR_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8754 /* flat_atomic_xor */, AMDGPU::FLAT_ATOMIC_XOR_RTN_ci, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8754 /* flat_atomic_xor */, AMDGPU::FLAT_ATOMIC_XOR_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8754 /* flat_atomic_xor */, AMDGPU::FLAT_ATOMIC_XOR_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8770 /* flat_atomic_xor_b32 */, AMDGPU::FLAT_ATOMIC_XOR_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8770 /* flat_atomic_xor_b32 */, AMDGPU::FLAT_ATOMIC_XOR_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 8770 /* flat_atomic_xor_b32 */, AMDGPU::FLAT_ATOMIC_XOR_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8770 /* flat_atomic_xor_b32 */, AMDGPU::FLAT_ATOMIC_XOR_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8770 /* flat_atomic_xor_b32 */, AMDGPU::FLAT_ATOMIC_XOR_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_FlatOffset, MCK_CPol }, },
  { 8770 /* flat_atomic_xor_b32 */, AMDGPU::FLAT_ATOMIC_XOR_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8790 /* flat_atomic_xor_b64 */, AMDGPU::FLAT_ATOMIC_XOR_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8790 /* flat_atomic_xor_b64 */, AMDGPU::FLAT_ATOMIC_XOR_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8790 /* flat_atomic_xor_b64 */, AMDGPU::FLAT_ATOMIC_XOR_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8790 /* flat_atomic_xor_b64 */, AMDGPU::FLAT_ATOMIC_XOR_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8790 /* flat_atomic_xor_b64 */, AMDGPU::FLAT_ATOMIC_XOR_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8790 /* flat_atomic_xor_b64 */, AMDGPU::FLAT_ATOMIC_XOR_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8810 /* flat_atomic_xor_x2 */, AMDGPU::FLAT_ATOMIC_XOR_X2_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8810 /* flat_atomic_xor_x2 */, AMDGPU::FLAT_ATOMIC_XOR_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8810 /* flat_atomic_xor_x2 */, AMDGPU::FLAT_ATOMIC_XOR_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8810 /* flat_atomic_xor_x2 */, AMDGPU::FLAT_ATOMIC_XOR_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 8810 /* flat_atomic_xor_x2 */, AMDGPU::FLAT_ATOMIC_XOR_X2_RTN_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8810 /* flat_atomic_xor_x2 */, AMDGPU::FLAT_ATOMIC_XOR_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8810 /* flat_atomic_xor_x2 */, AMDGPU::FLAT_ATOMIC_XOR_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8829 /* flat_load_b128 */, AMDGPU::FLAT_LOAD_DWORDX4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8829 /* flat_load_b128 */, AMDGPU::FLAT_LOAD_DWORDX4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8829 /* flat_load_b128 */, AMDGPU::FLAT_LOAD_DWORDX4_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 8844 /* flat_load_b32 */, AMDGPU::FLAT_LOAD_DWORD_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8844 /* flat_load_b32 */, AMDGPU::FLAT_LOAD_DWORD_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8844 /* flat_load_b32 */, AMDGPU::FLAT_LOAD_DWORD_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 8858 /* flat_load_b64 */, AMDGPU::FLAT_LOAD_DWORDX2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8858 /* flat_load_b64 */, AMDGPU::FLAT_LOAD_DWORDX2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8858 /* flat_load_b64 */, AMDGPU::FLAT_LOAD_DWORDX2_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 8872 /* flat_load_b96 */, AMDGPU::FLAT_LOAD_DWORDX3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8872 /* flat_load_b96 */, AMDGPU::FLAT_LOAD_DWORDX3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8872 /* flat_load_b96 */, AMDGPU::FLAT_LOAD_DWORDX3_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 8886 /* flat_load_d16_b16 */, AMDGPU::FLAT_LOAD_SHORT_D16_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8886 /* flat_load_d16_b16 */, AMDGPU::FLAT_LOAD_SHORT_D16_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8886 /* flat_load_d16_b16 */, AMDGPU::FLAT_LOAD_SHORT_D16_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 8904 /* flat_load_d16_hi_b16 */, AMDGPU::FLAT_LOAD_SHORT_D16_HI_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8904 /* flat_load_d16_hi_b16 */, AMDGPU::FLAT_LOAD_SHORT_D16_HI_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8904 /* flat_load_d16_hi_b16 */, AMDGPU::FLAT_LOAD_SHORT_D16_HI_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 8925 /* flat_load_d16_hi_i8 */, AMDGPU::FLAT_LOAD_SBYTE_D16_HI_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8925 /* flat_load_d16_hi_i8 */, AMDGPU::FLAT_LOAD_SBYTE_D16_HI_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8925 /* flat_load_d16_hi_i8 */, AMDGPU::FLAT_LOAD_SBYTE_D16_HI_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 8945 /* flat_load_d16_hi_u8 */, AMDGPU::FLAT_LOAD_UBYTE_D16_HI_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8945 /* flat_load_d16_hi_u8 */, AMDGPU::FLAT_LOAD_UBYTE_D16_HI_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8945 /* flat_load_d16_hi_u8 */, AMDGPU::FLAT_LOAD_UBYTE_D16_HI_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 8965 /* flat_load_d16_i8 */, AMDGPU::FLAT_LOAD_SBYTE_D16_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8965 /* flat_load_d16_i8 */, AMDGPU::FLAT_LOAD_SBYTE_D16_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8965 /* flat_load_d16_i8 */, AMDGPU::FLAT_LOAD_SBYTE_D16_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 8982 /* flat_load_d16_u8 */, AMDGPU::FLAT_LOAD_UBYTE_D16_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8982 /* flat_load_d16_u8 */, AMDGPU::FLAT_LOAD_UBYTE_D16_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8982 /* flat_load_d16_u8 */, AMDGPU::FLAT_LOAD_UBYTE_D16_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 8999 /* flat_load_dword */, AMDGPU::FLAT_LOAD_DWORD_ci, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8999 /* flat_load_dword */, AMDGPU::FLAT_LOAD_DWORD_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 8999 /* flat_load_dword */, AMDGPU::FLAT_LOAD_DWORD_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9015 /* flat_load_dwordx2 */, AMDGPU::FLAT_LOAD_DWORDX2_ci, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9015 /* flat_load_dwordx2 */, AMDGPU::FLAT_LOAD_DWORDX2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9015 /* flat_load_dwordx2 */, AMDGPU::FLAT_LOAD_DWORDX2_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9033 /* flat_load_dwordx3 */, AMDGPU::FLAT_LOAD_DWORDX3_ci, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9033 /* flat_load_dwordx3 */, AMDGPU::FLAT_LOAD_DWORDX3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9033 /* flat_load_dwordx3 */, AMDGPU::FLAT_LOAD_DWORDX3_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9051 /* flat_load_dwordx4 */, AMDGPU::FLAT_LOAD_DWORDX4_ci, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9051 /* flat_load_dwordx4 */, AMDGPU::FLAT_LOAD_DWORDX4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9051 /* flat_load_dwordx4 */, AMDGPU::FLAT_LOAD_DWORDX4_vi, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9069 /* flat_load_i16 */, AMDGPU::FLAT_LOAD_SSHORT_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9069 /* flat_load_i16 */, AMDGPU::FLAT_LOAD_SSHORT_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9069 /* flat_load_i16 */, AMDGPU::FLAT_LOAD_SSHORT_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9083 /* flat_load_i8 */, AMDGPU::FLAT_LOAD_SBYTE_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9083 /* flat_load_i8 */, AMDGPU::FLAT_LOAD_SBYTE_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9083 /* flat_load_i8 */, AMDGPU::FLAT_LOAD_SBYTE_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9096 /* flat_load_monitor_b128 */, AMDGPU::FLAT_LOAD_MONITOR_B128_gfx1250, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX125xOnly, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9096 /* flat_load_monitor_b128 */, AMDGPU::FLAT_LOAD_MONITOR_B128_SADDR_gfx1250, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_isGFX125xOnly, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9119 /* flat_load_monitor_b32 */, AMDGPU::FLAT_LOAD_MONITOR_B32_gfx1250, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX125xOnly, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9119 /* flat_load_monitor_b32 */, AMDGPU::FLAT_LOAD_MONITOR_B32_SADDR_gfx1250, Convert__Reg1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9141 /* flat_load_monitor_b64 */, AMDGPU::FLAT_LOAD_MONITOR_B64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9141 /* flat_load_monitor_b64 */, AMDGPU::FLAT_LOAD_MONITOR_B64_SADDR_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9163 /* flat_load_sbyte */, AMDGPU::FLAT_LOAD_SBYTE_ci, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9163 /* flat_load_sbyte */, AMDGPU::FLAT_LOAD_SBYTE_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9163 /* flat_load_sbyte */, AMDGPU::FLAT_LOAD_SBYTE_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9179 /* flat_load_sbyte_d16 */, AMDGPU::FLAT_LOAD_SBYTE_D16_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9179 /* flat_load_sbyte_d16 */, AMDGPU::FLAT_LOAD_SBYTE_D16_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9199 /* flat_load_sbyte_d16_hi */, AMDGPU::FLAT_LOAD_SBYTE_D16_HI_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9199 /* flat_load_sbyte_d16_hi */, AMDGPU::FLAT_LOAD_SBYTE_D16_HI_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9222 /* flat_load_short_d16 */, AMDGPU::FLAT_LOAD_SHORT_D16_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9222 /* flat_load_short_d16 */, AMDGPU::FLAT_LOAD_SHORT_D16_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9242 /* flat_load_short_d16_hi */, AMDGPU::FLAT_LOAD_SHORT_D16_HI_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9242 /* flat_load_short_d16_hi */, AMDGPU::FLAT_LOAD_SHORT_D16_HI_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9265 /* flat_load_sshort */, AMDGPU::FLAT_LOAD_SSHORT_ci, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9265 /* flat_load_sshort */, AMDGPU::FLAT_LOAD_SSHORT_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9265 /* flat_load_sshort */, AMDGPU::FLAT_LOAD_SSHORT_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9282 /* flat_load_u16 */, AMDGPU::FLAT_LOAD_USHORT_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9282 /* flat_load_u16 */, AMDGPU::FLAT_LOAD_USHORT_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9282 /* flat_load_u16 */, AMDGPU::FLAT_LOAD_USHORT_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9296 /* flat_load_u8 */, AMDGPU::FLAT_LOAD_UBYTE_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9296 /* flat_load_u8 */, AMDGPU::FLAT_LOAD_UBYTE_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9296 /* flat_load_u8 */, AMDGPU::FLAT_LOAD_UBYTE_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9309 /* flat_load_ubyte */, AMDGPU::FLAT_LOAD_UBYTE_ci, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9309 /* flat_load_ubyte */, AMDGPU::FLAT_LOAD_UBYTE_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9309 /* flat_load_ubyte */, AMDGPU::FLAT_LOAD_UBYTE_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9325 /* flat_load_ubyte_d16 */, AMDGPU::FLAT_LOAD_UBYTE_D16_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9325 /* flat_load_ubyte_d16 */, AMDGPU::FLAT_LOAD_UBYTE_D16_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9345 /* flat_load_ubyte_d16_hi */, AMDGPU::FLAT_LOAD_UBYTE_D16_HI_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9345 /* flat_load_ubyte_d16_hi */, AMDGPU::FLAT_LOAD_UBYTE_D16_HI_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3__imm_95_0, AMFBS_HasD16LoadStore_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9368 /* flat_load_ushort */, AMDGPU::FLAT_LOAD_USHORT_ci, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9368 /* flat_load_ushort */, AMDGPU::FLAT_LOAD_USHORT_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9368 /* flat_load_ushort */, AMDGPU::FLAT_LOAD_USHORT_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9385 /* flat_prefetch_b8 */, AMDGPU::FLAT_PREFETCH_B8_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_1__CPol1_2, AMFBS_HasVmemPrefInsts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9385 /* flat_prefetch_b8 */, AMDGPU::FLAT_PREFETCH_B8_SADDR_gfx1250, Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatGVSMode_HasVmemPrefInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 9402 /* flat_store_b128 */, AMDGPU::FLAT_STORE_DWORDX4_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9402 /* flat_store_b128 */, AMDGPU::FLAT_STORE_DWORDX4_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9402 /* flat_store_b128 */, AMDGPU::FLAT_STORE_DWORDX4_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9418 /* flat_store_b16 */, AMDGPU::FLAT_STORE_SHORT_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9418 /* flat_store_b16 */, AMDGPU::FLAT_STORE_SHORT_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9418 /* flat_store_b16 */, AMDGPU::FLAT_STORE_SHORT_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9433 /* flat_store_b32 */, AMDGPU::FLAT_STORE_DWORD_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9433 /* flat_store_b32 */, AMDGPU::FLAT_STORE_DWORD_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9433 /* flat_store_b32 */, AMDGPU::FLAT_STORE_DWORD_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9448 /* flat_store_b64 */, AMDGPU::FLAT_STORE_DWORDX2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9448 /* flat_store_b64 */, AMDGPU::FLAT_STORE_DWORDX2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9448 /* flat_store_b64 */, AMDGPU::FLAT_STORE_DWORDX2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9463 /* flat_store_b8 */, AMDGPU::FLAT_STORE_BYTE_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9463 /* flat_store_b8 */, AMDGPU::FLAT_STORE_BYTE_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9463 /* flat_store_b8 */, AMDGPU::FLAT_STORE_BYTE_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9477 /* flat_store_b96 */, AMDGPU::FLAT_STORE_DWORDX3_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9477 /* flat_store_b96 */, AMDGPU::FLAT_STORE_DWORDX3_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9477 /* flat_store_b96 */, AMDGPU::FLAT_STORE_DWORDX3_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9492 /* flat_store_byte */, AMDGPU::FLAT_STORE_BYTE_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9492 /* flat_store_byte */, AMDGPU::FLAT_STORE_BYTE_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9492 /* flat_store_byte */, AMDGPU::FLAT_STORE_BYTE_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9508 /* flat_store_byte_d16_hi */, AMDGPU::FLAT_STORE_BYTE_D16_HI_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9508 /* flat_store_byte_d16_hi */, AMDGPU::FLAT_STORE_BYTE_D16_HI_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasD16LoadStore_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9531 /* flat_store_d16_hi_b16 */, AMDGPU::FLAT_STORE_SHORT_D16_HI_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9531 /* flat_store_d16_hi_b16 */, AMDGPU::FLAT_STORE_SHORT_D16_HI_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9531 /* flat_store_d16_hi_b16 */, AMDGPU::FLAT_STORE_SHORT_D16_HI_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9553 /* flat_store_d16_hi_b8 */, AMDGPU::FLAT_STORE_BYTE_D16_HI_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasD16LoadStore_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9553 /* flat_store_d16_hi_b8 */, AMDGPU::FLAT_STORE_BYTE_D16_HI_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasD16LoadStore_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9553 /* flat_store_d16_hi_b8 */, AMDGPU::FLAT_STORE_BYTE_D16_HI_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9574 /* flat_store_dword */, AMDGPU::FLAT_STORE_DWORD_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9574 /* flat_store_dword */, AMDGPU::FLAT_STORE_DWORD_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9574 /* flat_store_dword */, AMDGPU::FLAT_STORE_DWORD_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9591 /* flat_store_dwordx2 */, AMDGPU::FLAT_STORE_DWORDX2_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9591 /* flat_store_dwordx2 */, AMDGPU::FLAT_STORE_DWORDX2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9591 /* flat_store_dwordx2 */, AMDGPU::FLAT_STORE_DWORDX2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9610 /* flat_store_dwordx3 */, AMDGPU::FLAT_STORE_DWORDX3_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9610 /* flat_store_dwordx3 */, AMDGPU::FLAT_STORE_DWORDX3_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9610 /* flat_store_dwordx3 */, AMDGPU::FLAT_STORE_DWORDX3_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9629 /* flat_store_dwordx4 */, AMDGPU::FLAT_STORE_DWORDX4_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9629 /* flat_store_dwordx4 */, AMDGPU::FLAT_STORE_DWORDX4_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9629 /* flat_store_dwordx4 */, AMDGPU::FLAT_STORE_DWORDX4_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_FlatOffset, MCK_CPol }, },
  { 9648 /* flat_store_short */, AMDGPU::FLAT_STORE_SHORT_ci, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9648 /* flat_store_short */, AMDGPU::FLAT_STORE_SHORT_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9648 /* flat_store_short */, AMDGPU::FLAT_STORE_SHORT_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatAddressSpace_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9665 /* flat_store_short_d16_hi */, AMDGPU::FLAT_STORE_SHORT_D16_HI_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasD16LoadStore_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9665 /* flat_store_short_d16_hi */, AMDGPU::FLAT_STORE_SHORT_D16_HI_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_2__CPol1_3, AMFBS_HasD16LoadStore_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_FlatOffset, MCK_CPol }, },
  { 9689 /* global_atomic_add */, AMDGPU::GLOBAL_ATOMIC_ADD_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9689 /* global_atomic_add */, AMDGPU::GLOBAL_ATOMIC_ADD_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9689 /* global_atomic_add */, AMDGPU::GLOBAL_ATOMIC_ADD_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9689 /* global_atomic_add */, AMDGPU::GLOBAL_ATOMIC_ADD_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9689 /* global_atomic_add */, AMDGPU::GLOBAL_ATOMIC_ADD_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9689 /* global_atomic_add */, AMDGPU::GLOBAL_ATOMIC_ADD_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9689 /* global_atomic_add */, AMDGPU::GLOBAL_ATOMIC_ADD_SADDR_RTN_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9689 /* global_atomic_add */, AMDGPU::GLOBAL_ATOMIC_ADD_SADDR_RTN_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9689 /* global_atomic_add */, AMDGPU::GLOBAL_ATOMIC_ADD_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9689 /* global_atomic_add */, AMDGPU::GLOBAL_ATOMIC_ADD_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9707 /* global_atomic_add_f32 */, AMDGPU::GLOBAL_ATOMIC_ADD_F32_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9707 /* global_atomic_add_f32 */, AMDGPU::GLOBAL_ATOMIC_ADD_F32_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9707 /* global_atomic_add_f32 */, AMDGPU::GLOBAL_ATOMIC_ADD_F32_SADDR_gfx940, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9707 /* global_atomic_add_f32 */, AMDGPU::GLOBAL_ATOMIC_ADD_F32_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX940, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9707 /* global_atomic_add_f32 */, AMDGPU::GLOBAL_ATOMIC_ADD_F32_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9707 /* global_atomic_add_f32 */, AMDGPU::GLOBAL_ATOMIC_ADD_F32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9707 /* global_atomic_add_f32 */, AMDGPU::GLOBAL_ATOMIC_ADD_F32_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9707 /* global_atomic_add_f32 */, AMDGPU::GLOBAL_ATOMIC_ADD_F32_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX940, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9707 /* global_atomic_add_f32 */, AMDGPU::GLOBAL_ATOMIC_ADD_F32_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9707 /* global_atomic_add_f32 */, AMDGPU::GLOBAL_ATOMIC_ADD_F32_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9707 /* global_atomic_add_f32 */, AMDGPU::GLOBAL_ATOMIC_ADD_F32_SADDR_RTN_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9707 /* global_atomic_add_f32 */, AMDGPU::GLOBAL_ATOMIC_ADD_F32_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9707 /* global_atomic_add_f32 */, AMDGPU::GLOBAL_ATOMIC_ADD_F32_SADDR_RTN_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9707 /* global_atomic_add_f32 */, AMDGPU::GLOBAL_ATOMIC_ADD_F32_SADDR_RTN_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9707 /* global_atomic_add_f32 */, AMDGPU::GLOBAL_ATOMIC_ADD_F32_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9707 /* global_atomic_add_f32 */, AMDGPU::GLOBAL_ATOMIC_ADD_F32_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9707 /* global_atomic_add_f32 */, AMDGPU::GLOBAL_ATOMIC_ADD_F32_RTN_gfx940, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9707 /* global_atomic_add_f32 */, AMDGPU::GLOBAL_ATOMIC_ADD_F32_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9729 /* global_atomic_add_f64 */, AMDGPU::GLOBAL_ATOMIC_ADD_F64_SADDR_gfx1250, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9729 /* global_atomic_add_f64 */, AMDGPU::GLOBAL_ATOMIC_ADD_F64_SADDR_gfx940, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9729 /* global_atomic_add_f64 */, AMDGPU::GLOBAL_ATOMIC_ADD_F64_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9729 /* global_atomic_add_f64 */, AMDGPU::GLOBAL_ATOMIC_ADD_F64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9729 /* global_atomic_add_f64 */, AMDGPU::GLOBAL_ATOMIC_ADD_F64_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9729 /* global_atomic_add_f64 */, AMDGPU::GLOBAL_ATOMIC_ADD_F64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9729 /* global_atomic_add_f64 */, AMDGPU::GLOBAL_ATOMIC_ADD_F64_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9729 /* global_atomic_add_f64 */, AMDGPU::GLOBAL_ATOMIC_ADD_F64_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9729 /* global_atomic_add_f64 */, AMDGPU::GLOBAL_ATOMIC_ADD_F64_SADDR_RTN_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9729 /* global_atomic_add_f64 */, AMDGPU::GLOBAL_ATOMIC_ADD_F64_SADDR_RTN_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9729 /* global_atomic_add_f64 */, AMDGPU::GLOBAL_ATOMIC_ADD_F64_SADDR_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9729 /* global_atomic_add_f64 */, AMDGPU::GLOBAL_ATOMIC_ADD_F64_RTN_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9729 /* global_atomic_add_f64 */, AMDGPU::GLOBAL_ATOMIC_ADD_F64_RTN_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9729 /* global_atomic_add_f64 */, AMDGPU::GLOBAL_ATOMIC_ADD_F64_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9751 /* global_atomic_add_u32 */, AMDGPU::GLOBAL_ATOMIC_ADD_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9751 /* global_atomic_add_u32 */, AMDGPU::GLOBAL_ATOMIC_ADD_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9751 /* global_atomic_add_u32 */, AMDGPU::GLOBAL_ATOMIC_ADD_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9751 /* global_atomic_add_u32 */, AMDGPU::GLOBAL_ATOMIC_ADD_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9751 /* global_atomic_add_u32 */, AMDGPU::GLOBAL_ATOMIC_ADD_SADDR_RTN_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9751 /* global_atomic_add_u32 */, AMDGPU::GLOBAL_ATOMIC_ADD_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9751 /* global_atomic_add_u32 */, AMDGPU::GLOBAL_ATOMIC_ADD_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9751 /* global_atomic_add_u32 */, AMDGPU::GLOBAL_ATOMIC_ADD_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9773 /* global_atomic_add_u64 */, AMDGPU::GLOBAL_ATOMIC_ADD_X2_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9773 /* global_atomic_add_u64 */, AMDGPU::GLOBAL_ATOMIC_ADD_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9773 /* global_atomic_add_u64 */, AMDGPU::GLOBAL_ATOMIC_ADD_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9773 /* global_atomic_add_u64 */, AMDGPU::GLOBAL_ATOMIC_ADD_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9773 /* global_atomic_add_u64 */, AMDGPU::GLOBAL_ATOMIC_ADD_X2_SADDR_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9773 /* global_atomic_add_u64 */, AMDGPU::GLOBAL_ATOMIC_ADD_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9773 /* global_atomic_add_u64 */, AMDGPU::GLOBAL_ATOMIC_ADD_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9773 /* global_atomic_add_u64 */, AMDGPU::GLOBAL_ATOMIC_ADD_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9795 /* global_atomic_add_x2 */, AMDGPU::GLOBAL_ATOMIC_ADD_X2_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9795 /* global_atomic_add_x2 */, AMDGPU::GLOBAL_ATOMIC_ADD_X2_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9795 /* global_atomic_add_x2 */, AMDGPU::GLOBAL_ATOMIC_ADD_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9795 /* global_atomic_add_x2 */, AMDGPU::GLOBAL_ATOMIC_ADD_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9795 /* global_atomic_add_x2 */, AMDGPU::GLOBAL_ATOMIC_ADD_X2_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9795 /* global_atomic_add_x2 */, AMDGPU::GLOBAL_ATOMIC_ADD_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9795 /* global_atomic_add_x2 */, AMDGPU::GLOBAL_ATOMIC_ADD_X2_SADDR_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9795 /* global_atomic_add_x2 */, AMDGPU::GLOBAL_ATOMIC_ADD_X2_SADDR_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9795 /* global_atomic_add_x2 */, AMDGPU::GLOBAL_ATOMIC_ADD_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9795 /* global_atomic_add_x2 */, AMDGPU::GLOBAL_ATOMIC_ADD_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9816 /* global_atomic_and */, AMDGPU::GLOBAL_ATOMIC_AND_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9816 /* global_atomic_and */, AMDGPU::GLOBAL_ATOMIC_AND_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9816 /* global_atomic_and */, AMDGPU::GLOBAL_ATOMIC_AND_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9816 /* global_atomic_and */, AMDGPU::GLOBAL_ATOMIC_AND_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9816 /* global_atomic_and */, AMDGPU::GLOBAL_ATOMIC_AND_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9816 /* global_atomic_and */, AMDGPU::GLOBAL_ATOMIC_AND_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9816 /* global_atomic_and */, AMDGPU::GLOBAL_ATOMIC_AND_SADDR_RTN_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9816 /* global_atomic_and */, AMDGPU::GLOBAL_ATOMIC_AND_SADDR_RTN_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9816 /* global_atomic_and */, AMDGPU::GLOBAL_ATOMIC_AND_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9816 /* global_atomic_and */, AMDGPU::GLOBAL_ATOMIC_AND_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9834 /* global_atomic_and_b32 */, AMDGPU::GLOBAL_ATOMIC_AND_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9834 /* global_atomic_and_b32 */, AMDGPU::GLOBAL_ATOMIC_AND_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9834 /* global_atomic_and_b32 */, AMDGPU::GLOBAL_ATOMIC_AND_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9834 /* global_atomic_and_b32 */, AMDGPU::GLOBAL_ATOMIC_AND_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9834 /* global_atomic_and_b32 */, AMDGPU::GLOBAL_ATOMIC_AND_SADDR_RTN_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9834 /* global_atomic_and_b32 */, AMDGPU::GLOBAL_ATOMIC_AND_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9834 /* global_atomic_and_b32 */, AMDGPU::GLOBAL_ATOMIC_AND_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9834 /* global_atomic_and_b32 */, AMDGPU::GLOBAL_ATOMIC_AND_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9856 /* global_atomic_and_b64 */, AMDGPU::GLOBAL_ATOMIC_AND_X2_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9856 /* global_atomic_and_b64 */, AMDGPU::GLOBAL_ATOMIC_AND_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9856 /* global_atomic_and_b64 */, AMDGPU::GLOBAL_ATOMIC_AND_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9856 /* global_atomic_and_b64 */, AMDGPU::GLOBAL_ATOMIC_AND_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9856 /* global_atomic_and_b64 */, AMDGPU::GLOBAL_ATOMIC_AND_X2_SADDR_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9856 /* global_atomic_and_b64 */, AMDGPU::GLOBAL_ATOMIC_AND_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9856 /* global_atomic_and_b64 */, AMDGPU::GLOBAL_ATOMIC_AND_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9856 /* global_atomic_and_b64 */, AMDGPU::GLOBAL_ATOMIC_AND_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9878 /* global_atomic_and_x2 */, AMDGPU::GLOBAL_ATOMIC_AND_X2_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9878 /* global_atomic_and_x2 */, AMDGPU::GLOBAL_ATOMIC_AND_X2_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9878 /* global_atomic_and_x2 */, AMDGPU::GLOBAL_ATOMIC_AND_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9878 /* global_atomic_and_x2 */, AMDGPU::GLOBAL_ATOMIC_AND_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9878 /* global_atomic_and_x2 */, AMDGPU::GLOBAL_ATOMIC_AND_X2_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9878 /* global_atomic_and_x2 */, AMDGPU::GLOBAL_ATOMIC_AND_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9878 /* global_atomic_and_x2 */, AMDGPU::GLOBAL_ATOMIC_AND_X2_SADDR_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9878 /* global_atomic_and_x2 */, AMDGPU::GLOBAL_ATOMIC_AND_X2_SADDR_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9878 /* global_atomic_and_x2 */, AMDGPU::GLOBAL_ATOMIC_AND_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9878 /* global_atomic_and_x2 */, AMDGPU::GLOBAL_ATOMIC_AND_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9899 /* global_atomic_cmpswap */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9899 /* global_atomic_cmpswap */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9899 /* global_atomic_cmpswap */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9899 /* global_atomic_cmpswap */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9899 /* global_atomic_cmpswap */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_VGPR_32, MCK_AReg_64, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9899 /* global_atomic_cmpswap */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9899 /* global_atomic_cmpswap */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_SADDR_RTN_gfx10, Convert__Reg1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9899 /* global_atomic_cmpswap */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_SADDR_RTN_vi, Convert__Reg1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9899 /* global_atomic_cmpswap */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9899 /* global_atomic_cmpswap */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9921 /* global_atomic_cmpswap_b32 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9921 /* global_atomic_cmpswap_b32 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9921 /* global_atomic_cmpswap_b32 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9921 /* global_atomic_cmpswap_b32 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9921 /* global_atomic_cmpswap_b32 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_SADDR_RTN_gfx11, Convert__Reg1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9921 /* global_atomic_cmpswap_b32 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9921 /* global_atomic_cmpswap_b32 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9921 /* global_atomic_cmpswap_b32 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9947 /* global_atomic_cmpswap_b64 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_X2_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9947 /* global_atomic_cmpswap_b64 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9947 /* global_atomic_cmpswap_b64 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9947 /* global_atomic_cmpswap_b64 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9947 /* global_atomic_cmpswap_b64 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_X2_SADDR_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_128_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9947 /* global_atomic_cmpswap_b64 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_128_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9947 /* global_atomic_cmpswap_b64 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_128_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9947 /* global_atomic_cmpswap_b64 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_128_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9973 /* global_atomic_cmpswap_f32 */, AMDGPU::GLOBAL_ATOMIC_FCMPSWAP_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9973 /* global_atomic_cmpswap_f32 */, AMDGPU::GLOBAL_ATOMIC_FCMPSWAP_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX10Plus_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9973 /* global_atomic_cmpswap_f32 */, AMDGPU::GLOBAL_ATOMIC_FCMPSWAP_SADDR_RTN_gfx11, Convert__Reg1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9973 /* global_atomic_cmpswap_f32 */, AMDGPU::GLOBAL_ATOMIC_FCMPSWAP_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9999 /* global_atomic_cmpswap_x2 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_X2_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9999 /* global_atomic_cmpswap_x2 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_X2_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9999 /* global_atomic_cmpswap_x2 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9999 /* global_atomic_cmpswap_x2 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9999 /* global_atomic_cmpswap_x2 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_X2_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_128, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9999 /* global_atomic_cmpswap_x2 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_128, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9999 /* global_atomic_cmpswap_x2 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_X2_SADDR_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_128_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9999 /* global_atomic_cmpswap_x2 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_X2_SADDR_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_128_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 9999 /* global_atomic_cmpswap_x2 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_128_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 9999 /* global_atomic_cmpswap_x2 */, AMDGPU::GLOBAL_ATOMIC_CMPSWAP_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_128_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10024 /* global_atomic_cond_sub_u32 */, AMDGPU::GLOBAL_ATOMIC_COND_SUB_U32_SADDR_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10024 /* global_atomic_cond_sub_u32 */, AMDGPU::GLOBAL_ATOMIC_COND_SUB_U32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10024 /* global_atomic_cond_sub_u32 */, AMDGPU::GLOBAL_ATOMIC_COND_SUB_U32_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10024 /* global_atomic_cond_sub_u32 */, AMDGPU::GLOBAL_ATOMIC_COND_SUB_U32_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10051 /* global_atomic_csub */, AMDGPU::GLOBAL_ATOMIC_CSUB_SADDR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasGFX10_BEncoding_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10051 /* global_atomic_csub */, AMDGPU::GLOBAL_ATOMIC_CSUB_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasGFX10_BEncoding_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10051 /* global_atomic_csub */, AMDGPU::GLOBAL_ATOMIC_CSUB_SADDR_RTN_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasGFX10_BEncoding_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10051 /* global_atomic_csub */, AMDGPU::GLOBAL_ATOMIC_CSUB_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasGFX10_BEncoding_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10070 /* global_atomic_csub_u32 */, AMDGPU::GLOBAL_ATOMIC_CSUB_SADDR_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasGFX10_BEncoding_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10070 /* global_atomic_csub_u32 */, AMDGPU::GLOBAL_ATOMIC_CSUB_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasGFX10_BEncoding_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10070 /* global_atomic_csub_u32 */, AMDGPU::GLOBAL_ATOMIC_CSUB_SADDR_RTN_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasGFX10_BEncoding_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10070 /* global_atomic_csub_u32 */, AMDGPU::GLOBAL_ATOMIC_CSUB_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasGFX10_BEncoding_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10093 /* global_atomic_dec */, AMDGPU::GLOBAL_ATOMIC_DEC_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10093 /* global_atomic_dec */, AMDGPU::GLOBAL_ATOMIC_DEC_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10093 /* global_atomic_dec */, AMDGPU::GLOBAL_ATOMIC_DEC_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10093 /* global_atomic_dec */, AMDGPU::GLOBAL_ATOMIC_DEC_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10093 /* global_atomic_dec */, AMDGPU::GLOBAL_ATOMIC_DEC_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10093 /* global_atomic_dec */, AMDGPU::GLOBAL_ATOMIC_DEC_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10093 /* global_atomic_dec */, AMDGPU::GLOBAL_ATOMIC_DEC_SADDR_RTN_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10093 /* global_atomic_dec */, AMDGPU::GLOBAL_ATOMIC_DEC_SADDR_RTN_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10093 /* global_atomic_dec */, AMDGPU::GLOBAL_ATOMIC_DEC_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10093 /* global_atomic_dec */, AMDGPU::GLOBAL_ATOMIC_DEC_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10111 /* global_atomic_dec_u32 */, AMDGPU::GLOBAL_ATOMIC_DEC_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10111 /* global_atomic_dec_u32 */, AMDGPU::GLOBAL_ATOMIC_DEC_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10111 /* global_atomic_dec_u32 */, AMDGPU::GLOBAL_ATOMIC_DEC_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10111 /* global_atomic_dec_u32 */, AMDGPU::GLOBAL_ATOMIC_DEC_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10111 /* global_atomic_dec_u32 */, AMDGPU::GLOBAL_ATOMIC_DEC_SADDR_RTN_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10111 /* global_atomic_dec_u32 */, AMDGPU::GLOBAL_ATOMIC_DEC_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10111 /* global_atomic_dec_u32 */, AMDGPU::GLOBAL_ATOMIC_DEC_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10111 /* global_atomic_dec_u32 */, AMDGPU::GLOBAL_ATOMIC_DEC_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10133 /* global_atomic_dec_u64 */, AMDGPU::GLOBAL_ATOMIC_DEC_X2_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10133 /* global_atomic_dec_u64 */, AMDGPU::GLOBAL_ATOMIC_DEC_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10133 /* global_atomic_dec_u64 */, AMDGPU::GLOBAL_ATOMIC_DEC_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10133 /* global_atomic_dec_u64 */, AMDGPU::GLOBAL_ATOMIC_DEC_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10133 /* global_atomic_dec_u64 */, AMDGPU::GLOBAL_ATOMIC_DEC_X2_SADDR_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10133 /* global_atomic_dec_u64 */, AMDGPU::GLOBAL_ATOMIC_DEC_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10133 /* global_atomic_dec_u64 */, AMDGPU::GLOBAL_ATOMIC_DEC_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10133 /* global_atomic_dec_u64 */, AMDGPU::GLOBAL_ATOMIC_DEC_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10155 /* global_atomic_dec_x2 */, AMDGPU::GLOBAL_ATOMIC_DEC_X2_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10155 /* global_atomic_dec_x2 */, AMDGPU::GLOBAL_ATOMIC_DEC_X2_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10155 /* global_atomic_dec_x2 */, AMDGPU::GLOBAL_ATOMIC_DEC_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10155 /* global_atomic_dec_x2 */, AMDGPU::GLOBAL_ATOMIC_DEC_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10155 /* global_atomic_dec_x2 */, AMDGPU::GLOBAL_ATOMIC_DEC_X2_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10155 /* global_atomic_dec_x2 */, AMDGPU::GLOBAL_ATOMIC_DEC_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10155 /* global_atomic_dec_x2 */, AMDGPU::GLOBAL_ATOMIC_DEC_X2_SADDR_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10155 /* global_atomic_dec_x2 */, AMDGPU::GLOBAL_ATOMIC_DEC_X2_SADDR_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10155 /* global_atomic_dec_x2 */, AMDGPU::GLOBAL_ATOMIC_DEC_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10155 /* global_atomic_dec_x2 */, AMDGPU::GLOBAL_ATOMIC_DEC_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10176 /* global_atomic_fcmpswap */, AMDGPU::GLOBAL_ATOMIC_FCMPSWAP_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX10Plus_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10176 /* global_atomic_fcmpswap */, AMDGPU::GLOBAL_ATOMIC_FCMPSWAP_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX10Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10176 /* global_atomic_fcmpswap */, AMDGPU::GLOBAL_ATOMIC_FCMPSWAP_SADDR_RTN_gfx10, Convert__Reg1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX10Plus_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10176 /* global_atomic_fcmpswap */, AMDGPU::GLOBAL_ATOMIC_FCMPSWAP_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX10Plus_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10199 /* global_atomic_fcmpswap_x2 */, AMDGPU::GLOBAL_ATOMIC_FCMPSWAP_X2_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX10Plus_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10199 /* global_atomic_fcmpswap_x2 */, AMDGPU::GLOBAL_ATOMIC_FCMPSWAP_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX10Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10199 /* global_atomic_fcmpswap_x2 */, AMDGPU::GLOBAL_ATOMIC_FCMPSWAP_X2_SADDR_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_128_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX10Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10199 /* global_atomic_fcmpswap_x2 */, AMDGPU::GLOBAL_ATOMIC_FCMPSWAP_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_128_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX10Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10225 /* global_atomic_fmax */, AMDGPU::GLOBAL_ATOMIC_FMAX_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX10Plus_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10225 /* global_atomic_fmax */, AMDGPU::GLOBAL_ATOMIC_FMAX_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX10Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10225 /* global_atomic_fmax */, AMDGPU::GLOBAL_ATOMIC_FMAX_SADDR_RTN_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX10Plus_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10225 /* global_atomic_fmax */, AMDGPU::GLOBAL_ATOMIC_FMAX_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX10Plus_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10244 /* global_atomic_fmax_x2 */, AMDGPU::GLOBAL_ATOMIC_FMAX_X2_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10244 /* global_atomic_fmax_x2 */, AMDGPU::GLOBAL_ATOMIC_FMAX_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10244 /* global_atomic_fmax_x2 */, AMDGPU::GLOBAL_ATOMIC_FMAX_X2_SADDR_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10244 /* global_atomic_fmax_x2 */, AMDGPU::GLOBAL_ATOMIC_FMAX_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10266 /* global_atomic_fmin */, AMDGPU::GLOBAL_ATOMIC_FMIN_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX10Plus_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10266 /* global_atomic_fmin */, AMDGPU::GLOBAL_ATOMIC_FMIN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX10Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10266 /* global_atomic_fmin */, AMDGPU::GLOBAL_ATOMIC_FMIN_SADDR_RTN_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX10Plus_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10266 /* global_atomic_fmin */, AMDGPU::GLOBAL_ATOMIC_FMIN_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX10Plus_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10285 /* global_atomic_fmin_x2 */, AMDGPU::GLOBAL_ATOMIC_FMIN_X2_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10285 /* global_atomic_fmin_x2 */, AMDGPU::GLOBAL_ATOMIC_FMIN_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10285 /* global_atomic_fmin_x2 */, AMDGPU::GLOBAL_ATOMIC_FMIN_X2_SADDR_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10285 /* global_atomic_fmin_x2 */, AMDGPU::GLOBAL_ATOMIC_FMIN_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10307 /* global_atomic_inc */, AMDGPU::GLOBAL_ATOMIC_INC_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10307 /* global_atomic_inc */, AMDGPU::GLOBAL_ATOMIC_INC_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10307 /* global_atomic_inc */, AMDGPU::GLOBAL_ATOMIC_INC_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10307 /* global_atomic_inc */, AMDGPU::GLOBAL_ATOMIC_INC_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10307 /* global_atomic_inc */, AMDGPU::GLOBAL_ATOMIC_INC_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10307 /* global_atomic_inc */, AMDGPU::GLOBAL_ATOMIC_INC_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10307 /* global_atomic_inc */, AMDGPU::GLOBAL_ATOMIC_INC_SADDR_RTN_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10307 /* global_atomic_inc */, AMDGPU::GLOBAL_ATOMIC_INC_SADDR_RTN_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10307 /* global_atomic_inc */, AMDGPU::GLOBAL_ATOMIC_INC_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10307 /* global_atomic_inc */, AMDGPU::GLOBAL_ATOMIC_INC_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10325 /* global_atomic_inc_u32 */, AMDGPU::GLOBAL_ATOMIC_INC_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10325 /* global_atomic_inc_u32 */, AMDGPU::GLOBAL_ATOMIC_INC_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10325 /* global_atomic_inc_u32 */, AMDGPU::GLOBAL_ATOMIC_INC_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10325 /* global_atomic_inc_u32 */, AMDGPU::GLOBAL_ATOMIC_INC_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10325 /* global_atomic_inc_u32 */, AMDGPU::GLOBAL_ATOMIC_INC_SADDR_RTN_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10325 /* global_atomic_inc_u32 */, AMDGPU::GLOBAL_ATOMIC_INC_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10325 /* global_atomic_inc_u32 */, AMDGPU::GLOBAL_ATOMIC_INC_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10325 /* global_atomic_inc_u32 */, AMDGPU::GLOBAL_ATOMIC_INC_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10347 /* global_atomic_inc_u64 */, AMDGPU::GLOBAL_ATOMIC_INC_X2_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10347 /* global_atomic_inc_u64 */, AMDGPU::GLOBAL_ATOMIC_INC_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10347 /* global_atomic_inc_u64 */, AMDGPU::GLOBAL_ATOMIC_INC_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10347 /* global_atomic_inc_u64 */, AMDGPU::GLOBAL_ATOMIC_INC_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10347 /* global_atomic_inc_u64 */, AMDGPU::GLOBAL_ATOMIC_INC_X2_SADDR_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10347 /* global_atomic_inc_u64 */, AMDGPU::GLOBAL_ATOMIC_INC_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10347 /* global_atomic_inc_u64 */, AMDGPU::GLOBAL_ATOMIC_INC_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10347 /* global_atomic_inc_u64 */, AMDGPU::GLOBAL_ATOMIC_INC_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10369 /* global_atomic_inc_x2 */, AMDGPU::GLOBAL_ATOMIC_INC_X2_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10369 /* global_atomic_inc_x2 */, AMDGPU::GLOBAL_ATOMIC_INC_X2_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10369 /* global_atomic_inc_x2 */, AMDGPU::GLOBAL_ATOMIC_INC_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10369 /* global_atomic_inc_x2 */, AMDGPU::GLOBAL_ATOMIC_INC_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10369 /* global_atomic_inc_x2 */, AMDGPU::GLOBAL_ATOMIC_INC_X2_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10369 /* global_atomic_inc_x2 */, AMDGPU::GLOBAL_ATOMIC_INC_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10369 /* global_atomic_inc_x2 */, AMDGPU::GLOBAL_ATOMIC_INC_X2_SADDR_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10369 /* global_atomic_inc_x2 */, AMDGPU::GLOBAL_ATOMIC_INC_X2_SADDR_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10369 /* global_atomic_inc_x2 */, AMDGPU::GLOBAL_ATOMIC_INC_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10369 /* global_atomic_inc_x2 */, AMDGPU::GLOBAL_ATOMIC_INC_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10390 /* global_atomic_max_f32 */, AMDGPU::GLOBAL_ATOMIC_FMAX_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10390 /* global_atomic_max_f32 */, AMDGPU::GLOBAL_ATOMIC_FMAX_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX10Plus_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10390 /* global_atomic_max_f32 */, AMDGPU::GLOBAL_ATOMIC_FMAX_SADDR_RTN_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10390 /* global_atomic_max_f32 */, AMDGPU::GLOBAL_ATOMIC_FMAX_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10412 /* global_atomic_max_f64 */, AMDGPU::GLOBAL_ATOMIC_MAX_F64_SADDR_gfx940, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10412 /* global_atomic_max_f64 */, AMDGPU::GLOBAL_ATOMIC_MAX_F64_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10412 /* global_atomic_max_f64 */, AMDGPU::GLOBAL_ATOMIC_MAX_F64_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10412 /* global_atomic_max_f64 */, AMDGPU::GLOBAL_ATOMIC_MAX_F64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10412 /* global_atomic_max_f64 */, AMDGPU::GLOBAL_ATOMIC_MAX_F64_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10412 /* global_atomic_max_f64 */, AMDGPU::GLOBAL_ATOMIC_MAX_F64_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10412 /* global_atomic_max_f64 */, AMDGPU::GLOBAL_ATOMIC_MAX_F64_SADDR_RTN_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10412 /* global_atomic_max_f64 */, AMDGPU::GLOBAL_ATOMIC_MAX_F64_SADDR_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10412 /* global_atomic_max_f64 */, AMDGPU::GLOBAL_ATOMIC_MAX_F64_RTN_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10412 /* global_atomic_max_f64 */, AMDGPU::GLOBAL_ATOMIC_MAX_F64_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10434 /* global_atomic_max_i32 */, AMDGPU::GLOBAL_ATOMIC_SMAX_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10434 /* global_atomic_max_i32 */, AMDGPU::GLOBAL_ATOMIC_SMAX_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10434 /* global_atomic_max_i32 */, AMDGPU::GLOBAL_ATOMIC_SMAX_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10434 /* global_atomic_max_i32 */, AMDGPU::GLOBAL_ATOMIC_SMAX_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10434 /* global_atomic_max_i32 */, AMDGPU::GLOBAL_ATOMIC_SMAX_SADDR_RTN_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10434 /* global_atomic_max_i32 */, AMDGPU::GLOBAL_ATOMIC_SMAX_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10434 /* global_atomic_max_i32 */, AMDGPU::GLOBAL_ATOMIC_SMAX_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10434 /* global_atomic_max_i32 */, AMDGPU::GLOBAL_ATOMIC_SMAX_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10456 /* global_atomic_max_i64 */, AMDGPU::GLOBAL_ATOMIC_SMAX_X2_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10456 /* global_atomic_max_i64 */, AMDGPU::GLOBAL_ATOMIC_SMAX_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10456 /* global_atomic_max_i64 */, AMDGPU::GLOBAL_ATOMIC_SMAX_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10456 /* global_atomic_max_i64 */, AMDGPU::GLOBAL_ATOMIC_SMAX_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10456 /* global_atomic_max_i64 */, AMDGPU::GLOBAL_ATOMIC_SMAX_X2_SADDR_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10456 /* global_atomic_max_i64 */, AMDGPU::GLOBAL_ATOMIC_SMAX_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10456 /* global_atomic_max_i64 */, AMDGPU::GLOBAL_ATOMIC_SMAX_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10456 /* global_atomic_max_i64 */, AMDGPU::GLOBAL_ATOMIC_SMAX_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10478 /* global_atomic_max_num_f32 */, AMDGPU::GLOBAL_ATOMIC_FMAX_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10478 /* global_atomic_max_num_f32 */, AMDGPU::GLOBAL_ATOMIC_FMAX_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX10Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10478 /* global_atomic_max_num_f32 */, AMDGPU::GLOBAL_ATOMIC_FMAX_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10478 /* global_atomic_max_num_f32 */, AMDGPU::GLOBAL_ATOMIC_FMAX_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10504 /* global_atomic_max_num_f64 */, AMDGPU::GLOBAL_ATOMIC_MAX_F64_SADDR_gfx1250, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10504 /* global_atomic_max_num_f64 */, AMDGPU::GLOBAL_ATOMIC_MAX_F64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10504 /* global_atomic_max_num_f64 */, AMDGPU::GLOBAL_ATOMIC_MAX_F64_SADDR_RTN_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10504 /* global_atomic_max_num_f64 */, AMDGPU::GLOBAL_ATOMIC_MAX_F64_RTN_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10530 /* global_atomic_max_u32 */, AMDGPU::GLOBAL_ATOMIC_UMAX_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10530 /* global_atomic_max_u32 */, AMDGPU::GLOBAL_ATOMIC_UMAX_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10530 /* global_atomic_max_u32 */, AMDGPU::GLOBAL_ATOMIC_UMAX_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10530 /* global_atomic_max_u32 */, AMDGPU::GLOBAL_ATOMIC_UMAX_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10530 /* global_atomic_max_u32 */, AMDGPU::GLOBAL_ATOMIC_UMAX_SADDR_RTN_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10530 /* global_atomic_max_u32 */, AMDGPU::GLOBAL_ATOMIC_UMAX_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10530 /* global_atomic_max_u32 */, AMDGPU::GLOBAL_ATOMIC_UMAX_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10530 /* global_atomic_max_u32 */, AMDGPU::GLOBAL_ATOMIC_UMAX_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10552 /* global_atomic_max_u64 */, AMDGPU::GLOBAL_ATOMIC_UMAX_X2_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10552 /* global_atomic_max_u64 */, AMDGPU::GLOBAL_ATOMIC_UMAX_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10552 /* global_atomic_max_u64 */, AMDGPU::GLOBAL_ATOMIC_UMAX_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10552 /* global_atomic_max_u64 */, AMDGPU::GLOBAL_ATOMIC_UMAX_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10552 /* global_atomic_max_u64 */, AMDGPU::GLOBAL_ATOMIC_UMAX_X2_SADDR_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10552 /* global_atomic_max_u64 */, AMDGPU::GLOBAL_ATOMIC_UMAX_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10552 /* global_atomic_max_u64 */, AMDGPU::GLOBAL_ATOMIC_UMAX_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10552 /* global_atomic_max_u64 */, AMDGPU::GLOBAL_ATOMIC_UMAX_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10574 /* global_atomic_min_f32 */, AMDGPU::GLOBAL_ATOMIC_FMIN_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10574 /* global_atomic_min_f32 */, AMDGPU::GLOBAL_ATOMIC_FMIN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX10Plus_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10574 /* global_atomic_min_f32 */, AMDGPU::GLOBAL_ATOMIC_FMIN_SADDR_RTN_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10574 /* global_atomic_min_f32 */, AMDGPU::GLOBAL_ATOMIC_FMIN_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10596 /* global_atomic_min_f64 */, AMDGPU::GLOBAL_ATOMIC_MIN_F64_SADDR_gfx940, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10596 /* global_atomic_min_f64 */, AMDGPU::GLOBAL_ATOMIC_MIN_F64_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10596 /* global_atomic_min_f64 */, AMDGPU::GLOBAL_ATOMIC_MIN_F64_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10596 /* global_atomic_min_f64 */, AMDGPU::GLOBAL_ATOMIC_MIN_F64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10596 /* global_atomic_min_f64 */, AMDGPU::GLOBAL_ATOMIC_MIN_F64_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10596 /* global_atomic_min_f64 */, AMDGPU::GLOBAL_ATOMIC_MIN_F64_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10596 /* global_atomic_min_f64 */, AMDGPU::GLOBAL_ATOMIC_MIN_F64_SADDR_RTN_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10596 /* global_atomic_min_f64 */, AMDGPU::GLOBAL_ATOMIC_MIN_F64_SADDR_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10596 /* global_atomic_min_f64 */, AMDGPU::GLOBAL_ATOMIC_MIN_F64_RTN_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10596 /* global_atomic_min_f64 */, AMDGPU::GLOBAL_ATOMIC_MIN_F64_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10618 /* global_atomic_min_i32 */, AMDGPU::GLOBAL_ATOMIC_SMIN_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10618 /* global_atomic_min_i32 */, AMDGPU::GLOBAL_ATOMIC_SMIN_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10618 /* global_atomic_min_i32 */, AMDGPU::GLOBAL_ATOMIC_SMIN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10618 /* global_atomic_min_i32 */, AMDGPU::GLOBAL_ATOMIC_SMIN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10618 /* global_atomic_min_i32 */, AMDGPU::GLOBAL_ATOMIC_SMIN_SADDR_RTN_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10618 /* global_atomic_min_i32 */, AMDGPU::GLOBAL_ATOMIC_SMIN_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10618 /* global_atomic_min_i32 */, AMDGPU::GLOBAL_ATOMIC_SMIN_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10618 /* global_atomic_min_i32 */, AMDGPU::GLOBAL_ATOMIC_SMIN_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10640 /* global_atomic_min_i64 */, AMDGPU::GLOBAL_ATOMIC_SMIN_X2_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10640 /* global_atomic_min_i64 */, AMDGPU::GLOBAL_ATOMIC_SMIN_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10640 /* global_atomic_min_i64 */, AMDGPU::GLOBAL_ATOMIC_SMIN_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10640 /* global_atomic_min_i64 */, AMDGPU::GLOBAL_ATOMIC_SMIN_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10640 /* global_atomic_min_i64 */, AMDGPU::GLOBAL_ATOMIC_SMIN_X2_SADDR_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10640 /* global_atomic_min_i64 */, AMDGPU::GLOBAL_ATOMIC_SMIN_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10640 /* global_atomic_min_i64 */, AMDGPU::GLOBAL_ATOMIC_SMIN_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10640 /* global_atomic_min_i64 */, AMDGPU::GLOBAL_ATOMIC_SMIN_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10662 /* global_atomic_min_num_f32 */, AMDGPU::GLOBAL_ATOMIC_FMIN_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10662 /* global_atomic_min_num_f32 */, AMDGPU::GLOBAL_ATOMIC_FMIN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX10Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10662 /* global_atomic_min_num_f32 */, AMDGPU::GLOBAL_ATOMIC_FMIN_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10662 /* global_atomic_min_num_f32 */, AMDGPU::GLOBAL_ATOMIC_FMIN_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10688 /* global_atomic_min_num_f64 */, AMDGPU::GLOBAL_ATOMIC_MIN_F64_SADDR_gfx1250, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10688 /* global_atomic_min_num_f64 */, AMDGPU::GLOBAL_ATOMIC_MIN_F64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10688 /* global_atomic_min_num_f64 */, AMDGPU::GLOBAL_ATOMIC_MIN_F64_SADDR_RTN_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10688 /* global_atomic_min_num_f64 */, AMDGPU::GLOBAL_ATOMIC_MIN_F64_RTN_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10714 /* global_atomic_min_u32 */, AMDGPU::GLOBAL_ATOMIC_UMIN_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10714 /* global_atomic_min_u32 */, AMDGPU::GLOBAL_ATOMIC_UMIN_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10714 /* global_atomic_min_u32 */, AMDGPU::GLOBAL_ATOMIC_UMIN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10714 /* global_atomic_min_u32 */, AMDGPU::GLOBAL_ATOMIC_UMIN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10714 /* global_atomic_min_u32 */, AMDGPU::GLOBAL_ATOMIC_UMIN_SADDR_RTN_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10714 /* global_atomic_min_u32 */, AMDGPU::GLOBAL_ATOMIC_UMIN_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10714 /* global_atomic_min_u32 */, AMDGPU::GLOBAL_ATOMIC_UMIN_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10714 /* global_atomic_min_u32 */, AMDGPU::GLOBAL_ATOMIC_UMIN_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10736 /* global_atomic_min_u64 */, AMDGPU::GLOBAL_ATOMIC_UMIN_X2_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10736 /* global_atomic_min_u64 */, AMDGPU::GLOBAL_ATOMIC_UMIN_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10736 /* global_atomic_min_u64 */, AMDGPU::GLOBAL_ATOMIC_UMIN_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10736 /* global_atomic_min_u64 */, AMDGPU::GLOBAL_ATOMIC_UMIN_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10736 /* global_atomic_min_u64 */, AMDGPU::GLOBAL_ATOMIC_UMIN_X2_SADDR_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10736 /* global_atomic_min_u64 */, AMDGPU::GLOBAL_ATOMIC_UMIN_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10736 /* global_atomic_min_u64 */, AMDGPU::GLOBAL_ATOMIC_UMIN_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10736 /* global_atomic_min_u64 */, AMDGPU::GLOBAL_ATOMIC_UMIN_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10758 /* global_atomic_or */, AMDGPU::GLOBAL_ATOMIC_OR_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10758 /* global_atomic_or */, AMDGPU::GLOBAL_ATOMIC_OR_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10758 /* global_atomic_or */, AMDGPU::GLOBAL_ATOMIC_OR_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10758 /* global_atomic_or */, AMDGPU::GLOBAL_ATOMIC_OR_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10758 /* global_atomic_or */, AMDGPU::GLOBAL_ATOMIC_OR_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10758 /* global_atomic_or */, AMDGPU::GLOBAL_ATOMIC_OR_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10758 /* global_atomic_or */, AMDGPU::GLOBAL_ATOMIC_OR_SADDR_RTN_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10758 /* global_atomic_or */, AMDGPU::GLOBAL_ATOMIC_OR_SADDR_RTN_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10758 /* global_atomic_or */, AMDGPU::GLOBAL_ATOMIC_OR_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10758 /* global_atomic_or */, AMDGPU::GLOBAL_ATOMIC_OR_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10775 /* global_atomic_or_b32 */, AMDGPU::GLOBAL_ATOMIC_OR_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10775 /* global_atomic_or_b32 */, AMDGPU::GLOBAL_ATOMIC_OR_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10775 /* global_atomic_or_b32 */, AMDGPU::GLOBAL_ATOMIC_OR_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10775 /* global_atomic_or_b32 */, AMDGPU::GLOBAL_ATOMIC_OR_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10775 /* global_atomic_or_b32 */, AMDGPU::GLOBAL_ATOMIC_OR_SADDR_RTN_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10775 /* global_atomic_or_b32 */, AMDGPU::GLOBAL_ATOMIC_OR_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10775 /* global_atomic_or_b32 */, AMDGPU::GLOBAL_ATOMIC_OR_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10775 /* global_atomic_or_b32 */, AMDGPU::GLOBAL_ATOMIC_OR_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10796 /* global_atomic_or_b64 */, AMDGPU::GLOBAL_ATOMIC_OR_X2_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10796 /* global_atomic_or_b64 */, AMDGPU::GLOBAL_ATOMIC_OR_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10796 /* global_atomic_or_b64 */, AMDGPU::GLOBAL_ATOMIC_OR_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10796 /* global_atomic_or_b64 */, AMDGPU::GLOBAL_ATOMIC_OR_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10796 /* global_atomic_or_b64 */, AMDGPU::GLOBAL_ATOMIC_OR_X2_SADDR_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10796 /* global_atomic_or_b64 */, AMDGPU::GLOBAL_ATOMIC_OR_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10796 /* global_atomic_or_b64 */, AMDGPU::GLOBAL_ATOMIC_OR_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10796 /* global_atomic_or_b64 */, AMDGPU::GLOBAL_ATOMIC_OR_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10817 /* global_atomic_or_x2 */, AMDGPU::GLOBAL_ATOMIC_OR_X2_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10817 /* global_atomic_or_x2 */, AMDGPU::GLOBAL_ATOMIC_OR_X2_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10817 /* global_atomic_or_x2 */, AMDGPU::GLOBAL_ATOMIC_OR_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10817 /* global_atomic_or_x2 */, AMDGPU::GLOBAL_ATOMIC_OR_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10817 /* global_atomic_or_x2 */, AMDGPU::GLOBAL_ATOMIC_OR_X2_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10817 /* global_atomic_or_x2 */, AMDGPU::GLOBAL_ATOMIC_OR_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10817 /* global_atomic_or_x2 */, AMDGPU::GLOBAL_ATOMIC_OR_X2_SADDR_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10817 /* global_atomic_or_x2 */, AMDGPU::GLOBAL_ATOMIC_OR_X2_SADDR_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10817 /* global_atomic_or_x2 */, AMDGPU::GLOBAL_ATOMIC_OR_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10817 /* global_atomic_or_x2 */, AMDGPU::GLOBAL_ATOMIC_OR_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10837 /* global_atomic_ordered_add_b64 */, AMDGPU::GLOBAL_ATOMIC_ORDERED_ADD_B64_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX12PlusNot12_50_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10837 /* global_atomic_ordered_add_b64 */, AMDGPU::GLOBAL_ATOMIC_ORDERED_ADD_B64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX12PlusNot12_50_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10837 /* global_atomic_ordered_add_b64 */, AMDGPU::GLOBAL_ATOMIC_ORDERED_ADD_B64_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX12PlusNot12_50_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10837 /* global_atomic_ordered_add_b64 */, AMDGPU::GLOBAL_ATOMIC_ORDERED_ADD_B64_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX12PlusNot12_50_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10867 /* global_atomic_pk_add_bf16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_BF16_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10867 /* global_atomic_pk_add_bf16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_BF16_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10867 /* global_atomic_pk_add_bf16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_BF16_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10867 /* global_atomic_pk_add_bf16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_BF16_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10867 /* global_atomic_pk_add_bf16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_BF16_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10867 /* global_atomic_pk_add_bf16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_BF16_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10867 /* global_atomic_pk_add_bf16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_BF16_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10867 /* global_atomic_pk_add_bf16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_BF16_SADDR_RTN_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10867 /* global_atomic_pk_add_bf16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_BF16_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10867 /* global_atomic_pk_add_bf16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_BF16_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10893 /* global_atomic_pk_add_f16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_F16_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10893 /* global_atomic_pk_add_f16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_F16_SADDR_gfx940, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10893 /* global_atomic_pk_add_f16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_F16_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX940, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10893 /* global_atomic_pk_add_f16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_F16_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10893 /* global_atomic_pk_add_f16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_F16_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10893 /* global_atomic_pk_add_f16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_F16_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX940, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10893 /* global_atomic_pk_add_f16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_F16_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10893 /* global_atomic_pk_add_f16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_F16_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10893 /* global_atomic_pk_add_f16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_F16_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10893 /* global_atomic_pk_add_f16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_F16_SADDR_RTN_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10893 /* global_atomic_pk_add_f16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_F16_SADDR_RTN_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10893 /* global_atomic_pk_add_f16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_F16_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10893 /* global_atomic_pk_add_f16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_F16_RTN_gfx940, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10893 /* global_atomic_pk_add_f16 */, AMDGPU::GLOBAL_ATOMIC_PK_ADD_F16_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10918 /* global_atomic_smax */, AMDGPU::GLOBAL_ATOMIC_SMAX_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10918 /* global_atomic_smax */, AMDGPU::GLOBAL_ATOMIC_SMAX_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10918 /* global_atomic_smax */, AMDGPU::GLOBAL_ATOMIC_SMAX_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10918 /* global_atomic_smax */, AMDGPU::GLOBAL_ATOMIC_SMAX_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10918 /* global_atomic_smax */, AMDGPU::GLOBAL_ATOMIC_SMAX_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10918 /* global_atomic_smax */, AMDGPU::GLOBAL_ATOMIC_SMAX_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10918 /* global_atomic_smax */, AMDGPU::GLOBAL_ATOMIC_SMAX_SADDR_RTN_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10918 /* global_atomic_smax */, AMDGPU::GLOBAL_ATOMIC_SMAX_SADDR_RTN_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10918 /* global_atomic_smax */, AMDGPU::GLOBAL_ATOMIC_SMAX_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10918 /* global_atomic_smax */, AMDGPU::GLOBAL_ATOMIC_SMAX_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10937 /* global_atomic_smax_x2 */, AMDGPU::GLOBAL_ATOMIC_SMAX_X2_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10937 /* global_atomic_smax_x2 */, AMDGPU::GLOBAL_ATOMIC_SMAX_X2_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10937 /* global_atomic_smax_x2 */, AMDGPU::GLOBAL_ATOMIC_SMAX_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10937 /* global_atomic_smax_x2 */, AMDGPU::GLOBAL_ATOMIC_SMAX_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10937 /* global_atomic_smax_x2 */, AMDGPU::GLOBAL_ATOMIC_SMAX_X2_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10937 /* global_atomic_smax_x2 */, AMDGPU::GLOBAL_ATOMIC_SMAX_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10937 /* global_atomic_smax_x2 */, AMDGPU::GLOBAL_ATOMIC_SMAX_X2_SADDR_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10937 /* global_atomic_smax_x2 */, AMDGPU::GLOBAL_ATOMIC_SMAX_X2_SADDR_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10937 /* global_atomic_smax_x2 */, AMDGPU::GLOBAL_ATOMIC_SMAX_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10937 /* global_atomic_smax_x2 */, AMDGPU::GLOBAL_ATOMIC_SMAX_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10959 /* global_atomic_smin */, AMDGPU::GLOBAL_ATOMIC_SMIN_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10959 /* global_atomic_smin */, AMDGPU::GLOBAL_ATOMIC_SMIN_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10959 /* global_atomic_smin */, AMDGPU::GLOBAL_ATOMIC_SMIN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10959 /* global_atomic_smin */, AMDGPU::GLOBAL_ATOMIC_SMIN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10959 /* global_atomic_smin */, AMDGPU::GLOBAL_ATOMIC_SMIN_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10959 /* global_atomic_smin */, AMDGPU::GLOBAL_ATOMIC_SMIN_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10959 /* global_atomic_smin */, AMDGPU::GLOBAL_ATOMIC_SMIN_SADDR_RTN_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10959 /* global_atomic_smin */, AMDGPU::GLOBAL_ATOMIC_SMIN_SADDR_RTN_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10959 /* global_atomic_smin */, AMDGPU::GLOBAL_ATOMIC_SMIN_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10959 /* global_atomic_smin */, AMDGPU::GLOBAL_ATOMIC_SMIN_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10978 /* global_atomic_smin_x2 */, AMDGPU::GLOBAL_ATOMIC_SMIN_X2_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10978 /* global_atomic_smin_x2 */, AMDGPU::GLOBAL_ATOMIC_SMIN_X2_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10978 /* global_atomic_smin_x2 */, AMDGPU::GLOBAL_ATOMIC_SMIN_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10978 /* global_atomic_smin_x2 */, AMDGPU::GLOBAL_ATOMIC_SMIN_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10978 /* global_atomic_smin_x2 */, AMDGPU::GLOBAL_ATOMIC_SMIN_X2_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10978 /* global_atomic_smin_x2 */, AMDGPU::GLOBAL_ATOMIC_SMIN_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10978 /* global_atomic_smin_x2 */, AMDGPU::GLOBAL_ATOMIC_SMIN_X2_SADDR_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10978 /* global_atomic_smin_x2 */, AMDGPU::GLOBAL_ATOMIC_SMIN_X2_SADDR_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 10978 /* global_atomic_smin_x2 */, AMDGPU::GLOBAL_ATOMIC_SMIN_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 10978 /* global_atomic_smin_x2 */, AMDGPU::GLOBAL_ATOMIC_SMIN_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11000 /* global_atomic_sub */, AMDGPU::GLOBAL_ATOMIC_SUB_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11000 /* global_atomic_sub */, AMDGPU::GLOBAL_ATOMIC_SUB_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11000 /* global_atomic_sub */, AMDGPU::GLOBAL_ATOMIC_SUB_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11000 /* global_atomic_sub */, AMDGPU::GLOBAL_ATOMIC_SUB_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11000 /* global_atomic_sub */, AMDGPU::GLOBAL_ATOMIC_SUB_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11000 /* global_atomic_sub */, AMDGPU::GLOBAL_ATOMIC_SUB_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11000 /* global_atomic_sub */, AMDGPU::GLOBAL_ATOMIC_SUB_SADDR_RTN_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11000 /* global_atomic_sub */, AMDGPU::GLOBAL_ATOMIC_SUB_SADDR_RTN_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11000 /* global_atomic_sub */, AMDGPU::GLOBAL_ATOMIC_SUB_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11000 /* global_atomic_sub */, AMDGPU::GLOBAL_ATOMIC_SUB_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11018 /* global_atomic_sub_clamp_u32 */, AMDGPU::GLOBAL_ATOMIC_CSUB_SADDR_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasGFX10_BEncoding_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11018 /* global_atomic_sub_clamp_u32 */, AMDGPU::GLOBAL_ATOMIC_CSUB_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasGFX10_BEncoding_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11018 /* global_atomic_sub_clamp_u32 */, AMDGPU::GLOBAL_ATOMIC_CSUB_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasGFX10_BEncoding_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11018 /* global_atomic_sub_clamp_u32 */, AMDGPU::GLOBAL_ATOMIC_CSUB_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasGFX10_BEncoding_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11046 /* global_atomic_sub_u32 */, AMDGPU::GLOBAL_ATOMIC_SUB_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11046 /* global_atomic_sub_u32 */, AMDGPU::GLOBAL_ATOMIC_SUB_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11046 /* global_atomic_sub_u32 */, AMDGPU::GLOBAL_ATOMIC_SUB_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11046 /* global_atomic_sub_u32 */, AMDGPU::GLOBAL_ATOMIC_SUB_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11046 /* global_atomic_sub_u32 */, AMDGPU::GLOBAL_ATOMIC_SUB_SADDR_RTN_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11046 /* global_atomic_sub_u32 */, AMDGPU::GLOBAL_ATOMIC_SUB_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11046 /* global_atomic_sub_u32 */, AMDGPU::GLOBAL_ATOMIC_SUB_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11046 /* global_atomic_sub_u32 */, AMDGPU::GLOBAL_ATOMIC_SUB_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11068 /* global_atomic_sub_u64 */, AMDGPU::GLOBAL_ATOMIC_SUB_X2_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11068 /* global_atomic_sub_u64 */, AMDGPU::GLOBAL_ATOMIC_SUB_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11068 /* global_atomic_sub_u64 */, AMDGPU::GLOBAL_ATOMIC_SUB_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11068 /* global_atomic_sub_u64 */, AMDGPU::GLOBAL_ATOMIC_SUB_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11068 /* global_atomic_sub_u64 */, AMDGPU::GLOBAL_ATOMIC_SUB_X2_SADDR_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11068 /* global_atomic_sub_u64 */, AMDGPU::GLOBAL_ATOMIC_SUB_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11068 /* global_atomic_sub_u64 */, AMDGPU::GLOBAL_ATOMIC_SUB_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11068 /* global_atomic_sub_u64 */, AMDGPU::GLOBAL_ATOMIC_SUB_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11090 /* global_atomic_sub_x2 */, AMDGPU::GLOBAL_ATOMIC_SUB_X2_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11090 /* global_atomic_sub_x2 */, AMDGPU::GLOBAL_ATOMIC_SUB_X2_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11090 /* global_atomic_sub_x2 */, AMDGPU::GLOBAL_ATOMIC_SUB_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11090 /* global_atomic_sub_x2 */, AMDGPU::GLOBAL_ATOMIC_SUB_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11090 /* global_atomic_sub_x2 */, AMDGPU::GLOBAL_ATOMIC_SUB_X2_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11090 /* global_atomic_sub_x2 */, AMDGPU::GLOBAL_ATOMIC_SUB_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11090 /* global_atomic_sub_x2 */, AMDGPU::GLOBAL_ATOMIC_SUB_X2_SADDR_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11090 /* global_atomic_sub_x2 */, AMDGPU::GLOBAL_ATOMIC_SUB_X2_SADDR_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11090 /* global_atomic_sub_x2 */, AMDGPU::GLOBAL_ATOMIC_SUB_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11090 /* global_atomic_sub_x2 */, AMDGPU::GLOBAL_ATOMIC_SUB_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11111 /* global_atomic_swap */, AMDGPU::GLOBAL_ATOMIC_SWAP_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11111 /* global_atomic_swap */, AMDGPU::GLOBAL_ATOMIC_SWAP_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11111 /* global_atomic_swap */, AMDGPU::GLOBAL_ATOMIC_SWAP_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11111 /* global_atomic_swap */, AMDGPU::GLOBAL_ATOMIC_SWAP_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11111 /* global_atomic_swap */, AMDGPU::GLOBAL_ATOMIC_SWAP_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11111 /* global_atomic_swap */, AMDGPU::GLOBAL_ATOMIC_SWAP_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11111 /* global_atomic_swap */, AMDGPU::GLOBAL_ATOMIC_SWAP_SADDR_RTN_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11111 /* global_atomic_swap */, AMDGPU::GLOBAL_ATOMIC_SWAP_SADDR_RTN_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11111 /* global_atomic_swap */, AMDGPU::GLOBAL_ATOMIC_SWAP_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11111 /* global_atomic_swap */, AMDGPU::GLOBAL_ATOMIC_SWAP_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11130 /* global_atomic_swap_b32 */, AMDGPU::GLOBAL_ATOMIC_SWAP_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11130 /* global_atomic_swap_b32 */, AMDGPU::GLOBAL_ATOMIC_SWAP_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11130 /* global_atomic_swap_b32 */, AMDGPU::GLOBAL_ATOMIC_SWAP_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11130 /* global_atomic_swap_b32 */, AMDGPU::GLOBAL_ATOMIC_SWAP_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11130 /* global_atomic_swap_b32 */, AMDGPU::GLOBAL_ATOMIC_SWAP_SADDR_RTN_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11130 /* global_atomic_swap_b32 */, AMDGPU::GLOBAL_ATOMIC_SWAP_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11130 /* global_atomic_swap_b32 */, AMDGPU::GLOBAL_ATOMIC_SWAP_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11130 /* global_atomic_swap_b32 */, AMDGPU::GLOBAL_ATOMIC_SWAP_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11153 /* global_atomic_swap_b64 */, AMDGPU::GLOBAL_ATOMIC_SWAP_X2_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11153 /* global_atomic_swap_b64 */, AMDGPU::GLOBAL_ATOMIC_SWAP_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11153 /* global_atomic_swap_b64 */, AMDGPU::GLOBAL_ATOMIC_SWAP_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11153 /* global_atomic_swap_b64 */, AMDGPU::GLOBAL_ATOMIC_SWAP_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11153 /* global_atomic_swap_b64 */, AMDGPU::GLOBAL_ATOMIC_SWAP_X2_SADDR_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11153 /* global_atomic_swap_b64 */, AMDGPU::GLOBAL_ATOMIC_SWAP_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11153 /* global_atomic_swap_b64 */, AMDGPU::GLOBAL_ATOMIC_SWAP_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11153 /* global_atomic_swap_b64 */, AMDGPU::GLOBAL_ATOMIC_SWAP_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11176 /* global_atomic_swap_x2 */, AMDGPU::GLOBAL_ATOMIC_SWAP_X2_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11176 /* global_atomic_swap_x2 */, AMDGPU::GLOBAL_ATOMIC_SWAP_X2_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11176 /* global_atomic_swap_x2 */, AMDGPU::GLOBAL_ATOMIC_SWAP_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11176 /* global_atomic_swap_x2 */, AMDGPU::GLOBAL_ATOMIC_SWAP_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11176 /* global_atomic_swap_x2 */, AMDGPU::GLOBAL_ATOMIC_SWAP_X2_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11176 /* global_atomic_swap_x2 */, AMDGPU::GLOBAL_ATOMIC_SWAP_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11176 /* global_atomic_swap_x2 */, AMDGPU::GLOBAL_ATOMIC_SWAP_X2_SADDR_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11176 /* global_atomic_swap_x2 */, AMDGPU::GLOBAL_ATOMIC_SWAP_X2_SADDR_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11176 /* global_atomic_swap_x2 */, AMDGPU::GLOBAL_ATOMIC_SWAP_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11176 /* global_atomic_swap_x2 */, AMDGPU::GLOBAL_ATOMIC_SWAP_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11198 /* global_atomic_umax */, AMDGPU::GLOBAL_ATOMIC_UMAX_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11198 /* global_atomic_umax */, AMDGPU::GLOBAL_ATOMIC_UMAX_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11198 /* global_atomic_umax */, AMDGPU::GLOBAL_ATOMIC_UMAX_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11198 /* global_atomic_umax */, AMDGPU::GLOBAL_ATOMIC_UMAX_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11198 /* global_atomic_umax */, AMDGPU::GLOBAL_ATOMIC_UMAX_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11198 /* global_atomic_umax */, AMDGPU::GLOBAL_ATOMIC_UMAX_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11198 /* global_atomic_umax */, AMDGPU::GLOBAL_ATOMIC_UMAX_SADDR_RTN_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11198 /* global_atomic_umax */, AMDGPU::GLOBAL_ATOMIC_UMAX_SADDR_RTN_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11198 /* global_atomic_umax */, AMDGPU::GLOBAL_ATOMIC_UMAX_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11198 /* global_atomic_umax */, AMDGPU::GLOBAL_ATOMIC_UMAX_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11217 /* global_atomic_umax_x2 */, AMDGPU::GLOBAL_ATOMIC_UMAX_X2_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11217 /* global_atomic_umax_x2 */, AMDGPU::GLOBAL_ATOMIC_UMAX_X2_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11217 /* global_atomic_umax_x2 */, AMDGPU::GLOBAL_ATOMIC_UMAX_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11217 /* global_atomic_umax_x2 */, AMDGPU::GLOBAL_ATOMIC_UMAX_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11217 /* global_atomic_umax_x2 */, AMDGPU::GLOBAL_ATOMIC_UMAX_X2_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11217 /* global_atomic_umax_x2 */, AMDGPU::GLOBAL_ATOMIC_UMAX_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11217 /* global_atomic_umax_x2 */, AMDGPU::GLOBAL_ATOMIC_UMAX_X2_SADDR_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11217 /* global_atomic_umax_x2 */, AMDGPU::GLOBAL_ATOMIC_UMAX_X2_SADDR_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11217 /* global_atomic_umax_x2 */, AMDGPU::GLOBAL_ATOMIC_UMAX_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11217 /* global_atomic_umax_x2 */, AMDGPU::GLOBAL_ATOMIC_UMAX_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11239 /* global_atomic_umin */, AMDGPU::GLOBAL_ATOMIC_UMIN_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11239 /* global_atomic_umin */, AMDGPU::GLOBAL_ATOMIC_UMIN_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11239 /* global_atomic_umin */, AMDGPU::GLOBAL_ATOMIC_UMIN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11239 /* global_atomic_umin */, AMDGPU::GLOBAL_ATOMIC_UMIN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11239 /* global_atomic_umin */, AMDGPU::GLOBAL_ATOMIC_UMIN_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11239 /* global_atomic_umin */, AMDGPU::GLOBAL_ATOMIC_UMIN_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11239 /* global_atomic_umin */, AMDGPU::GLOBAL_ATOMIC_UMIN_SADDR_RTN_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11239 /* global_atomic_umin */, AMDGPU::GLOBAL_ATOMIC_UMIN_SADDR_RTN_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11239 /* global_atomic_umin */, AMDGPU::GLOBAL_ATOMIC_UMIN_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11239 /* global_atomic_umin */, AMDGPU::GLOBAL_ATOMIC_UMIN_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11258 /* global_atomic_umin_x2 */, AMDGPU::GLOBAL_ATOMIC_UMIN_X2_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11258 /* global_atomic_umin_x2 */, AMDGPU::GLOBAL_ATOMIC_UMIN_X2_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11258 /* global_atomic_umin_x2 */, AMDGPU::GLOBAL_ATOMIC_UMIN_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11258 /* global_atomic_umin_x2 */, AMDGPU::GLOBAL_ATOMIC_UMIN_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11258 /* global_atomic_umin_x2 */, AMDGPU::GLOBAL_ATOMIC_UMIN_X2_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11258 /* global_atomic_umin_x2 */, AMDGPU::GLOBAL_ATOMIC_UMIN_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11258 /* global_atomic_umin_x2 */, AMDGPU::GLOBAL_ATOMIC_UMIN_X2_SADDR_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11258 /* global_atomic_umin_x2 */, AMDGPU::GLOBAL_ATOMIC_UMIN_X2_SADDR_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11258 /* global_atomic_umin_x2 */, AMDGPU::GLOBAL_ATOMIC_UMIN_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11258 /* global_atomic_umin_x2 */, AMDGPU::GLOBAL_ATOMIC_UMIN_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11280 /* global_atomic_xor */, AMDGPU::GLOBAL_ATOMIC_XOR_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11280 /* global_atomic_xor */, AMDGPU::GLOBAL_ATOMIC_XOR_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11280 /* global_atomic_xor */, AMDGPU::GLOBAL_ATOMIC_XOR_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11280 /* global_atomic_xor */, AMDGPU::GLOBAL_ATOMIC_XOR_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11280 /* global_atomic_xor */, AMDGPU::GLOBAL_ATOMIC_XOR_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_VGPR_32, MCK_AGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11280 /* global_atomic_xor */, AMDGPU::GLOBAL_ATOMIC_XOR_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11280 /* global_atomic_xor */, AMDGPU::GLOBAL_ATOMIC_XOR_SADDR_RTN_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11280 /* global_atomic_xor */, AMDGPU::GLOBAL_ATOMIC_XOR_SADDR_RTN_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11280 /* global_atomic_xor */, AMDGPU::GLOBAL_ATOMIC_XOR_RTN_gfx10, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11280 /* global_atomic_xor */, AMDGPU::GLOBAL_ATOMIC_XOR_RTN_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11298 /* global_atomic_xor_b32 */, AMDGPU::GLOBAL_ATOMIC_XOR_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11298 /* global_atomic_xor_b32 */, AMDGPU::GLOBAL_ATOMIC_XOR_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11298 /* global_atomic_xor_b32 */, AMDGPU::GLOBAL_ATOMIC_XOR_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11298 /* global_atomic_xor_b32 */, AMDGPU::GLOBAL_ATOMIC_XOR_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11298 /* global_atomic_xor_b32 */, AMDGPU::GLOBAL_ATOMIC_XOR_SADDR_RTN_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11298 /* global_atomic_xor_b32 */, AMDGPU::GLOBAL_ATOMIC_XOR_SADDR_RTN_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11298 /* global_atomic_xor_b32 */, AMDGPU::GLOBAL_ATOMIC_XOR_RTN_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11298 /* global_atomic_xor_b32 */, AMDGPU::GLOBAL_ATOMIC_XOR_RTN_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11320 /* global_atomic_xor_b64 */, AMDGPU::GLOBAL_ATOMIC_XOR_X2_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11320 /* global_atomic_xor_b64 */, AMDGPU::GLOBAL_ATOMIC_XOR_X2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11320 /* global_atomic_xor_b64 */, AMDGPU::GLOBAL_ATOMIC_XOR_X2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11320 /* global_atomic_xor_b64 */, AMDGPU::GLOBAL_ATOMIC_XOR_X2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11320 /* global_atomic_xor_b64 */, AMDGPU::GLOBAL_ATOMIC_XOR_X2_SADDR_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11320 /* global_atomic_xor_b64 */, AMDGPU::GLOBAL_ATOMIC_XOR_X2_SADDR_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11320 /* global_atomic_xor_b64 */, AMDGPU::GLOBAL_ATOMIC_XOR_X2_RTN_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11320 /* global_atomic_xor_b64 */, AMDGPU::GLOBAL_ATOMIC_XOR_X2_RTN_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11342 /* global_atomic_xor_x2 */, AMDGPU::GLOBAL_ATOMIC_XOR_X2_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11342 /* global_atomic_xor_x2 */, AMDGPU::GLOBAL_ATOMIC_XOR_X2_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11342 /* global_atomic_xor_x2 */, AMDGPU::GLOBAL_ATOMIC_XOR_X2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11342 /* global_atomic_xor_x2 */, AMDGPU::GLOBAL_ATOMIC_XOR_X2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11342 /* global_atomic_xor_x2 */, AMDGPU::GLOBAL_ATOMIC_XOR_X2_SADDR_RTN_agpr_vi, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_VGPR_32, MCK_AReg_64, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11342 /* global_atomic_xor_x2 */, AMDGPU::GLOBAL_ATOMIC_XOR_X2_RTN_agpr_vi, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__FlatOffset1_4__CPol1_5, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AReg_64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_AReg_64, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11342 /* global_atomic_xor_x2 */, AMDGPU::GLOBAL_ATOMIC_XOR_X2_SADDR_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11342 /* global_atomic_xor_x2 */, AMDGPU::GLOBAL_ATOMIC_XOR_X2_SADDR_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11342 /* global_atomic_xor_x2 */, AMDGPU::GLOBAL_ATOMIC_XOR_X2_RTN_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11342 /* global_atomic_xor_x2 */, AMDGPU::GLOBAL_ATOMIC_XOR_X2_RTN_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__FlatOffset1_4__CPol1_5, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11363 /* global_inv */, AMDGPU::GLOBAL_INV_gfx12, Convert__CPol1_0, AMFBS_isGFX12Plus_isGFX12Only, { MCK_CPol }, },
  { 11374 /* global_load_addtid_b32 */, AMDGPU::GLOBAL_LOAD_DWORD_ADDTID_gfx11, Convert__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11374 /* global_load_addtid_b32 */, AMDGPU::GLOBAL_LOAD_DWORD_ADDTID_gfx12, Convert__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11374 /* global_load_addtid_b32 */, AMDGPU::GLOBAL_LOAD_DWORD_ADDTID_SADDR_gfx11, Convert__Reg1_0__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 11374 /* global_load_addtid_b32 */, AMDGPU::GLOBAL_LOAD_DWORD_ADDTID_SADDR_gfx12, Convert__Reg1_0__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 11397 /* global_load_async_to_lds_b128 */, AMDGPU::GLOBAL_LOAD_ASYNC_TO_LDS_B128_SADDR_gfx1250, Convert__Reg1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 11397 /* global_load_async_to_lds_b128 */, AMDGPU::GLOBAL_LOAD_ASYNC_TO_LDS_B128_gfx1250, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11427 /* global_load_async_to_lds_b32 */, AMDGPU::GLOBAL_LOAD_ASYNC_TO_LDS_B32_SADDR_gfx1250, Convert__Reg1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 11427 /* global_load_async_to_lds_b32 */, AMDGPU::GLOBAL_LOAD_ASYNC_TO_LDS_B32_gfx1250, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11456 /* global_load_async_to_lds_b64 */, AMDGPU::GLOBAL_LOAD_ASYNC_TO_LDS_B64_SADDR_gfx1250, Convert__Reg1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 11456 /* global_load_async_to_lds_b64 */, AMDGPU::GLOBAL_LOAD_ASYNC_TO_LDS_B64_gfx1250, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11485 /* global_load_async_to_lds_b8 */, AMDGPU::GLOBAL_LOAD_ASYNC_TO_LDS_B8_SADDR_gfx1250, Convert__Reg1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 11485 /* global_load_async_to_lds_b8 */, AMDGPU::GLOBAL_LOAD_ASYNC_TO_LDS_B8_gfx1250, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11513 /* global_load_b128 */, AMDGPU::GLOBAL_LOAD_DWORDX4_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11513 /* global_load_b128 */, AMDGPU::GLOBAL_LOAD_DWORDX4_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11513 /* global_load_b128 */, AMDGPU::GLOBAL_LOAD_DWORDX4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11513 /* global_load_b128 */, AMDGPU::GLOBAL_LOAD_DWORDX4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11530 /* global_load_b32 */, AMDGPU::GLOBAL_LOAD_DWORD_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11530 /* global_load_b32 */, AMDGPU::GLOBAL_LOAD_DWORD_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11530 /* global_load_b32 */, AMDGPU::GLOBAL_LOAD_DWORD_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11530 /* global_load_b32 */, AMDGPU::GLOBAL_LOAD_DWORD_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11546 /* global_load_b64 */, AMDGPU::GLOBAL_LOAD_DWORDX2_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11546 /* global_load_b64 */, AMDGPU::GLOBAL_LOAD_DWORDX2_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11546 /* global_load_b64 */, AMDGPU::GLOBAL_LOAD_DWORDX2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11546 /* global_load_b64 */, AMDGPU::GLOBAL_LOAD_DWORDX2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11562 /* global_load_b96 */, AMDGPU::GLOBAL_LOAD_DWORDX3_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11562 /* global_load_b96 */, AMDGPU::GLOBAL_LOAD_DWORDX3_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11562 /* global_load_b96 */, AMDGPU::GLOBAL_LOAD_DWORDX3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11562 /* global_load_b96 */, AMDGPU::GLOBAL_LOAD_DWORDX3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11578 /* global_load_block */, AMDGPU::GLOBAL_LOAD_BLOCK_SADDR_gfx12, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11578 /* global_load_block */, AMDGPU::GLOBAL_LOAD_BLOCK_gfx12, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11596 /* global_load_d16_b16 */, AMDGPU::GLOBAL_LOAD_SHORT_D16_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11596 /* global_load_d16_b16 */, AMDGPU::GLOBAL_LOAD_SHORT_D16_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11596 /* global_load_d16_b16 */, AMDGPU::GLOBAL_LOAD_SHORT_D16_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11596 /* global_load_d16_b16 */, AMDGPU::GLOBAL_LOAD_SHORT_D16_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11616 /* global_load_d16_hi_b16 */, AMDGPU::GLOBAL_LOAD_SHORT_D16_HI_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11616 /* global_load_d16_hi_b16 */, AMDGPU::GLOBAL_LOAD_SHORT_D16_HI_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11616 /* global_load_d16_hi_b16 */, AMDGPU::GLOBAL_LOAD_SHORT_D16_HI_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11616 /* global_load_d16_hi_b16 */, AMDGPU::GLOBAL_LOAD_SHORT_D16_HI_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11639 /* global_load_d16_hi_i8 */, AMDGPU::GLOBAL_LOAD_SBYTE_D16_HI_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11639 /* global_load_d16_hi_i8 */, AMDGPU::GLOBAL_LOAD_SBYTE_D16_HI_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11639 /* global_load_d16_hi_i8 */, AMDGPU::GLOBAL_LOAD_SBYTE_D16_HI_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11639 /* global_load_d16_hi_i8 */, AMDGPU::GLOBAL_LOAD_SBYTE_D16_HI_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11661 /* global_load_d16_hi_u8 */, AMDGPU::GLOBAL_LOAD_UBYTE_D16_HI_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11661 /* global_load_d16_hi_u8 */, AMDGPU::GLOBAL_LOAD_UBYTE_D16_HI_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11661 /* global_load_d16_hi_u8 */, AMDGPU::GLOBAL_LOAD_UBYTE_D16_HI_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11661 /* global_load_d16_hi_u8 */, AMDGPU::GLOBAL_LOAD_UBYTE_D16_HI_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11683 /* global_load_d16_i8 */, AMDGPU::GLOBAL_LOAD_SBYTE_D16_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11683 /* global_load_d16_i8 */, AMDGPU::GLOBAL_LOAD_SBYTE_D16_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11683 /* global_load_d16_i8 */, AMDGPU::GLOBAL_LOAD_SBYTE_D16_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11683 /* global_load_d16_i8 */, AMDGPU::GLOBAL_LOAD_SBYTE_D16_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11702 /* global_load_d16_u8 */, AMDGPU::GLOBAL_LOAD_UBYTE_D16_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11702 /* global_load_d16_u8 */, AMDGPU::GLOBAL_LOAD_UBYTE_D16_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11702 /* global_load_d16_u8 */, AMDGPU::GLOBAL_LOAD_UBYTE_D16_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11702 /* global_load_d16_u8 */, AMDGPU::GLOBAL_LOAD_UBYTE_D16_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11721 /* global_load_dword */, AMDGPU::GLOBAL_LOAD_LDS_DWORD_SADDR_vi, Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 11721 /* global_load_dword */, AMDGPU::GLOBAL_LOAD_LDS_DWORD_SADDR_gfx10, Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 11721 /* global_load_dword */, AMDGPU::GLOBAL_LOAD_DWORD_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11721 /* global_load_dword */, AMDGPU::GLOBAL_LOAD_DWORD_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11721 /* global_load_dword */, AMDGPU::GLOBAL_LOAD_DWORD_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11721 /* global_load_dword */, AMDGPU::GLOBAL_LOAD_DWORD_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11721 /* global_load_dword */, AMDGPU::GLOBAL_LOAD_LDS_DWORD_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 11721 /* global_load_dword */, AMDGPU::GLOBAL_LOAD_LDS_DWORD_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 11739 /* global_load_dword_addtid */, AMDGPU::GLOBAL_LOAD_DWORD_ADDTID_gfx10, Convert__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11739 /* global_load_dword_addtid */, AMDGPU::GLOBAL_LOAD_DWORD_ADDTID_SADDR_gfx10, Convert__Reg1_0__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 11764 /* global_load_dwordx2 */, AMDGPU::GLOBAL_LOAD_DWORDX2_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11764 /* global_load_dwordx2 */, AMDGPU::GLOBAL_LOAD_DWORDX2_SADDR_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11764 /* global_load_dwordx2 */, AMDGPU::GLOBAL_LOAD_DWORDX2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11764 /* global_load_dwordx2 */, AMDGPU::GLOBAL_LOAD_DWORDX2_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11784 /* global_load_dwordx3 */, AMDGPU::GLOBAL_LOAD_LDS_DWORDX3_SADDR_vi, Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 11784 /* global_load_dwordx3 */, AMDGPU::GLOBAL_LOAD_DWORDX3_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11784 /* global_load_dwordx3 */, AMDGPU::GLOBAL_LOAD_DWORDX3_SADDR_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11784 /* global_load_dwordx3 */, AMDGPU::GLOBAL_LOAD_DWORDX3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11784 /* global_load_dwordx3 */, AMDGPU::GLOBAL_LOAD_DWORDX3_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11784 /* global_load_dwordx3 */, AMDGPU::GLOBAL_LOAD_LDS_DWORDX3_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 11804 /* global_load_dwordx4 */, AMDGPU::GLOBAL_LOAD_LDS_DWORDX4_SADDR_vi, Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 11804 /* global_load_dwordx4 */, AMDGPU::GLOBAL_LOAD_DWORDX4_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11804 /* global_load_dwordx4 */, AMDGPU::GLOBAL_LOAD_DWORDX4_SADDR_vi, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11804 /* global_load_dwordx4 */, AMDGPU::GLOBAL_LOAD_DWORDX4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11804 /* global_load_dwordx4 */, AMDGPU::GLOBAL_LOAD_DWORDX4_vi, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11804 /* global_load_dwordx4 */, AMDGPU::GLOBAL_LOAD_LDS_DWORDX4_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 11824 /* global_load_i16 */, AMDGPU::GLOBAL_LOAD_SSHORT_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11824 /* global_load_i16 */, AMDGPU::GLOBAL_LOAD_SSHORT_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11824 /* global_load_i16 */, AMDGPU::GLOBAL_LOAD_SSHORT_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11824 /* global_load_i16 */, AMDGPU::GLOBAL_LOAD_SSHORT_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11840 /* global_load_i8 */, AMDGPU::GLOBAL_LOAD_SBYTE_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11840 /* global_load_i8 */, AMDGPU::GLOBAL_LOAD_SBYTE_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 11840 /* global_load_i8 */, AMDGPU::GLOBAL_LOAD_SBYTE_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11840 /* global_load_i8 */, AMDGPU::GLOBAL_LOAD_SBYTE_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11855 /* global_load_lds_dword */, AMDGPU::GLOBAL_LOAD_LDS_DWORD_SADDR_gfx940, Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatGlobalInsts_isGFX940Plus, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 11855 /* global_load_lds_dword */, AMDGPU::GLOBAL_LOAD_LDS_DWORD_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatGlobalInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11877 /* global_load_lds_dwordx3 */, AMDGPU::GLOBAL_LOAD_LDS_DWORDX3_SADDR_gfx940, Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 11877 /* global_load_lds_dwordx3 */, AMDGPU::GLOBAL_LOAD_LDS_DWORDX3_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_2__CPol1_3, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11901 /* global_load_lds_dwordx4 */, AMDGPU::GLOBAL_LOAD_LDS_DWORDX4_SADDR_gfx940, Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 11901 /* global_load_lds_dwordx4 */, AMDGPU::GLOBAL_LOAD_LDS_DWORDX4_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_2__CPol1_3, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11925 /* global_load_lds_sbyte */, AMDGPU::GLOBAL_LOAD_LDS_SBYTE_SADDR_gfx940, Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatGlobalInsts_isGFX940Plus, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 11925 /* global_load_lds_sbyte */, AMDGPU::GLOBAL_LOAD_LDS_SBYTE_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatGlobalInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11947 /* global_load_lds_sshort */, AMDGPU::GLOBAL_LOAD_LDS_SSHORT_SADDR_gfx940, Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatGlobalInsts_isGFX940Plus, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 11947 /* global_load_lds_sshort */, AMDGPU::GLOBAL_LOAD_LDS_SSHORT_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatGlobalInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11970 /* global_load_lds_ubyte */, AMDGPU::GLOBAL_LOAD_LDS_UBYTE_SADDR_gfx940, Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatGlobalInsts_isGFX940Plus, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 11970 /* global_load_lds_ubyte */, AMDGPU::GLOBAL_LOAD_LDS_UBYTE_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatGlobalInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 11992 /* global_load_lds_ushort */, AMDGPU::GLOBAL_LOAD_LDS_USHORT_SADDR_gfx940, Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatGlobalInsts_isGFX940Plus, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 11992 /* global_load_lds_ushort */, AMDGPU::GLOBAL_LOAD_LDS_USHORT_gfx940, Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatGlobalInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12015 /* global_load_monitor_b128 */, AMDGPU::GLOBAL_LOAD_MONITOR_B128_SADDR_gfx1250, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX125xOnly, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12015 /* global_load_monitor_b128 */, AMDGPU::GLOBAL_LOAD_MONITOR_B128_gfx1250, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX125xOnly, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12040 /* global_load_monitor_b32 */, AMDGPU::GLOBAL_LOAD_MONITOR_B32_SADDR_gfx1250, Convert__Reg1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12040 /* global_load_monitor_b32 */, AMDGPU::GLOBAL_LOAD_MONITOR_B32_gfx1250, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX125xOnly, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12064 /* global_load_monitor_b64 */, AMDGPU::GLOBAL_LOAD_MONITOR_B64_SADDR_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12064 /* global_load_monitor_b64 */, AMDGPU::GLOBAL_LOAD_MONITOR_B64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12088 /* global_load_sbyte */, AMDGPU::GLOBAL_LOAD_LDS_SBYTE_SADDR_vi, Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 12088 /* global_load_sbyte */, AMDGPU::GLOBAL_LOAD_LDS_SBYTE_SADDR_gfx10, Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 12088 /* global_load_sbyte */, AMDGPU::GLOBAL_LOAD_SBYTE_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12088 /* global_load_sbyte */, AMDGPU::GLOBAL_LOAD_SBYTE_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12088 /* global_load_sbyte */, AMDGPU::GLOBAL_LOAD_SBYTE_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12088 /* global_load_sbyte */, AMDGPU::GLOBAL_LOAD_SBYTE_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12088 /* global_load_sbyte */, AMDGPU::GLOBAL_LOAD_LDS_SBYTE_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 12088 /* global_load_sbyte */, AMDGPU::GLOBAL_LOAD_LDS_SBYTE_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 12106 /* global_load_sbyte_d16 */, AMDGPU::GLOBAL_LOAD_SBYTE_D16_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12106 /* global_load_sbyte_d16 */, AMDGPU::GLOBAL_LOAD_SBYTE_D16_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12106 /* global_load_sbyte_d16 */, AMDGPU::GLOBAL_LOAD_SBYTE_D16_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12106 /* global_load_sbyte_d16 */, AMDGPU::GLOBAL_LOAD_SBYTE_D16_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12128 /* global_load_sbyte_d16_hi */, AMDGPU::GLOBAL_LOAD_SBYTE_D16_HI_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12128 /* global_load_sbyte_d16_hi */, AMDGPU::GLOBAL_LOAD_SBYTE_D16_HI_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12128 /* global_load_sbyte_d16_hi */, AMDGPU::GLOBAL_LOAD_SBYTE_D16_HI_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12128 /* global_load_sbyte_d16_hi */, AMDGPU::GLOBAL_LOAD_SBYTE_D16_HI_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12153 /* global_load_short_d16 */, AMDGPU::GLOBAL_LOAD_SHORT_D16_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12153 /* global_load_short_d16 */, AMDGPU::GLOBAL_LOAD_SHORT_D16_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12153 /* global_load_short_d16 */, AMDGPU::GLOBAL_LOAD_SHORT_D16_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12153 /* global_load_short_d16 */, AMDGPU::GLOBAL_LOAD_SHORT_D16_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12175 /* global_load_short_d16_hi */, AMDGPU::GLOBAL_LOAD_SHORT_D16_HI_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12175 /* global_load_short_d16_hi */, AMDGPU::GLOBAL_LOAD_SHORT_D16_HI_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12175 /* global_load_short_d16_hi */, AMDGPU::GLOBAL_LOAD_SHORT_D16_HI_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12175 /* global_load_short_d16_hi */, AMDGPU::GLOBAL_LOAD_SHORT_D16_HI_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12200 /* global_load_sshort */, AMDGPU::GLOBAL_LOAD_LDS_SSHORT_SADDR_vi, Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 12200 /* global_load_sshort */, AMDGPU::GLOBAL_LOAD_LDS_SSHORT_SADDR_gfx10, Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 12200 /* global_load_sshort */, AMDGPU::GLOBAL_LOAD_SSHORT_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12200 /* global_load_sshort */, AMDGPU::GLOBAL_LOAD_SSHORT_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12200 /* global_load_sshort */, AMDGPU::GLOBAL_LOAD_SSHORT_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12200 /* global_load_sshort */, AMDGPU::GLOBAL_LOAD_SSHORT_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12200 /* global_load_sshort */, AMDGPU::GLOBAL_LOAD_LDS_SSHORT_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 12200 /* global_load_sshort */, AMDGPU::GLOBAL_LOAD_LDS_SSHORT_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 12219 /* global_load_tr16_b128 */, AMDGPU::GLOBAL_LOAD_TR_B128_w32_SADDR_gfx1250, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12219 /* global_load_tr16_b128 */, AMDGPU::GLOBAL_LOAD_TR_B128_w32_gfx1250, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12241 /* global_load_tr4_b64 */, AMDGPU::GLOBAL_LOAD_TR4_B64_SADDR_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12241 /* global_load_tr4_b64 */, AMDGPU::GLOBAL_LOAD_TR4_B64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12261 /* global_load_tr6_b96 */, AMDGPU::GLOBAL_LOAD_TR6_B96_SADDR_gfx1250, Convert__Reg1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32, { MCK_VReg_96, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12261 /* global_load_tr6_b96 */, AMDGPU::GLOBAL_LOAD_TR6_B96_gfx1250, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32, { MCK_VReg_96, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12281 /* global_load_tr8_b64 */, AMDGPU::GLOBAL_LOAD_TR_B64_w32_SADDR_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12281 /* global_load_tr8_b64 */, AMDGPU::GLOBAL_LOAD_TR_B64_w32_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12301 /* global_load_tr_b128 */, AMDGPU::GLOBAL_LOAD_TR_B128_w64_SADDR_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12301 /* global_load_tr_b128 */, AMDGPU::GLOBAL_LOAD_TR_B128_w64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12301 /* global_load_tr_b128 */, AMDGPU::GLOBAL_LOAD_TR_B128_w32_SADDR_gfx12, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12301 /* global_load_tr_b128 */, AMDGPU::GLOBAL_LOAD_TR_B128_w32_gfx12, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12321 /* global_load_tr_b64 */, AMDGPU::GLOBAL_LOAD_TR_B64_w64_SADDR_gfx12, Convert__Reg1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12321 /* global_load_tr_b64 */, AMDGPU::GLOBAL_LOAD_TR_B64_w64_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64, { MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12321 /* global_load_tr_b64 */, AMDGPU::GLOBAL_LOAD_TR_B64_w32_SADDR_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12321 /* global_load_tr_b64 */, AMDGPU::GLOBAL_LOAD_TR_B64_w32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12340 /* global_load_u16 */, AMDGPU::GLOBAL_LOAD_USHORT_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12340 /* global_load_u16 */, AMDGPU::GLOBAL_LOAD_USHORT_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12340 /* global_load_u16 */, AMDGPU::GLOBAL_LOAD_USHORT_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12340 /* global_load_u16 */, AMDGPU::GLOBAL_LOAD_USHORT_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12356 /* global_load_u8 */, AMDGPU::GLOBAL_LOAD_UBYTE_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12356 /* global_load_u8 */, AMDGPU::GLOBAL_LOAD_UBYTE_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12356 /* global_load_u8 */, AMDGPU::GLOBAL_LOAD_UBYTE_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12356 /* global_load_u8 */, AMDGPU::GLOBAL_LOAD_UBYTE_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12371 /* global_load_ubyte */, AMDGPU::GLOBAL_LOAD_LDS_UBYTE_SADDR_vi, Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 12371 /* global_load_ubyte */, AMDGPU::GLOBAL_LOAD_LDS_UBYTE_SADDR_gfx10, Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 12371 /* global_load_ubyte */, AMDGPU::GLOBAL_LOAD_UBYTE_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12371 /* global_load_ubyte */, AMDGPU::GLOBAL_LOAD_UBYTE_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12371 /* global_load_ubyte */, AMDGPU::GLOBAL_LOAD_UBYTE_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12371 /* global_load_ubyte */, AMDGPU::GLOBAL_LOAD_UBYTE_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12371 /* global_load_ubyte */, AMDGPU::GLOBAL_LOAD_LDS_UBYTE_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 12371 /* global_load_ubyte */, AMDGPU::GLOBAL_LOAD_LDS_UBYTE_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 12389 /* global_load_ubyte_d16 */, AMDGPU::GLOBAL_LOAD_UBYTE_D16_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12389 /* global_load_ubyte_d16 */, AMDGPU::GLOBAL_LOAD_UBYTE_D16_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12389 /* global_load_ubyte_d16 */, AMDGPU::GLOBAL_LOAD_UBYTE_D16_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12389 /* global_load_ubyte_d16 */, AMDGPU::GLOBAL_LOAD_UBYTE_D16_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12411 /* global_load_ubyte_d16_hi */, AMDGPU::GLOBAL_LOAD_UBYTE_D16_HI_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12411 /* global_load_ubyte_d16_hi */, AMDGPU::GLOBAL_LOAD_UBYTE_D16_HI_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12411 /* global_load_ubyte_d16_hi */, AMDGPU::GLOBAL_LOAD_UBYTE_D16_HI_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12411 /* global_load_ubyte_d16_hi */, AMDGPU::GLOBAL_LOAD_UBYTE_D16_HI_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12436 /* global_load_ushort */, AMDGPU::GLOBAL_LOAD_LDS_USHORT_SADDR_vi, Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 12436 /* global_load_ushort */, AMDGPU::GLOBAL_LOAD_LDS_USHORT_SADDR_gfx10, Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 12436 /* global_load_ushort */, AMDGPU::GLOBAL_LOAD_USHORT_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12436 /* global_load_ushort */, AMDGPU::GLOBAL_LOAD_USHORT_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12436 /* global_load_ushort */, AMDGPU::GLOBAL_LOAD_USHORT_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12436 /* global_load_ushort */, AMDGPU::GLOBAL_LOAD_USHORT_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12436 /* global_load_ushort */, AMDGPU::GLOBAL_LOAD_LDS_USHORT_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 12436 /* global_load_ushort */, AMDGPU::GLOBAL_LOAD_LDS_USHORT_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 12455 /* global_prefetch_b8 */, AMDGPU::GLOBAL_PREFETCH_B8_SADDR_gfx1250, Convert__Reg1_1__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasVmemPrefInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 12455 /* global_prefetch_b8 */, AMDGPU::GLOBAL_PREFETCH_B8_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__FlatOffset1_2__CPol1_3, AMFBS_HasVmemPrefInsts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12474 /* global_store_addtid_b32 */, AMDGPU::GLOBAL_STORE_DWORD_ADDTID_gfx11, Convert__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12474 /* global_store_addtid_b32 */, AMDGPU::GLOBAL_STORE_DWORD_ADDTID_gfx12, Convert__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12474 /* global_store_addtid_b32 */, AMDGPU::GLOBAL_STORE_DWORD_ADDTID_SADDR_gfx11, Convert__Reg1_0__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 12474 /* global_store_addtid_b32 */, AMDGPU::GLOBAL_STORE_DWORD_ADDTID_SADDR_gfx12, Convert__Reg1_0__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 12498 /* global_store_async_from_lds_b128 */, AMDGPU::GLOBAL_STORE_ASYNC_FROM_LDS_B128_SADDR_gfx1250, Convert__Reg1_2__Reg1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 12498 /* global_store_async_from_lds_b128 */, AMDGPU::GLOBAL_STORE_ASYNC_FROM_LDS_B128_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12531 /* global_store_async_from_lds_b32 */, AMDGPU::GLOBAL_STORE_ASYNC_FROM_LDS_B32_SADDR_gfx1250, Convert__Reg1_2__Reg1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 12531 /* global_store_async_from_lds_b32 */, AMDGPU::GLOBAL_STORE_ASYNC_FROM_LDS_B32_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12563 /* global_store_async_from_lds_b64 */, AMDGPU::GLOBAL_STORE_ASYNC_FROM_LDS_B64_SADDR_gfx1250, Convert__Reg1_2__Reg1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 12563 /* global_store_async_from_lds_b64 */, AMDGPU::GLOBAL_STORE_ASYNC_FROM_LDS_B64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12595 /* global_store_async_from_lds_b8 */, AMDGPU::GLOBAL_STORE_ASYNC_FROM_LDS_B8_SADDR_gfx1250, Convert__Reg1_2__Reg1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 12595 /* global_store_async_from_lds_b8 */, AMDGPU::GLOBAL_STORE_ASYNC_FROM_LDS_B8_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasMcastLoadInsts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12626 /* global_store_b128 */, AMDGPU::GLOBAL_STORE_DWORDX4_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12626 /* global_store_b128 */, AMDGPU::GLOBAL_STORE_DWORDX4_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12626 /* global_store_b128 */, AMDGPU::GLOBAL_STORE_DWORDX4_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12626 /* global_store_b128 */, AMDGPU::GLOBAL_STORE_DWORDX4_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12644 /* global_store_b16 */, AMDGPU::GLOBAL_STORE_SHORT_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12644 /* global_store_b16 */, AMDGPU::GLOBAL_STORE_SHORT_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12644 /* global_store_b16 */, AMDGPU::GLOBAL_STORE_SHORT_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12644 /* global_store_b16 */, AMDGPU::GLOBAL_STORE_SHORT_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12661 /* global_store_b32 */, AMDGPU::GLOBAL_STORE_DWORD_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12661 /* global_store_b32 */, AMDGPU::GLOBAL_STORE_DWORD_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12661 /* global_store_b32 */, AMDGPU::GLOBAL_STORE_DWORD_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12661 /* global_store_b32 */, AMDGPU::GLOBAL_STORE_DWORD_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12678 /* global_store_b64 */, AMDGPU::GLOBAL_STORE_DWORDX2_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12678 /* global_store_b64 */, AMDGPU::GLOBAL_STORE_DWORDX2_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12678 /* global_store_b64 */, AMDGPU::GLOBAL_STORE_DWORDX2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12678 /* global_store_b64 */, AMDGPU::GLOBAL_STORE_DWORDX2_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12695 /* global_store_b8 */, AMDGPU::GLOBAL_STORE_BYTE_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12695 /* global_store_b8 */, AMDGPU::GLOBAL_STORE_BYTE_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12695 /* global_store_b8 */, AMDGPU::GLOBAL_STORE_BYTE_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12695 /* global_store_b8 */, AMDGPU::GLOBAL_STORE_BYTE_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12711 /* global_store_b96 */, AMDGPU::GLOBAL_STORE_DWORDX3_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12711 /* global_store_b96 */, AMDGPU::GLOBAL_STORE_DWORDX3_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12711 /* global_store_b96 */, AMDGPU::GLOBAL_STORE_DWORDX3_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12711 /* global_store_b96 */, AMDGPU::GLOBAL_STORE_DWORDX3_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12728 /* global_store_block */, AMDGPU::GLOBAL_STORE_BLOCK_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_VReg_1024_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12728 /* global_store_block */, AMDGPU::GLOBAL_STORE_BLOCK_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_1024_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12747 /* global_store_byte */, AMDGPU::GLOBAL_STORE_BYTE_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12747 /* global_store_byte */, AMDGPU::GLOBAL_STORE_BYTE_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12747 /* global_store_byte */, AMDGPU::GLOBAL_STORE_BYTE_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12747 /* global_store_byte */, AMDGPU::GLOBAL_STORE_BYTE_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12765 /* global_store_byte_d16_hi */, AMDGPU::GLOBAL_STORE_BYTE_D16_HI_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12765 /* global_store_byte_d16_hi */, AMDGPU::GLOBAL_STORE_BYTE_D16_HI_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12765 /* global_store_byte_d16_hi */, AMDGPU::GLOBAL_STORE_BYTE_D16_HI_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12765 /* global_store_byte_d16_hi */, AMDGPU::GLOBAL_STORE_BYTE_D16_HI_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12790 /* global_store_d16_hi_b16 */, AMDGPU::GLOBAL_STORE_SHORT_D16_HI_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12790 /* global_store_d16_hi_b16 */, AMDGPU::GLOBAL_STORE_SHORT_D16_HI_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12790 /* global_store_d16_hi_b16 */, AMDGPU::GLOBAL_STORE_SHORT_D16_HI_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12790 /* global_store_d16_hi_b16 */, AMDGPU::GLOBAL_STORE_SHORT_D16_HI_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12814 /* global_store_d16_hi_b8 */, AMDGPU::GLOBAL_STORE_BYTE_D16_HI_SADDR_gfx11, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12814 /* global_store_d16_hi_b8 */, AMDGPU::GLOBAL_STORE_BYTE_D16_HI_SADDR_gfx12, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12814 /* global_store_d16_hi_b8 */, AMDGPU::GLOBAL_STORE_BYTE_D16_HI_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12814 /* global_store_d16_hi_b8 */, AMDGPU::GLOBAL_STORE_BYTE_D16_HI_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12837 /* global_store_dword */, AMDGPU::GLOBAL_STORE_DWORD_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12837 /* global_store_dword */, AMDGPU::GLOBAL_STORE_DWORD_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12837 /* global_store_dword */, AMDGPU::GLOBAL_STORE_DWORD_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12837 /* global_store_dword */, AMDGPU::GLOBAL_STORE_DWORD_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12856 /* global_store_dword_addtid */, AMDGPU::GLOBAL_STORE_DWORD_ADDTID_gfx10, Convert__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12856 /* global_store_dword_addtid */, AMDGPU::GLOBAL_STORE_DWORD_ADDTID_SADDR_gfx10, Convert__Reg1_0__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 12882 /* global_store_dwordx2 */, AMDGPU::GLOBAL_STORE_DWORDX2_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12882 /* global_store_dwordx2 */, AMDGPU::GLOBAL_STORE_DWORDX2_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12882 /* global_store_dwordx2 */, AMDGPU::GLOBAL_STORE_DWORDX2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12882 /* global_store_dwordx2 */, AMDGPU::GLOBAL_STORE_DWORDX2_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12903 /* global_store_dwordx3 */, AMDGPU::GLOBAL_STORE_DWORDX3_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12903 /* global_store_dwordx3 */, AMDGPU::GLOBAL_STORE_DWORDX3_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12903 /* global_store_dwordx3 */, AMDGPU::GLOBAL_STORE_DWORDX3_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12903 /* global_store_dwordx3 */, AMDGPU::GLOBAL_STORE_DWORDX3_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_96_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12924 /* global_store_dwordx4 */, AMDGPU::GLOBAL_STORE_DWORDX4_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12924 /* global_store_dwordx4 */, AMDGPU::GLOBAL_STORE_DWORDX4_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12924 /* global_store_dwordx4 */, AMDGPU::GLOBAL_STORE_DWORDX4_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12924 /* global_store_dwordx4 */, AMDGPU::GLOBAL_STORE_DWORDX4_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12945 /* global_store_short */, AMDGPU::GLOBAL_STORE_SHORT_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12945 /* global_store_short */, AMDGPU::GLOBAL_STORE_SHORT_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12945 /* global_store_short */, AMDGPU::GLOBAL_STORE_SHORT_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12945 /* global_store_short */, AMDGPU::GLOBAL_STORE_SHORT_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12964 /* global_store_short_d16_hi */, AMDGPU::GLOBAL_STORE_SHORT_D16_HI_SADDR_gfx10, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12964 /* global_store_short_d16_hi */, AMDGPU::GLOBAL_STORE_SHORT_D16_HI_SADDR_vi, Convert__Reg1_0__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_64_XEXEC_XNULL, MCK_FlatOffset, MCK_CPol }, },
  { 12964 /* global_store_short_d16_hi */, AMDGPU::GLOBAL_STORE_SHORT_D16_HI_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12964 /* global_store_short_d16_hi */, AMDGPU::GLOBAL_STORE_SHORT_D16_HI_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatGlobalInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 12990 /* global_wb */, AMDGPU::GLOBAL_WB_gfx12, Convert__CPol1_0, AMFBS_isGFX12Plus_isGFX12Only, { MCK_CPol }, },
  { 13000 /* global_wbinv */, AMDGPU::GLOBAL_WBINV_gfx12, Convert__CPol1_0, AMFBS_isGFX12Plus_isGFX12Only, { MCK_CPol }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V4_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V4_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V3_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V3_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V2_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V2_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V1_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V1_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V4_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V4_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V3_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V3_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V2_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V2_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V1_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V1_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V4_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V4_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V3_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V3_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V2_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V2_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V1_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V1_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13013 /* image_atomic_add */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13030 /* image_atomic_add_flt */, AMDGPU::IMAGE_ATOMIC_ADD_FLT_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13030 /* image_atomic_add_flt */, AMDGPU::IMAGE_ATOMIC_ADD_FLT_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13030 /* image_atomic_add_flt */, AMDGPU::IMAGE_ATOMIC_ADD_FLT_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13030 /* image_atomic_add_flt */, AMDGPU::IMAGE_ATOMIC_ADD_FLT_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13030 /* image_atomic_add_flt */, AMDGPU::IMAGE_ATOMIC_ADD_FLT_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13030 /* image_atomic_add_flt */, AMDGPU::IMAGE_ATOMIC_ADD_FLT_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13030 /* image_atomic_add_flt */, AMDGPU::IMAGE_ATOMIC_ADD_FLT_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13030 /* image_atomic_add_flt */, AMDGPU::IMAGE_ATOMIC_ADD_FLT_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13030 /* image_atomic_add_flt */, AMDGPU::IMAGE_ATOMIC_ADD_FLT_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13030 /* image_atomic_add_flt */, AMDGPU::IMAGE_ATOMIC_ADD_FLT_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13030 /* image_atomic_add_flt */, AMDGPU::IMAGE_ATOMIC_ADD_FLT_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13030 /* image_atomic_add_flt */, AMDGPU::IMAGE_ATOMIC_ADD_FLT_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13051 /* image_atomic_add_uint */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13051 /* image_atomic_add_uint */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13051 /* image_atomic_add_uint */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13051 /* image_atomic_add_uint */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13051 /* image_atomic_add_uint */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13051 /* image_atomic_add_uint */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13051 /* image_atomic_add_uint */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13051 /* image_atomic_add_uint */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13051 /* image_atomic_add_uint */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13051 /* image_atomic_add_uint */, AMDGPU::IMAGE_ATOMIC_ADD_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13051 /* image_atomic_add_uint */, AMDGPU::IMAGE_ATOMIC_ADD_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13051 /* image_atomic_add_uint */, AMDGPU::IMAGE_ATOMIC_ADD_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V4_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V4_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V3_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V3_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V2_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V2_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V1_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V1_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V4_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V4_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V3_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V3_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V2_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V2_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V1_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V1_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V4_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V4_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V3_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V3_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V2_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V2_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V1_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V1_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13073 /* image_atomic_and */, AMDGPU::IMAGE_ATOMIC_AND_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V4_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V4_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V3_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V3_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V2_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V2_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V1_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V1_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V4_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V4_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V3_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V3_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V2_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V2_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V1_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V1_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V4_si, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V4_vi, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V3_si, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V3_vi, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V2_si, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V2_vi, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V1_si, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V1_vi, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V4_si, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V4_vi, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V3_si, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V3_vi, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V2_si, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V2_vi, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V1_si, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V1_vi, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13090 /* image_atomic_cmpswap */, AMDGPU::IMAGE_ATOMIC_CMPSWAP_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V4_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V4_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V3_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V3_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V2_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V2_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V1_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V1_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V4_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V4_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V3_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V3_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V2_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V2_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V1_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V1_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V4_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V4_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V3_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V3_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V2_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V2_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V1_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V1_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13111 /* image_atomic_dec */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13128 /* image_atomic_dec_uint */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13128 /* image_atomic_dec_uint */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13128 /* image_atomic_dec_uint */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13128 /* image_atomic_dec_uint */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13128 /* image_atomic_dec_uint */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13128 /* image_atomic_dec_uint */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13128 /* image_atomic_dec_uint */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13128 /* image_atomic_dec_uint */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13128 /* image_atomic_dec_uint */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13128 /* image_atomic_dec_uint */, AMDGPU::IMAGE_ATOMIC_DEC_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13128 /* image_atomic_dec_uint */, AMDGPU::IMAGE_ATOMIC_DEC_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13128 /* image_atomic_dec_uint */, AMDGPU::IMAGE_ATOMIC_DEC_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V2_V4_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V2_V3_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V2_V2_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V2_V1_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V3_V4_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V3_V3_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V3_V2_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V3_V1_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V4_V4_si, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V4_V3_si, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V4_V2_si, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V4_V1_si, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V5_V4_si, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V5_V3_si, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V5_V2_si, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V5_V1_si, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13150 /* image_atomic_fcmpswap */, AMDGPU::IMAGE_ATOMIC_FCMPSWAP_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V1_V4_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V1_V3_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V1_V2_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V1_V1_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V2_V4_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V2_V3_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V2_V2_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V2_V1_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V3_V4_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V3_V3_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V3_V2_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V3_V1_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13172 /* image_atomic_fmax */, AMDGPU::IMAGE_ATOMIC_FMAX_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V1_V4_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V1_V3_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V1_V2_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V1_V1_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V2_V4_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V2_V3_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V2_V2_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V2_V1_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V3_V4_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V3_V3_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V3_V2_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V3_V1_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13190 /* image_atomic_fmin */, AMDGPU::IMAGE_ATOMIC_FMIN_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V4_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V4_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V3_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V3_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V2_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V2_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V1_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V1_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V4_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V4_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V3_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V3_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V2_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V2_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V1_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V1_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V4_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V4_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V3_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V3_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V2_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V2_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V1_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V1_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13208 /* image_atomic_inc */, AMDGPU::IMAGE_ATOMIC_INC_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13225 /* image_atomic_inc_uint */, AMDGPU::IMAGE_ATOMIC_INC_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13225 /* image_atomic_inc_uint */, AMDGPU::IMAGE_ATOMIC_INC_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13225 /* image_atomic_inc_uint */, AMDGPU::IMAGE_ATOMIC_INC_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13225 /* image_atomic_inc_uint */, AMDGPU::IMAGE_ATOMIC_INC_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13225 /* image_atomic_inc_uint */, AMDGPU::IMAGE_ATOMIC_INC_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13225 /* image_atomic_inc_uint */, AMDGPU::IMAGE_ATOMIC_INC_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13225 /* image_atomic_inc_uint */, AMDGPU::IMAGE_ATOMIC_INC_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13225 /* image_atomic_inc_uint */, AMDGPU::IMAGE_ATOMIC_INC_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13225 /* image_atomic_inc_uint */, AMDGPU::IMAGE_ATOMIC_INC_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13225 /* image_atomic_inc_uint */, AMDGPU::IMAGE_ATOMIC_INC_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13225 /* image_atomic_inc_uint */, AMDGPU::IMAGE_ATOMIC_INC_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13225 /* image_atomic_inc_uint */, AMDGPU::IMAGE_ATOMIC_INC_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13247 /* image_atomic_max_flt */, AMDGPU::IMAGE_ATOMIC_MAX_FLT_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13247 /* image_atomic_max_flt */, AMDGPU::IMAGE_ATOMIC_MAX_FLT_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13247 /* image_atomic_max_flt */, AMDGPU::IMAGE_ATOMIC_MAX_FLT_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13247 /* image_atomic_max_flt */, AMDGPU::IMAGE_ATOMIC_MAX_FLT_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13247 /* image_atomic_max_flt */, AMDGPU::IMAGE_ATOMIC_MAX_FLT_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13247 /* image_atomic_max_flt */, AMDGPU::IMAGE_ATOMIC_MAX_FLT_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13247 /* image_atomic_max_flt */, AMDGPU::IMAGE_ATOMIC_MAX_FLT_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13247 /* image_atomic_max_flt */, AMDGPU::IMAGE_ATOMIC_MAX_FLT_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13247 /* image_atomic_max_flt */, AMDGPU::IMAGE_ATOMIC_MAX_FLT_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13247 /* image_atomic_max_flt */, AMDGPU::IMAGE_ATOMIC_MAX_FLT_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13247 /* image_atomic_max_flt */, AMDGPU::IMAGE_ATOMIC_MAX_FLT_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13247 /* image_atomic_max_flt */, AMDGPU::IMAGE_ATOMIC_MAX_FLT_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13268 /* image_atomic_max_int */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13268 /* image_atomic_max_int */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13268 /* image_atomic_max_int */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13268 /* image_atomic_max_int */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13268 /* image_atomic_max_int */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13268 /* image_atomic_max_int */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13268 /* image_atomic_max_int */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13268 /* image_atomic_max_int */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13268 /* image_atomic_max_int */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13268 /* image_atomic_max_int */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13268 /* image_atomic_max_int */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13268 /* image_atomic_max_int */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13289 /* image_atomic_max_uint */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13289 /* image_atomic_max_uint */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13289 /* image_atomic_max_uint */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13289 /* image_atomic_max_uint */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13289 /* image_atomic_max_uint */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13289 /* image_atomic_max_uint */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13289 /* image_atomic_max_uint */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13289 /* image_atomic_max_uint */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13289 /* image_atomic_max_uint */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13289 /* image_atomic_max_uint */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13289 /* image_atomic_max_uint */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13289 /* image_atomic_max_uint */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13311 /* image_atomic_min_flt */, AMDGPU::IMAGE_ATOMIC_MIN_FLT_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13311 /* image_atomic_min_flt */, AMDGPU::IMAGE_ATOMIC_MIN_FLT_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13311 /* image_atomic_min_flt */, AMDGPU::IMAGE_ATOMIC_MIN_FLT_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13311 /* image_atomic_min_flt */, AMDGPU::IMAGE_ATOMIC_MIN_FLT_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13311 /* image_atomic_min_flt */, AMDGPU::IMAGE_ATOMIC_MIN_FLT_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13311 /* image_atomic_min_flt */, AMDGPU::IMAGE_ATOMIC_MIN_FLT_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13311 /* image_atomic_min_flt */, AMDGPU::IMAGE_ATOMIC_MIN_FLT_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13311 /* image_atomic_min_flt */, AMDGPU::IMAGE_ATOMIC_MIN_FLT_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13311 /* image_atomic_min_flt */, AMDGPU::IMAGE_ATOMIC_MIN_FLT_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13311 /* image_atomic_min_flt */, AMDGPU::IMAGE_ATOMIC_MIN_FLT_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13311 /* image_atomic_min_flt */, AMDGPU::IMAGE_ATOMIC_MIN_FLT_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13311 /* image_atomic_min_flt */, AMDGPU::IMAGE_ATOMIC_MIN_FLT_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13332 /* image_atomic_min_int */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13332 /* image_atomic_min_int */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13332 /* image_atomic_min_int */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13332 /* image_atomic_min_int */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13332 /* image_atomic_min_int */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13332 /* image_atomic_min_int */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13332 /* image_atomic_min_int */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13332 /* image_atomic_min_int */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13332 /* image_atomic_min_int */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13332 /* image_atomic_min_int */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13332 /* image_atomic_min_int */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13332 /* image_atomic_min_int */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13353 /* image_atomic_min_uint */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13353 /* image_atomic_min_uint */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13353 /* image_atomic_min_uint */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13353 /* image_atomic_min_uint */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13353 /* image_atomic_min_uint */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13353 /* image_atomic_min_uint */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13353 /* image_atomic_min_uint */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13353 /* image_atomic_min_uint */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13353 /* image_atomic_min_uint */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13353 /* image_atomic_min_uint */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13353 /* image_atomic_min_uint */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13353 /* image_atomic_min_uint */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V4_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V4_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V3_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V3_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V2_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V2_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V1_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V1_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V4_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V4_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V3_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V3_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V2_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V2_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V1_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V1_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V4_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V4_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V3_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V3_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V2_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V2_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V1_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V1_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13375 /* image_atomic_or */, AMDGPU::IMAGE_ATOMIC_OR_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13391 /* image_atomic_pk_add_bf16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_BF16_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13391 /* image_atomic_pk_add_bf16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_BF16_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13391 /* image_atomic_pk_add_bf16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_BF16_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13391 /* image_atomic_pk_add_bf16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_BF16_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13391 /* image_atomic_pk_add_bf16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_BF16_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13391 /* image_atomic_pk_add_bf16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_BF16_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13391 /* image_atomic_pk_add_bf16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_BF16_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13391 /* image_atomic_pk_add_bf16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_BF16_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13391 /* image_atomic_pk_add_bf16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_BF16_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13391 /* image_atomic_pk_add_bf16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_BF16_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13391 /* image_atomic_pk_add_bf16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_BF16_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13391 /* image_atomic_pk_add_bf16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_BF16_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13416 /* image_atomic_pk_add_f16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_F16_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13416 /* image_atomic_pk_add_f16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_F16_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13416 /* image_atomic_pk_add_f16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_F16_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13416 /* image_atomic_pk_add_f16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_F16_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13416 /* image_atomic_pk_add_f16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_F16_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13416 /* image_atomic_pk_add_f16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_F16_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13416 /* image_atomic_pk_add_f16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_F16_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13416 /* image_atomic_pk_add_f16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_F16_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13416 /* image_atomic_pk_add_f16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_F16_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13416 /* image_atomic_pk_add_f16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_F16_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13416 /* image_atomic_pk_add_f16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_F16_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13416 /* image_atomic_pk_add_f16 */, AMDGPU::IMAGE_ATOMIC_PK_ADD_F16_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13440 /* image_atomic_rsub */, AMDGPU::IMAGE_ATOMIC_RSUB_V1_V4_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13440 /* image_atomic_rsub */, AMDGPU::IMAGE_ATOMIC_RSUB_V1_V3_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13440 /* image_atomic_rsub */, AMDGPU::IMAGE_ATOMIC_RSUB_V1_V2_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13440 /* image_atomic_rsub */, AMDGPU::IMAGE_ATOMIC_RSUB_V1_V1_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13440 /* image_atomic_rsub */, AMDGPU::IMAGE_ATOMIC_RSUB_V2_V4_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13440 /* image_atomic_rsub */, AMDGPU::IMAGE_ATOMIC_RSUB_V2_V3_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13440 /* image_atomic_rsub */, AMDGPU::IMAGE_ATOMIC_RSUB_V2_V2_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13440 /* image_atomic_rsub */, AMDGPU::IMAGE_ATOMIC_RSUB_V2_V1_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13440 /* image_atomic_rsub */, AMDGPU::IMAGE_ATOMIC_RSUB_V3_V4_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13440 /* image_atomic_rsub */, AMDGPU::IMAGE_ATOMIC_RSUB_V3_V3_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13440 /* image_atomic_rsub */, AMDGPU::IMAGE_ATOMIC_RSUB_V3_V2_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13440 /* image_atomic_rsub */, AMDGPU::IMAGE_ATOMIC_RSUB_V3_V1_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V4_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V4_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V3_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V3_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V2_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V2_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V1_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V1_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V4_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V4_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V3_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V3_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V2_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V2_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V1_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V1_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V4_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V4_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V3_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V3_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V2_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V2_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V1_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V1_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13458 /* image_atomic_smax */, AMDGPU::IMAGE_ATOMIC_SMAX_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V4_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V4_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V3_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V3_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V2_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V2_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V1_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V1_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V4_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V4_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V3_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V3_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V2_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V2_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V1_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V1_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V4_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V4_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V3_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V3_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V2_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V2_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V1_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V1_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13476 /* image_atomic_smin */, AMDGPU::IMAGE_ATOMIC_SMIN_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V4_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V4_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V3_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V3_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V2_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V2_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V1_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V1_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V4_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V4_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V3_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V3_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V2_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V2_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V1_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V1_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V4_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V4_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V3_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V3_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V2_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V2_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V1_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V1_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13494 /* image_atomic_sub */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13511 /* image_atomic_sub_uint */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13511 /* image_atomic_sub_uint */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13511 /* image_atomic_sub_uint */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13511 /* image_atomic_sub_uint */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13511 /* image_atomic_sub_uint */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13511 /* image_atomic_sub_uint */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13511 /* image_atomic_sub_uint */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13511 /* image_atomic_sub_uint */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13511 /* image_atomic_sub_uint */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13511 /* image_atomic_sub_uint */, AMDGPU::IMAGE_ATOMIC_SUB_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13511 /* image_atomic_sub_uint */, AMDGPU::IMAGE_ATOMIC_SUB_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13511 /* image_atomic_sub_uint */, AMDGPU::IMAGE_ATOMIC_SUB_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V4_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V4_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V3_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V3_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V2_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V2_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V1_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V1_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V4_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V4_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V3_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V3_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V2_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V2_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V1_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V1_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V4_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V4_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V3_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V3_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V2_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V2_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V1_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V1_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13533 /* image_atomic_swap */, AMDGPU::IMAGE_ATOMIC_SWAP_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V4_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V4_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V3_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V3_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V2_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V2_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V1_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V1_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V4_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V4_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V3_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V3_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V2_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V2_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V1_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V1_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V4_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V4_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V3_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V3_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V2_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V2_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V1_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V1_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13551 /* image_atomic_umax */, AMDGPU::IMAGE_ATOMIC_UMAX_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V4_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V4_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V3_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V3_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V2_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V2_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V1_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V1_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V4_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V4_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V3_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V3_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V2_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V2_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V1_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V1_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V4_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V4_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V3_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V3_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V2_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V2_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V1_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V1_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13569 /* image_atomic_umin */, AMDGPU::IMAGE_ATOMIC_UMIN_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V4_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V4_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V3_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V3_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V2_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V2_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V1_si, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V1_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V4_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V4_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V3_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V3_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V2_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V2_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V1_si, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V1_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V4_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V4_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V3_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V3_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V2_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V2_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V1_si, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V1_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13587 /* image_atomic_xor */, AMDGPU::IMAGE_ATOMIC_XOR_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Tie0_1_1__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 13604 /* image_bvh64_intersect_ray */, AMDGPU::IMAGE_BVH64_INTERSECT_RAY_a16_sa_gfx10, Convert__Reg1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__A161_3, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_VReg_128, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_128_XNULL, MCK_A16 }, },
  { 13604 /* image_bvh64_intersect_ray */, AMDGPU::IMAGE_BVH64_INTERSECT_RAY_a16_sa_gfx11, Convert__Reg1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__A161_3, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_VReg_128, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_128_XNULL, MCK_A16 }, },
  { 13604 /* image_bvh64_intersect_ray */, AMDGPU::IMAGE_BVH64_INTERSECT_RAY_sa_gfx10, Convert__Reg1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__A161_3, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_VReg_128, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_128_XNULL, MCK_A16 }, },
  { 13604 /* image_bvh64_intersect_ray */, AMDGPU::IMAGE_BVH64_INTERSECT_RAY_sa_gfx11, Convert__Reg1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__A161_3, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_VReg_128, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_128_XNULL, MCK_A16 }, },
  { 13604 /* image_bvh64_intersect_ray */, AMDGPU::IMAGE_BVH64_INTERSECT_RAY_a16_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__RegByHwMode_VReg_96_AlignTarget1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__A161_8, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus, { MCK_VReg_128, MCK__91_, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_128_XNULL, MCK_A16 }, },
  { 13604 /* image_bvh64_intersect_ray */, AMDGPU::IMAGE_BVH64_INTERSECT_RAY_a16_nsa_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__RegByHwMode_VReg_96_AlignTarget1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__A161_8, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_VReg_128, MCK__91_, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_128_XNULL, MCK_A16 }, },
  { 13604 /* image_bvh64_intersect_ray */, AMDGPU::IMAGE_BVH64_INTERSECT_RAY_gfx12, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__RegByHwMode_VReg_96_AlignTarget1_4__RegByHwMode_VReg_96_AlignTarget1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__A161_9, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus, { MCK_VReg_128, MCK__91_, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_128_XNULL, MCK_A16 }, },
  { 13604 /* image_bvh64_intersect_ray */, AMDGPU::IMAGE_BVH64_INTERSECT_RAY_nsa_gfx11, Convert__Reg1_0__RegByHwMode_VReg_64_AlignTarget1_2__Reg1_3__RegByHwMode_VReg_96_AlignTarget1_4__RegByHwMode_VReg_96_AlignTarget1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__A161_9, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_VReg_128, MCK__91_, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_128_XNULL, MCK_A16 }, },
  { 13604 /* image_bvh64_intersect_ray */, AMDGPU::IMAGE_BVH64_INTERSECT_RAY_a16_nsa_gfx10, Convert__Reg1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__A161_13, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_VReg_128, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_128_XNULL, MCK_A16 }, },
  { 13604 /* image_bvh64_intersect_ray */, AMDGPU::IMAGE_BVH64_INTERSECT_RAY_nsa_gfx10, Convert__Reg1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__A161_16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_VReg_128, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_128_XNULL, MCK_A16 }, },
  { 13630 /* image_bvh8_intersect_ray */, AMDGPU::IMAGE_BVH8_INTERSECT_RAY_gfx12, Convert__Reg1_0__RegByHwMode_VReg_96_AlignTarget1_4__RegByHwMode_VReg_96_AlignTarget1_5__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Tie1_5_5__Tie2_6_6__Reg1_6__Reg1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_VReg_320, MCK__91_, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_VGPR_32, MCK__93_, MCK_SReg_128_XNULL }, },
  { 13655 /* image_bvh_dual_intersect_ray */, AMDGPU::IMAGE_BVH_DUAL_INTERSECT_RAY_gfx12, Convert__Reg1_0__RegByHwMode_VReg_96_AlignTarget1_4__RegByHwMode_VReg_96_AlignTarget1_5__RegByHwMode_VReg_64_AlignTarget1_2__RegByHwMode_VReg_64_AlignTarget1_3__Tie1_5_5__Tie2_6_6__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_VReg_320, MCK__91_, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_128_XNULL }, },
  { 13684 /* image_bvh_intersect_ray */, AMDGPU::IMAGE_BVH_INTERSECT_RAY_a16_sa_gfx10, Convert__Reg1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__A161_3, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_VReg_128, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_128_XNULL, MCK_A16 }, },
  { 13684 /* image_bvh_intersect_ray */, AMDGPU::IMAGE_BVH_INTERSECT_RAY_a16_sa_gfx11, Convert__Reg1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__A161_3, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_VReg_128, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_128_XNULL, MCK_A16 }, },
  { 13684 /* image_bvh_intersect_ray */, AMDGPU::IMAGE_BVH_INTERSECT_RAY_sa_gfx10, Convert__Reg1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__A161_3, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_VReg_128, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_128_XNULL, MCK_A16 }, },
  { 13684 /* image_bvh_intersect_ray */, AMDGPU::IMAGE_BVH_INTERSECT_RAY_sa_gfx11, Convert__Reg1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__A161_3, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_VReg_128, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_128_XNULL, MCK_A16 }, },
  { 13684 /* image_bvh_intersect_ray */, AMDGPU::IMAGE_BVH_INTERSECT_RAY_a16_gfx12, Convert__Reg1_0__Reg1_2__Reg1_3__RegByHwMode_VReg_96_AlignTarget1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__A161_8, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus, { MCK_VReg_128, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_128_XNULL, MCK_A16 }, },
  { 13684 /* image_bvh_intersect_ray */, AMDGPU::IMAGE_BVH_INTERSECT_RAY_a16_nsa_gfx11, Convert__Reg1_0__Reg1_2__Reg1_3__RegByHwMode_VReg_96_AlignTarget1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__A161_8, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_VReg_128, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_128_XNULL, MCK_A16 }, },
  { 13684 /* image_bvh_intersect_ray */, AMDGPU::IMAGE_BVH_INTERSECT_RAY_gfx12, Convert__Reg1_0__Reg1_2__Reg1_3__RegByHwMode_VReg_96_AlignTarget1_4__RegByHwMode_VReg_96_AlignTarget1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__A161_9, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus, { MCK_VReg_128, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_128_XNULL, MCK_A16 }, },
  { 13684 /* image_bvh_intersect_ray */, AMDGPU::IMAGE_BVH_INTERSECT_RAY_nsa_gfx11, Convert__Reg1_0__Reg1_2__Reg1_3__RegByHwMode_VReg_96_AlignTarget1_4__RegByHwMode_VReg_96_AlignTarget1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__A161_9, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_VReg_128, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_128_XNULL, MCK_A16 }, },
  { 13684 /* image_bvh_intersect_ray */, AMDGPU::IMAGE_BVH_INTERSECT_RAY_a16_nsa_gfx10, Convert__Reg1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__A161_12, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_VReg_128, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_128_XNULL, MCK_A16 }, },
  { 13684 /* image_bvh_intersect_ray */, AMDGPU::IMAGE_BVH_INTERSECT_RAY_nsa_gfx10, Convert__Reg1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__A161_15, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_VReg_128, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_128_XNULL, MCK_A16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V2_V1, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V4_V1, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V5_V1, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13708 /* image_gather4 */, AMDGPU::IMAGE_GATHER4_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13722 /* image_gather4_b */, AMDGPU::IMAGE_GATHER4_B_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13738 /* image_gather4_b_cl */, AMDGPU::IMAGE_GATHER4_B_CL_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13757 /* image_gather4_b_cl_o */, AMDGPU::IMAGE_GATHER4_B_CL_O_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13778 /* image_gather4_b_o */, AMDGPU::IMAGE_GATHER4_B_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13796 /* image_gather4_c */, AMDGPU::IMAGE_GATHER4_C_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13812 /* image_gather4_c_b */, AMDGPU::IMAGE_GATHER4_C_B_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13830 /* image_gather4_c_b_cl */, AMDGPU::IMAGE_GATHER4_C_B_CL_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13851 /* image_gather4_c_b_cl_o */, AMDGPU::IMAGE_GATHER4_C_B_CL_O_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13874 /* image_gather4_c_b_o */, AMDGPU::IMAGE_GATHER4_C_B_O_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13894 /* image_gather4_c_cl */, AMDGPU::IMAGE_GATHER4_C_CL_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13913 /* image_gather4_c_cl_o */, AMDGPU::IMAGE_GATHER4_C_CL_O_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13934 /* image_gather4_c_l */, AMDGPU::IMAGE_GATHER4_C_L_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13952 /* image_gather4_c_l_o */, AMDGPU::IMAGE_GATHER4_C_L_O_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13972 /* image_gather4_c_lz */, AMDGPU::IMAGE_GATHER4_C_LZ_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 13991 /* image_gather4_c_lz_o */, AMDGPU::IMAGE_GATHER4_C_LZ_O_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14012 /* image_gather4_c_o */, AMDGPU::IMAGE_GATHER4_C_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V2_V1, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V4_V1, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V5_V1, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14030 /* image_gather4_cl */, AMDGPU::IMAGE_GATHER4_CL_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14047 /* image_gather4_cl_o */, AMDGPU::IMAGE_GATHER4_CL_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V2_V1, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V4_V1, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V5_V1, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14066 /* image_gather4_l */, AMDGPU::IMAGE_GATHER4_L_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14082 /* image_gather4_l_o */, AMDGPU::IMAGE_GATHER4_L_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V2_V1, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V4_V1, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V5_V1, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14100 /* image_gather4_lz */, AMDGPU::IMAGE_GATHER4_LZ_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14117 /* image_gather4_lz_o */, AMDGPU::IMAGE_GATHER4_LZ_O_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14136 /* image_gather4_o */, AMDGPU::IMAGE_GATHER4_O_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V2_V1, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V4_V1, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V5_V1, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14152 /* image_gather4h */, AMDGPU::IMAGE_GATHER4H_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V1, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V1, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V1, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V1, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V1, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14167 /* image_get_lod */, AMDGPU::IMAGE_GET_LOD_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V1, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V1, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V1, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V1, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V1, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14181 /* image_get_resinfo */, AMDGPU::IMAGE_GET_RESINFO_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V1, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V1, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V1, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V1, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V1, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14199 /* image_load */, AMDGPU::IMAGE_LOAD_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V1, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V1, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V1, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V1, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V1, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14210 /* image_load_mip */, AMDGPU::IMAGE_LOAD_MIP_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V1, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V1, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V1, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V1, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V1, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14225 /* image_load_mip_pck */, AMDGPU::IMAGE_LOAD_MIP_PCK_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V1, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V1, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V1, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V1, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V1, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14244 /* image_load_mip_pck_sgn */, AMDGPU::IMAGE_LOAD_MIP_PCK_SGN_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V1, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V1, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V1, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V1, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V1, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14267 /* image_load_pck */, AMDGPU::IMAGE_LOAD_PCK_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V1, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V1, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V1, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V1, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V1, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14282 /* image_load_pck_sgn */, AMDGPU::IMAGE_LOAD_PCK_SGN_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V1_V1, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V2_V1, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V3_V1, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V4_V1, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V5_V1, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14301 /* image_msaa_load */, AMDGPU::IMAGE_MSAA_LOAD_X_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V1, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V1, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V1, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V1, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V1, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_nortn_V1_gfx10, Convert__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_off, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_nortn_V1_gfx11, Convert__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_off, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_nortn_V1_gfx12, Convert__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_off, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_nortn_V2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_nortn_V2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_nortn_V2_gfx12, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_nortn_V2_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_nortn_V2_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14317 /* image_sample */, AMDGPU::IMAGE_SAMPLE_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_nortn_V2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_nortn_V2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_nortn_V2_gfx12, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_nortn_V2_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_nortn_V2_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14330 /* image_sample_b */, AMDGPU::IMAGE_SAMPLE_B_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_nortn_V2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_nortn_V2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_nortn_V2_gfx12, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_nortn_V2_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_nortn_V2_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14345 /* image_sample_b_cl */, AMDGPU::IMAGE_SAMPLE_B_CL_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_nortn_V6_gfx11, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V6_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V6_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_nortn_V6_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V6_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V6_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_nortn_V6_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14363 /* image_sample_b_cl_o */, AMDGPU::IMAGE_SAMPLE_B_CL_O_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14383 /* image_sample_b_o */, AMDGPU::IMAGE_SAMPLE_B_O_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_nortn_V2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_nortn_V2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_nortn_V2_gfx12, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_nortn_V2_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_nortn_V2_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14400 /* image_sample_c */, AMDGPU::IMAGE_SAMPLE_C_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14415 /* image_sample_c_b */, AMDGPU::IMAGE_SAMPLE_C_B_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_nortn_V6_gfx11, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V6_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V6_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_nortn_V6_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V6_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V6_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_nortn_V6_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14432 /* image_sample_c_b_cl */, AMDGPU::IMAGE_SAMPLE_C_B_CL_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_nortn_V6_gfx11, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_nortn_V7_gfx11, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V6_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V7_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V7_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V6_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V7_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V7_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V7_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_nortn_V6_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_nortn_V7_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V6_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V7_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V7_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V6_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V7_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V7_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V7_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_nortn_V6_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_nortn_V7_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14452 /* image_sample_c_b_cl_o */, AMDGPU::IMAGE_SAMPLE_C_B_CL_O_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_nortn_V6_gfx11, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V1_V6_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V3_V6_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_nortn_V6_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V1_V6_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V3_V6_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_nortn_V6_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V1_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V3_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14474 /* image_sample_c_b_o */, AMDGPU::IMAGE_SAMPLE_C_B_O_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_nortn_V10_gfx10, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V10_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V10_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V10_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V10_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V10_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_nortn_V10_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V1_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V2_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V3_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V4_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14493 /* image_sample_c_cd */, AMDGPU::IMAGE_SAMPLE_C_CD_V5_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_nortn_V10_gfx10, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_nortn_V11_gfx10, Convert__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V10_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V11_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V10_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V11_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V10_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V11_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V10_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V11_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V10_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V11_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_nortn_V10_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_nortn_V11_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V1_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V2_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V3_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V4_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14511 /* image_sample_c_cd_cl */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_V5_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14532 /* image_sample_c_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_G16_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_nortn_V10_gfx10, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_nortn_V11_gfx10, Convert__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_nortn_V12_gfx10, Convert__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V10_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V11_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V12_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V10_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V11_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V12_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V10_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V11_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V12_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V10_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V11_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V12_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V10_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V11_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V12_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_nortn_V10_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_nortn_V11_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_nortn_V12_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V1_V12_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V2_V12_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V3_V12_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V4_V12_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14557 /* image_sample_c_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_V5_V12_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V1_V10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V2_V10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V3_V10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V4_V10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V5_V10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_nortn_V10_gfx10, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V1_V10_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V2_V10_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V3_V10_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V4_V10_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V5_V10_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_nortn_V10_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V1_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V2_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V3_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V4_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_CL_O_G16_V5_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14607 /* image_sample_c_cd_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_G16_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_nortn_V10_gfx10, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_nortn_V11_gfx10, Convert__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V10_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V11_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V10_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V11_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V10_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V11_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V10_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V11_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V10_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V11_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_nortn_V10_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_nortn_V11_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V1_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V2_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V3_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V4_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14629 /* image_sample_c_cd_o */, AMDGPU::IMAGE_SAMPLE_C_CD_O_V5_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14649 /* image_sample_c_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_CD_O_G16_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_nortn_V2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_nortn_V2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_nortn_V2_gfx12, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_nortn_V2_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_nortn_V2_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14673 /* image_sample_c_cl */, AMDGPU::IMAGE_SAMPLE_C_CL_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_nortn_V6_gfx11, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V6_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V6_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_nortn_V6_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V6_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V6_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_nortn_V6_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14691 /* image_sample_c_cl_o */, AMDGPU::IMAGE_SAMPLE_C_CL_O_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V6_gfx11, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V7_gfx11, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V9_gfx11, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V10_gfx10, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V10_gfx11, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V6_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V7_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V9_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V10_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V10_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V7_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V9_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V10_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V10_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V6_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V7_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V9_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V10_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V10_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V7_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V9_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V10_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V10_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V7_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V9_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V10_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V10_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V6_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V7_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V8_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V9_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V10_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V6_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V7_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V8_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V9_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V10_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V7_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V8_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V9_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V10_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V6_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V7_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V8_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V9_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V10_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V7_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V8_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V9_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V10_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V7_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V8_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V9_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V10_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V6_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V7_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V8_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V9_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V10_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_nortn_V10_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V1_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V2_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V3_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V4_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14711 /* image_sample_c_d */, AMDGPU::IMAGE_SAMPLE_C_D_V5_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V6_gfx11, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V7_gfx11, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V9_gfx11, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V10_gfx10, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V10_gfx11, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V11_gfx10, Convert__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V11_gfx11, Convert__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V6_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V7_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V9_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V10_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V10_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V11_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V11_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V7_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V9_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V10_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V10_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V11_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V11_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V6_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V7_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V9_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V10_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V10_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V11_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V11_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V7_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V9_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V10_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V10_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V11_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V11_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V7_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V9_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V10_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V10_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V11_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V11_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V6_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V7_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V8_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V9_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V10_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V11_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V6_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V7_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V8_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V9_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V10_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V11_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V7_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V8_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V9_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V10_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V11_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V6_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V7_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V8_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V9_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V10_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V11_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V7_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V8_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V9_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V10_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V11_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V7_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V8_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V9_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V10_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V11_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V6_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V7_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V8_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V9_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V10_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V11_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V11_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V11_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V11_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V11_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V11_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V10_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_nortn_V11_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V1_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V2_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V3_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V4_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14728 /* image_sample_c_d_cl */, AMDGPU::IMAGE_SAMPLE_C_D_CL_V5_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V6_gfx11, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V7_gfx11, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V9_gfx11, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V6_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V7_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V9_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V7_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V9_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V6_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V7_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V9_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V7_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V9_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V7_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V9_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V6_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V7_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V8_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V9_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V6_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V7_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V8_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V9_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V7_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V8_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V9_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V6_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V7_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V8_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V9_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V7_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V8_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V9_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V7_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V8_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V9_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V6_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V7_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V8_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V9_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14748 /* image_sample_c_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_G16_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V6_gfx11, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V7_gfx11, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V9_gfx11, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V10_gfx10, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V10_gfx11, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V11_gfx10, Convert__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V11_gfx11, Convert__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V12_gfx10, Convert__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V12_gfx11, Convert__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V6_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V7_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V9_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V10_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V10_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V11_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V11_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V12_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V12_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V7_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V9_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V10_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V10_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V11_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V11_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V12_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V12_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V6_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V7_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V9_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V10_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V10_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V11_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V11_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V12_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V12_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V7_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V9_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V10_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V10_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V11_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V11_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V12_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V12_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V7_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V9_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V10_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V10_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V11_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V11_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V12_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V12_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_384_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V6_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V7_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V8_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V9_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V10_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V11_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V12_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_288_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_288_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V6_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V7_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V8_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V9_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V10_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V11_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V12_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_288_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_288_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V7_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V8_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V9_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V10_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V11_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V12_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_288_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_288_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V6_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V7_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V8_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V9_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V10_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V11_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V12_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_288_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_288_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V7_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V8_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V9_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V10_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V11_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V12_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_288_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_288_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V7_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V8_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V9_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V10_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V11_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V12_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_288_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_288_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V6_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V7_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V8_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V9_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V10_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V11_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V12_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_256_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V11_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V12_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_256_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V11_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V12_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_256_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V11_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V12_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_256_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V11_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V12_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_256_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V11_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V12_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_256_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V10_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V11_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_nortn_V12_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V1_V12_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V2_V12_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V3_V12_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V4_V12_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14772 /* image_sample_c_d_cl_o */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_V5_V12_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_13__Reg1_15__Reg1_16__DMask1_17__Dim1_18__UNorm1_19__CPol1_20__R128A161_21__A161_22__TFE1_23__LWE1_24__D161_25, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V6_gfx11, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V7_gfx11, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V9_gfx11, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V10_gfx10, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V10_gfx11, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V6_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V7_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V9_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V10_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V10_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V7_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V9_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V10_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V10_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V6_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V7_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V9_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V10_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V10_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V7_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V9_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V10_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V10_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V7_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V9_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V10_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V10_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V6_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V7_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V8_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V9_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V10_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V6_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V7_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V8_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V9_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V10_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V7_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V8_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V9_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V10_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V6_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V7_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V8_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V9_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V10_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V7_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V8_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V9_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V10_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V7_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V8_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V9_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V10_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V6_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V7_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V8_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V9_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V10_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_nortn_V10_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V1_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V2_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V3_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V4_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14794 /* image_sample_c_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_CL_O_G16_V5_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V6_gfx11, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V7_gfx11, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V6_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V7_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V7_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V6_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V7_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V7_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V7_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V6_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V7_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V8_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V6_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V7_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V8_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V7_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V8_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V6_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V7_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V8_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V7_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V8_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V7_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V8_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V6_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V7_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V8_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14820 /* image_sample_c_d_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_G16_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V6_gfx11, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V7_gfx11, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V9_gfx11, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V10_gfx10, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V10_gfx11, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V11_gfx10, Convert__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V11_gfx11, Convert__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V6_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V7_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V9_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V10_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V10_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V11_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V11_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V7_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V9_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V10_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V10_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V11_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V11_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V6_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V7_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V9_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V10_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V10_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V11_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V11_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V7_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V9_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V10_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V10_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V11_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V11_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V7_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V9_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V10_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V10_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V11_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V11_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V6_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V7_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V8_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V9_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V10_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V11_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V6_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V7_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V8_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V9_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V10_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V11_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V7_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V8_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V9_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V10_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V11_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V6_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V7_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V8_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V9_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V10_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V11_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V7_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V8_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V9_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V10_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V11_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V7_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V8_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V9_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V10_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V11_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V6_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V7_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V8_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V9_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V10_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V11_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V11_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V11_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V11_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V11_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V11_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V10_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_nortn_V11_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V1_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V2_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V3_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V4_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14841 /* image_sample_c_d_o */, AMDGPU::IMAGE_SAMPLE_C_D_O_V5_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V6_gfx11, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V7_gfx11, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V9_gfx11, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V6_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V7_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V9_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V7_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V9_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V6_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V7_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V9_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V7_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V9_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V7_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V9_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V6_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V7_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V8_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V9_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V6_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V7_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V8_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V9_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V7_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V8_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V9_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V6_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V7_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V8_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V9_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V7_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V8_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V9_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V7_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V8_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V9_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V6_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V7_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V8_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V9_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14860 /* image_sample_c_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_C_D_O_G16_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_nortn_V2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_nortn_V2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_nortn_V2_gfx12, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_nortn_V2_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_nortn_V2_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14883 /* image_sample_c_l */, AMDGPU::IMAGE_SAMPLE_C_L_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_nortn_V6_gfx11, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V6_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V6_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_nortn_V6_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V6_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V6_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_nortn_V6_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14900 /* image_sample_c_l_o */, AMDGPU::IMAGE_SAMPLE_C_L_O_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_nortn_V2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_nortn_V2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_nortn_V2_gfx12, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_nortn_V2_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_nortn_V2_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14919 /* image_sample_c_lz */, AMDGPU::IMAGE_SAMPLE_C_LZ_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14937 /* image_sample_c_lz_o */, AMDGPU::IMAGE_SAMPLE_C_LZ_O_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14957 /* image_sample_c_o */, AMDGPU::IMAGE_SAMPLE_C_O_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_nortn_V2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_nortn_V2_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14974 /* image_sample_cd */, AMDGPU::IMAGE_SAMPLE_CD_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_nortn_V2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_nortn_V10_gfx10, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V10_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V10_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V10_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V10_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V10_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_nortn_V2_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_nortn_V10_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V1_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V2_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V3_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V4_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 14990 /* image_sample_cd_cl */, AMDGPU::IMAGE_SAMPLE_CD_CL_V5_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_nortn_V2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_nortn_V2_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15009 /* image_sample_cd_cl_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_G16_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_nortn_V10_gfx10, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_nortn_V11_gfx10, Convert__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V10_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V11_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V10_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V11_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V10_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V11_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V10_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V11_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V10_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V11_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_nortn_V10_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_nortn_V11_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V1_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V2_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V3_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V4_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15032 /* image_sample_cd_cl_o */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_V5_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15053 /* image_sample_cd_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_CL_O_G16_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_nortn_V2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_nortn_V2_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15078 /* image_sample_cd_g16 */, AMDGPU::IMAGE_SAMPLE_CD_G16_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_nortn_V10_gfx10, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V10_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V10_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V10_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V10_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V10_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_nortn_V10_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V1_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V2_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V3_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V4_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15098 /* image_sample_cd_o */, AMDGPU::IMAGE_SAMPLE_CD_O_V5_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15116 /* image_sample_cd_o_g16 */, AMDGPU::IMAGE_SAMPLE_CD_O_G16_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V1_V1, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V2_V1, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V3_V1, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V4_V1, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V5_V1, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_nortn_V1_gfx10, Convert__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_nortn_V1_gfx11, Convert__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_nortn_V1_gfx12, Convert__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_nortn_V2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_nortn_V2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_nortn_V2_gfx12, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_nortn_V2_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_nortn_V2_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15138 /* image_sample_cl */, AMDGPU::IMAGE_SAMPLE_CL_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_nortn_V2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_nortn_V2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_nortn_V2_gfx12, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_nortn_V2_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_nortn_V2_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15154 /* image_sample_cl_o */, AMDGPU::IMAGE_SAMPLE_CL_O_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V6_gfx11, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V7_gfx11, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V9_gfx11, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V6_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V7_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V9_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V7_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V9_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V6_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V7_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V9_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V7_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V9_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V7_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V9_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V2_gfx12, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V2_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V2_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V6_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V7_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V8_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V9_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V6_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V7_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V8_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V9_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V7_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V8_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V9_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V6_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V7_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V8_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V9_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V7_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V8_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V9_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V7_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V8_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V9_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V6_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V7_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V8_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V9_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15172 /* image_sample_d */, AMDGPU::IMAGE_SAMPLE_D_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V6_gfx11, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V7_gfx11, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V9_gfx11, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V10_gfx10, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V10_gfx11, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V6_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V7_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V9_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V10_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V10_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V7_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V9_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V10_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V10_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V6_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V7_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V9_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V10_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V10_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V7_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V9_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V10_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V10_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V7_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V9_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V10_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V10_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V2_gfx12, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V2_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V2_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V6_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V7_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V8_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V9_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V10_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V6_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V7_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V8_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V9_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V10_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V7_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V8_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V9_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V10_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V6_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V7_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V8_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V9_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V10_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V7_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V8_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V9_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V10_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V7_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V8_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V9_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V10_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V6_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V7_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V8_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V9_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V10_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_nortn_V10_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V1_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V2_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V3_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V4_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15187 /* image_sample_d_cl */, AMDGPU::IMAGE_SAMPLE_D_CL_V5_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V6_gfx11, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V7_gfx11, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V6_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V7_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V7_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V6_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V7_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V7_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V7_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V2_gfx12, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V2_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V2_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V6_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V7_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V8_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V6_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V7_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V8_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V7_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V8_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V6_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V7_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V8_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V7_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V8_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V7_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V8_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V6_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V7_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V8_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15205 /* image_sample_d_cl_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_G16_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V6_gfx11, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V7_gfx11, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V9_gfx11, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V10_gfx10, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V10_gfx11, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V11_gfx10, Convert__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V11_gfx11, Convert__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V6_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V7_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V9_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V10_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V10_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V11_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V11_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V7_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V9_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V10_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V10_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V11_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V11_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V6_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V7_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V9_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V10_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V10_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V11_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V11_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V7_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V9_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V10_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V10_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V11_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V11_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V7_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V9_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V10_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V10_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V11_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V11_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_352_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_352_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V6_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V7_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V8_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V9_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V10_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V11_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V6_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V7_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V8_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V9_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V10_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V11_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V7_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V8_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V9_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V10_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V11_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V6_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V7_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V8_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V9_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V10_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V11_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V7_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V8_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V9_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V10_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V11_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V7_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V8_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V9_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V10_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V11_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_256_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V6_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V7_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V8_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V9_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V10_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V11_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V11_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V11_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V11_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V11_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V11_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_224_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V10_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_nortn_V11_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V1_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V2_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V3_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V4_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15227 /* image_sample_d_cl_o */, AMDGPU::IMAGE_SAMPLE_D_CL_O_V5_V11_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_12__Reg1_14__Reg1_15__DMask1_16__Dim1_17__UNorm1_18__CPol1_19__R128A161_20__A161_21__TFE1_22__LWE1_23__D161_24, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V6_gfx11, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V7_gfx11, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V9_gfx11, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V6_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V7_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V9_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V7_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V9_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V6_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V7_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V9_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V7_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V9_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V7_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V9_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V6_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V7_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V8_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V9_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V6_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V7_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V8_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V9_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V7_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V8_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V9_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V6_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V7_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V8_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V9_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V7_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V8_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V9_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V7_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V8_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V9_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V6_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V7_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V8_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V9_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15247 /* image_sample_d_cl_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_CL_O_G16_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V6_gfx11, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V7_gfx11, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V6_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V7_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V7_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V6_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V7_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V7_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V7_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V2_gfx12, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V2_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V2_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V6_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V7_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V6_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V7_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V7_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V6_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V7_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V7_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V7_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V6_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V7_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15271 /* image_sample_d_g16 */, AMDGPU::IMAGE_SAMPLE_D_G16_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V9, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V9, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V9, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V9, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V9, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V6_gfx11, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V7_gfx11, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V9_gfx10, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V9_gfx11, Convert__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V10_gfx10, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V10_gfx11, Convert__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V6_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V7_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V9_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V9_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V10_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V10_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V7_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V9_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V9_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V10_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V10_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V6_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V7_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V9_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V9_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V10_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V10_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V7_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V9_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V9_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V10_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V10_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V7_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V9_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V9_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_288_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_288_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V10_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V10_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_320_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_320_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V6_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V7_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V8_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V9_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V10_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V6_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V7_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V8_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V9_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V10_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V7_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V8_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V9_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V10_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V6_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V7_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V8_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V9_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V10_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V7_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V8_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V9_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V10_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V7_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V8_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V9_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_192_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V10_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_224_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_224_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V6_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V7_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V8_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V9_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V10_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V9_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_160_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V10_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_192_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_192_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V9_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V9_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_12__Reg1_13__DMask1_14__Dim1_15__UNorm1_16__CPol1_17__R128A161_18__A161_19__TFE1_20__LWE1_21__D161_22, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_nortn_V10_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V1_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V2_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V3_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V4_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15290 /* image_sample_d_o */, AMDGPU::IMAGE_SAMPLE_D_O_V5_V10_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_10__Reg1_11__Reg1_13__Reg1_14__DMask1_15__Dim1_16__UNorm1_17__CPol1_18__R128A161_19__A161_20__TFE1_21__LWE1_22__D161_23, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V6, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V6, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V6, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V6, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V6, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V7, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V6_gfx10, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V6_gfx11, Convert__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V7_gfx10, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V7_gfx11, Convert__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V6_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V6_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V7_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V7_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V6_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V6_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V7_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V7_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V6_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V6_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V7_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V7_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V6_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V6_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V7_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V7_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V6_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V6_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V7_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V7_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_224_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_224_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V6_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V7_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V8_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V6_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V7_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V8_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V6_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V7_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V8_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V6_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V7_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V8_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V6_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V7_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V8_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V6_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_96_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V7_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_128_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V8_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_160_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_160_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V6_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V7_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V8_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V6_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_64_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V7_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_96_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_96_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V8_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__RegByHwMode_VReg_128_AlignTarget1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V6_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V6_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_9__Reg1_10__DMask1_11__Dim1_12__UNorm1_13__CPol1_14__R128A161_15__A161_16__TFE1_17__LWE1_18__D161_19, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V7_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V7_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_10__Reg1_11__DMask1_12__Dim1_13__UNorm1_14__CPol1_15__R128A161_16__A161_17__TFE1_18__LWE1_19__D161_20, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_nortn_V8_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V1_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V2_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V3_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V4_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15307 /* image_sample_d_o_g16 */, AMDGPU::IMAGE_SAMPLE_D_O_G16_V5_V8_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_7__Reg1_8__Reg1_9__Reg1_11__Reg1_12__DMask1_13__Dim1_14__UNorm1_15__CPol1_16__R128A161_17__A161_18__TFE1_19__LWE1_20__D161_21, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V1_V1, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V2_V1, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V3_V1, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V4_V1, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V5_V1, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_nortn_V1_gfx10, Convert__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_nortn_V1_gfx11, Convert__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_nortn_V1_gfx12, Convert__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_nortn_V2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_nortn_V2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_nortn_V2_gfx12, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_nortn_V2_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_nortn_V2_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15328 /* image_sample_l */, AMDGPU::IMAGE_SAMPLE_L_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V5, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V8, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V5, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V8, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V5, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V8, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V5, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V8, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V5, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V8, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_nortn_V2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_nortn_V2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_nortn_V5_gfx10, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_nortn_V5_gfx11, Convert__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_nortn_V8_gfx10, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_nortn_V8_gfx11, Convert__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V5_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V5_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V8_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V8_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V5_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V5_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V8_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V8_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V5_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V5_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V8_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V8_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V5_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V5_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V8_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V8_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V5_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V5_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_160_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_160_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V8_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V8_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_nortn_V2_gfx12, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_nortn_V2_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_nortn_V2_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_nortn_V5_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V5_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V5_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V5_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V5_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V5_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__RegByHwMode_VReg_64_AlignTarget1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_nortn_V5_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_nortn_V5_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V1_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V2_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V3_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V4_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V5_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15343 /* image_sample_l_o */, AMDGPU::IMAGE_SAMPLE_L_O_V5_V5_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_6__Reg1_8__Reg1_9__DMask1_10__Dim1_11__UNorm1_12__CPol1_13__R128A161_14__A161_15__TFE1_16__LWE1_17__D161_18, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V1_V1, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V2_V1, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V3_V1, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V4_V1, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V5_V1, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_nortn_V1_gfx10, Convert__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_nortn_V1_gfx11, Convert__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_nortn_V1_gfx12, Convert__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_nortn_V2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_nortn_V2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_nortn_V2_gfx12, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_nortn_V2_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_nortn_V2_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15360 /* image_sample_lz */, AMDGPU::IMAGE_SAMPLE_LZ_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_nortn_V2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_nortn_V2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_nortn_V2_gfx12, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_nortn_V2_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_nortn_V2_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15376 /* image_sample_lz_o */, AMDGPU::IMAGE_SAMPLE_LZ_O_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__UNorm1_5__CPol1_6__R128A161_7__TFE1_8__LWE1_9__DA1_10__D161_11, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_nortn_V2_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_nortn_V2_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_nortn_V3_gfx10, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_nortn_V3_gfx11, Convert__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_nortn_V4_gfx10, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_nortn_V4_gfx11, Convert__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__Reg1_2__Reg1_3__DMask1_4__Dim1_5__UNorm1_6__CPol1_7__R128A161_8__A161_9__TFE1_10__LWE1_11__D161_12, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_nortn_V2_gfx12, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_nortn_V2_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_nortn_V2_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_nortn_V3_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_nortn_V3_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_nortn_V3_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_nortn_V4_gfx12, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_nortn_V4_nsa_gfx10, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_nortn_V4_nsa_gfx11, Convert__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_off, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15394 /* image_sample_o */, AMDGPU::IMAGE_SAMPLE_O_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__Reg1_8__DMask1_9__Dim1_10__UNorm1_11__CPol1_12__R128A161_13__A161_14__TFE1_15__LWE1_16__D161_17, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V1, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V1, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V1, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V1, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V1, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15409 /* image_store */, AMDGPU::IMAGE_STORE_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8__D161_9, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8__D161_9, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V1, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V1, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V1, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V1, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V1, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9__D161_10, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10__D161_11, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11__D161_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__D161_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13__D161_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__D161_14, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14__D161_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15421 /* image_store_mip */, AMDGPU::IMAGE_STORE_MIP_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15__D161_16, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE, MCK_D16 }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V1, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V1, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V1, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V1, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V1, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15437 /* image_store_mip_pck */, AMDGPU::IMAGE_STORE_MIP_PCK_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V1_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_64_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V1_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_96_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V1_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_128_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V1_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V4_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_128_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V3_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_96_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V2_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VReg_64_Align2, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V1_gfx90a, Convert__RegByHwMode_AV_LdSt_160_Align21_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__LWE1_7__DA1_8, AMFBS_HasImageInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_160_Align2, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V1_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__CPol1_5__R128A161_6__A161_7__TFE1_8, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V4, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V3, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V2, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V1, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V4, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V3, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V2, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V1, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V4, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V3, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V2, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V1, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V4, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V3, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V2, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V1, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V4, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V3, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V2, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V1, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__UNorm1_4__CPol1_5__R128A161_6__TFE1_7__LWE1_8__DA1_9, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_TFE, MCK_LWE, MCK_DA }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V4_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V4_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V3_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V3_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V2_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V2_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V1_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V1_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V4_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V4_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V3_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V3_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V1_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V1_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V4_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V4_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V2_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V2_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V1_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V1_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V3_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V3_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V2_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V2_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V1_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V1_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V4_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V4_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_128, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V3_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V3_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_96, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V2_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V2_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VReg_64, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V1_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V1_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_1__Reg1_2__DMask1_3__Dim1_4__UNorm1_5__CPol1_6__R128A161_7__A161_8__TFE1_9__LWE1_10, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK_VGPR_32, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V2_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V2_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V2_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V2_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__CPol1_8__R128A161_9__A161_10__TFE1_11, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V3_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V3_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V3_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V3_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__CPol1_9__R128A161_10__A161_11__TFE1_12, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V4_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V4_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V4_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V2_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V2_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_5__DMask1_6__Dim1_7__UNorm1_8__CPol1_9__R128A161_10__A161_11__TFE1_12__LWE1_13, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V4_gfx12, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__CPol1_10__R128A161_11__A161_12__TFE1_13, AMFBS_HasImageInsts_isGFX12Plus, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V3_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V3_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_6__DMask1_7__Dim1_8__UNorm1_9__CPol1_10__R128A161_11__A161_12__TFE1_13__LWE1_14, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V1_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V2_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V3_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V4_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V4_nsa_gfx10, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15457 /* image_store_pck */, AMDGPU::IMAGE_STORE_PCK_V5_V4_nsa_gfx11, Convert__RegByHwMode_AV_LdSt_160_AlignTarget1_0__Reg1_2__Reg1_3__Reg1_4__Reg1_5__Reg1_7__DMask1_8__Dim1_9__UNorm1_10__CPol1_11__R128A161_12__A161_13__TFE1_14__LWE1_15, AMFBS_HasImageInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_160_AlignTarget, MCK__91_, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK__93_, MCK_SReg_256_XNULL, MCK_DMask, MCK_Dim, MCK_UNorm, MCK_CPol, MCK_R128A16, MCK_A16, MCK_TFE, MCK_LWE }, },
  { 15473 /* lds_direct_load */, AMDGPU::LDS_DIRECT_LOAD_gfx11, Convert__Reg1_0__WaitVDST1_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_WaitVDST }, },
  { 15489 /* lds_param_load */, AMDGPU::LDS_PARAM_LOAD_gfx11, Convert__Reg1_0__InterpAttr1_1__InterpAttrChan1_2__WaitVDST1_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_InterpAttr, MCK_InterpAttrChan, MCK_WaitVDST }, },
  { 15504 /* s_abs_i32 */, AMDGPU::S_ABS_I32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 15504 /* s_abs_i32 */, AMDGPU::S_ABS_I32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 15504 /* s_abs_i32 */, AMDGPU::S_ABS_I32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 15504 /* s_abs_i32 */, AMDGPU::S_ABS_I32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 15504 /* s_abs_i32 */, AMDGPU::S_ABS_I32_vi, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 15514 /* s_absdiff_i32 */, AMDGPU::S_ABSDIFF_I32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15514 /* s_absdiff_i32 */, AMDGPU::S_ABSDIFF_I32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15514 /* s_absdiff_i32 */, AMDGPU::S_ABSDIFF_I32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15514 /* s_absdiff_i32 */, AMDGPU::S_ABSDIFF_I32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15514 /* s_absdiff_i32 */, AMDGPU::S_ABSDIFF_I32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15528 /* s_add_co_ci_u32 */, AMDGPU::S_ADDC_U32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15544 /* s_add_co_i32 */, AMDGPU::S_ADD_I32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15557 /* s_add_co_u32 */, AMDGPU::S_ADD_U32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15570 /* s_add_f16 */, AMDGPU::S_ADD_F16_gfx11, Convert__Reg1_0__SSrc_f161_1__SSrc_f161_2, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_f16, MCK_SSrc_f16 }, },
  { 15570 /* s_add_f16 */, AMDGPU::S_ADD_F16_gfx12, Convert__Reg1_0__SSrc_f161_1__SSrc_f161_2, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_f16, MCK_SSrc_f16 }, },
  { 15580 /* s_add_f32 */, AMDGPU::S_ADD_F32_gfx11, Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_f32, MCK_SSrc_f32 }, },
  { 15580 /* s_add_f32 */, AMDGPU::S_ADD_F32_gfx12, Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_f32, MCK_SSrc_f32 }, },
  { 15590 /* s_add_i32 */, AMDGPU::S_ADD_I32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15590 /* s_add_i32 */, AMDGPU::S_ADD_I32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15590 /* s_add_i32 */, AMDGPU::S_ADD_I32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15590 /* s_add_i32 */, AMDGPU::S_ADD_I32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15600 /* s_add_nc_u64 */, AMDGPU::S_ADD_U64_gfx12, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX12Plus_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 15613 /* s_add_pc_i64 */, AMDGPU::S_ADD_PC_I64_gfx12, Convert__SSrc_b641_0, AMFBS_HasAddPC64Inst_isGFX12Only, { MCK_SSrc_b64 }, },
  { 15626 /* s_add_u32 */, AMDGPU::S_ADD_U32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15626 /* s_add_u32 */, AMDGPU::S_ADD_U32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15626 /* s_add_u32 */, AMDGPU::S_ADD_U32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15626 /* s_add_u32 */, AMDGPU::S_ADD_U32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15636 /* s_addc_u32 */, AMDGPU::S_ADDC_U32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15636 /* s_addc_u32 */, AMDGPU::S_ADDC_U32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15636 /* s_addc_u32 */, AMDGPU::S_ADDC_U32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15636 /* s_addc_u32 */, AMDGPU::S_ADDC_U32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15647 /* s_addk_co_i32 */, AMDGPU::S_ADDK_I32_gfx12, Convert__Reg1_0__Tie0_1_1__S16Imm1_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 15661 /* s_addk_i32 */, AMDGPU::S_ADDK_I32_gfx10, Convert__Reg1_0__Tie0_1_1__S16Imm1_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 15661 /* s_addk_i32 */, AMDGPU::S_ADDK_I32_gfx11, Convert__Reg1_0__Tie0_1_1__S16Imm1_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 15661 /* s_addk_i32 */, AMDGPU::S_ADDK_I32_gfx6_gfx7, Convert__Reg1_0__Tie0_1_1__S16Imm1_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_S16Imm }, },
  { 15661 /* s_addk_i32 */, AMDGPU::S_ADDK_I32_vi, Convert__Reg1_0__Tie0_1_1__S16Imm1_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_S16Imm }, },
  { 15672 /* s_alloc_vgpr */, AMDGPU::S_ALLOC_VGPR_gfx12, Convert__SSrc_b321_0, AMFBS_isGFX12Plus_isGFX12Only, { MCK_SSrc_b32 }, },
  { 15685 /* s_and_b32 */, AMDGPU::S_AND_B32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15685 /* s_and_b32 */, AMDGPU::S_AND_B32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15685 /* s_and_b32 */, AMDGPU::S_AND_B32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15685 /* s_and_b32 */, AMDGPU::S_AND_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15685 /* s_and_b32 */, AMDGPU::S_AND_B32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15695 /* s_and_b64 */, AMDGPU::S_AND_B64_gfx10, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 15695 /* s_and_b64 */, AMDGPU::S_AND_B64_gfx11, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 15695 /* s_and_b64 */, AMDGPU::S_AND_B64_gfx12, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 15695 /* s_and_b64 */, AMDGPU::S_AND_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 15695 /* s_and_b64 */, AMDGPU::S_AND_B64_vi, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 15705 /* s_and_not0_saveexec_b32 */, AMDGPU::S_ANDN1_SAVEEXEC_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 15705 /* s_and_not0_saveexec_b32 */, AMDGPU::S_ANDN1_SAVEEXEC_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 15729 /* s_and_not0_saveexec_b64 */, AMDGPU::S_ANDN1_SAVEEXEC_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX9Plus_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 15729 /* s_and_not0_saveexec_b64 */, AMDGPU::S_ANDN1_SAVEEXEC_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX9Plus_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 15753 /* s_and_not0_wrexec_b32 */, AMDGPU::S_ANDN1_WREXEC_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 15753 /* s_and_not0_wrexec_b32 */, AMDGPU::S_ANDN1_WREXEC_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 15775 /* s_and_not0_wrexec_b64 */, AMDGPU::S_ANDN1_WREXEC_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX9Plus_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 15775 /* s_and_not0_wrexec_b64 */, AMDGPU::S_ANDN1_WREXEC_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX9Plus_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 15797 /* s_and_not1_b32 */, AMDGPU::S_ANDN2_B32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15797 /* s_and_not1_b32 */, AMDGPU::S_ANDN2_B32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 15812 /* s_and_not1_b64 */, AMDGPU::S_ANDN2_B64_gfx11, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 15812 /* s_and_not1_b64 */, AMDGPU::S_ANDN2_B64_gfx12, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 15827 /* s_and_not1_saveexec_b32 */, AMDGPU::S_ANDN2_SAVEEXEC_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 15827 /* s_and_not1_saveexec_b32 */, AMDGPU::S_ANDN2_SAVEEXEC_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 15851 /* s_and_not1_saveexec_b64 */, AMDGPU::S_ANDN2_SAVEEXEC_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 15851 /* s_and_not1_saveexec_b64 */, AMDGPU::S_ANDN2_SAVEEXEC_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 15875 /* s_and_not1_wrexec_b32 */, AMDGPU::S_ANDN2_WREXEC_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 15875 /* s_and_not1_wrexec_b32 */, AMDGPU::S_ANDN2_WREXEC_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 15897 /* s_and_not1_wrexec_b64 */, AMDGPU::S_ANDN2_WREXEC_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX9Plus_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 15897 /* s_and_not1_wrexec_b64 */, AMDGPU::S_ANDN2_WREXEC_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX9Plus_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 15919 /* s_and_saveexec_b32 */, AMDGPU::S_AND_SAVEEXEC_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 15919 /* s_and_saveexec_b32 */, AMDGPU::S_AND_SAVEEXEC_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 15919 /* s_and_saveexec_b32 */, AMDGPU::S_AND_SAVEEXEC_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 15938 /* s_and_saveexec_b64 */, AMDGPU::S_AND_SAVEEXEC_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 15938 /* s_and_saveexec_b64 */, AMDGPU::S_AND_SAVEEXEC_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 15938 /* s_and_saveexec_b64 */, AMDGPU::S_AND_SAVEEXEC_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 15938 /* s_and_saveexec_b64 */, AMDGPU::S_AND_SAVEEXEC_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 15938 /* s_and_saveexec_b64 */, AMDGPU::S_AND_SAVEEXEC_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 15957 /* s_andn1_saveexec_b32 */, AMDGPU::S_ANDN1_SAVEEXEC_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 15978 /* s_andn1_saveexec_b64 */, AMDGPU::S_ANDN1_SAVEEXEC_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX9Plus_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 15978 /* s_andn1_saveexec_b64 */, AMDGPU::S_ANDN1_SAVEEXEC_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 15999 /* s_andn1_wrexec_b32 */, AMDGPU::S_ANDN1_WREXEC_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16018 /* s_andn1_wrexec_b64 */, AMDGPU::S_ANDN1_WREXEC_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX9Plus_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 16018 /* s_andn1_wrexec_b64 */, AMDGPU::S_ANDN1_WREXEC_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 16037 /* s_andn2_b32 */, AMDGPU::S_ANDN2_B32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16037 /* s_andn2_b32 */, AMDGPU::S_ANDN2_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16037 /* s_andn2_b32 */, AMDGPU::S_ANDN2_B32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16049 /* s_andn2_b64 */, AMDGPU::S_ANDN2_B64_gfx10, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 16049 /* s_andn2_b64 */, AMDGPU::S_ANDN2_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 16049 /* s_andn2_b64 */, AMDGPU::S_ANDN2_B64_vi, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 16061 /* s_andn2_saveexec_b32 */, AMDGPU::S_ANDN2_SAVEEXEC_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16082 /* s_andn2_saveexec_b64 */, AMDGPU::S_ANDN2_SAVEEXEC_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 16082 /* s_andn2_saveexec_b64 */, AMDGPU::S_ANDN2_SAVEEXEC_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 16082 /* s_andn2_saveexec_b64 */, AMDGPU::S_ANDN2_SAVEEXEC_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 16103 /* s_andn2_wrexec_b32 */, AMDGPU::S_ANDN2_WREXEC_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16122 /* s_andn2_wrexec_b64 */, AMDGPU::S_ANDN2_WREXEC_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX9Plus_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 16122 /* s_andn2_wrexec_b64 */, AMDGPU::S_ANDN2_WREXEC_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 16141 /* s_ashr_i32 */, AMDGPU::S_ASHR_I32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16141 /* s_ashr_i32 */, AMDGPU::S_ASHR_I32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16141 /* s_ashr_i32 */, AMDGPU::S_ASHR_I32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16141 /* s_ashr_i32 */, AMDGPU::S_ASHR_I32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16141 /* s_ashr_i32 */, AMDGPU::S_ASHR_I32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16152 /* s_ashr_i64 */, AMDGPU::S_ASHR_I64_gfx10, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16152 /* s_ashr_i64 */, AMDGPU::S_ASHR_I64_gfx11, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16152 /* s_ashr_i64 */, AMDGPU::S_ASHR_I64_gfx12, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16152 /* s_ashr_i64 */, AMDGPU::S_ASHR_I64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16152 /* s_ashr_i64 */, AMDGPU::S_ASHR_I64_vi, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16163 /* s_atc_probe */, AMDGPU::S_ATC_PROBE_SGPR_gfx10, Convert__Imm1_0__Reg1_1__Reg1_2, AMFBS_isGFX8Plus_isGFX10Only, { MCK_Imm, MCK_SReg_64, MCK_SReg_32 }, },
  { 16163 /* s_atc_probe */, AMDGPU::S_ATC_PROBE_SGPR_gfx11, Convert__Imm1_0__Reg1_1__Reg1_2, AMFBS_isGFX8Plus_isGFX11Only, { MCK_Imm, MCK_SReg_64, MCK_SReg_32 }, },
  { 16163 /* s_atc_probe */, AMDGPU::S_ATC_PROBE_SGPR_vi, Convert__Imm1_0__Reg1_1__Reg1_2, AMFBS_isGFX8Plus_isGFX8GFX9, { MCK_Imm, MCK_SReg_64, MCK_SReg_32 }, },
  { 16163 /* s_atc_probe */, AMDGPU::S_ATC_PROBE_IMM_gfx10, Convert__Imm1_0__Reg1_1__SMEMOffset1_2, AMFBS_isGFX8Plus_isGFX10Only, { MCK_Imm, MCK_SReg_64, MCK_SMEMOffset }, },
  { 16163 /* s_atc_probe */, AMDGPU::S_ATC_PROBE_IMM_gfx11, Convert__Imm1_0__Reg1_1__SMEMOffset1_2, AMFBS_isGFX8Plus_isGFX11Only, { MCK_Imm, MCK_SReg_64, MCK_SMEMOffset }, },
  { 16163 /* s_atc_probe */, AMDGPU::S_ATC_PROBE_IMM_gfx12, Convert__Imm1_0__Reg1_1__SMEMOffset1_2, AMFBS_isGFX8Plus_isGFX12Plus, { MCK_Imm, MCK_SReg_64, MCK_SMEMOffset }, },
  { 16163 /* s_atc_probe */, AMDGPU::S_ATC_PROBE_IMM_vi, Convert__Imm1_0__Reg1_1__SMEMOffset1_2, AMFBS_isGFX8Plus_isGFX8GFX9, { MCK_Imm, MCK_SReg_64, MCK_SMEMOffset }, },
  { 16163 /* s_atc_probe */, AMDGPU::S_ATC_PROBE_SGPR_IMM_gfx10, Convert__Imm1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3, AMFBS_isGFX8Plus_isGFX10Only, { MCK_Imm, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod }, },
  { 16163 /* s_atc_probe */, AMDGPU::S_ATC_PROBE_SGPR_IMM_gfx11, Convert__Imm1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3, AMFBS_isGFX8Plus_isGFX11Only, { MCK_Imm, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod }, },
  { 16163 /* s_atc_probe */, AMDGPU::S_ATC_PROBE_SGPR_IMM_gfx9, Convert__Imm1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3, AMFBS_isGFX8Plus_isGFX9Only, { MCK_Imm, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod }, },
  { 16163 /* s_atc_probe */, AMDGPU::S_ATC_PROBE_SGPR_IMM_gfx12, Convert__Imm1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3, AMFBS_isGFX8Plus_isGFX12Plus, { MCK_Imm, MCK_SReg_64, MCK_SReg_32, MCK_OptSMEMOffsetMod }, },
  { 16175 /* s_atc_probe_buffer */, AMDGPU::S_ATC_PROBE_BUFFER_SGPR_gfx10, Convert__Imm1_0__Reg1_1__Reg1_2, AMFBS_isGFX8Plus_isGFX10Only, { MCK_Imm, MCK_SReg_128_XNULL, MCK_SReg_32 }, },
  { 16175 /* s_atc_probe_buffer */, AMDGPU::S_ATC_PROBE_BUFFER_SGPR_gfx11, Convert__Imm1_0__Reg1_1__Reg1_2, AMFBS_isGFX8Plus_isGFX11Only, { MCK_Imm, MCK_SReg_128_XNULL, MCK_SReg_32 }, },
  { 16175 /* s_atc_probe_buffer */, AMDGPU::S_ATC_PROBE_BUFFER_SGPR_vi, Convert__Imm1_0__Reg1_1__Reg1_2, AMFBS_isGFX8Plus_isGFX8GFX9, { MCK_Imm, MCK_SReg_128_XNULL, MCK_SReg_32 }, },
  { 16175 /* s_atc_probe_buffer */, AMDGPU::S_ATC_PROBE_BUFFER_IMM_gfx10, Convert__Imm1_0__Reg1_1__SMEMOffset1_2, AMFBS_isGFX8Plus_isGFX10Only, { MCK_Imm, MCK_SReg_128_XNULL, MCK_SMEMOffset }, },
  { 16175 /* s_atc_probe_buffer */, AMDGPU::S_ATC_PROBE_BUFFER_IMM_gfx11, Convert__Imm1_0__Reg1_1__SMEMOffset1_2, AMFBS_isGFX8Plus_isGFX11Only, { MCK_Imm, MCK_SReg_128_XNULL, MCK_SMEMOffset }, },
  { 16175 /* s_atc_probe_buffer */, AMDGPU::S_ATC_PROBE_BUFFER_IMM_gfx12, Convert__Imm1_0__Reg1_1__SMEMOffset1_2, AMFBS_isGFX8Plus_isGFX12Plus, { MCK_Imm, MCK_SReg_128_XNULL, MCK_SMEMOffset }, },
  { 16175 /* s_atc_probe_buffer */, AMDGPU::S_ATC_PROBE_BUFFER_IMM_vi, Convert__Imm1_0__Reg1_1__SMEMOffset1_2, AMFBS_isGFX8Plus_isGFX8GFX9, { MCK_Imm, MCK_SReg_128_XNULL, MCK_SMEMOffset }, },
  { 16175 /* s_atc_probe_buffer */, AMDGPU::S_ATC_PROBE_BUFFER_SGPR_IMM_gfx10, Convert__Imm1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3, AMFBS_isGFX8Plus_isGFX10Only, { MCK_Imm, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod }, },
  { 16175 /* s_atc_probe_buffer */, AMDGPU::S_ATC_PROBE_BUFFER_SGPR_IMM_gfx11, Convert__Imm1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3, AMFBS_isGFX8Plus_isGFX11Only, { MCK_Imm, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod }, },
  { 16175 /* s_atc_probe_buffer */, AMDGPU::S_ATC_PROBE_BUFFER_SGPR_IMM_gfx9, Convert__Imm1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3, AMFBS_isGFX8Plus_isGFX9Only, { MCK_Imm, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod }, },
  { 16175 /* s_atc_probe_buffer */, AMDGPU::S_ATC_PROBE_BUFFER_SGPR_IMM_gfx12, Convert__Imm1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3, AMFBS_isGFX8Plus_isGFX12Plus, { MCK_Imm, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_OptSMEMOffsetMod }, },
  { 16194 /* s_atomic_add */, AMDGPU::S_ATOMIC_ADD_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16194 /* s_atomic_add */, AMDGPU::S_ATOMIC_ADD_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16194 /* s_atomic_add */, AMDGPU::S_ATOMIC_ADD_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16194 /* s_atomic_add */, AMDGPU::S_ATOMIC_ADD_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16194 /* s_atomic_add */, AMDGPU::S_ATOMIC_ADD_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16194 /* s_atomic_add */, AMDGPU::S_ATOMIC_ADD_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16194 /* s_atomic_add */, AMDGPU::S_ATOMIC_ADD_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16194 /* s_atomic_add */, AMDGPU::S_ATOMIC_ADD_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16194 /* s_atomic_add */, AMDGPU::S_ATOMIC_ADD_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16194 /* s_atomic_add */, AMDGPU::S_ATOMIC_ADD_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16194 /* s_atomic_add */, AMDGPU::S_ATOMIC_ADD_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16194 /* s_atomic_add */, AMDGPU::S_ATOMIC_ADD_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16207 /* s_atomic_add_x2 */, AMDGPU::S_ATOMIC_ADD_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16207 /* s_atomic_add_x2 */, AMDGPU::S_ATOMIC_ADD_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16207 /* s_atomic_add_x2 */, AMDGPU::S_ATOMIC_ADD_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16207 /* s_atomic_add_x2 */, AMDGPU::S_ATOMIC_ADD_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16207 /* s_atomic_add_x2 */, AMDGPU::S_ATOMIC_ADD_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16207 /* s_atomic_add_x2 */, AMDGPU::S_ATOMIC_ADD_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16207 /* s_atomic_add_x2 */, AMDGPU::S_ATOMIC_ADD_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16207 /* s_atomic_add_x2 */, AMDGPU::S_ATOMIC_ADD_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16207 /* s_atomic_add_x2 */, AMDGPU::S_ATOMIC_ADD_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16207 /* s_atomic_add_x2 */, AMDGPU::S_ATOMIC_ADD_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16207 /* s_atomic_add_x2 */, AMDGPU::S_ATOMIC_ADD_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16207 /* s_atomic_add_x2 */, AMDGPU::S_ATOMIC_ADD_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16223 /* s_atomic_and */, AMDGPU::S_ATOMIC_AND_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16223 /* s_atomic_and */, AMDGPU::S_ATOMIC_AND_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16223 /* s_atomic_and */, AMDGPU::S_ATOMIC_AND_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16223 /* s_atomic_and */, AMDGPU::S_ATOMIC_AND_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16223 /* s_atomic_and */, AMDGPU::S_ATOMIC_AND_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16223 /* s_atomic_and */, AMDGPU::S_ATOMIC_AND_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16223 /* s_atomic_and */, AMDGPU::S_ATOMIC_AND_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16223 /* s_atomic_and */, AMDGPU::S_ATOMIC_AND_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16223 /* s_atomic_and */, AMDGPU::S_ATOMIC_AND_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16223 /* s_atomic_and */, AMDGPU::S_ATOMIC_AND_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16223 /* s_atomic_and */, AMDGPU::S_ATOMIC_AND_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16223 /* s_atomic_and */, AMDGPU::S_ATOMIC_AND_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16236 /* s_atomic_and_x2 */, AMDGPU::S_ATOMIC_AND_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16236 /* s_atomic_and_x2 */, AMDGPU::S_ATOMIC_AND_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16236 /* s_atomic_and_x2 */, AMDGPU::S_ATOMIC_AND_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16236 /* s_atomic_and_x2 */, AMDGPU::S_ATOMIC_AND_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16236 /* s_atomic_and_x2 */, AMDGPU::S_ATOMIC_AND_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16236 /* s_atomic_and_x2 */, AMDGPU::S_ATOMIC_AND_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16236 /* s_atomic_and_x2 */, AMDGPU::S_ATOMIC_AND_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16236 /* s_atomic_and_x2 */, AMDGPU::S_ATOMIC_AND_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16236 /* s_atomic_and_x2 */, AMDGPU::S_ATOMIC_AND_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16236 /* s_atomic_and_x2 */, AMDGPU::S_ATOMIC_AND_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16236 /* s_atomic_and_x2 */, AMDGPU::S_ATOMIC_AND_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16236 /* s_atomic_and_x2 */, AMDGPU::S_ATOMIC_AND_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16252 /* s_atomic_cmpswap */, AMDGPU::S_ATOMIC_CMPSWAP_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16252 /* s_atomic_cmpswap */, AMDGPU::S_ATOMIC_CMPSWAP_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16252 /* s_atomic_cmpswap */, AMDGPU::S_ATOMIC_CMPSWAP_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16252 /* s_atomic_cmpswap */, AMDGPU::S_ATOMIC_CMPSWAP_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16252 /* s_atomic_cmpswap */, AMDGPU::S_ATOMIC_CMPSWAP_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16252 /* s_atomic_cmpswap */, AMDGPU::S_ATOMIC_CMPSWAP_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16252 /* s_atomic_cmpswap */, AMDGPU::S_ATOMIC_CMPSWAP_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16252 /* s_atomic_cmpswap */, AMDGPU::S_ATOMIC_CMPSWAP_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16252 /* s_atomic_cmpswap */, AMDGPU::S_ATOMIC_CMPSWAP_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16252 /* s_atomic_cmpswap */, AMDGPU::S_ATOMIC_CMPSWAP_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16252 /* s_atomic_cmpswap */, AMDGPU::S_ATOMIC_CMPSWAP_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16252 /* s_atomic_cmpswap */, AMDGPU::S_ATOMIC_CMPSWAP_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16269 /* s_atomic_cmpswap_x2 */, AMDGPU::S_ATOMIC_CMPSWAP_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16269 /* s_atomic_cmpswap_x2 */, AMDGPU::S_ATOMIC_CMPSWAP_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16269 /* s_atomic_cmpswap_x2 */, AMDGPU::S_ATOMIC_CMPSWAP_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16269 /* s_atomic_cmpswap_x2 */, AMDGPU::S_ATOMIC_CMPSWAP_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16269 /* s_atomic_cmpswap_x2 */, AMDGPU::S_ATOMIC_CMPSWAP_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_128, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16269 /* s_atomic_cmpswap_x2 */, AMDGPU::S_ATOMIC_CMPSWAP_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_128, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16269 /* s_atomic_cmpswap_x2 */, AMDGPU::S_ATOMIC_CMPSWAP_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_128, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16269 /* s_atomic_cmpswap_x2 */, AMDGPU::S_ATOMIC_CMPSWAP_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_128, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16269 /* s_atomic_cmpswap_x2 */, AMDGPU::S_ATOMIC_CMPSWAP_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16269 /* s_atomic_cmpswap_x2 */, AMDGPU::S_ATOMIC_CMPSWAP_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16269 /* s_atomic_cmpswap_x2 */, AMDGPU::S_ATOMIC_CMPSWAP_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16269 /* s_atomic_cmpswap_x2 */, AMDGPU::S_ATOMIC_CMPSWAP_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16289 /* s_atomic_dec */, AMDGPU::S_ATOMIC_DEC_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16289 /* s_atomic_dec */, AMDGPU::S_ATOMIC_DEC_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16289 /* s_atomic_dec */, AMDGPU::S_ATOMIC_DEC_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16289 /* s_atomic_dec */, AMDGPU::S_ATOMIC_DEC_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16289 /* s_atomic_dec */, AMDGPU::S_ATOMIC_DEC_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16289 /* s_atomic_dec */, AMDGPU::S_ATOMIC_DEC_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16289 /* s_atomic_dec */, AMDGPU::S_ATOMIC_DEC_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16289 /* s_atomic_dec */, AMDGPU::S_ATOMIC_DEC_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16289 /* s_atomic_dec */, AMDGPU::S_ATOMIC_DEC_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16289 /* s_atomic_dec */, AMDGPU::S_ATOMIC_DEC_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16289 /* s_atomic_dec */, AMDGPU::S_ATOMIC_DEC_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16289 /* s_atomic_dec */, AMDGPU::S_ATOMIC_DEC_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16302 /* s_atomic_dec_x2 */, AMDGPU::S_ATOMIC_DEC_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16302 /* s_atomic_dec_x2 */, AMDGPU::S_ATOMIC_DEC_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16302 /* s_atomic_dec_x2 */, AMDGPU::S_ATOMIC_DEC_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16302 /* s_atomic_dec_x2 */, AMDGPU::S_ATOMIC_DEC_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16302 /* s_atomic_dec_x2 */, AMDGPU::S_ATOMIC_DEC_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16302 /* s_atomic_dec_x2 */, AMDGPU::S_ATOMIC_DEC_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16302 /* s_atomic_dec_x2 */, AMDGPU::S_ATOMIC_DEC_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16302 /* s_atomic_dec_x2 */, AMDGPU::S_ATOMIC_DEC_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16302 /* s_atomic_dec_x2 */, AMDGPU::S_ATOMIC_DEC_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16302 /* s_atomic_dec_x2 */, AMDGPU::S_ATOMIC_DEC_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16302 /* s_atomic_dec_x2 */, AMDGPU::S_ATOMIC_DEC_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16302 /* s_atomic_dec_x2 */, AMDGPU::S_ATOMIC_DEC_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16318 /* s_atomic_inc */, AMDGPU::S_ATOMIC_INC_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16318 /* s_atomic_inc */, AMDGPU::S_ATOMIC_INC_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16318 /* s_atomic_inc */, AMDGPU::S_ATOMIC_INC_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16318 /* s_atomic_inc */, AMDGPU::S_ATOMIC_INC_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16318 /* s_atomic_inc */, AMDGPU::S_ATOMIC_INC_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16318 /* s_atomic_inc */, AMDGPU::S_ATOMIC_INC_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16318 /* s_atomic_inc */, AMDGPU::S_ATOMIC_INC_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16318 /* s_atomic_inc */, AMDGPU::S_ATOMIC_INC_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16318 /* s_atomic_inc */, AMDGPU::S_ATOMIC_INC_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16318 /* s_atomic_inc */, AMDGPU::S_ATOMIC_INC_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16318 /* s_atomic_inc */, AMDGPU::S_ATOMIC_INC_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16318 /* s_atomic_inc */, AMDGPU::S_ATOMIC_INC_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16331 /* s_atomic_inc_x2 */, AMDGPU::S_ATOMIC_INC_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16331 /* s_atomic_inc_x2 */, AMDGPU::S_ATOMIC_INC_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16331 /* s_atomic_inc_x2 */, AMDGPU::S_ATOMIC_INC_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16331 /* s_atomic_inc_x2 */, AMDGPU::S_ATOMIC_INC_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16331 /* s_atomic_inc_x2 */, AMDGPU::S_ATOMIC_INC_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16331 /* s_atomic_inc_x2 */, AMDGPU::S_ATOMIC_INC_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16331 /* s_atomic_inc_x2 */, AMDGPU::S_ATOMIC_INC_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16331 /* s_atomic_inc_x2 */, AMDGPU::S_ATOMIC_INC_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16331 /* s_atomic_inc_x2 */, AMDGPU::S_ATOMIC_INC_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16331 /* s_atomic_inc_x2 */, AMDGPU::S_ATOMIC_INC_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16331 /* s_atomic_inc_x2 */, AMDGPU::S_ATOMIC_INC_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16331 /* s_atomic_inc_x2 */, AMDGPU::S_ATOMIC_INC_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16347 /* s_atomic_or */, AMDGPU::S_ATOMIC_OR_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16347 /* s_atomic_or */, AMDGPU::S_ATOMIC_OR_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16347 /* s_atomic_or */, AMDGPU::S_ATOMIC_OR_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16347 /* s_atomic_or */, AMDGPU::S_ATOMIC_OR_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16347 /* s_atomic_or */, AMDGPU::S_ATOMIC_OR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16347 /* s_atomic_or */, AMDGPU::S_ATOMIC_OR_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16347 /* s_atomic_or */, AMDGPU::S_ATOMIC_OR_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16347 /* s_atomic_or */, AMDGPU::S_ATOMIC_OR_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16347 /* s_atomic_or */, AMDGPU::S_ATOMIC_OR_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16347 /* s_atomic_or */, AMDGPU::S_ATOMIC_OR_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16347 /* s_atomic_or */, AMDGPU::S_ATOMIC_OR_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16347 /* s_atomic_or */, AMDGPU::S_ATOMIC_OR_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16359 /* s_atomic_or_x2 */, AMDGPU::S_ATOMIC_OR_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16359 /* s_atomic_or_x2 */, AMDGPU::S_ATOMIC_OR_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16359 /* s_atomic_or_x2 */, AMDGPU::S_ATOMIC_OR_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16359 /* s_atomic_or_x2 */, AMDGPU::S_ATOMIC_OR_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16359 /* s_atomic_or_x2 */, AMDGPU::S_ATOMIC_OR_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16359 /* s_atomic_or_x2 */, AMDGPU::S_ATOMIC_OR_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16359 /* s_atomic_or_x2 */, AMDGPU::S_ATOMIC_OR_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16359 /* s_atomic_or_x2 */, AMDGPU::S_ATOMIC_OR_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16359 /* s_atomic_or_x2 */, AMDGPU::S_ATOMIC_OR_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16359 /* s_atomic_or_x2 */, AMDGPU::S_ATOMIC_OR_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16359 /* s_atomic_or_x2 */, AMDGPU::S_ATOMIC_OR_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16359 /* s_atomic_or_x2 */, AMDGPU::S_ATOMIC_OR_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16374 /* s_atomic_smax */, AMDGPU::S_ATOMIC_SMAX_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16374 /* s_atomic_smax */, AMDGPU::S_ATOMIC_SMAX_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16374 /* s_atomic_smax */, AMDGPU::S_ATOMIC_SMAX_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16374 /* s_atomic_smax */, AMDGPU::S_ATOMIC_SMAX_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16374 /* s_atomic_smax */, AMDGPU::S_ATOMIC_SMAX_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16374 /* s_atomic_smax */, AMDGPU::S_ATOMIC_SMAX_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16374 /* s_atomic_smax */, AMDGPU::S_ATOMIC_SMAX_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16374 /* s_atomic_smax */, AMDGPU::S_ATOMIC_SMAX_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16374 /* s_atomic_smax */, AMDGPU::S_ATOMIC_SMAX_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16374 /* s_atomic_smax */, AMDGPU::S_ATOMIC_SMAX_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16374 /* s_atomic_smax */, AMDGPU::S_ATOMIC_SMAX_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16374 /* s_atomic_smax */, AMDGPU::S_ATOMIC_SMAX_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16388 /* s_atomic_smax_x2 */, AMDGPU::S_ATOMIC_SMAX_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16388 /* s_atomic_smax_x2 */, AMDGPU::S_ATOMIC_SMAX_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16388 /* s_atomic_smax_x2 */, AMDGPU::S_ATOMIC_SMAX_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16388 /* s_atomic_smax_x2 */, AMDGPU::S_ATOMIC_SMAX_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16388 /* s_atomic_smax_x2 */, AMDGPU::S_ATOMIC_SMAX_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16388 /* s_atomic_smax_x2 */, AMDGPU::S_ATOMIC_SMAX_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16388 /* s_atomic_smax_x2 */, AMDGPU::S_ATOMIC_SMAX_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16388 /* s_atomic_smax_x2 */, AMDGPU::S_ATOMIC_SMAX_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16388 /* s_atomic_smax_x2 */, AMDGPU::S_ATOMIC_SMAX_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16388 /* s_atomic_smax_x2 */, AMDGPU::S_ATOMIC_SMAX_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16388 /* s_atomic_smax_x2 */, AMDGPU::S_ATOMIC_SMAX_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16388 /* s_atomic_smax_x2 */, AMDGPU::S_ATOMIC_SMAX_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16405 /* s_atomic_smin */, AMDGPU::S_ATOMIC_SMIN_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16405 /* s_atomic_smin */, AMDGPU::S_ATOMIC_SMIN_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16405 /* s_atomic_smin */, AMDGPU::S_ATOMIC_SMIN_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16405 /* s_atomic_smin */, AMDGPU::S_ATOMIC_SMIN_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16405 /* s_atomic_smin */, AMDGPU::S_ATOMIC_SMIN_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16405 /* s_atomic_smin */, AMDGPU::S_ATOMIC_SMIN_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16405 /* s_atomic_smin */, AMDGPU::S_ATOMIC_SMIN_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16405 /* s_atomic_smin */, AMDGPU::S_ATOMIC_SMIN_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16405 /* s_atomic_smin */, AMDGPU::S_ATOMIC_SMIN_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16405 /* s_atomic_smin */, AMDGPU::S_ATOMIC_SMIN_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16405 /* s_atomic_smin */, AMDGPU::S_ATOMIC_SMIN_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16405 /* s_atomic_smin */, AMDGPU::S_ATOMIC_SMIN_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16419 /* s_atomic_smin_x2 */, AMDGPU::S_ATOMIC_SMIN_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16419 /* s_atomic_smin_x2 */, AMDGPU::S_ATOMIC_SMIN_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16419 /* s_atomic_smin_x2 */, AMDGPU::S_ATOMIC_SMIN_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16419 /* s_atomic_smin_x2 */, AMDGPU::S_ATOMIC_SMIN_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16419 /* s_atomic_smin_x2 */, AMDGPU::S_ATOMIC_SMIN_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16419 /* s_atomic_smin_x2 */, AMDGPU::S_ATOMIC_SMIN_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16419 /* s_atomic_smin_x2 */, AMDGPU::S_ATOMIC_SMIN_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16419 /* s_atomic_smin_x2 */, AMDGPU::S_ATOMIC_SMIN_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16419 /* s_atomic_smin_x2 */, AMDGPU::S_ATOMIC_SMIN_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16419 /* s_atomic_smin_x2 */, AMDGPU::S_ATOMIC_SMIN_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16419 /* s_atomic_smin_x2 */, AMDGPU::S_ATOMIC_SMIN_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16419 /* s_atomic_smin_x2 */, AMDGPU::S_ATOMIC_SMIN_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16436 /* s_atomic_sub */, AMDGPU::S_ATOMIC_SUB_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16436 /* s_atomic_sub */, AMDGPU::S_ATOMIC_SUB_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16436 /* s_atomic_sub */, AMDGPU::S_ATOMIC_SUB_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16436 /* s_atomic_sub */, AMDGPU::S_ATOMIC_SUB_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16436 /* s_atomic_sub */, AMDGPU::S_ATOMIC_SUB_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16436 /* s_atomic_sub */, AMDGPU::S_ATOMIC_SUB_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16436 /* s_atomic_sub */, AMDGPU::S_ATOMIC_SUB_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16436 /* s_atomic_sub */, AMDGPU::S_ATOMIC_SUB_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16436 /* s_atomic_sub */, AMDGPU::S_ATOMIC_SUB_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16436 /* s_atomic_sub */, AMDGPU::S_ATOMIC_SUB_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16436 /* s_atomic_sub */, AMDGPU::S_ATOMIC_SUB_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16436 /* s_atomic_sub */, AMDGPU::S_ATOMIC_SUB_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16449 /* s_atomic_sub_x2 */, AMDGPU::S_ATOMIC_SUB_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16449 /* s_atomic_sub_x2 */, AMDGPU::S_ATOMIC_SUB_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16449 /* s_atomic_sub_x2 */, AMDGPU::S_ATOMIC_SUB_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16449 /* s_atomic_sub_x2 */, AMDGPU::S_ATOMIC_SUB_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16449 /* s_atomic_sub_x2 */, AMDGPU::S_ATOMIC_SUB_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16449 /* s_atomic_sub_x2 */, AMDGPU::S_ATOMIC_SUB_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16449 /* s_atomic_sub_x2 */, AMDGPU::S_ATOMIC_SUB_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16449 /* s_atomic_sub_x2 */, AMDGPU::S_ATOMIC_SUB_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16449 /* s_atomic_sub_x2 */, AMDGPU::S_ATOMIC_SUB_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16449 /* s_atomic_sub_x2 */, AMDGPU::S_ATOMIC_SUB_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16449 /* s_atomic_sub_x2 */, AMDGPU::S_ATOMIC_SUB_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16449 /* s_atomic_sub_x2 */, AMDGPU::S_ATOMIC_SUB_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16465 /* s_atomic_swap */, AMDGPU::S_ATOMIC_SWAP_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16465 /* s_atomic_swap */, AMDGPU::S_ATOMIC_SWAP_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16465 /* s_atomic_swap */, AMDGPU::S_ATOMIC_SWAP_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16465 /* s_atomic_swap */, AMDGPU::S_ATOMIC_SWAP_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16465 /* s_atomic_swap */, AMDGPU::S_ATOMIC_SWAP_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16465 /* s_atomic_swap */, AMDGPU::S_ATOMIC_SWAP_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16465 /* s_atomic_swap */, AMDGPU::S_ATOMIC_SWAP_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16465 /* s_atomic_swap */, AMDGPU::S_ATOMIC_SWAP_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16465 /* s_atomic_swap */, AMDGPU::S_ATOMIC_SWAP_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16465 /* s_atomic_swap */, AMDGPU::S_ATOMIC_SWAP_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16465 /* s_atomic_swap */, AMDGPU::S_ATOMIC_SWAP_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16465 /* s_atomic_swap */, AMDGPU::S_ATOMIC_SWAP_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16479 /* s_atomic_swap_x2 */, AMDGPU::S_ATOMIC_SWAP_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16479 /* s_atomic_swap_x2 */, AMDGPU::S_ATOMIC_SWAP_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16479 /* s_atomic_swap_x2 */, AMDGPU::S_ATOMIC_SWAP_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16479 /* s_atomic_swap_x2 */, AMDGPU::S_ATOMIC_SWAP_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16479 /* s_atomic_swap_x2 */, AMDGPU::S_ATOMIC_SWAP_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16479 /* s_atomic_swap_x2 */, AMDGPU::S_ATOMIC_SWAP_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16479 /* s_atomic_swap_x2 */, AMDGPU::S_ATOMIC_SWAP_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16479 /* s_atomic_swap_x2 */, AMDGPU::S_ATOMIC_SWAP_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16479 /* s_atomic_swap_x2 */, AMDGPU::S_ATOMIC_SWAP_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16479 /* s_atomic_swap_x2 */, AMDGPU::S_ATOMIC_SWAP_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16479 /* s_atomic_swap_x2 */, AMDGPU::S_ATOMIC_SWAP_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16479 /* s_atomic_swap_x2 */, AMDGPU::S_ATOMIC_SWAP_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16496 /* s_atomic_umax */, AMDGPU::S_ATOMIC_UMAX_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16496 /* s_atomic_umax */, AMDGPU::S_ATOMIC_UMAX_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16496 /* s_atomic_umax */, AMDGPU::S_ATOMIC_UMAX_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16496 /* s_atomic_umax */, AMDGPU::S_ATOMIC_UMAX_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16496 /* s_atomic_umax */, AMDGPU::S_ATOMIC_UMAX_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16496 /* s_atomic_umax */, AMDGPU::S_ATOMIC_UMAX_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16496 /* s_atomic_umax */, AMDGPU::S_ATOMIC_UMAX_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16496 /* s_atomic_umax */, AMDGPU::S_ATOMIC_UMAX_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16496 /* s_atomic_umax */, AMDGPU::S_ATOMIC_UMAX_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16496 /* s_atomic_umax */, AMDGPU::S_ATOMIC_UMAX_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16496 /* s_atomic_umax */, AMDGPU::S_ATOMIC_UMAX_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16496 /* s_atomic_umax */, AMDGPU::S_ATOMIC_UMAX_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16510 /* s_atomic_umax_x2 */, AMDGPU::S_ATOMIC_UMAX_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16510 /* s_atomic_umax_x2 */, AMDGPU::S_ATOMIC_UMAX_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16510 /* s_atomic_umax_x2 */, AMDGPU::S_ATOMIC_UMAX_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16510 /* s_atomic_umax_x2 */, AMDGPU::S_ATOMIC_UMAX_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16510 /* s_atomic_umax_x2 */, AMDGPU::S_ATOMIC_UMAX_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16510 /* s_atomic_umax_x2 */, AMDGPU::S_ATOMIC_UMAX_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16510 /* s_atomic_umax_x2 */, AMDGPU::S_ATOMIC_UMAX_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16510 /* s_atomic_umax_x2 */, AMDGPU::S_ATOMIC_UMAX_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16510 /* s_atomic_umax_x2 */, AMDGPU::S_ATOMIC_UMAX_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16510 /* s_atomic_umax_x2 */, AMDGPU::S_ATOMIC_UMAX_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16510 /* s_atomic_umax_x2 */, AMDGPU::S_ATOMIC_UMAX_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16510 /* s_atomic_umax_x2 */, AMDGPU::S_ATOMIC_UMAX_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16527 /* s_atomic_umin */, AMDGPU::S_ATOMIC_UMIN_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16527 /* s_atomic_umin */, AMDGPU::S_ATOMIC_UMIN_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16527 /* s_atomic_umin */, AMDGPU::S_ATOMIC_UMIN_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16527 /* s_atomic_umin */, AMDGPU::S_ATOMIC_UMIN_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16527 /* s_atomic_umin */, AMDGPU::S_ATOMIC_UMIN_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16527 /* s_atomic_umin */, AMDGPU::S_ATOMIC_UMIN_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16527 /* s_atomic_umin */, AMDGPU::S_ATOMIC_UMIN_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16527 /* s_atomic_umin */, AMDGPU::S_ATOMIC_UMIN_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16527 /* s_atomic_umin */, AMDGPU::S_ATOMIC_UMIN_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16527 /* s_atomic_umin */, AMDGPU::S_ATOMIC_UMIN_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16527 /* s_atomic_umin */, AMDGPU::S_ATOMIC_UMIN_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16527 /* s_atomic_umin */, AMDGPU::S_ATOMIC_UMIN_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16541 /* s_atomic_umin_x2 */, AMDGPU::S_ATOMIC_UMIN_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16541 /* s_atomic_umin_x2 */, AMDGPU::S_ATOMIC_UMIN_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16541 /* s_atomic_umin_x2 */, AMDGPU::S_ATOMIC_UMIN_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16541 /* s_atomic_umin_x2 */, AMDGPU::S_ATOMIC_UMIN_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16541 /* s_atomic_umin_x2 */, AMDGPU::S_ATOMIC_UMIN_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16541 /* s_atomic_umin_x2 */, AMDGPU::S_ATOMIC_UMIN_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16541 /* s_atomic_umin_x2 */, AMDGPU::S_ATOMIC_UMIN_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16541 /* s_atomic_umin_x2 */, AMDGPU::S_ATOMIC_UMIN_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16541 /* s_atomic_umin_x2 */, AMDGPU::S_ATOMIC_UMIN_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16541 /* s_atomic_umin_x2 */, AMDGPU::S_ATOMIC_UMIN_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16541 /* s_atomic_umin_x2 */, AMDGPU::S_ATOMIC_UMIN_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16541 /* s_atomic_umin_x2 */, AMDGPU::S_ATOMIC_UMIN_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16558 /* s_atomic_xor */, AMDGPU::S_ATOMIC_XOR_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16558 /* s_atomic_xor */, AMDGPU::S_ATOMIC_XOR_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16558 /* s_atomic_xor */, AMDGPU::S_ATOMIC_XOR_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16558 /* s_atomic_xor */, AMDGPU::S_ATOMIC_XOR_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16558 /* s_atomic_xor */, AMDGPU::S_ATOMIC_XOR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16558 /* s_atomic_xor */, AMDGPU::S_ATOMIC_XOR_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16558 /* s_atomic_xor */, AMDGPU::S_ATOMIC_XOR_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16558 /* s_atomic_xor */, AMDGPU::S_ATOMIC_XOR_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16558 /* s_atomic_xor */, AMDGPU::S_ATOMIC_XOR_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16558 /* s_atomic_xor */, AMDGPU::S_ATOMIC_XOR_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16558 /* s_atomic_xor */, AMDGPU::S_ATOMIC_XOR_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16558 /* s_atomic_xor */, AMDGPU::S_ATOMIC_XOR_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16571 /* s_atomic_xor_x2 */, AMDGPU::S_ATOMIC_XOR_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16571 /* s_atomic_xor_x2 */, AMDGPU::S_ATOMIC_XOR_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16571 /* s_atomic_xor_x2 */, AMDGPU::S_ATOMIC_XOR_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16571 /* s_atomic_xor_x2 */, AMDGPU::S_ATOMIC_XOR_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16571 /* s_atomic_xor_x2 */, AMDGPU::S_ATOMIC_XOR_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16571 /* s_atomic_xor_x2 */, AMDGPU::S_ATOMIC_XOR_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16571 /* s_atomic_xor_x2 */, AMDGPU::S_ATOMIC_XOR_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16571 /* s_atomic_xor_x2 */, AMDGPU::S_ATOMIC_XOR_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16571 /* s_atomic_xor_x2 */, AMDGPU::S_ATOMIC_XOR_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16571 /* s_atomic_xor_x2 */, AMDGPU::S_ATOMIC_XOR_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16571 /* s_atomic_xor_x2 */, AMDGPU::S_ATOMIC_XOR_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16571 /* s_atomic_xor_x2 */, AMDGPU::S_ATOMIC_XOR_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16587 /* s_barrier */, AMDGPU::S_BARRIER_gfx10, Convert_NoOperands, AMFBS_isGFX10Only, {  }, },
  { 16587 /* s_barrier */, AMDGPU::S_BARRIER_gfx11, Convert_NoOperands, AMFBS_isGFX11Only, {  }, },
  { 16587 /* s_barrier */, AMDGPU::S_BARRIER_gfx6_gfx7, Convert_NoOperands, AMFBS_isGFX6GFX7, {  }, },
  { 16587 /* s_barrier */, AMDGPU::S_BARRIER_vi, Convert_NoOperands, AMFBS_isGFX8GFX9, {  }, },
  { 16597 /* s_barrier_init */, AMDGPU::S_BARRIER_INIT_M0_gfx12, Convert_NoOperands, AMFBS_isGFX12Only, { MCK_M0 }, },
  { 16597 /* s_barrier_init */, AMDGPU::S_BARRIER_INIT_IMM_gfx12, Convert__SplitBarrier1_0, AMFBS_isGFX12Only, { MCK_SplitBarrier }, },
  { 16612 /* s_barrier_join */, AMDGPU::S_BARRIER_JOIN_M0_gfx12, Convert_NoOperands, AMFBS_isGFX12Only, { MCK_M0 }, },
  { 16612 /* s_barrier_join */, AMDGPU::S_BARRIER_JOIN_IMM_gfx12, Convert__SplitBarrier1_0, AMFBS_isGFX12Only, { MCK_SplitBarrier }, },
  { 16627 /* s_barrier_leave */, AMDGPU::S_BARRIER_LEAVE_gfx12, Convert_NoOperands, AMFBS_isGFX12Only, {  }, },
  { 16643 /* s_barrier_signal */, AMDGPU::S_BARRIER_SIGNAL_M0_gfx12, Convert_NoOperands, AMFBS_isGFX12Only, { MCK_M0 }, },
  { 16643 /* s_barrier_signal */, AMDGPU::S_BARRIER_SIGNAL_IMM_gfx12, Convert__SplitBarrier1_0, AMFBS_isGFX12Only, { MCK_SplitBarrier }, },
  { 16660 /* s_barrier_signal_isfirst */, AMDGPU::S_BARRIER_SIGNAL_ISFIRST_M0_gfx12, Convert_NoOperands, AMFBS_isGFX12Only, { MCK_M0 }, },
  { 16660 /* s_barrier_signal_isfirst */, AMDGPU::S_BARRIER_SIGNAL_ISFIRST_IMM_gfx12, Convert__SplitBarrier1_0, AMFBS_isGFX12Only, { MCK_SplitBarrier }, },
  { 16685 /* s_barrier_wait */, AMDGPU::S_BARRIER_WAIT_gfx12, Convert__Imm1_0, AMFBS_isGFX12Only, { MCK_Imm }, },
  { 16700 /* s_bcnt0_i32_b32 */, AMDGPU::S_BCNT0_I32_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16700 /* s_bcnt0_i32_b32 */, AMDGPU::S_BCNT0_I32_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16700 /* s_bcnt0_i32_b32 */, AMDGPU::S_BCNT0_I32_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16700 /* s_bcnt0_i32_b32 */, AMDGPU::S_BCNT0_I32_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16700 /* s_bcnt0_i32_b32 */, AMDGPU::S_BCNT0_I32_B32_vi, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16716 /* s_bcnt0_i32_b64 */, AMDGPU::S_BCNT0_I32_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 16716 /* s_bcnt0_i32_b64 */, AMDGPU::S_BCNT0_I32_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 16716 /* s_bcnt0_i32_b64 */, AMDGPU::S_BCNT0_I32_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 16716 /* s_bcnt0_i32_b64 */, AMDGPU::S_BCNT0_I32_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 16716 /* s_bcnt0_i32_b64 */, AMDGPU::S_BCNT0_I32_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 16732 /* s_bcnt1_i32_b32 */, AMDGPU::S_BCNT1_I32_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16732 /* s_bcnt1_i32_b32 */, AMDGPU::S_BCNT1_I32_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16732 /* s_bcnt1_i32_b32 */, AMDGPU::S_BCNT1_I32_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16732 /* s_bcnt1_i32_b32 */, AMDGPU::S_BCNT1_I32_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16732 /* s_bcnt1_i32_b32 */, AMDGPU::S_BCNT1_I32_B32_vi, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16748 /* s_bcnt1_i32_b64 */, AMDGPU::S_BCNT1_I32_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 16748 /* s_bcnt1_i32_b64 */, AMDGPU::S_BCNT1_I32_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 16748 /* s_bcnt1_i32_b64 */, AMDGPU::S_BCNT1_I32_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 16748 /* s_bcnt1_i32_b64 */, AMDGPU::S_BCNT1_I32_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 16748 /* s_bcnt1_i32_b64 */, AMDGPU::S_BCNT1_I32_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 16764 /* s_bfe_i32 */, AMDGPU::S_BFE_I32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16764 /* s_bfe_i32 */, AMDGPU::S_BFE_I32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16764 /* s_bfe_i32 */, AMDGPU::S_BFE_I32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16764 /* s_bfe_i32 */, AMDGPU::S_BFE_I32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16764 /* s_bfe_i32 */, AMDGPU::S_BFE_I32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16774 /* s_bfe_i64 */, AMDGPU::S_BFE_I64_gfx10, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16774 /* s_bfe_i64 */, AMDGPU::S_BFE_I64_gfx11, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16774 /* s_bfe_i64 */, AMDGPU::S_BFE_I64_gfx12, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16774 /* s_bfe_i64 */, AMDGPU::S_BFE_I64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16774 /* s_bfe_i64 */, AMDGPU::S_BFE_I64_vi, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16784 /* s_bfe_u32 */, AMDGPU::S_BFE_U32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16784 /* s_bfe_u32 */, AMDGPU::S_BFE_U32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16784 /* s_bfe_u32 */, AMDGPU::S_BFE_U32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16784 /* s_bfe_u32 */, AMDGPU::S_BFE_U32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16784 /* s_bfe_u32 */, AMDGPU::S_BFE_U32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16794 /* s_bfe_u64 */, AMDGPU::S_BFE_U64_gfx10, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16794 /* s_bfe_u64 */, AMDGPU::S_BFE_U64_gfx11, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16794 /* s_bfe_u64 */, AMDGPU::S_BFE_U64_gfx12, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16794 /* s_bfe_u64 */, AMDGPU::S_BFE_U64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16794 /* s_bfe_u64 */, AMDGPU::S_BFE_U64_vi, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16804 /* s_bfm_b32 */, AMDGPU::S_BFM_B32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16804 /* s_bfm_b32 */, AMDGPU::S_BFM_B32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16804 /* s_bfm_b32 */, AMDGPU::S_BFM_B32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16804 /* s_bfm_b32 */, AMDGPU::S_BFM_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16804 /* s_bfm_b32 */, AMDGPU::S_BFM_B32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16814 /* s_bfm_b64 */, AMDGPU::S_BFM_B64_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16814 /* s_bfm_b64 */, AMDGPU::S_BFM_B64_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16814 /* s_bfm_b64 */, AMDGPU::S_BFM_B64_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16814 /* s_bfm_b64 */, AMDGPU::S_BFM_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16814 /* s_bfm_b64 */, AMDGPU::S_BFM_B64_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16824 /* s_bitcmp0_b32 */, AMDGPU::S_BITCMP0_B32_gfx10, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16824 /* s_bitcmp0_b32 */, AMDGPU::S_BITCMP0_B32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16824 /* s_bitcmp0_b32 */, AMDGPU::S_BITCMP0_B32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16824 /* s_bitcmp0_b32 */, AMDGPU::S_BITCMP0_B32_gfx6_gfx7, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16824 /* s_bitcmp0_b32 */, AMDGPU::S_BITCMP0_B32_vi, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16838 /* s_bitcmp0_b64 */, AMDGPU::S_BITCMP0_B64_gfx10, Convert__SSrc_b641_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16838 /* s_bitcmp0_b64 */, AMDGPU::S_BITCMP0_B64_gfx11, Convert__SSrc_b641_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16838 /* s_bitcmp0_b64 */, AMDGPU::S_BITCMP0_B64_gfx12, Convert__SSrc_b641_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16838 /* s_bitcmp0_b64 */, AMDGPU::S_BITCMP0_B64_gfx6_gfx7, Convert__SSrc_b641_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16838 /* s_bitcmp0_b64 */, AMDGPU::S_BITCMP0_B64_vi, Convert__SSrc_b641_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16852 /* s_bitcmp1_b32 */, AMDGPU::S_BITCMP1_B32_gfx10, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16852 /* s_bitcmp1_b32 */, AMDGPU::S_BITCMP1_B32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16852 /* s_bitcmp1_b32 */, AMDGPU::S_BITCMP1_B32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16852 /* s_bitcmp1_b32 */, AMDGPU::S_BITCMP1_B32_gfx6_gfx7, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16852 /* s_bitcmp1_b32 */, AMDGPU::S_BITCMP1_B32_vi, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 16866 /* s_bitcmp1_b64 */, AMDGPU::S_BITCMP1_B64_gfx10, Convert__SSrc_b641_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16866 /* s_bitcmp1_b64 */, AMDGPU::S_BITCMP1_B64_gfx11, Convert__SSrc_b641_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16866 /* s_bitcmp1_b64 */, AMDGPU::S_BITCMP1_B64_gfx12, Convert__SSrc_b641_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16866 /* s_bitcmp1_b64 */, AMDGPU::S_BITCMP1_B64_gfx6_gfx7, Convert__SSrc_b641_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16866 /* s_bitcmp1_b64 */, AMDGPU::S_BITCMP1_B64_vi, Convert__SSrc_b641_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 16880 /* s_bitreplicate_b64_b32 */, AMDGPU::S_BITREPLICATE_B64_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX9Plus_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b32 }, },
  { 16880 /* s_bitreplicate_b64_b32 */, AMDGPU::S_BITREPLICATE_B64_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX9Plus_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b32 }, },
  { 16880 /* s_bitreplicate_b64_b32 */, AMDGPU::S_BITREPLICATE_B64_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX9Plus_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b32 }, },
  { 16880 /* s_bitreplicate_b64_b32 */, AMDGPU::S_BITREPLICATE_B64_B32_vi, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b32 }, },
  { 16903 /* s_bitset0_b32 */, AMDGPU::S_BITSET0_B32_gfx10, Convert__Reg1_0__SSrc_b321_1__imm_95_0, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16903 /* s_bitset0_b32 */, AMDGPU::S_BITSET0_B32_gfx11, Convert__Reg1_0__SSrc_b321_1__imm_95_0, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16903 /* s_bitset0_b32 */, AMDGPU::S_BITSET0_B32_gfx12, Convert__Reg1_0__SSrc_b321_1__imm_95_0, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16903 /* s_bitset0_b32 */, AMDGPU::S_BITSET0_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__imm_95_0, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16903 /* s_bitset0_b32 */, AMDGPU::S_BITSET0_B32_vi, Convert__Reg1_0__SSrc_b321_1__imm_95_0, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16917 /* s_bitset0_b64 */, AMDGPU::S_BITSET0_B64_gfx10, Convert__Reg1_0__SSrc_b321_1__imm_95_0, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b32 }, },
  { 16917 /* s_bitset0_b64 */, AMDGPU::S_BITSET0_B64_gfx11, Convert__Reg1_0__SSrc_b321_1__imm_95_0, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b32 }, },
  { 16917 /* s_bitset0_b64 */, AMDGPU::S_BITSET0_B64_gfx12, Convert__Reg1_0__SSrc_b321_1__imm_95_0, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b32 }, },
  { 16917 /* s_bitset0_b64 */, AMDGPU::S_BITSET0_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__imm_95_0, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b32 }, },
  { 16917 /* s_bitset0_b64 */, AMDGPU::S_BITSET0_B64_vi, Convert__Reg1_0__SSrc_b321_1__imm_95_0, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b32 }, },
  { 16931 /* s_bitset1_b32 */, AMDGPU::S_BITSET1_B32_gfx10, Convert__Reg1_0__SSrc_b321_1__imm_95_0, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16931 /* s_bitset1_b32 */, AMDGPU::S_BITSET1_B32_gfx11, Convert__Reg1_0__SSrc_b321_1__imm_95_0, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16931 /* s_bitset1_b32 */, AMDGPU::S_BITSET1_B32_gfx12, Convert__Reg1_0__SSrc_b321_1__imm_95_0, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16931 /* s_bitset1_b32 */, AMDGPU::S_BITSET1_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__imm_95_0, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16931 /* s_bitset1_b32 */, AMDGPU::S_BITSET1_B32_vi, Convert__Reg1_0__SSrc_b321_1__imm_95_0, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16945 /* s_bitset1_b64 */, AMDGPU::S_BITSET1_B64_gfx10, Convert__Reg1_0__SSrc_b321_1__imm_95_0, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b32 }, },
  { 16945 /* s_bitset1_b64 */, AMDGPU::S_BITSET1_B64_gfx11, Convert__Reg1_0__SSrc_b321_1__imm_95_0, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b32 }, },
  { 16945 /* s_bitset1_b64 */, AMDGPU::S_BITSET1_B64_gfx12, Convert__Reg1_0__SSrc_b321_1__imm_95_0, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b32 }, },
  { 16945 /* s_bitset1_b64 */, AMDGPU::S_BITSET1_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__imm_95_0, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b32 }, },
  { 16945 /* s_bitset1_b64 */, AMDGPU::S_BITSET1_B64_vi, Convert__Reg1_0__SSrc_b321_1__imm_95_0, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b32 }, },
  { 16959 /* s_branch */, AMDGPU::S_BRANCH_gfx10, Convert__SOPPBrTarget1_0, AMFBS_isGFX10Only, { MCK_SOPPBrTarget }, },
  { 16959 /* s_branch */, AMDGPU::S_BRANCH_gfx11, Convert__SOPPBrTarget1_0, AMFBS_isGFX11Only, { MCK_SOPPBrTarget }, },
  { 16959 /* s_branch */, AMDGPU::S_BRANCH_gfx12, Convert__SOPPBrTarget1_0, AMFBS_isGFX12Only, { MCK_SOPPBrTarget }, },
  { 16959 /* s_branch */, AMDGPU::S_BRANCH_gfx6_gfx7, Convert__SOPPBrTarget1_0, AMFBS_isGFX6GFX7, { MCK_SOPPBrTarget }, },
  { 16959 /* s_branch */, AMDGPU::S_BRANCH_vi, Convert__SOPPBrTarget1_0, AMFBS_isGFX8GFX9, { MCK_SOPPBrTarget }, },
  { 16968 /* s_brev_b32 */, AMDGPU::S_BREV_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16968 /* s_brev_b32 */, AMDGPU::S_BREV_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16968 /* s_brev_b32 */, AMDGPU::S_BREV_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16968 /* s_brev_b32 */, AMDGPU::S_BREV_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16968 /* s_brev_b32 */, AMDGPU::S_BREV_B32_vi, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 16979 /* s_brev_b64 */, AMDGPU::S_BREV_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 16979 /* s_brev_b64 */, AMDGPU::S_BREV_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 16979 /* s_brev_b64 */, AMDGPU::S_BREV_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 16979 /* s_brev_b64 */, AMDGPU::S_BREV_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 16979 /* s_brev_b64 */, AMDGPU::S_BREV_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 16990 /* s_buffer_atomic_add */, AMDGPU::S_BUFFER_ATOMIC_ADD_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16990 /* s_buffer_atomic_add */, AMDGPU::S_BUFFER_ATOMIC_ADD_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 16990 /* s_buffer_atomic_add */, AMDGPU::S_BUFFER_ATOMIC_ADD_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16990 /* s_buffer_atomic_add */, AMDGPU::S_BUFFER_ATOMIC_ADD_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 16990 /* s_buffer_atomic_add */, AMDGPU::S_BUFFER_ATOMIC_ADD_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16990 /* s_buffer_atomic_add */, AMDGPU::S_BUFFER_ATOMIC_ADD_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 16990 /* s_buffer_atomic_add */, AMDGPU::S_BUFFER_ATOMIC_ADD_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16990 /* s_buffer_atomic_add */, AMDGPU::S_BUFFER_ATOMIC_ADD_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 16990 /* s_buffer_atomic_add */, AMDGPU::S_BUFFER_ATOMIC_ADD_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16990 /* s_buffer_atomic_add */, AMDGPU::S_BUFFER_ATOMIC_ADD_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 16990 /* s_buffer_atomic_add */, AMDGPU::S_BUFFER_ATOMIC_ADD_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 16990 /* s_buffer_atomic_add */, AMDGPU::S_BUFFER_ATOMIC_ADD_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17010 /* s_buffer_atomic_add_x2 */, AMDGPU::S_BUFFER_ATOMIC_ADD_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17010 /* s_buffer_atomic_add_x2 */, AMDGPU::S_BUFFER_ATOMIC_ADD_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17010 /* s_buffer_atomic_add_x2 */, AMDGPU::S_BUFFER_ATOMIC_ADD_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17010 /* s_buffer_atomic_add_x2 */, AMDGPU::S_BUFFER_ATOMIC_ADD_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17010 /* s_buffer_atomic_add_x2 */, AMDGPU::S_BUFFER_ATOMIC_ADD_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17010 /* s_buffer_atomic_add_x2 */, AMDGPU::S_BUFFER_ATOMIC_ADD_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17010 /* s_buffer_atomic_add_x2 */, AMDGPU::S_BUFFER_ATOMIC_ADD_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17010 /* s_buffer_atomic_add_x2 */, AMDGPU::S_BUFFER_ATOMIC_ADD_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17010 /* s_buffer_atomic_add_x2 */, AMDGPU::S_BUFFER_ATOMIC_ADD_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17010 /* s_buffer_atomic_add_x2 */, AMDGPU::S_BUFFER_ATOMIC_ADD_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17010 /* s_buffer_atomic_add_x2 */, AMDGPU::S_BUFFER_ATOMIC_ADD_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17010 /* s_buffer_atomic_add_x2 */, AMDGPU::S_BUFFER_ATOMIC_ADD_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17033 /* s_buffer_atomic_and */, AMDGPU::S_BUFFER_ATOMIC_AND_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17033 /* s_buffer_atomic_and */, AMDGPU::S_BUFFER_ATOMIC_AND_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17033 /* s_buffer_atomic_and */, AMDGPU::S_BUFFER_ATOMIC_AND_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17033 /* s_buffer_atomic_and */, AMDGPU::S_BUFFER_ATOMIC_AND_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17033 /* s_buffer_atomic_and */, AMDGPU::S_BUFFER_ATOMIC_AND_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17033 /* s_buffer_atomic_and */, AMDGPU::S_BUFFER_ATOMIC_AND_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17033 /* s_buffer_atomic_and */, AMDGPU::S_BUFFER_ATOMIC_AND_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17033 /* s_buffer_atomic_and */, AMDGPU::S_BUFFER_ATOMIC_AND_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17033 /* s_buffer_atomic_and */, AMDGPU::S_BUFFER_ATOMIC_AND_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17033 /* s_buffer_atomic_and */, AMDGPU::S_BUFFER_ATOMIC_AND_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17033 /* s_buffer_atomic_and */, AMDGPU::S_BUFFER_ATOMIC_AND_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17033 /* s_buffer_atomic_and */, AMDGPU::S_BUFFER_ATOMIC_AND_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17053 /* s_buffer_atomic_and_x2 */, AMDGPU::S_BUFFER_ATOMIC_AND_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17053 /* s_buffer_atomic_and_x2 */, AMDGPU::S_BUFFER_ATOMIC_AND_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17053 /* s_buffer_atomic_and_x2 */, AMDGPU::S_BUFFER_ATOMIC_AND_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17053 /* s_buffer_atomic_and_x2 */, AMDGPU::S_BUFFER_ATOMIC_AND_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17053 /* s_buffer_atomic_and_x2 */, AMDGPU::S_BUFFER_ATOMIC_AND_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17053 /* s_buffer_atomic_and_x2 */, AMDGPU::S_BUFFER_ATOMIC_AND_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17053 /* s_buffer_atomic_and_x2 */, AMDGPU::S_BUFFER_ATOMIC_AND_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17053 /* s_buffer_atomic_and_x2 */, AMDGPU::S_BUFFER_ATOMIC_AND_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17053 /* s_buffer_atomic_and_x2 */, AMDGPU::S_BUFFER_ATOMIC_AND_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17053 /* s_buffer_atomic_and_x2 */, AMDGPU::S_BUFFER_ATOMIC_AND_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17053 /* s_buffer_atomic_and_x2 */, AMDGPU::S_BUFFER_ATOMIC_AND_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17053 /* s_buffer_atomic_and_x2 */, AMDGPU::S_BUFFER_ATOMIC_AND_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17076 /* s_buffer_atomic_cmpswap */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17076 /* s_buffer_atomic_cmpswap */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17076 /* s_buffer_atomic_cmpswap */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17076 /* s_buffer_atomic_cmpswap */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17076 /* s_buffer_atomic_cmpswap */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17076 /* s_buffer_atomic_cmpswap */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17076 /* s_buffer_atomic_cmpswap */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17076 /* s_buffer_atomic_cmpswap */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17076 /* s_buffer_atomic_cmpswap */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17076 /* s_buffer_atomic_cmpswap */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17076 /* s_buffer_atomic_cmpswap */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17076 /* s_buffer_atomic_cmpswap */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17100 /* s_buffer_atomic_cmpswap_x2 */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17100 /* s_buffer_atomic_cmpswap_x2 */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17100 /* s_buffer_atomic_cmpswap_x2 */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17100 /* s_buffer_atomic_cmpswap_x2 */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17100 /* s_buffer_atomic_cmpswap_x2 */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17100 /* s_buffer_atomic_cmpswap_x2 */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17100 /* s_buffer_atomic_cmpswap_x2 */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17100 /* s_buffer_atomic_cmpswap_x2 */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17100 /* s_buffer_atomic_cmpswap_x2 */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17100 /* s_buffer_atomic_cmpswap_x2 */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17100 /* s_buffer_atomic_cmpswap_x2 */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17100 /* s_buffer_atomic_cmpswap_x2 */, AMDGPU::S_BUFFER_ATOMIC_CMPSWAP_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17127 /* s_buffer_atomic_dec */, AMDGPU::S_BUFFER_ATOMIC_DEC_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17127 /* s_buffer_atomic_dec */, AMDGPU::S_BUFFER_ATOMIC_DEC_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17127 /* s_buffer_atomic_dec */, AMDGPU::S_BUFFER_ATOMIC_DEC_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17127 /* s_buffer_atomic_dec */, AMDGPU::S_BUFFER_ATOMIC_DEC_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17127 /* s_buffer_atomic_dec */, AMDGPU::S_BUFFER_ATOMIC_DEC_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17127 /* s_buffer_atomic_dec */, AMDGPU::S_BUFFER_ATOMIC_DEC_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17127 /* s_buffer_atomic_dec */, AMDGPU::S_BUFFER_ATOMIC_DEC_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17127 /* s_buffer_atomic_dec */, AMDGPU::S_BUFFER_ATOMIC_DEC_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17127 /* s_buffer_atomic_dec */, AMDGPU::S_BUFFER_ATOMIC_DEC_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17127 /* s_buffer_atomic_dec */, AMDGPU::S_BUFFER_ATOMIC_DEC_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17127 /* s_buffer_atomic_dec */, AMDGPU::S_BUFFER_ATOMIC_DEC_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17127 /* s_buffer_atomic_dec */, AMDGPU::S_BUFFER_ATOMIC_DEC_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17147 /* s_buffer_atomic_dec_x2 */, AMDGPU::S_BUFFER_ATOMIC_DEC_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17147 /* s_buffer_atomic_dec_x2 */, AMDGPU::S_BUFFER_ATOMIC_DEC_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17147 /* s_buffer_atomic_dec_x2 */, AMDGPU::S_BUFFER_ATOMIC_DEC_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17147 /* s_buffer_atomic_dec_x2 */, AMDGPU::S_BUFFER_ATOMIC_DEC_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17147 /* s_buffer_atomic_dec_x2 */, AMDGPU::S_BUFFER_ATOMIC_DEC_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17147 /* s_buffer_atomic_dec_x2 */, AMDGPU::S_BUFFER_ATOMIC_DEC_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17147 /* s_buffer_atomic_dec_x2 */, AMDGPU::S_BUFFER_ATOMIC_DEC_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17147 /* s_buffer_atomic_dec_x2 */, AMDGPU::S_BUFFER_ATOMIC_DEC_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17147 /* s_buffer_atomic_dec_x2 */, AMDGPU::S_BUFFER_ATOMIC_DEC_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17147 /* s_buffer_atomic_dec_x2 */, AMDGPU::S_BUFFER_ATOMIC_DEC_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17147 /* s_buffer_atomic_dec_x2 */, AMDGPU::S_BUFFER_ATOMIC_DEC_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17147 /* s_buffer_atomic_dec_x2 */, AMDGPU::S_BUFFER_ATOMIC_DEC_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17170 /* s_buffer_atomic_inc */, AMDGPU::S_BUFFER_ATOMIC_INC_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17170 /* s_buffer_atomic_inc */, AMDGPU::S_BUFFER_ATOMIC_INC_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17170 /* s_buffer_atomic_inc */, AMDGPU::S_BUFFER_ATOMIC_INC_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17170 /* s_buffer_atomic_inc */, AMDGPU::S_BUFFER_ATOMIC_INC_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17170 /* s_buffer_atomic_inc */, AMDGPU::S_BUFFER_ATOMIC_INC_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17170 /* s_buffer_atomic_inc */, AMDGPU::S_BUFFER_ATOMIC_INC_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17170 /* s_buffer_atomic_inc */, AMDGPU::S_BUFFER_ATOMIC_INC_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17170 /* s_buffer_atomic_inc */, AMDGPU::S_BUFFER_ATOMIC_INC_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17170 /* s_buffer_atomic_inc */, AMDGPU::S_BUFFER_ATOMIC_INC_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17170 /* s_buffer_atomic_inc */, AMDGPU::S_BUFFER_ATOMIC_INC_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17170 /* s_buffer_atomic_inc */, AMDGPU::S_BUFFER_ATOMIC_INC_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17170 /* s_buffer_atomic_inc */, AMDGPU::S_BUFFER_ATOMIC_INC_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17190 /* s_buffer_atomic_inc_x2 */, AMDGPU::S_BUFFER_ATOMIC_INC_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17190 /* s_buffer_atomic_inc_x2 */, AMDGPU::S_BUFFER_ATOMIC_INC_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17190 /* s_buffer_atomic_inc_x2 */, AMDGPU::S_BUFFER_ATOMIC_INC_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17190 /* s_buffer_atomic_inc_x2 */, AMDGPU::S_BUFFER_ATOMIC_INC_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17190 /* s_buffer_atomic_inc_x2 */, AMDGPU::S_BUFFER_ATOMIC_INC_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17190 /* s_buffer_atomic_inc_x2 */, AMDGPU::S_BUFFER_ATOMIC_INC_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17190 /* s_buffer_atomic_inc_x2 */, AMDGPU::S_BUFFER_ATOMIC_INC_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17190 /* s_buffer_atomic_inc_x2 */, AMDGPU::S_BUFFER_ATOMIC_INC_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17190 /* s_buffer_atomic_inc_x2 */, AMDGPU::S_BUFFER_ATOMIC_INC_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17190 /* s_buffer_atomic_inc_x2 */, AMDGPU::S_BUFFER_ATOMIC_INC_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17190 /* s_buffer_atomic_inc_x2 */, AMDGPU::S_BUFFER_ATOMIC_INC_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17190 /* s_buffer_atomic_inc_x2 */, AMDGPU::S_BUFFER_ATOMIC_INC_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17213 /* s_buffer_atomic_or */, AMDGPU::S_BUFFER_ATOMIC_OR_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17213 /* s_buffer_atomic_or */, AMDGPU::S_BUFFER_ATOMIC_OR_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17213 /* s_buffer_atomic_or */, AMDGPU::S_BUFFER_ATOMIC_OR_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17213 /* s_buffer_atomic_or */, AMDGPU::S_BUFFER_ATOMIC_OR_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17213 /* s_buffer_atomic_or */, AMDGPU::S_BUFFER_ATOMIC_OR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17213 /* s_buffer_atomic_or */, AMDGPU::S_BUFFER_ATOMIC_OR_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17213 /* s_buffer_atomic_or */, AMDGPU::S_BUFFER_ATOMIC_OR_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17213 /* s_buffer_atomic_or */, AMDGPU::S_BUFFER_ATOMIC_OR_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17213 /* s_buffer_atomic_or */, AMDGPU::S_BUFFER_ATOMIC_OR_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17213 /* s_buffer_atomic_or */, AMDGPU::S_BUFFER_ATOMIC_OR_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17213 /* s_buffer_atomic_or */, AMDGPU::S_BUFFER_ATOMIC_OR_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17213 /* s_buffer_atomic_or */, AMDGPU::S_BUFFER_ATOMIC_OR_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17232 /* s_buffer_atomic_or_x2 */, AMDGPU::S_BUFFER_ATOMIC_OR_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17232 /* s_buffer_atomic_or_x2 */, AMDGPU::S_BUFFER_ATOMIC_OR_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17232 /* s_buffer_atomic_or_x2 */, AMDGPU::S_BUFFER_ATOMIC_OR_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17232 /* s_buffer_atomic_or_x2 */, AMDGPU::S_BUFFER_ATOMIC_OR_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17232 /* s_buffer_atomic_or_x2 */, AMDGPU::S_BUFFER_ATOMIC_OR_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17232 /* s_buffer_atomic_or_x2 */, AMDGPU::S_BUFFER_ATOMIC_OR_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17232 /* s_buffer_atomic_or_x2 */, AMDGPU::S_BUFFER_ATOMIC_OR_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17232 /* s_buffer_atomic_or_x2 */, AMDGPU::S_BUFFER_ATOMIC_OR_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17232 /* s_buffer_atomic_or_x2 */, AMDGPU::S_BUFFER_ATOMIC_OR_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17232 /* s_buffer_atomic_or_x2 */, AMDGPU::S_BUFFER_ATOMIC_OR_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17232 /* s_buffer_atomic_or_x2 */, AMDGPU::S_BUFFER_ATOMIC_OR_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17232 /* s_buffer_atomic_or_x2 */, AMDGPU::S_BUFFER_ATOMIC_OR_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17254 /* s_buffer_atomic_smax */, AMDGPU::S_BUFFER_ATOMIC_SMAX_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17254 /* s_buffer_atomic_smax */, AMDGPU::S_BUFFER_ATOMIC_SMAX_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17254 /* s_buffer_atomic_smax */, AMDGPU::S_BUFFER_ATOMIC_SMAX_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17254 /* s_buffer_atomic_smax */, AMDGPU::S_BUFFER_ATOMIC_SMAX_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17254 /* s_buffer_atomic_smax */, AMDGPU::S_BUFFER_ATOMIC_SMAX_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17254 /* s_buffer_atomic_smax */, AMDGPU::S_BUFFER_ATOMIC_SMAX_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17254 /* s_buffer_atomic_smax */, AMDGPU::S_BUFFER_ATOMIC_SMAX_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17254 /* s_buffer_atomic_smax */, AMDGPU::S_BUFFER_ATOMIC_SMAX_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17254 /* s_buffer_atomic_smax */, AMDGPU::S_BUFFER_ATOMIC_SMAX_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17254 /* s_buffer_atomic_smax */, AMDGPU::S_BUFFER_ATOMIC_SMAX_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17254 /* s_buffer_atomic_smax */, AMDGPU::S_BUFFER_ATOMIC_SMAX_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17254 /* s_buffer_atomic_smax */, AMDGPU::S_BUFFER_ATOMIC_SMAX_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17275 /* s_buffer_atomic_smax_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMAX_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17275 /* s_buffer_atomic_smax_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMAX_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17275 /* s_buffer_atomic_smax_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMAX_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17275 /* s_buffer_atomic_smax_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMAX_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17275 /* s_buffer_atomic_smax_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMAX_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17275 /* s_buffer_atomic_smax_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMAX_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17275 /* s_buffer_atomic_smax_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMAX_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17275 /* s_buffer_atomic_smax_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMAX_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17275 /* s_buffer_atomic_smax_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMAX_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17275 /* s_buffer_atomic_smax_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMAX_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17275 /* s_buffer_atomic_smax_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMAX_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17275 /* s_buffer_atomic_smax_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMAX_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17299 /* s_buffer_atomic_smin */, AMDGPU::S_BUFFER_ATOMIC_SMIN_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17299 /* s_buffer_atomic_smin */, AMDGPU::S_BUFFER_ATOMIC_SMIN_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17299 /* s_buffer_atomic_smin */, AMDGPU::S_BUFFER_ATOMIC_SMIN_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17299 /* s_buffer_atomic_smin */, AMDGPU::S_BUFFER_ATOMIC_SMIN_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17299 /* s_buffer_atomic_smin */, AMDGPU::S_BUFFER_ATOMIC_SMIN_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17299 /* s_buffer_atomic_smin */, AMDGPU::S_BUFFER_ATOMIC_SMIN_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17299 /* s_buffer_atomic_smin */, AMDGPU::S_BUFFER_ATOMIC_SMIN_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17299 /* s_buffer_atomic_smin */, AMDGPU::S_BUFFER_ATOMIC_SMIN_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17299 /* s_buffer_atomic_smin */, AMDGPU::S_BUFFER_ATOMIC_SMIN_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17299 /* s_buffer_atomic_smin */, AMDGPU::S_BUFFER_ATOMIC_SMIN_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17299 /* s_buffer_atomic_smin */, AMDGPU::S_BUFFER_ATOMIC_SMIN_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17299 /* s_buffer_atomic_smin */, AMDGPU::S_BUFFER_ATOMIC_SMIN_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17320 /* s_buffer_atomic_smin_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMIN_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17320 /* s_buffer_atomic_smin_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMIN_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17320 /* s_buffer_atomic_smin_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMIN_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17320 /* s_buffer_atomic_smin_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMIN_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17320 /* s_buffer_atomic_smin_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMIN_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17320 /* s_buffer_atomic_smin_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMIN_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17320 /* s_buffer_atomic_smin_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMIN_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17320 /* s_buffer_atomic_smin_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMIN_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17320 /* s_buffer_atomic_smin_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMIN_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17320 /* s_buffer_atomic_smin_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMIN_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17320 /* s_buffer_atomic_smin_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMIN_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17320 /* s_buffer_atomic_smin_x2 */, AMDGPU::S_BUFFER_ATOMIC_SMIN_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17344 /* s_buffer_atomic_sub */, AMDGPU::S_BUFFER_ATOMIC_SUB_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17344 /* s_buffer_atomic_sub */, AMDGPU::S_BUFFER_ATOMIC_SUB_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17344 /* s_buffer_atomic_sub */, AMDGPU::S_BUFFER_ATOMIC_SUB_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17344 /* s_buffer_atomic_sub */, AMDGPU::S_BUFFER_ATOMIC_SUB_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17344 /* s_buffer_atomic_sub */, AMDGPU::S_BUFFER_ATOMIC_SUB_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17344 /* s_buffer_atomic_sub */, AMDGPU::S_BUFFER_ATOMIC_SUB_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17344 /* s_buffer_atomic_sub */, AMDGPU::S_BUFFER_ATOMIC_SUB_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17344 /* s_buffer_atomic_sub */, AMDGPU::S_BUFFER_ATOMIC_SUB_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17344 /* s_buffer_atomic_sub */, AMDGPU::S_BUFFER_ATOMIC_SUB_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17344 /* s_buffer_atomic_sub */, AMDGPU::S_BUFFER_ATOMIC_SUB_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17344 /* s_buffer_atomic_sub */, AMDGPU::S_BUFFER_ATOMIC_SUB_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17344 /* s_buffer_atomic_sub */, AMDGPU::S_BUFFER_ATOMIC_SUB_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17364 /* s_buffer_atomic_sub_x2 */, AMDGPU::S_BUFFER_ATOMIC_SUB_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17364 /* s_buffer_atomic_sub_x2 */, AMDGPU::S_BUFFER_ATOMIC_SUB_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17364 /* s_buffer_atomic_sub_x2 */, AMDGPU::S_BUFFER_ATOMIC_SUB_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17364 /* s_buffer_atomic_sub_x2 */, AMDGPU::S_BUFFER_ATOMIC_SUB_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17364 /* s_buffer_atomic_sub_x2 */, AMDGPU::S_BUFFER_ATOMIC_SUB_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17364 /* s_buffer_atomic_sub_x2 */, AMDGPU::S_BUFFER_ATOMIC_SUB_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17364 /* s_buffer_atomic_sub_x2 */, AMDGPU::S_BUFFER_ATOMIC_SUB_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17364 /* s_buffer_atomic_sub_x2 */, AMDGPU::S_BUFFER_ATOMIC_SUB_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17364 /* s_buffer_atomic_sub_x2 */, AMDGPU::S_BUFFER_ATOMIC_SUB_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17364 /* s_buffer_atomic_sub_x2 */, AMDGPU::S_BUFFER_ATOMIC_SUB_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17364 /* s_buffer_atomic_sub_x2 */, AMDGPU::S_BUFFER_ATOMIC_SUB_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17364 /* s_buffer_atomic_sub_x2 */, AMDGPU::S_BUFFER_ATOMIC_SUB_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17387 /* s_buffer_atomic_swap */, AMDGPU::S_BUFFER_ATOMIC_SWAP_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17387 /* s_buffer_atomic_swap */, AMDGPU::S_BUFFER_ATOMIC_SWAP_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17387 /* s_buffer_atomic_swap */, AMDGPU::S_BUFFER_ATOMIC_SWAP_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17387 /* s_buffer_atomic_swap */, AMDGPU::S_BUFFER_ATOMIC_SWAP_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17387 /* s_buffer_atomic_swap */, AMDGPU::S_BUFFER_ATOMIC_SWAP_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17387 /* s_buffer_atomic_swap */, AMDGPU::S_BUFFER_ATOMIC_SWAP_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17387 /* s_buffer_atomic_swap */, AMDGPU::S_BUFFER_ATOMIC_SWAP_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17387 /* s_buffer_atomic_swap */, AMDGPU::S_BUFFER_ATOMIC_SWAP_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17387 /* s_buffer_atomic_swap */, AMDGPU::S_BUFFER_ATOMIC_SWAP_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17387 /* s_buffer_atomic_swap */, AMDGPU::S_BUFFER_ATOMIC_SWAP_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17387 /* s_buffer_atomic_swap */, AMDGPU::S_BUFFER_ATOMIC_SWAP_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17387 /* s_buffer_atomic_swap */, AMDGPU::S_BUFFER_ATOMIC_SWAP_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17408 /* s_buffer_atomic_swap_x2 */, AMDGPU::S_BUFFER_ATOMIC_SWAP_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17408 /* s_buffer_atomic_swap_x2 */, AMDGPU::S_BUFFER_ATOMIC_SWAP_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17408 /* s_buffer_atomic_swap_x2 */, AMDGPU::S_BUFFER_ATOMIC_SWAP_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17408 /* s_buffer_atomic_swap_x2 */, AMDGPU::S_BUFFER_ATOMIC_SWAP_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17408 /* s_buffer_atomic_swap_x2 */, AMDGPU::S_BUFFER_ATOMIC_SWAP_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17408 /* s_buffer_atomic_swap_x2 */, AMDGPU::S_BUFFER_ATOMIC_SWAP_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17408 /* s_buffer_atomic_swap_x2 */, AMDGPU::S_BUFFER_ATOMIC_SWAP_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17408 /* s_buffer_atomic_swap_x2 */, AMDGPU::S_BUFFER_ATOMIC_SWAP_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17408 /* s_buffer_atomic_swap_x2 */, AMDGPU::S_BUFFER_ATOMIC_SWAP_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17408 /* s_buffer_atomic_swap_x2 */, AMDGPU::S_BUFFER_ATOMIC_SWAP_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17408 /* s_buffer_atomic_swap_x2 */, AMDGPU::S_BUFFER_ATOMIC_SWAP_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17408 /* s_buffer_atomic_swap_x2 */, AMDGPU::S_BUFFER_ATOMIC_SWAP_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17432 /* s_buffer_atomic_umax */, AMDGPU::S_BUFFER_ATOMIC_UMAX_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17432 /* s_buffer_atomic_umax */, AMDGPU::S_BUFFER_ATOMIC_UMAX_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17432 /* s_buffer_atomic_umax */, AMDGPU::S_BUFFER_ATOMIC_UMAX_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17432 /* s_buffer_atomic_umax */, AMDGPU::S_BUFFER_ATOMIC_UMAX_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17432 /* s_buffer_atomic_umax */, AMDGPU::S_BUFFER_ATOMIC_UMAX_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17432 /* s_buffer_atomic_umax */, AMDGPU::S_BUFFER_ATOMIC_UMAX_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17432 /* s_buffer_atomic_umax */, AMDGPU::S_BUFFER_ATOMIC_UMAX_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17432 /* s_buffer_atomic_umax */, AMDGPU::S_BUFFER_ATOMIC_UMAX_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17432 /* s_buffer_atomic_umax */, AMDGPU::S_BUFFER_ATOMIC_UMAX_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17432 /* s_buffer_atomic_umax */, AMDGPU::S_BUFFER_ATOMIC_UMAX_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17432 /* s_buffer_atomic_umax */, AMDGPU::S_BUFFER_ATOMIC_UMAX_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17432 /* s_buffer_atomic_umax */, AMDGPU::S_BUFFER_ATOMIC_UMAX_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17453 /* s_buffer_atomic_umax_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMAX_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17453 /* s_buffer_atomic_umax_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMAX_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17453 /* s_buffer_atomic_umax_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMAX_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17453 /* s_buffer_atomic_umax_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMAX_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17453 /* s_buffer_atomic_umax_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMAX_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17453 /* s_buffer_atomic_umax_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMAX_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17453 /* s_buffer_atomic_umax_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMAX_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17453 /* s_buffer_atomic_umax_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMAX_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17453 /* s_buffer_atomic_umax_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMAX_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17453 /* s_buffer_atomic_umax_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMAX_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17453 /* s_buffer_atomic_umax_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMAX_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17453 /* s_buffer_atomic_umax_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMAX_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17477 /* s_buffer_atomic_umin */, AMDGPU::S_BUFFER_ATOMIC_UMIN_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17477 /* s_buffer_atomic_umin */, AMDGPU::S_BUFFER_ATOMIC_UMIN_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17477 /* s_buffer_atomic_umin */, AMDGPU::S_BUFFER_ATOMIC_UMIN_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17477 /* s_buffer_atomic_umin */, AMDGPU::S_BUFFER_ATOMIC_UMIN_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17477 /* s_buffer_atomic_umin */, AMDGPU::S_BUFFER_ATOMIC_UMIN_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17477 /* s_buffer_atomic_umin */, AMDGPU::S_BUFFER_ATOMIC_UMIN_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17477 /* s_buffer_atomic_umin */, AMDGPU::S_BUFFER_ATOMIC_UMIN_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17477 /* s_buffer_atomic_umin */, AMDGPU::S_BUFFER_ATOMIC_UMIN_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17477 /* s_buffer_atomic_umin */, AMDGPU::S_BUFFER_ATOMIC_UMIN_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17477 /* s_buffer_atomic_umin */, AMDGPU::S_BUFFER_ATOMIC_UMIN_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17477 /* s_buffer_atomic_umin */, AMDGPU::S_BUFFER_ATOMIC_UMIN_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17477 /* s_buffer_atomic_umin */, AMDGPU::S_BUFFER_ATOMIC_UMIN_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17498 /* s_buffer_atomic_umin_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMIN_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17498 /* s_buffer_atomic_umin_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMIN_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17498 /* s_buffer_atomic_umin_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMIN_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17498 /* s_buffer_atomic_umin_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMIN_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17498 /* s_buffer_atomic_umin_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMIN_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17498 /* s_buffer_atomic_umin_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMIN_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17498 /* s_buffer_atomic_umin_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMIN_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17498 /* s_buffer_atomic_umin_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMIN_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17498 /* s_buffer_atomic_umin_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMIN_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17498 /* s_buffer_atomic_umin_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMIN_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17498 /* s_buffer_atomic_umin_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMIN_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17498 /* s_buffer_atomic_umin_x2 */, AMDGPU::S_BUFFER_ATOMIC_UMIN_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17522 /* s_buffer_atomic_xor */, AMDGPU::S_BUFFER_ATOMIC_XOR_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17522 /* s_buffer_atomic_xor */, AMDGPU::S_BUFFER_ATOMIC_XOR_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17522 /* s_buffer_atomic_xor */, AMDGPU::S_BUFFER_ATOMIC_XOR_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17522 /* s_buffer_atomic_xor */, AMDGPU::S_BUFFER_ATOMIC_XOR_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17522 /* s_buffer_atomic_xor */, AMDGPU::S_BUFFER_ATOMIC_XOR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17522 /* s_buffer_atomic_xor */, AMDGPU::S_BUFFER_ATOMIC_XOR_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17522 /* s_buffer_atomic_xor */, AMDGPU::S_BUFFER_ATOMIC_XOR_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17522 /* s_buffer_atomic_xor */, AMDGPU::S_BUFFER_ATOMIC_XOR_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17522 /* s_buffer_atomic_xor */, AMDGPU::S_BUFFER_ATOMIC_XOR_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17522 /* s_buffer_atomic_xor */, AMDGPU::S_BUFFER_ATOMIC_XOR_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17522 /* s_buffer_atomic_xor */, AMDGPU::S_BUFFER_ATOMIC_XOR_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17522 /* s_buffer_atomic_xor */, AMDGPU::S_BUFFER_ATOMIC_XOR_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17542 /* s_buffer_atomic_xor_x2 */, AMDGPU::S_BUFFER_ATOMIC_XOR_X2_SGPR_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17542 /* s_buffer_atomic_xor_x2 */, AMDGPU::S_BUFFER_ATOMIC_XOR_X2_SGPR_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_GLC }, },
  { 17542 /* s_buffer_atomic_xor_x2 */, AMDGPU::S_BUFFER_ATOMIC_XOR_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17542 /* s_buffer_atomic_xor_x2 */, AMDGPU::S_BUFFER_ATOMIC_XOR_X2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol_NonGLC }, },
  { 17542 /* s_buffer_atomic_xor_x2 */, AMDGPU::S_BUFFER_ATOMIC_XOR_X2_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17542 /* s_buffer_atomic_xor_x2 */, AMDGPU::S_BUFFER_ATOMIC_XOR_X2_IMM_RTN_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__SMEMOffset1_2__CPol_GLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_GLC }, },
  { 17542 /* s_buffer_atomic_xor_x2 */, AMDGPU::S_BUFFER_ATOMIC_XOR_X2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17542 /* s_buffer_atomic_xor_x2 */, AMDGPU::S_BUFFER_ATOMIC_XOR_X2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol_NonGLC1_3, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol_NonGLC }, },
  { 17542 /* s_buffer_atomic_xor_x2 */, AMDGPU::S_BUFFER_ATOMIC_XOR_X2_SGPR_IMM_RTN_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17542 /* s_buffer_atomic_xor_x2 */, AMDGPU::S_BUFFER_ATOMIC_XOR_X2_SGPR_IMM_RTN_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_GLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_GLC }, },
  { 17542 /* s_buffer_atomic_xor_x2 */, AMDGPU::S_BUFFER_ATOMIC_XOR_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17542 /* s_buffer_atomic_xor_x2 */, AMDGPU::S_BUFFER_ATOMIC_XOR_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol_NonGLC1_4, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol_NonGLC }, },
  { 17565 /* s_buffer_load_b128 */, AMDGPU::S_BUFFER_LOAD_B128_SGPR_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX11Only, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17565 /* s_buffer_load_b128 */, AMDGPU::S_BUFFER_LOAD_B128_IMM_gfx11, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX11Only, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17565 /* s_buffer_load_b128 */, AMDGPU::S_BUFFER_LOAD_B128_IMM_gfx12, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX12Plus, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17565 /* s_buffer_load_b128 */, AMDGPU::S_BUFFER_LOAD_B128_SGPR_IMM_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX11Only, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 17565 /* s_buffer_load_b128 */, AMDGPU::S_BUFFER_LOAD_B128_SGPR_IMM_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX12Plus, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_OptSMEMOffsetMod, MCK_CPol }, },
  { 17584 /* s_buffer_load_b256 */, AMDGPU::S_BUFFER_LOAD_B256_SGPR_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX11Only, { MCK_SReg_256, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17584 /* s_buffer_load_b256 */, AMDGPU::S_BUFFER_LOAD_B256_IMM_gfx11, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX11Only, { MCK_SReg_256, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17584 /* s_buffer_load_b256 */, AMDGPU::S_BUFFER_LOAD_B256_IMM_gfx12, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX12Plus, { MCK_SReg_256, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17584 /* s_buffer_load_b256 */, AMDGPU::S_BUFFER_LOAD_B256_SGPR_IMM_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX11Only, { MCK_SReg_256, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 17584 /* s_buffer_load_b256 */, AMDGPU::S_BUFFER_LOAD_B256_SGPR_IMM_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX12Plus, { MCK_SReg_256, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_OptSMEMOffsetMod, MCK_CPol }, },
  { 17603 /* s_buffer_load_b32 */, AMDGPU::S_BUFFER_LOAD_B32_SGPR_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX11Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17603 /* s_buffer_load_b32 */, AMDGPU::S_BUFFER_LOAD_B32_IMM_gfx11, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX11Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17603 /* s_buffer_load_b32 */, AMDGPU::S_BUFFER_LOAD_B32_IMM_gfx12, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX12Plus, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17603 /* s_buffer_load_b32 */, AMDGPU::S_BUFFER_LOAD_B32_SGPR_IMM_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX11Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 17603 /* s_buffer_load_b32 */, AMDGPU::S_BUFFER_LOAD_B32_SGPR_IMM_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX12Plus, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_OptSMEMOffsetMod, MCK_CPol }, },
  { 17621 /* s_buffer_load_b512 */, AMDGPU::S_BUFFER_LOAD_B512_SGPR_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX11Only, { MCK_SReg_512, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17621 /* s_buffer_load_b512 */, AMDGPU::S_BUFFER_LOAD_B512_IMM_gfx11, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX11Only, { MCK_SReg_512, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17621 /* s_buffer_load_b512 */, AMDGPU::S_BUFFER_LOAD_B512_IMM_gfx12, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX12Plus, { MCK_SReg_512, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17621 /* s_buffer_load_b512 */, AMDGPU::S_BUFFER_LOAD_B512_SGPR_IMM_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX11Only, { MCK_SReg_512, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 17621 /* s_buffer_load_b512 */, AMDGPU::S_BUFFER_LOAD_B512_SGPR_IMM_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX12Plus, { MCK_SReg_512, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_OptSMEMOffsetMod, MCK_CPol }, },
  { 17640 /* s_buffer_load_b64 */, AMDGPU::S_BUFFER_LOAD_B64_SGPR_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX11Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17640 /* s_buffer_load_b64 */, AMDGPU::S_BUFFER_LOAD_B64_IMM_gfx11, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX11Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17640 /* s_buffer_load_b64 */, AMDGPU::S_BUFFER_LOAD_B64_IMM_gfx12, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX12Plus, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17640 /* s_buffer_load_b64 */, AMDGPU::S_BUFFER_LOAD_B64_SGPR_IMM_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX11Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 17640 /* s_buffer_load_b64 */, AMDGPU::S_BUFFER_LOAD_B64_SGPR_IMM_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX12Plus, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_OptSMEMOffsetMod, MCK_CPol }, },
  { 17658 /* s_buffer_load_b96 */, AMDGPU::S_BUFFER_LOAD_B96_IMM_gfx12, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX12Plus, { MCK_SReg_96, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17658 /* s_buffer_load_b96 */, AMDGPU::S_BUFFER_LOAD_B96_SGPR_IMM_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX12Plus, { MCK_SReg_96, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_OptSMEMOffsetMod, MCK_CPol }, },
  { 17676 /* s_buffer_load_dword */, AMDGPU::S_BUFFER_LOAD_DWORD_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17676 /* s_buffer_load_dword */, AMDGPU::S_BUFFER_LOAD_DWORD_SGPR_si, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX6GFX7, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17676 /* s_buffer_load_dword */, AMDGPU::S_BUFFER_LOAD_DWORD_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17676 /* s_buffer_load_dword */, AMDGPU::S_BUFFER_LOAD_DWORD_IMM_si, Convert__Reg1_0__Reg1_1__SMRDOffset81_2__CPol1_3, AMFBS_isGFX6GFX7, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMRDOffset8, MCK_CPol }, },
  { 17676 /* s_buffer_load_dword */, AMDGPU::S_BUFFER_LOAD_DWORD_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17676 /* s_buffer_load_dword */, AMDGPU::S_BUFFER_LOAD_DWORD_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17676 /* s_buffer_load_dword */, AMDGPU::S_BUFFER_LOAD_DWORD_IMM_ci, Convert__Reg1_0__Reg1_1__SMRDLiteralOffset1_2__CPol1_3, AMFBS_isGFX7Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMRDLiteralOffset, MCK_CPol }, },
  { 17676 /* s_buffer_load_dword */, AMDGPU::S_BUFFER_LOAD_DWORD_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 17676 /* s_buffer_load_dword */, AMDGPU::S_BUFFER_LOAD_DWORD_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 17696 /* s_buffer_load_dwordx16 */, AMDGPU::S_BUFFER_LOAD_DWORDX16_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX10Only, { MCK_SReg_512, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17696 /* s_buffer_load_dwordx16 */, AMDGPU::S_BUFFER_LOAD_DWORDX16_SGPR_si, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX6GFX7, { MCK_SReg_512, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17696 /* s_buffer_load_dwordx16 */, AMDGPU::S_BUFFER_LOAD_DWORDX16_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX8GFX9, { MCK_SReg_512, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17696 /* s_buffer_load_dwordx16 */, AMDGPU::S_BUFFER_LOAD_DWORDX16_IMM_si, Convert__Reg1_0__Reg1_1__SMRDOffset81_2__CPol1_3, AMFBS_isGFX6GFX7, { MCK_SReg_512, MCK_SReg_128_XNULL, MCK_SMRDOffset8, MCK_CPol }, },
  { 17696 /* s_buffer_load_dwordx16 */, AMDGPU::S_BUFFER_LOAD_DWORDX16_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX10Only, { MCK_SReg_512, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17696 /* s_buffer_load_dwordx16 */, AMDGPU::S_BUFFER_LOAD_DWORDX16_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX8GFX9, { MCK_SReg_512, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17696 /* s_buffer_load_dwordx16 */, AMDGPU::S_BUFFER_LOAD_DWORDX16_IMM_ci, Convert__Reg1_0__Reg1_1__SMRDLiteralOffset1_2__CPol1_3, AMFBS_isGFX7Only, { MCK_SReg_512, MCK_SReg_128_XNULL, MCK_SMRDLiteralOffset, MCK_CPol }, },
  { 17696 /* s_buffer_load_dwordx16 */, AMDGPU::S_BUFFER_LOAD_DWORDX16_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX10Only, { MCK_SReg_512, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 17696 /* s_buffer_load_dwordx16 */, AMDGPU::S_BUFFER_LOAD_DWORDX16_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX9Only, { MCK_SReg_512, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 17719 /* s_buffer_load_dwordx2 */, AMDGPU::S_BUFFER_LOAD_DWORDX2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17719 /* s_buffer_load_dwordx2 */, AMDGPU::S_BUFFER_LOAD_DWORDX2_SGPR_si, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX6GFX7, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17719 /* s_buffer_load_dwordx2 */, AMDGPU::S_BUFFER_LOAD_DWORDX2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17719 /* s_buffer_load_dwordx2 */, AMDGPU::S_BUFFER_LOAD_DWORDX2_IMM_si, Convert__Reg1_0__Reg1_1__SMRDOffset81_2__CPol1_3, AMFBS_isGFX6GFX7, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMRDOffset8, MCK_CPol }, },
  { 17719 /* s_buffer_load_dwordx2 */, AMDGPU::S_BUFFER_LOAD_DWORDX2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17719 /* s_buffer_load_dwordx2 */, AMDGPU::S_BUFFER_LOAD_DWORDX2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17719 /* s_buffer_load_dwordx2 */, AMDGPU::S_BUFFER_LOAD_DWORDX2_IMM_ci, Convert__Reg1_0__Reg1_1__SMRDLiteralOffset1_2__CPol1_3, AMFBS_isGFX7Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMRDLiteralOffset, MCK_CPol }, },
  { 17719 /* s_buffer_load_dwordx2 */, AMDGPU::S_BUFFER_LOAD_DWORDX2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 17719 /* s_buffer_load_dwordx2 */, AMDGPU::S_BUFFER_LOAD_DWORDX2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 17741 /* s_buffer_load_dwordx4 */, AMDGPU::S_BUFFER_LOAD_DWORDX4_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX10Only, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17741 /* s_buffer_load_dwordx4 */, AMDGPU::S_BUFFER_LOAD_DWORDX4_SGPR_si, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX6GFX7, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17741 /* s_buffer_load_dwordx4 */, AMDGPU::S_BUFFER_LOAD_DWORDX4_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX8GFX9, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17741 /* s_buffer_load_dwordx4 */, AMDGPU::S_BUFFER_LOAD_DWORDX4_IMM_si, Convert__Reg1_0__Reg1_1__SMRDOffset81_2__CPol1_3, AMFBS_isGFX6GFX7, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SMRDOffset8, MCK_CPol }, },
  { 17741 /* s_buffer_load_dwordx4 */, AMDGPU::S_BUFFER_LOAD_DWORDX4_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX10Only, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17741 /* s_buffer_load_dwordx4 */, AMDGPU::S_BUFFER_LOAD_DWORDX4_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX8GFX9, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17741 /* s_buffer_load_dwordx4 */, AMDGPU::S_BUFFER_LOAD_DWORDX4_IMM_ci, Convert__Reg1_0__Reg1_1__SMRDLiteralOffset1_2__CPol1_3, AMFBS_isGFX7Only, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SMRDLiteralOffset, MCK_CPol }, },
  { 17741 /* s_buffer_load_dwordx4 */, AMDGPU::S_BUFFER_LOAD_DWORDX4_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX10Only, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 17741 /* s_buffer_load_dwordx4 */, AMDGPU::S_BUFFER_LOAD_DWORDX4_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX9Only, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 17763 /* s_buffer_load_dwordx8 */, AMDGPU::S_BUFFER_LOAD_DWORDX8_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX10Only, { MCK_SReg_256, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17763 /* s_buffer_load_dwordx8 */, AMDGPU::S_BUFFER_LOAD_DWORDX8_SGPR_si, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX6GFX7, { MCK_SReg_256, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17763 /* s_buffer_load_dwordx8 */, AMDGPU::S_BUFFER_LOAD_DWORDX8_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX8GFX9, { MCK_SReg_256, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17763 /* s_buffer_load_dwordx8 */, AMDGPU::S_BUFFER_LOAD_DWORDX8_IMM_si, Convert__Reg1_0__Reg1_1__SMRDOffset81_2__CPol1_3, AMFBS_isGFX6GFX7, { MCK_SReg_256, MCK_SReg_128_XNULL, MCK_SMRDOffset8, MCK_CPol }, },
  { 17763 /* s_buffer_load_dwordx8 */, AMDGPU::S_BUFFER_LOAD_DWORDX8_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX10Only, { MCK_SReg_256, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17763 /* s_buffer_load_dwordx8 */, AMDGPU::S_BUFFER_LOAD_DWORDX8_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX8GFX9, { MCK_SReg_256, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17763 /* s_buffer_load_dwordx8 */, AMDGPU::S_BUFFER_LOAD_DWORDX8_IMM_ci, Convert__Reg1_0__Reg1_1__SMRDLiteralOffset1_2__CPol1_3, AMFBS_isGFX7Only, { MCK_SReg_256, MCK_SReg_128_XNULL, MCK_SMRDLiteralOffset, MCK_CPol }, },
  { 17763 /* s_buffer_load_dwordx8 */, AMDGPU::S_BUFFER_LOAD_DWORDX8_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX10Only, { MCK_SReg_256, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 17763 /* s_buffer_load_dwordx8 */, AMDGPU::S_BUFFER_LOAD_DWORDX8_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX9Only, { MCK_SReg_256, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 17785 /* s_buffer_load_i16 */, AMDGPU::S_BUFFER_LOAD_I16_IMM_gfx12, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX12Plus, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17785 /* s_buffer_load_i16 */, AMDGPU::S_BUFFER_LOAD_I16_SGPR_IMM_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX12Plus, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_OptSMEMOffsetMod, MCK_CPol }, },
  { 17803 /* s_buffer_load_i8 */, AMDGPU::S_BUFFER_LOAD_I8_IMM_gfx12, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX12Plus, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17803 /* s_buffer_load_i8 */, AMDGPU::S_BUFFER_LOAD_I8_SGPR_IMM_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX12Plus, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_OptSMEMOffsetMod, MCK_CPol }, },
  { 17820 /* s_buffer_load_u16 */, AMDGPU::S_BUFFER_LOAD_U16_IMM_gfx12, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX12Plus, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17820 /* s_buffer_load_u16 */, AMDGPU::S_BUFFER_LOAD_U16_SGPR_IMM_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX12Plus, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_OptSMEMOffsetMod, MCK_CPol }, },
  { 17838 /* s_buffer_load_u8 */, AMDGPU::S_BUFFER_LOAD_U8_IMM_gfx12, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX12Plus, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17838 /* s_buffer_load_u8 */, AMDGPU::S_BUFFER_LOAD_U8_SGPR_IMM_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX12Plus, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_OptSMEMOffsetMod, MCK_CPol }, },
  { 17855 /* s_buffer_prefetch_data */, AMDGPU::S_BUFFER_PREFETCH_DATA_gfx12, Convert__Reg1_0__SMEMOffset1_1__Reg1_2__Imm1_3, AMFBS_isGFX12Plus, { MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_SReg_32, MCK_Imm }, },
  { 17878 /* s_buffer_store_dword */, AMDGPU::S_BUFFER_STORE_DWORD_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarStores_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17878 /* s_buffer_store_dword */, AMDGPU::S_BUFFER_STORE_DWORD_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarStores_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17878 /* s_buffer_store_dword */, AMDGPU::S_BUFFER_STORE_DWORD_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarStores_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17878 /* s_buffer_store_dword */, AMDGPU::S_BUFFER_STORE_DWORD_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarStores_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17878 /* s_buffer_store_dword */, AMDGPU::S_BUFFER_STORE_DWORD_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarStores_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 17878 /* s_buffer_store_dword */, AMDGPU::S_BUFFER_STORE_DWORD_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarStores_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 17899 /* s_buffer_store_dwordx2 */, AMDGPU::S_BUFFER_STORE_DWORDX2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarStores_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17899 /* s_buffer_store_dwordx2 */, AMDGPU::S_BUFFER_STORE_DWORDX2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarStores_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17899 /* s_buffer_store_dwordx2 */, AMDGPU::S_BUFFER_STORE_DWORDX2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarStores_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17899 /* s_buffer_store_dwordx2 */, AMDGPU::S_BUFFER_STORE_DWORDX2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarStores_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17899 /* s_buffer_store_dwordx2 */, AMDGPU::S_BUFFER_STORE_DWORDX2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarStores_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 17899 /* s_buffer_store_dwordx2 */, AMDGPU::S_BUFFER_STORE_DWORDX2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarStores_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 17922 /* s_buffer_store_dwordx4 */, AMDGPU::S_BUFFER_STORE_DWORDX4_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarStores_isGFX10Only, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17922 /* s_buffer_store_dwordx4 */, AMDGPU::S_BUFFER_STORE_DWORDX4_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarStores_isGFX8GFX9, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_CPol }, },
  { 17922 /* s_buffer_store_dwordx4 */, AMDGPU::S_BUFFER_STORE_DWORDX4_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarStores_isGFX10Only, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17922 /* s_buffer_store_dwordx4 */, AMDGPU::S_BUFFER_STORE_DWORDX4_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarStores_isGFX8GFX9, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SMEMOffset, MCK_CPol }, },
  { 17922 /* s_buffer_store_dwordx4 */, AMDGPU::S_BUFFER_STORE_DWORDX4_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarStores_isGFX10Only, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 17922 /* s_buffer_store_dwordx4 */, AMDGPU::S_BUFFER_STORE_DWORDX4_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarStores_isGFX9Only, { MCK_SReg_128, MCK_SReg_128_XNULL, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 17945 /* s_call_b64 */, AMDGPU::S_CALL_B64_gfx11, Convert__Reg1_0__SOPPBrTarget1_1, AMFBS_isNotGFX1250Plus_isGFX9Plus_isGFX11Only, { MCK_SReg_64, MCK_SOPPBrTarget }, },
  { 17945 /* s_call_b64 */, AMDGPU::S_CALL_B64_gfx12, Convert__Reg1_0__SOPPBrTarget1_1, AMFBS_isNotGFX1250Plus_isGFX9Plus_isGFX12Only, { MCK_SReg_64, MCK_SOPPBrTarget }, },
  { 17945 /* s_call_b64 */, AMDGPU::S_CALL_B64_gfx10, Convert__Reg1_0__SOPPBrTarget1_1, AMFBS_isGFX9Plus_isGFX10Only, { MCK_SReg_64, MCK_SOPPBrTarget }, },
  { 17945 /* s_call_b64 */, AMDGPU::S_CALL_B64_vi, Convert__Reg1_0__SOPPBrTarget1_1, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_SReg_64, MCK_SOPPBrTarget }, },
  { 17956 /* s_call_i64 */, AMDGPU::S_CALL_B64_gfx1250, Convert__Reg1_0__SOPPBrTarget1_1, AMFBS_isGFX9Plus_isGFX125xOnly, { MCK_SReg_64, MCK_SOPPBrTarget }, },
  { 17967 /* s_cbranch_cdbgsys */, AMDGPU::S_CBRANCH_CDBGSYS_gfx10, Convert__SOPPBrTarget1_0, AMFBS_isGFX10Only, { MCK_SOPPBrTarget }, },
  { 17967 /* s_cbranch_cdbgsys */, AMDGPU::S_CBRANCH_CDBGSYS_gfx11, Convert__SOPPBrTarget1_0, AMFBS_isGFX11Only, { MCK_SOPPBrTarget }, },
  { 17967 /* s_cbranch_cdbgsys */, AMDGPU::S_CBRANCH_CDBGSYS_gfx6_gfx7, Convert__SOPPBrTarget1_0, AMFBS_isGFX6GFX7, { MCK_SOPPBrTarget }, },
  { 17967 /* s_cbranch_cdbgsys */, AMDGPU::S_CBRANCH_CDBGSYS_vi, Convert__SOPPBrTarget1_0, AMFBS_isGFX8GFX9, { MCK_SOPPBrTarget }, },
  { 17985 /* s_cbranch_cdbgsys_and_user */, AMDGPU::S_CBRANCH_CDBGSYS_AND_USER_gfx10, Convert__SOPPBrTarget1_0, AMFBS_isGFX10Only, { MCK_SOPPBrTarget }, },
  { 17985 /* s_cbranch_cdbgsys_and_user */, AMDGPU::S_CBRANCH_CDBGSYS_AND_USER_gfx11, Convert__SOPPBrTarget1_0, AMFBS_isGFX11Only, { MCK_SOPPBrTarget }, },
  { 17985 /* s_cbranch_cdbgsys_and_user */, AMDGPU::S_CBRANCH_CDBGSYS_AND_USER_gfx6_gfx7, Convert__SOPPBrTarget1_0, AMFBS_isGFX6GFX7, { MCK_SOPPBrTarget }, },
  { 17985 /* s_cbranch_cdbgsys_and_user */, AMDGPU::S_CBRANCH_CDBGSYS_AND_USER_vi, Convert__SOPPBrTarget1_0, AMFBS_isGFX8GFX9, { MCK_SOPPBrTarget }, },
  { 18012 /* s_cbranch_cdbgsys_or_user */, AMDGPU::S_CBRANCH_CDBGSYS_OR_USER_gfx10, Convert__SOPPBrTarget1_0, AMFBS_isGFX10Only, { MCK_SOPPBrTarget }, },
  { 18012 /* s_cbranch_cdbgsys_or_user */, AMDGPU::S_CBRANCH_CDBGSYS_OR_USER_gfx11, Convert__SOPPBrTarget1_0, AMFBS_isGFX11Only, { MCK_SOPPBrTarget }, },
  { 18012 /* s_cbranch_cdbgsys_or_user */, AMDGPU::S_CBRANCH_CDBGSYS_OR_USER_gfx6_gfx7, Convert__SOPPBrTarget1_0, AMFBS_isGFX6GFX7, { MCK_SOPPBrTarget }, },
  { 18012 /* s_cbranch_cdbgsys_or_user */, AMDGPU::S_CBRANCH_CDBGSYS_OR_USER_vi, Convert__SOPPBrTarget1_0, AMFBS_isGFX8GFX9, { MCK_SOPPBrTarget }, },
  { 18038 /* s_cbranch_cdbguser */, AMDGPU::S_CBRANCH_CDBGUSER_gfx10, Convert__SOPPBrTarget1_0, AMFBS_isGFX10Only, { MCK_SOPPBrTarget }, },
  { 18038 /* s_cbranch_cdbguser */, AMDGPU::S_CBRANCH_CDBGUSER_gfx11, Convert__SOPPBrTarget1_0, AMFBS_isGFX11Only, { MCK_SOPPBrTarget }, },
  { 18038 /* s_cbranch_cdbguser */, AMDGPU::S_CBRANCH_CDBGUSER_gfx6_gfx7, Convert__SOPPBrTarget1_0, AMFBS_isGFX6GFX7, { MCK_SOPPBrTarget }, },
  { 18038 /* s_cbranch_cdbguser */, AMDGPU::S_CBRANCH_CDBGUSER_vi, Convert__SOPPBrTarget1_0, AMFBS_isGFX8GFX9, { MCK_SOPPBrTarget }, },
  { 18057 /* s_cbranch_execnz */, AMDGPU::S_CBRANCH_EXECNZ_gfx10, Convert__SOPPBrTarget1_0, AMFBS_isGFX10Only, { MCK_SOPPBrTarget }, },
  { 18057 /* s_cbranch_execnz */, AMDGPU::S_CBRANCH_EXECNZ_gfx11, Convert__SOPPBrTarget1_0, AMFBS_isGFX11Only, { MCK_SOPPBrTarget }, },
  { 18057 /* s_cbranch_execnz */, AMDGPU::S_CBRANCH_EXECNZ_gfx12, Convert__SOPPBrTarget1_0, AMFBS_isGFX12Only, { MCK_SOPPBrTarget }, },
  { 18057 /* s_cbranch_execnz */, AMDGPU::S_CBRANCH_EXECNZ_gfx6_gfx7, Convert__SOPPBrTarget1_0, AMFBS_isGFX6GFX7, { MCK_SOPPBrTarget }, },
  { 18057 /* s_cbranch_execnz */, AMDGPU::S_CBRANCH_EXECNZ_vi, Convert__SOPPBrTarget1_0, AMFBS_isGFX8GFX9, { MCK_SOPPBrTarget }, },
  { 18074 /* s_cbranch_execz */, AMDGPU::S_CBRANCH_EXECZ_gfx10, Convert__SOPPBrTarget1_0, AMFBS_isGFX10Only, { MCK_SOPPBrTarget }, },
  { 18074 /* s_cbranch_execz */, AMDGPU::S_CBRANCH_EXECZ_gfx11, Convert__SOPPBrTarget1_0, AMFBS_isGFX11Only, { MCK_SOPPBrTarget }, },
  { 18074 /* s_cbranch_execz */, AMDGPU::S_CBRANCH_EXECZ_gfx12, Convert__SOPPBrTarget1_0, AMFBS_isGFX12Only, { MCK_SOPPBrTarget }, },
  { 18074 /* s_cbranch_execz */, AMDGPU::S_CBRANCH_EXECZ_gfx6_gfx7, Convert__SOPPBrTarget1_0, AMFBS_isGFX6GFX7, { MCK_SOPPBrTarget }, },
  { 18074 /* s_cbranch_execz */, AMDGPU::S_CBRANCH_EXECZ_vi, Convert__SOPPBrTarget1_0, AMFBS_isGFX8GFX9, { MCK_SOPPBrTarget }, },
  { 18090 /* s_cbranch_g_fork */, AMDGPU::S_CBRANCH_G_FORK_gfx6_gfx7, Convert__SCSrc_b641_0__SCSrc_b641_1, AMFBS_isGFX6GFX7GFX8GFX9_isGFX6GFX7, { MCK_SCSrc_b64, MCK_SCSrc_b64 }, },
  { 18090 /* s_cbranch_g_fork */, AMDGPU::S_CBRANCH_G_FORK_vi, Convert__SCSrc_b641_0__SCSrc_b641_1, AMFBS_isGFX6GFX7GFX8GFX9_isGFX8GFX9, { MCK_SCSrc_b64, MCK_SCSrc_b64 }, },
  { 18107 /* s_cbranch_i_fork */, AMDGPU::S_CBRANCH_I_FORK_gfx6_gfx7, Convert__Reg1_0__SOPPBrTarget1_1, AMFBS_isGFX6GFX7GFX8GFX9_isGFX6GFX7, { MCK_SReg_64, MCK_SOPPBrTarget }, },
  { 18107 /* s_cbranch_i_fork */, AMDGPU::S_CBRANCH_I_FORK_vi, Convert__Reg1_0__SOPPBrTarget1_1, AMFBS_isGFX6GFX7GFX8GFX9_isGFX8GFX9, { MCK_SReg_64, MCK_SOPPBrTarget }, },
  { 18124 /* s_cbranch_join */, AMDGPU::S_CBRANCH_JOIN_gfx6_gfx7, Convert__Reg1_0, AMFBS_isGFX6GFX7GFX8GFX9_isGFX6GFX7, { MCK_SReg_32 }, },
  { 18124 /* s_cbranch_join */, AMDGPU::S_CBRANCH_JOIN_vi, Convert__Reg1_0, AMFBS_isGFX6GFX7GFX8GFX9_isGFX8GFX9, { MCK_SReg_32 }, },
  { 18139 /* s_cbranch_scc0 */, AMDGPU::S_CBRANCH_SCC0_gfx10, Convert__SOPPBrTarget1_0, AMFBS_isGFX10Only, { MCK_SOPPBrTarget }, },
  { 18139 /* s_cbranch_scc0 */, AMDGPU::S_CBRANCH_SCC0_gfx11, Convert__SOPPBrTarget1_0, AMFBS_isGFX11Only, { MCK_SOPPBrTarget }, },
  { 18139 /* s_cbranch_scc0 */, AMDGPU::S_CBRANCH_SCC0_gfx12, Convert__SOPPBrTarget1_0, AMFBS_isGFX12Only, { MCK_SOPPBrTarget }, },
  { 18139 /* s_cbranch_scc0 */, AMDGPU::S_CBRANCH_SCC0_gfx6_gfx7, Convert__SOPPBrTarget1_0, AMFBS_isGFX6GFX7, { MCK_SOPPBrTarget }, },
  { 18139 /* s_cbranch_scc0 */, AMDGPU::S_CBRANCH_SCC0_vi, Convert__SOPPBrTarget1_0, AMFBS_isGFX8GFX9, { MCK_SOPPBrTarget }, },
  { 18154 /* s_cbranch_scc1 */, AMDGPU::S_CBRANCH_SCC1_gfx10, Convert__SOPPBrTarget1_0, AMFBS_isGFX10Only, { MCK_SOPPBrTarget }, },
  { 18154 /* s_cbranch_scc1 */, AMDGPU::S_CBRANCH_SCC1_gfx11, Convert__SOPPBrTarget1_0, AMFBS_isGFX11Only, { MCK_SOPPBrTarget }, },
  { 18154 /* s_cbranch_scc1 */, AMDGPU::S_CBRANCH_SCC1_gfx12, Convert__SOPPBrTarget1_0, AMFBS_isGFX12Only, { MCK_SOPPBrTarget }, },
  { 18154 /* s_cbranch_scc1 */, AMDGPU::S_CBRANCH_SCC1_gfx6_gfx7, Convert__SOPPBrTarget1_0, AMFBS_isGFX6GFX7, { MCK_SOPPBrTarget }, },
  { 18154 /* s_cbranch_scc1 */, AMDGPU::S_CBRANCH_SCC1_vi, Convert__SOPPBrTarget1_0, AMFBS_isGFX8GFX9, { MCK_SOPPBrTarget }, },
  { 18169 /* s_cbranch_vccnz */, AMDGPU::S_CBRANCH_VCCNZ_gfx10, Convert__SOPPBrTarget1_0, AMFBS_isGFX10Only, { MCK_SOPPBrTarget }, },
  { 18169 /* s_cbranch_vccnz */, AMDGPU::S_CBRANCH_VCCNZ_gfx11, Convert__SOPPBrTarget1_0, AMFBS_isGFX11Only, { MCK_SOPPBrTarget }, },
  { 18169 /* s_cbranch_vccnz */, AMDGPU::S_CBRANCH_VCCNZ_gfx12, Convert__SOPPBrTarget1_0, AMFBS_isGFX12Only, { MCK_SOPPBrTarget }, },
  { 18169 /* s_cbranch_vccnz */, AMDGPU::S_CBRANCH_VCCNZ_gfx6_gfx7, Convert__SOPPBrTarget1_0, AMFBS_isGFX6GFX7, { MCK_SOPPBrTarget }, },
  { 18169 /* s_cbranch_vccnz */, AMDGPU::S_CBRANCH_VCCNZ_vi, Convert__SOPPBrTarget1_0, AMFBS_isGFX8GFX9, { MCK_SOPPBrTarget }, },
  { 18185 /* s_cbranch_vccz */, AMDGPU::S_CBRANCH_VCCZ_gfx10, Convert__SOPPBrTarget1_0, AMFBS_isGFX10Only, { MCK_SOPPBrTarget }, },
  { 18185 /* s_cbranch_vccz */, AMDGPU::S_CBRANCH_VCCZ_gfx11, Convert__SOPPBrTarget1_0, AMFBS_isGFX11Only, { MCK_SOPPBrTarget }, },
  { 18185 /* s_cbranch_vccz */, AMDGPU::S_CBRANCH_VCCZ_gfx12, Convert__SOPPBrTarget1_0, AMFBS_isGFX12Only, { MCK_SOPPBrTarget }, },
  { 18185 /* s_cbranch_vccz */, AMDGPU::S_CBRANCH_VCCZ_gfx6_gfx7, Convert__SOPPBrTarget1_0, AMFBS_isGFX6GFX7, { MCK_SOPPBrTarget }, },
  { 18185 /* s_cbranch_vccz */, AMDGPU::S_CBRANCH_VCCZ_vi, Convert__SOPPBrTarget1_0, AMFBS_isGFX8GFX9, { MCK_SOPPBrTarget }, },
  { 18200 /* s_ceil_f16 */, AMDGPU::S_CEIL_F16_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 18200 /* s_ceil_f16 */, AMDGPU::S_CEIL_F16_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 18211 /* s_ceil_f32 */, AMDGPU::S_CEIL_F32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 18211 /* s_ceil_f32 */, AMDGPU::S_CEIL_F32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 18222 /* s_clause */, AMDGPU::S_CLAUSE_gfx10, Convert__S16Imm1_0, AMFBS_isGFX10Plus_isGFX10Only, { MCK_S16Imm }, },
  { 18222 /* s_clause */, AMDGPU::S_CLAUSE_gfx11, Convert__S16Imm1_0, AMFBS_isGFX10Plus_isGFX11Only, { MCK_S16Imm }, },
  { 18222 /* s_clause */, AMDGPU::S_CLAUSE_gfx12, Convert__S16Imm1_0, AMFBS_isGFX10Plus_isGFX12Only, { MCK_S16Imm }, },
  { 18231 /* s_cls_i32 */, AMDGPU::S_FLBIT_I32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 18231 /* s_cls_i32 */, AMDGPU::S_FLBIT_I32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 18241 /* s_cls_i32_i64 */, AMDGPU::S_FLBIT_I32_I64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 18241 /* s_cls_i32_i64 */, AMDGPU::S_FLBIT_I32_I64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 18255 /* s_clz_i32_u32 */, AMDGPU::S_FLBIT_I32_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 18255 /* s_clz_i32_u32 */, AMDGPU::S_FLBIT_I32_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 18269 /* s_clz_i32_u64 */, AMDGPU::S_FLBIT_I32_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 18269 /* s_clz_i32_u64 */, AMDGPU::S_FLBIT_I32_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 18283 /* s_cmov_b32 */, AMDGPU::S_CMOV_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 18283 /* s_cmov_b32 */, AMDGPU::S_CMOV_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 18283 /* s_cmov_b32 */, AMDGPU::S_CMOV_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 18283 /* s_cmov_b32 */, AMDGPU::S_CMOV_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 18283 /* s_cmov_b32 */, AMDGPU::S_CMOV_B32_vi, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 18294 /* s_cmov_b64 */, AMDGPU::S_CMOV_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 18294 /* s_cmov_b64 */, AMDGPU::S_CMOV_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 18294 /* s_cmov_b64 */, AMDGPU::S_CMOV_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 18294 /* s_cmov_b64 */, AMDGPU::S_CMOV_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 18294 /* s_cmov_b64 */, AMDGPU::S_CMOV_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 18305 /* s_cmovk_i32 */, AMDGPU::S_CMOVK_I32_gfx10, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 18305 /* s_cmovk_i32 */, AMDGPU::S_CMOVK_I32_gfx11, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 18305 /* s_cmovk_i32 */, AMDGPU::S_CMOVK_I32_gfx12, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 18305 /* s_cmovk_i32 */, AMDGPU::S_CMOVK_I32_gfx6_gfx7, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_S16Imm }, },
  { 18305 /* s_cmovk_i32 */, AMDGPU::S_CMOVK_I32_vi, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_S16Imm }, },
  { 18317 /* s_cmp_eq_f16 */, AMDGPU::S_CMP_EQ_F16_gfx11, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18317 /* s_cmp_eq_f16 */, AMDGPU::S_CMP_EQ_F16_gfx12, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18330 /* s_cmp_eq_f32 */, AMDGPU::S_CMP_EQ_F32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18330 /* s_cmp_eq_f32 */, AMDGPU::S_CMP_EQ_F32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18343 /* s_cmp_eq_i32 */, AMDGPU::S_CMP_EQ_I32_gfx10, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18343 /* s_cmp_eq_i32 */, AMDGPU::S_CMP_EQ_I32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18343 /* s_cmp_eq_i32 */, AMDGPU::S_CMP_EQ_I32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18343 /* s_cmp_eq_i32 */, AMDGPU::S_CMP_EQ_I32_gfx6_gfx7, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18343 /* s_cmp_eq_i32 */, AMDGPU::S_CMP_EQ_I32_vi, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18356 /* s_cmp_eq_u32 */, AMDGPU::S_CMP_EQ_U32_gfx10, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18356 /* s_cmp_eq_u32 */, AMDGPU::S_CMP_EQ_U32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18356 /* s_cmp_eq_u32 */, AMDGPU::S_CMP_EQ_U32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18356 /* s_cmp_eq_u32 */, AMDGPU::S_CMP_EQ_U32_gfx6_gfx7, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18356 /* s_cmp_eq_u32 */, AMDGPU::S_CMP_EQ_U32_vi, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18369 /* s_cmp_eq_u64 */, AMDGPU::S_CMP_EQ_U64_gfx10, Convert__SSrc_b641_0__SSrc_b641_1, AMFBS_isGFX8Plus_isGFX10Only, { MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 18369 /* s_cmp_eq_u64 */, AMDGPU::S_CMP_EQ_U64_gfx11, Convert__SSrc_b641_0__SSrc_b641_1, AMFBS_isGFX8Plus_isGFX11Only, { MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 18369 /* s_cmp_eq_u64 */, AMDGPU::S_CMP_EQ_U64_gfx12, Convert__SSrc_b641_0__SSrc_b641_1, AMFBS_isGFX8Plus_isGFX12Only, { MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 18369 /* s_cmp_eq_u64 */, AMDGPU::S_CMP_EQ_U64_vi, Convert__SSrc_b641_0__SSrc_b641_1, AMFBS_isGFX8Plus_isGFX8GFX9, { MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 18382 /* s_cmp_ge_f16 */, AMDGPU::S_CMP_GE_F16_gfx11, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18382 /* s_cmp_ge_f16 */, AMDGPU::S_CMP_GE_F16_gfx12, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18395 /* s_cmp_ge_f32 */, AMDGPU::S_CMP_GE_F32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18395 /* s_cmp_ge_f32 */, AMDGPU::S_CMP_GE_F32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18408 /* s_cmp_ge_i32 */, AMDGPU::S_CMP_GE_I32_gfx10, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18408 /* s_cmp_ge_i32 */, AMDGPU::S_CMP_GE_I32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18408 /* s_cmp_ge_i32 */, AMDGPU::S_CMP_GE_I32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18408 /* s_cmp_ge_i32 */, AMDGPU::S_CMP_GE_I32_gfx6_gfx7, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18408 /* s_cmp_ge_i32 */, AMDGPU::S_CMP_GE_I32_vi, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18421 /* s_cmp_ge_u32 */, AMDGPU::S_CMP_GE_U32_gfx10, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18421 /* s_cmp_ge_u32 */, AMDGPU::S_CMP_GE_U32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18421 /* s_cmp_ge_u32 */, AMDGPU::S_CMP_GE_U32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18421 /* s_cmp_ge_u32 */, AMDGPU::S_CMP_GE_U32_gfx6_gfx7, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18421 /* s_cmp_ge_u32 */, AMDGPU::S_CMP_GE_U32_vi, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18434 /* s_cmp_gt_f16 */, AMDGPU::S_CMP_GT_F16_gfx11, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18434 /* s_cmp_gt_f16 */, AMDGPU::S_CMP_GT_F16_gfx12, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18447 /* s_cmp_gt_f32 */, AMDGPU::S_CMP_GT_F32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18447 /* s_cmp_gt_f32 */, AMDGPU::S_CMP_GT_F32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18460 /* s_cmp_gt_i32 */, AMDGPU::S_CMP_GT_I32_gfx10, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18460 /* s_cmp_gt_i32 */, AMDGPU::S_CMP_GT_I32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18460 /* s_cmp_gt_i32 */, AMDGPU::S_CMP_GT_I32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18460 /* s_cmp_gt_i32 */, AMDGPU::S_CMP_GT_I32_gfx6_gfx7, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18460 /* s_cmp_gt_i32 */, AMDGPU::S_CMP_GT_I32_vi, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18473 /* s_cmp_gt_u32 */, AMDGPU::S_CMP_GT_U32_gfx10, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18473 /* s_cmp_gt_u32 */, AMDGPU::S_CMP_GT_U32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18473 /* s_cmp_gt_u32 */, AMDGPU::S_CMP_GT_U32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18473 /* s_cmp_gt_u32 */, AMDGPU::S_CMP_GT_U32_gfx6_gfx7, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18473 /* s_cmp_gt_u32 */, AMDGPU::S_CMP_GT_U32_vi, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18486 /* s_cmp_le_f16 */, AMDGPU::S_CMP_LE_F16_gfx11, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18486 /* s_cmp_le_f16 */, AMDGPU::S_CMP_LE_F16_gfx12, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18499 /* s_cmp_le_f32 */, AMDGPU::S_CMP_LE_F32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18499 /* s_cmp_le_f32 */, AMDGPU::S_CMP_LE_F32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18512 /* s_cmp_le_i32 */, AMDGPU::S_CMP_LE_I32_gfx10, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18512 /* s_cmp_le_i32 */, AMDGPU::S_CMP_LE_I32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18512 /* s_cmp_le_i32 */, AMDGPU::S_CMP_LE_I32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18512 /* s_cmp_le_i32 */, AMDGPU::S_CMP_LE_I32_gfx6_gfx7, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18512 /* s_cmp_le_i32 */, AMDGPU::S_CMP_LE_I32_vi, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18525 /* s_cmp_le_u32 */, AMDGPU::S_CMP_LE_U32_gfx10, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18525 /* s_cmp_le_u32 */, AMDGPU::S_CMP_LE_U32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18525 /* s_cmp_le_u32 */, AMDGPU::S_CMP_LE_U32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18525 /* s_cmp_le_u32 */, AMDGPU::S_CMP_LE_U32_gfx6_gfx7, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18525 /* s_cmp_le_u32 */, AMDGPU::S_CMP_LE_U32_vi, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18538 /* s_cmp_lg_f16 */, AMDGPU::S_CMP_LG_F16_gfx11, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18538 /* s_cmp_lg_f16 */, AMDGPU::S_CMP_LG_F16_gfx12, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18551 /* s_cmp_lg_f32 */, AMDGPU::S_CMP_LG_F32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18551 /* s_cmp_lg_f32 */, AMDGPU::S_CMP_LG_F32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18564 /* s_cmp_lg_i32 */, AMDGPU::S_CMP_LG_I32_gfx10, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18564 /* s_cmp_lg_i32 */, AMDGPU::S_CMP_LG_I32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18564 /* s_cmp_lg_i32 */, AMDGPU::S_CMP_LG_I32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18564 /* s_cmp_lg_i32 */, AMDGPU::S_CMP_LG_I32_gfx6_gfx7, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18564 /* s_cmp_lg_i32 */, AMDGPU::S_CMP_LG_I32_vi, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18577 /* s_cmp_lg_u32 */, AMDGPU::S_CMP_LG_U32_gfx10, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18577 /* s_cmp_lg_u32 */, AMDGPU::S_CMP_LG_U32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18577 /* s_cmp_lg_u32 */, AMDGPU::S_CMP_LG_U32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18577 /* s_cmp_lg_u32 */, AMDGPU::S_CMP_LG_U32_gfx6_gfx7, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18577 /* s_cmp_lg_u32 */, AMDGPU::S_CMP_LG_U32_vi, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18590 /* s_cmp_lg_u64 */, AMDGPU::S_CMP_LG_U64_gfx10, Convert__SSrc_b641_0__SSrc_b641_1, AMFBS_isGFX8Plus_isGFX10Only, { MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 18590 /* s_cmp_lg_u64 */, AMDGPU::S_CMP_LG_U64_gfx11, Convert__SSrc_b641_0__SSrc_b641_1, AMFBS_isGFX8Plus_isGFX11Only, { MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 18590 /* s_cmp_lg_u64 */, AMDGPU::S_CMP_LG_U64_gfx12, Convert__SSrc_b641_0__SSrc_b641_1, AMFBS_isGFX8Plus_isGFX12Only, { MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 18590 /* s_cmp_lg_u64 */, AMDGPU::S_CMP_LG_U64_vi, Convert__SSrc_b641_0__SSrc_b641_1, AMFBS_isGFX8Plus_isGFX8GFX9, { MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 18603 /* s_cmp_lt_f16 */, AMDGPU::S_CMP_LT_F16_gfx11, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18603 /* s_cmp_lt_f16 */, AMDGPU::S_CMP_LT_F16_gfx12, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18616 /* s_cmp_lt_f32 */, AMDGPU::S_CMP_LT_F32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18616 /* s_cmp_lt_f32 */, AMDGPU::S_CMP_LT_F32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18629 /* s_cmp_lt_i32 */, AMDGPU::S_CMP_LT_I32_gfx10, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18629 /* s_cmp_lt_i32 */, AMDGPU::S_CMP_LT_I32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18629 /* s_cmp_lt_i32 */, AMDGPU::S_CMP_LT_I32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18629 /* s_cmp_lt_i32 */, AMDGPU::S_CMP_LT_I32_gfx6_gfx7, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18629 /* s_cmp_lt_i32 */, AMDGPU::S_CMP_LT_I32_vi, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18642 /* s_cmp_lt_u32 */, AMDGPU::S_CMP_LT_U32_gfx10, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18642 /* s_cmp_lt_u32 */, AMDGPU::S_CMP_LT_U32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18642 /* s_cmp_lt_u32 */, AMDGPU::S_CMP_LT_U32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18642 /* s_cmp_lt_u32 */, AMDGPU::S_CMP_LT_U32_gfx6_gfx7, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18642 /* s_cmp_lt_u32 */, AMDGPU::S_CMP_LT_U32_vi, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18655 /* s_cmp_neq_f16 */, AMDGPU::S_CMP_NEQ_F16_gfx11, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18655 /* s_cmp_neq_f16 */, AMDGPU::S_CMP_NEQ_F16_gfx12, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18669 /* s_cmp_neq_f32 */, AMDGPU::S_CMP_NEQ_F32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18669 /* s_cmp_neq_f32 */, AMDGPU::S_CMP_NEQ_F32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18683 /* s_cmp_nge_f16 */, AMDGPU::S_CMP_NGE_F16_gfx11, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18683 /* s_cmp_nge_f16 */, AMDGPU::S_CMP_NGE_F16_gfx12, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18697 /* s_cmp_nge_f32 */, AMDGPU::S_CMP_NGE_F32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18697 /* s_cmp_nge_f32 */, AMDGPU::S_CMP_NGE_F32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18711 /* s_cmp_ngt_f16 */, AMDGPU::S_CMP_NGT_F16_gfx11, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18711 /* s_cmp_ngt_f16 */, AMDGPU::S_CMP_NGT_F16_gfx12, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18725 /* s_cmp_ngt_f32 */, AMDGPU::S_CMP_NGT_F32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18725 /* s_cmp_ngt_f32 */, AMDGPU::S_CMP_NGT_F32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18739 /* s_cmp_nle_f16 */, AMDGPU::S_CMP_NLE_F16_gfx11, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18739 /* s_cmp_nle_f16 */, AMDGPU::S_CMP_NLE_F16_gfx12, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18753 /* s_cmp_nle_f32 */, AMDGPU::S_CMP_NLE_F32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18753 /* s_cmp_nle_f32 */, AMDGPU::S_CMP_NLE_F32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18767 /* s_cmp_nlg_f16 */, AMDGPU::S_CMP_NLG_F16_gfx11, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18767 /* s_cmp_nlg_f16 */, AMDGPU::S_CMP_NLG_F16_gfx12, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18781 /* s_cmp_nlg_f32 */, AMDGPU::S_CMP_NLG_F32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18781 /* s_cmp_nlg_f32 */, AMDGPU::S_CMP_NLG_F32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18795 /* s_cmp_nlt_f16 */, AMDGPU::S_CMP_NLT_F16_gfx11, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18795 /* s_cmp_nlt_f16 */, AMDGPU::S_CMP_NLT_F16_gfx12, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18809 /* s_cmp_nlt_f32 */, AMDGPU::S_CMP_NLT_F32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18809 /* s_cmp_nlt_f32 */, AMDGPU::S_CMP_NLT_F32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18823 /* s_cmp_o_f16 */, AMDGPU::S_CMP_O_F16_gfx11, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18823 /* s_cmp_o_f16 */, AMDGPU::S_CMP_O_F16_gfx12, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18835 /* s_cmp_o_f32 */, AMDGPU::S_CMP_O_F32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18835 /* s_cmp_o_f32 */, AMDGPU::S_CMP_O_F32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18847 /* s_cmp_u_f16 */, AMDGPU::S_CMP_U_F16_gfx11, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18847 /* s_cmp_u_f16 */, AMDGPU::S_CMP_U_F16_gfx12, Convert__SSrc_b161_0__SSrc_b161_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b16, MCK_SSrc_b16 }, },
  { 18859 /* s_cmp_u_f32 */, AMDGPU::S_CMP_U_F32_gfx11, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18859 /* s_cmp_u_f32 */, AMDGPU::S_CMP_U_F32_gfx12, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 18871 /* s_cmpk_eq_i32 */, AMDGPU::S_CMPK_EQ_I32_gfx10, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 18871 /* s_cmpk_eq_i32 */, AMDGPU::S_CMPK_EQ_I32_gfx11, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 18871 /* s_cmpk_eq_i32 */, AMDGPU::S_CMPK_EQ_I32_gfx6_gfx7, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_S16Imm }, },
  { 18871 /* s_cmpk_eq_i32 */, AMDGPU::S_CMPK_EQ_I32_vi, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_S16Imm }, },
  { 18885 /* s_cmpk_eq_u32 */, AMDGPU::S_CMPK_EQ_U32_gfx10, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_U16Imm }, },
  { 18885 /* s_cmpk_eq_u32 */, AMDGPU::S_CMPK_EQ_U32_gfx11, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_U16Imm }, },
  { 18885 /* s_cmpk_eq_u32 */, AMDGPU::S_CMPK_EQ_U32_gfx6_gfx7, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_U16Imm }, },
  { 18885 /* s_cmpk_eq_u32 */, AMDGPU::S_CMPK_EQ_U32_vi, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_U16Imm }, },
  { 18899 /* s_cmpk_ge_i32 */, AMDGPU::S_CMPK_GE_I32_gfx10, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 18899 /* s_cmpk_ge_i32 */, AMDGPU::S_CMPK_GE_I32_gfx11, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 18899 /* s_cmpk_ge_i32 */, AMDGPU::S_CMPK_GE_I32_gfx6_gfx7, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_S16Imm }, },
  { 18899 /* s_cmpk_ge_i32 */, AMDGPU::S_CMPK_GE_I32_vi, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_S16Imm }, },
  { 18913 /* s_cmpk_ge_u32 */, AMDGPU::S_CMPK_GE_U32_gfx10, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_U16Imm }, },
  { 18913 /* s_cmpk_ge_u32 */, AMDGPU::S_CMPK_GE_U32_gfx11, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_U16Imm }, },
  { 18913 /* s_cmpk_ge_u32 */, AMDGPU::S_CMPK_GE_U32_gfx6_gfx7, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_U16Imm }, },
  { 18913 /* s_cmpk_ge_u32 */, AMDGPU::S_CMPK_GE_U32_vi, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_U16Imm }, },
  { 18927 /* s_cmpk_gt_i32 */, AMDGPU::S_CMPK_GT_I32_gfx10, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 18927 /* s_cmpk_gt_i32 */, AMDGPU::S_CMPK_GT_I32_gfx11, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 18927 /* s_cmpk_gt_i32 */, AMDGPU::S_CMPK_GT_I32_gfx6_gfx7, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_S16Imm }, },
  { 18927 /* s_cmpk_gt_i32 */, AMDGPU::S_CMPK_GT_I32_vi, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_S16Imm }, },
  { 18941 /* s_cmpk_gt_u32 */, AMDGPU::S_CMPK_GT_U32_gfx10, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_U16Imm }, },
  { 18941 /* s_cmpk_gt_u32 */, AMDGPU::S_CMPK_GT_U32_gfx11, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_U16Imm }, },
  { 18941 /* s_cmpk_gt_u32 */, AMDGPU::S_CMPK_GT_U32_gfx6_gfx7, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_U16Imm }, },
  { 18941 /* s_cmpk_gt_u32 */, AMDGPU::S_CMPK_GT_U32_vi, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_U16Imm }, },
  { 18955 /* s_cmpk_le_i32 */, AMDGPU::S_CMPK_LE_I32_gfx10, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 18955 /* s_cmpk_le_i32 */, AMDGPU::S_CMPK_LE_I32_gfx11, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 18955 /* s_cmpk_le_i32 */, AMDGPU::S_CMPK_LE_I32_gfx6_gfx7, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_S16Imm }, },
  { 18955 /* s_cmpk_le_i32 */, AMDGPU::S_CMPK_LE_I32_vi, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_S16Imm }, },
  { 18969 /* s_cmpk_le_u32 */, AMDGPU::S_CMPK_LE_U32_gfx10, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_U16Imm }, },
  { 18969 /* s_cmpk_le_u32 */, AMDGPU::S_CMPK_LE_U32_gfx11, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_U16Imm }, },
  { 18969 /* s_cmpk_le_u32 */, AMDGPU::S_CMPK_LE_U32_gfx6_gfx7, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_U16Imm }, },
  { 18969 /* s_cmpk_le_u32 */, AMDGPU::S_CMPK_LE_U32_vi, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_U16Imm }, },
  { 18983 /* s_cmpk_lg_i32 */, AMDGPU::S_CMPK_LG_I32_gfx10, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 18983 /* s_cmpk_lg_i32 */, AMDGPU::S_CMPK_LG_I32_gfx11, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 18983 /* s_cmpk_lg_i32 */, AMDGPU::S_CMPK_LG_I32_gfx6_gfx7, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_S16Imm }, },
  { 18983 /* s_cmpk_lg_i32 */, AMDGPU::S_CMPK_LG_I32_vi, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_S16Imm }, },
  { 18997 /* s_cmpk_lg_u32 */, AMDGPU::S_CMPK_LG_U32_gfx10, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_U16Imm }, },
  { 18997 /* s_cmpk_lg_u32 */, AMDGPU::S_CMPK_LG_U32_gfx11, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_U16Imm }, },
  { 18997 /* s_cmpk_lg_u32 */, AMDGPU::S_CMPK_LG_U32_gfx6_gfx7, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_U16Imm }, },
  { 18997 /* s_cmpk_lg_u32 */, AMDGPU::S_CMPK_LG_U32_vi, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_U16Imm }, },
  { 19011 /* s_cmpk_lt_i32 */, AMDGPU::S_CMPK_LT_I32_gfx10, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 19011 /* s_cmpk_lt_i32 */, AMDGPU::S_CMPK_LT_I32_gfx11, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 19011 /* s_cmpk_lt_i32 */, AMDGPU::S_CMPK_LT_I32_gfx6_gfx7, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_S16Imm }, },
  { 19011 /* s_cmpk_lt_i32 */, AMDGPU::S_CMPK_LT_I32_vi, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_S16Imm }, },
  { 19025 /* s_cmpk_lt_u32 */, AMDGPU::S_CMPK_LT_U32_gfx10, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_U16Imm }, },
  { 19025 /* s_cmpk_lt_u32 */, AMDGPU::S_CMPK_LT_U32_gfx11, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_U16Imm }, },
  { 19025 /* s_cmpk_lt_u32 */, AMDGPU::S_CMPK_LT_U32_gfx6_gfx7, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_U16Imm }, },
  { 19025 /* s_cmpk_lt_u32 */, AMDGPU::S_CMPK_LT_U32_vi, Convert__Reg1_0__U16Imm1_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_U16Imm }, },
  { 19039 /* s_code_end */, AMDGPU::S_CODE_END_gfx10, Convert_NoOperands, AMFBS_isGFX10Plus_isGFX10Only, {  }, },
  { 19039 /* s_code_end */, AMDGPU::S_CODE_END_gfx11, Convert_NoOperands, AMFBS_isGFX10Plus_isGFX11Only, {  }, },
  { 19039 /* s_code_end */, AMDGPU::S_CODE_END_gfx12, Convert_NoOperands, AMFBS_isGFX10Plus_isGFX12Only, {  }, },
  { 19050 /* s_cselect_b32 */, AMDGPU::S_CSELECT_B32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 19050 /* s_cselect_b32 */, AMDGPU::S_CSELECT_B32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 19050 /* s_cselect_b32 */, AMDGPU::S_CSELECT_B32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 19050 /* s_cselect_b32 */, AMDGPU::S_CSELECT_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 19050 /* s_cselect_b32 */, AMDGPU::S_CSELECT_B32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 19064 /* s_cselect_b64 */, AMDGPU::S_CSELECT_B64_gfx10, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 19064 /* s_cselect_b64 */, AMDGPU::S_CSELECT_B64_gfx11, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 19064 /* s_cselect_b64 */, AMDGPU::S_CSELECT_B64_gfx12, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 19064 /* s_cselect_b64 */, AMDGPU::S_CSELECT_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 19064 /* s_cselect_b64 */, AMDGPU::S_CSELECT_B64_vi, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 19078 /* s_ctz_i32_b32 */, AMDGPU::S_FF1_I32_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19078 /* s_ctz_i32_b32 */, AMDGPU::S_FF1_I32_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19092 /* s_ctz_i32_b64 */, AMDGPU::S_FF1_I32_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 19092 /* s_ctz_i32_b64 */, AMDGPU::S_FF1_I32_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 19106 /* s_cvt_f16_f32 */, AMDGPU::S_CVT_F16_F32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19106 /* s_cvt_f16_f32 */, AMDGPU::S_CVT_F16_F32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19120 /* s_cvt_f32_f16 */, AMDGPU::S_CVT_F32_F16_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19120 /* s_cvt_f32_f16 */, AMDGPU::S_CVT_F32_F16_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19134 /* s_cvt_f32_i32 */, AMDGPU::S_CVT_F32_I32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19134 /* s_cvt_f32_i32 */, AMDGPU::S_CVT_F32_I32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19148 /* s_cvt_f32_u32 */, AMDGPU::S_CVT_F32_U32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19148 /* s_cvt_f32_u32 */, AMDGPU::S_CVT_F32_U32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19162 /* s_cvt_hi_f32_f16 */, AMDGPU::S_CVT_HI_F32_F16_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19162 /* s_cvt_hi_f32_f16 */, AMDGPU::S_CVT_HI_F32_F16_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19179 /* s_cvt_i32_f32 */, AMDGPU::S_CVT_I32_F32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19179 /* s_cvt_i32_f32 */, AMDGPU::S_CVT_I32_F32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19193 /* s_cvt_pk_rtz_f16_f32 */, AMDGPU::S_CVT_PK_RTZ_F16_F32_gfx11, Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_f32, MCK_SSrc_f32 }, },
  { 19193 /* s_cvt_pk_rtz_f16_f32 */, AMDGPU::S_CVT_PK_RTZ_F16_F32_gfx12, Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_f32, MCK_SSrc_f32 }, },
  { 19214 /* s_cvt_u32_f32 */, AMDGPU::S_CVT_U32_F32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19214 /* s_cvt_u32_f32 */, AMDGPU::S_CVT_U32_F32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19228 /* s_dcache_discard */, AMDGPU::S_DCACHE_DISCARD_SGPR_gfx10, Convert__Reg1_0__Reg1_1, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64, MCK_SReg_32 }, },
  { 19228 /* s_dcache_discard */, AMDGPU::S_DCACHE_DISCARD_SGPR_vi, Convert__Reg1_0__Reg1_1, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64, MCK_SReg_32 }, },
  { 19228 /* s_dcache_discard */, AMDGPU::S_DCACHE_DISCARD_IMM_gfx10, Convert__Reg1_0__SMEMOffset1_1, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64, MCK_SMEMOffset }, },
  { 19228 /* s_dcache_discard */, AMDGPU::S_DCACHE_DISCARD_IMM_vi, Convert__Reg1_0__SMEMOffset1_1, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64, MCK_SMEMOffset }, },
  { 19228 /* s_dcache_discard */, AMDGPU::S_DCACHE_DISCARD_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffsetMod1_2, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod }, },
  { 19228 /* s_dcache_discard */, AMDGPU::S_DCACHE_DISCARD_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__SMEMOffsetMod1_2, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod }, },
  { 19245 /* s_dcache_discard_x2 */, AMDGPU::S_DCACHE_DISCARD_X2_SGPR_gfx10, Convert__Reg1_0__Reg1_1, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64, MCK_SReg_32 }, },
  { 19245 /* s_dcache_discard_x2 */, AMDGPU::S_DCACHE_DISCARD_X2_SGPR_vi, Convert__Reg1_0__Reg1_1, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64, MCK_SReg_32 }, },
  { 19245 /* s_dcache_discard_x2 */, AMDGPU::S_DCACHE_DISCARD_X2_IMM_gfx10, Convert__Reg1_0__SMEMOffset1_1, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64, MCK_SMEMOffset }, },
  { 19245 /* s_dcache_discard_x2 */, AMDGPU::S_DCACHE_DISCARD_X2_IMM_vi, Convert__Reg1_0__SMEMOffset1_1, AMFBS_HasScalarAtomics_isGFX8GFX9, { MCK_SReg_64, MCK_SMEMOffset }, },
  { 19245 /* s_dcache_discard_x2 */, AMDGPU::S_DCACHE_DISCARD_X2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffsetMod1_2, AMFBS_HasScalarAtomics_isGFX10Only, { MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod }, },
  { 19245 /* s_dcache_discard_x2 */, AMDGPU::S_DCACHE_DISCARD_X2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__SMEMOffsetMod1_2, AMFBS_HasScalarAtomics_isGFX9Only, { MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod }, },
  { 19265 /* s_dcache_inv */, AMDGPU::S_DCACHE_INV_gfx10, Convert_NoOperands, AMFBS_isGFX10Only, {  }, },
  { 19265 /* s_dcache_inv */, AMDGPU::S_DCACHE_INV_gfx11, Convert_NoOperands, AMFBS_isGFX11Only, {  }, },
  { 19265 /* s_dcache_inv */, AMDGPU::S_DCACHE_INV_gfx12, Convert_NoOperands, AMFBS_isGFX12Plus, {  }, },
  { 19265 /* s_dcache_inv */, AMDGPU::S_DCACHE_INV_si, Convert_NoOperands, AMFBS_isGFX6GFX7, {  }, },
  { 19265 /* s_dcache_inv */, AMDGPU::S_DCACHE_INV_vi, Convert_NoOperands, AMFBS_isGFX8GFX9, {  }, },
  { 19278 /* s_dcache_inv_vol */, AMDGPU::S_DCACHE_INV_VOL_ci, Convert_NoOperands, AMFBS_isGFX7GFX8GFX9_isGFX7Only, {  }, },
  { 19278 /* s_dcache_inv_vol */, AMDGPU::S_DCACHE_INV_VOL_vi, Convert_NoOperands, AMFBS_isGFX7GFX8GFX9_isGFX8GFX9, {  }, },
  { 19295 /* s_dcache_wb */, AMDGPU::S_DCACHE_WB_gfx10, Convert_NoOperands, AMFBS_HasScalarStores_isGFX8Plus_isGFX10Only, {  }, },
  { 19295 /* s_dcache_wb */, AMDGPU::S_DCACHE_WB_vi, Convert_NoOperands, AMFBS_HasScalarStores_isGFX8Plus_isGFX8GFX9, {  }, },
  { 19307 /* s_dcache_wb_vol */, AMDGPU::S_DCACHE_WB_VOL_vi, Convert_NoOperands, AMFBS_HasScalarStores_isGFX8Plus_isGFX8GFX9, {  }, },
  { 19323 /* s_decperflevel */, AMDGPU::S_DECPERFLEVEL_gfx10, Convert__Imm1_0, AMFBS_isGFX10Only, { MCK_Imm }, },
  { 19323 /* s_decperflevel */, AMDGPU::S_DECPERFLEVEL_gfx11, Convert__Imm1_0, AMFBS_isGFX11Only, { MCK_Imm }, },
  { 19323 /* s_decperflevel */, AMDGPU::S_DECPERFLEVEL_gfx12, Convert__Imm1_0, AMFBS_isGFX12Only, { MCK_Imm }, },
  { 19323 /* s_decperflevel */, AMDGPU::S_DECPERFLEVEL_gfx6_gfx7, Convert__Imm1_0, AMFBS_isGFX6GFX7, { MCK_Imm }, },
  { 19323 /* s_decperflevel */, AMDGPU::S_DECPERFLEVEL_vi, Convert__Imm1_0, AMFBS_isGFX8GFX9, { MCK_Imm }, },
  { 19338 /* s_delay_alu */, AMDGPU::S_DELAY_ALU_gfx11, Convert__SDelayALU1_0, AMFBS_isGFX11Plus_isGFX11Only, { MCK_SDelayALU }, },
  { 19338 /* s_delay_alu */, AMDGPU::S_DELAY_ALU_gfx12, Convert__SDelayALU1_0, AMFBS_isGFX11Plus_isGFX12Only, { MCK_SDelayALU }, },
  { 19350 /* s_denorm_mode */, AMDGPU::S_DENORM_MODE_gfx10, Convert__Imm1_0, AMFBS_isGFX10Plus_isGFX10Only, { MCK_Imm }, },
  { 19350 /* s_denorm_mode */, AMDGPU::S_DENORM_MODE_gfx11, Convert__Imm1_0, AMFBS_isGFX10Plus_isGFX11Only, { MCK_Imm }, },
  { 19350 /* s_denorm_mode */, AMDGPU::S_DENORM_MODE_gfx12, Convert__Imm1_0, AMFBS_isGFX10Plus_isGFX12Only, { MCK_Imm }, },
  { 19364 /* s_endpgm */, AMDGPU::S_ENDPGM_gfx10, Convert__Endpgm1_0, AMFBS_isGFX10Only, { MCK_Endpgm }, },
  { 19364 /* s_endpgm */, AMDGPU::S_ENDPGM_gfx11, Convert__Endpgm1_0, AMFBS_isGFX11Only, { MCK_Endpgm }, },
  { 19364 /* s_endpgm */, AMDGPU::S_ENDPGM_gfx12, Convert__Endpgm1_0, AMFBS_isGFX12Only, { MCK_Endpgm }, },
  { 19364 /* s_endpgm */, AMDGPU::S_ENDPGM_gfx6_gfx7, Convert__Endpgm1_0, AMFBS_isGFX6GFX7, { MCK_Endpgm }, },
  { 19364 /* s_endpgm */, AMDGPU::S_ENDPGM_vi, Convert__Endpgm1_0, AMFBS_isGFX8GFX9, { MCK_Endpgm }, },
  { 19373 /* s_endpgm_ordered_ps_done */, AMDGPU::S_ENDPGM_ORDERED_PS_DONE_gfx10, Convert_NoOperands, AMFBS_isGFX9GFX10GFX11_isGFX10Only, {  }, },
  { 19373 /* s_endpgm_ordered_ps_done */, AMDGPU::S_ENDPGM_ORDERED_PS_DONE_gfx11, Convert_NoOperands, AMFBS_isGFX9GFX10GFX11_isGFX11Only, {  }, },
  { 19373 /* s_endpgm_ordered_ps_done */, AMDGPU::S_ENDPGM_ORDERED_PS_DONE_vi, Convert_NoOperands, AMFBS_isGFX9GFX10GFX11_isGFX8GFX9, {  }, },
  { 19398 /* s_endpgm_saved */, AMDGPU::S_ENDPGM_SAVED_gfx10, Convert_NoOperands, AMFBS_isGFX8Plus_isGFX10Only, {  }, },
  { 19398 /* s_endpgm_saved */, AMDGPU::S_ENDPGM_SAVED_gfx11, Convert_NoOperands, AMFBS_isGFX8Plus_isGFX11Only, {  }, },
  { 19398 /* s_endpgm_saved */, AMDGPU::S_ENDPGM_SAVED_gfx12, Convert_NoOperands, AMFBS_isGFX8Plus_isGFX12Only, {  }, },
  { 19398 /* s_endpgm_saved */, AMDGPU::S_ENDPGM_SAVED_gfx6_gfx7, Convert_NoOperands, AMFBS_isGFX8Plus_isGFX6GFX7, {  }, },
  { 19398 /* s_endpgm_saved */, AMDGPU::S_ENDPGM_SAVED_vi, Convert_NoOperands, AMFBS_isGFX8Plus_isGFX8GFX9, {  }, },
  { 19413 /* s_ff0_i32_b32 */, AMDGPU::S_FF0_I32_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19413 /* s_ff0_i32_b32 */, AMDGPU::S_FF0_I32_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19413 /* s_ff0_i32_b32 */, AMDGPU::S_FF0_I32_B32_vi, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19427 /* s_ff0_i32_b64 */, AMDGPU::S_FF0_I32_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 19427 /* s_ff0_i32_b64 */, AMDGPU::S_FF0_I32_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 19427 /* s_ff0_i32_b64 */, AMDGPU::S_FF0_I32_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 19441 /* s_ff1_i32_b32 */, AMDGPU::S_FF1_I32_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19441 /* s_ff1_i32_b32 */, AMDGPU::S_FF1_I32_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19441 /* s_ff1_i32_b32 */, AMDGPU::S_FF1_I32_B32_vi, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19455 /* s_ff1_i32_b64 */, AMDGPU::S_FF1_I32_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 19455 /* s_ff1_i32_b64 */, AMDGPU::S_FF1_I32_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 19455 /* s_ff1_i32_b64 */, AMDGPU::S_FF1_I32_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 19469 /* s_flbit_i32 */, AMDGPU::S_FLBIT_I32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19469 /* s_flbit_i32 */, AMDGPU::S_FLBIT_I32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19469 /* s_flbit_i32 */, AMDGPU::S_FLBIT_I32_vi, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19481 /* s_flbit_i32_b32 */, AMDGPU::S_FLBIT_I32_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19481 /* s_flbit_i32_b32 */, AMDGPU::S_FLBIT_I32_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19481 /* s_flbit_i32_b32 */, AMDGPU::S_FLBIT_I32_B32_vi, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19497 /* s_flbit_i32_b64 */, AMDGPU::S_FLBIT_I32_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 19497 /* s_flbit_i32_b64 */, AMDGPU::S_FLBIT_I32_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 19497 /* s_flbit_i32_b64 */, AMDGPU::S_FLBIT_I32_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 19513 /* s_flbit_i32_i64 */, AMDGPU::S_FLBIT_I32_I64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 19513 /* s_flbit_i32_i64 */, AMDGPU::S_FLBIT_I32_I64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 19513 /* s_flbit_i32_i64 */, AMDGPU::S_FLBIT_I32_I64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b64 }, },
  { 19529 /* s_floor_f16 */, AMDGPU::S_FLOOR_F16_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19529 /* s_floor_f16 */, AMDGPU::S_FLOOR_F16_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19541 /* s_floor_f32 */, AMDGPU::S_FLOOR_F32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19541 /* s_floor_f32 */, AMDGPU::S_FLOOR_F32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 19553 /* s_fmaak_f32 */, AMDGPU::S_FMAAK_F32_gfx11, Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2__KImmFP321_3, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_f32, MCK_SSrc_f32, MCK_KImmFP32 }, },
  { 19553 /* s_fmaak_f32 */, AMDGPU::S_FMAAK_F32_gfx12, Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2__KImmFP321_3, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_f32, MCK_SSrc_f32, MCK_KImmFP32 }, },
  { 19565 /* s_fmac_f16 */, AMDGPU::S_FMAC_F16_gfx11, Convert__Reg1_0__SSrc_f161_1__SSrc_f161_2__Tie0_1_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_f16, MCK_SSrc_f16 }, },
  { 19565 /* s_fmac_f16 */, AMDGPU::S_FMAC_F16_gfx12, Convert__Reg1_0__SSrc_f161_1__SSrc_f161_2__Tie0_1_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_f16, MCK_SSrc_f16 }, },
  { 19576 /* s_fmac_f32 */, AMDGPU::S_FMAC_F32_gfx11, Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2__Tie0_1_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_f32, MCK_SSrc_f32 }, },
  { 19576 /* s_fmac_f32 */, AMDGPU::S_FMAC_F32_gfx12, Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2__Tie0_1_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_f32, MCK_SSrc_f32 }, },
  { 19587 /* s_fmamk_f32 */, AMDGPU::S_FMAMK_F32_gfx11, Convert__Reg1_0__SSrc_f321_1__KImmFP321_2__SSrc_f321_3, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_f32, MCK_KImmFP32, MCK_SSrc_f32 }, },
  { 19587 /* s_fmamk_f32 */, AMDGPU::S_FMAMK_F32_gfx12, Convert__Reg1_0__SSrc_f321_1__KImmFP321_2__SSrc_f321_3, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_f32, MCK_KImmFP32, MCK_SSrc_f32 }, },
  { 19599 /* s_get_barrier_state */, AMDGPU::S_GET_BARRIER_STATE_M0_gfx12, Convert__SSrc_b321_0, AMFBS_isGFX12Only, { MCK_SSrc_b32, MCK_M0 }, },
  { 19599 /* s_get_barrier_state */, AMDGPU::S_GET_BARRIER_STATE_IMM_gfx12, Convert__SSrc_b321_0__SplitBarrier1_1, AMFBS_isGFX12Only, { MCK_SSrc_b32, MCK_SplitBarrier }, },
  { 19619 /* s_get_pc_i64 */, AMDGPU::S_GETPC_B64_gfx1250, Convert__Reg1_0, AMFBS_isGFX125xOnly, { MCK_SReg_64 }, },
  { 19632 /* s_get_shader_cycles_u64 */, AMDGPU::S_GET_SHADER_CYCLES_U64_gfx12, Convert__Reg1_0, AMFBS_HasSGetShaderCyclesInst_isGFX12Only, { MCK_SReg_64 }, },
  { 19656 /* s_get_waveid_in_workgroup */, AMDGPU::S_GET_WAVEID_IN_WORKGROUP_gfx10, Convert__Reg1_0, AMFBS_HasGetWaveIdInst_isGFX10Only, { MCK_SReg_32_XM0_XEXEC }, },
  { 19682 /* s_getpc_b64 */, AMDGPU::S_GETPC_B64_gfx11, Convert__Reg1_0, AMFBS_isNotGFX1250Plus_isGFX11Only, { MCK_SReg_64 }, },
  { 19682 /* s_getpc_b64 */, AMDGPU::S_GETPC_B64_gfx12, Convert__Reg1_0, AMFBS_isNotGFX1250Plus_isGFX12Only, { MCK_SReg_64 }, },
  { 19682 /* s_getpc_b64 */, AMDGPU::S_GETPC_B64_gfx10, Convert__Reg1_0, AMFBS_isGFX10Only, { MCK_SReg_64 }, },
  { 19682 /* s_getpc_b64 */, AMDGPU::S_GETPC_B64_gfx6_gfx7, Convert__Reg1_0, AMFBS_isGFX6GFX7, { MCK_SReg_64 }, },
  { 19682 /* s_getpc_b64 */, AMDGPU::S_GETPC_B64_vi, Convert__Reg1_0, AMFBS_isGFX8GFX9, { MCK_SReg_64 }, },
  { 19694 /* s_getreg_b32 */, AMDGPU::S_GETREG_B32_gfx10, Convert__Reg1_0__Hwreg1_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_Hwreg }, },
  { 19694 /* s_getreg_b32 */, AMDGPU::S_GETREG_B32_gfx11, Convert__Reg1_0__Hwreg1_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_Hwreg }, },
  { 19694 /* s_getreg_b32 */, AMDGPU::S_GETREG_B32_gfx12, Convert__Reg1_0__Hwreg1_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_Hwreg }, },
  { 19694 /* s_getreg_b32 */, AMDGPU::S_GETREG_B32_gfx6_gfx7, Convert__Reg1_0__Hwreg1_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_Hwreg }, },
  { 19694 /* s_getreg_b32 */, AMDGPU::S_GETREG_B32_vi, Convert__Reg1_0__Hwreg1_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_Hwreg }, },
  { 19707 /* s_gl1_inv */, AMDGPU::S_GL1_INV_gfx10, Convert_NoOperands, AMFBS_isGFX10Plus_isGFX10Only, {  }, },
  { 19707 /* s_gl1_inv */, AMDGPU::S_GL1_INV_gfx11, Convert_NoOperands, AMFBS_isGFX10Plus_isGFX11Only, {  }, },
  { 19717 /* s_icache_inv */, AMDGPU::S_ICACHE_INV_gfx10, Convert_NoOperands, AMFBS_isGFX10Only, {  }, },
  { 19717 /* s_icache_inv */, AMDGPU::S_ICACHE_INV_gfx11, Convert_NoOperands, AMFBS_isGFX11Only, {  }, },
  { 19717 /* s_icache_inv */, AMDGPU::S_ICACHE_INV_gfx12, Convert_NoOperands, AMFBS_isGFX12Only, {  }, },
  { 19717 /* s_icache_inv */, AMDGPU::S_ICACHE_INV_gfx6_gfx7, Convert_NoOperands, AMFBS_isGFX6GFX7, {  }, },
  { 19717 /* s_icache_inv */, AMDGPU::S_ICACHE_INV_vi, Convert_NoOperands, AMFBS_isGFX8GFX9, {  }, },
  { 19730 /* s_incperflevel */, AMDGPU::S_INCPERFLEVEL_gfx10, Convert__Imm1_0, AMFBS_isGFX10Only, { MCK_Imm }, },
  { 19730 /* s_incperflevel */, AMDGPU::S_INCPERFLEVEL_gfx11, Convert__Imm1_0, AMFBS_isGFX11Only, { MCK_Imm }, },
  { 19730 /* s_incperflevel */, AMDGPU::S_INCPERFLEVEL_gfx12, Convert__Imm1_0, AMFBS_isGFX12Only, { MCK_Imm }, },
  { 19730 /* s_incperflevel */, AMDGPU::S_INCPERFLEVEL_gfx6_gfx7, Convert__Imm1_0, AMFBS_isGFX6GFX7, { MCK_Imm }, },
  { 19730 /* s_incperflevel */, AMDGPU::S_INCPERFLEVEL_vi, Convert__Imm1_0, AMFBS_isGFX8GFX9, { MCK_Imm }, },
  { 19745 /* s_inst_prefetch */, AMDGPU::S_INST_PREFETCH_gfx10, Convert__S16Imm1_0, AMFBS_isGFX10Plus_isGFX10Only, { MCK_S16Imm }, },
  { 19761 /* s_load_b128 */, AMDGPU::S_LOAD_B128_SGPR_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX11Only, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 19761 /* s_load_b128 */, AMDGPU::S_LOAD_B128_IMM_gfx11, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX11Only, { MCK_SReg_128, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19761 /* s_load_b128 */, AMDGPU::S_LOAD_B128_IMM_gfx12, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX12Plus, { MCK_SReg_128, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19761 /* s_load_b128 */, AMDGPU::S_LOAD_B128_SGPR_IMM_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX11Only, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 19761 /* s_load_b128 */, AMDGPU::S_LOAD_B128_SGPR_IMM_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX12Plus, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_OptSMEMOffsetMod, MCK_CPol }, },
  { 19773 /* s_load_b256 */, AMDGPU::S_LOAD_B256_SGPR_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX11Only, { MCK_SReg_256, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 19773 /* s_load_b256 */, AMDGPU::S_LOAD_B256_IMM_gfx11, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX11Only, { MCK_SReg_256, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19773 /* s_load_b256 */, AMDGPU::S_LOAD_B256_IMM_gfx12, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX12Plus, { MCK_SReg_256, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19773 /* s_load_b256 */, AMDGPU::S_LOAD_B256_SGPR_IMM_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX11Only, { MCK_SReg_256, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 19773 /* s_load_b256 */, AMDGPU::S_LOAD_B256_SGPR_IMM_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX12Plus, { MCK_SReg_256, MCK_SReg_64, MCK_SReg_32, MCK_OptSMEMOffsetMod, MCK_CPol }, },
  { 19785 /* s_load_b32 */, AMDGPU::S_LOAD_B32_SGPR_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX11Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 19785 /* s_load_b32 */, AMDGPU::S_LOAD_B32_IMM_gfx11, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX11Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19785 /* s_load_b32 */, AMDGPU::S_LOAD_B32_IMM_gfx12, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX12Plus, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19785 /* s_load_b32 */, AMDGPU::S_LOAD_B32_SGPR_IMM_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX11Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 19785 /* s_load_b32 */, AMDGPU::S_LOAD_B32_SGPR_IMM_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX12Plus, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_OptSMEMOffsetMod, MCK_CPol }, },
  { 19796 /* s_load_b512 */, AMDGPU::S_LOAD_B512_SGPR_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX11Only, { MCK_SReg_512, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 19796 /* s_load_b512 */, AMDGPU::S_LOAD_B512_IMM_gfx11, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX11Only, { MCK_SReg_512, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19796 /* s_load_b512 */, AMDGPU::S_LOAD_B512_IMM_gfx12, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX12Plus, { MCK_SReg_512, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19796 /* s_load_b512 */, AMDGPU::S_LOAD_B512_SGPR_IMM_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX11Only, { MCK_SReg_512, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 19796 /* s_load_b512 */, AMDGPU::S_LOAD_B512_SGPR_IMM_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX12Plus, { MCK_SReg_512, MCK_SReg_64, MCK_SReg_32, MCK_OptSMEMOffsetMod, MCK_CPol }, },
  { 19808 /* s_load_b64 */, AMDGPU::S_LOAD_B64_SGPR_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX11Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 19808 /* s_load_b64 */, AMDGPU::S_LOAD_B64_IMM_gfx11, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX11Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19808 /* s_load_b64 */, AMDGPU::S_LOAD_B64_IMM_gfx12, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX12Plus, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19808 /* s_load_b64 */, AMDGPU::S_LOAD_B64_SGPR_IMM_gfx11, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX11Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 19808 /* s_load_b64 */, AMDGPU::S_LOAD_B64_SGPR_IMM_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX12Plus, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_OptSMEMOffsetMod, MCK_CPol }, },
  { 19819 /* s_load_b96 */, AMDGPU::S_LOAD_B96_IMM_gfx12, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX12Plus, { MCK_SReg_96, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19819 /* s_load_b96 */, AMDGPU::S_LOAD_B96_SGPR_IMM_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX12Plus, { MCK_SReg_96, MCK_SReg_64, MCK_SReg_32, MCK_OptSMEMOffsetMod, MCK_CPol }, },
  { 19830 /* s_load_dword */, AMDGPU::S_LOAD_DWORD_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 19830 /* s_load_dword */, AMDGPU::S_LOAD_DWORD_SGPR_si, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX6GFX7, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 19830 /* s_load_dword */, AMDGPU::S_LOAD_DWORD_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 19830 /* s_load_dword */, AMDGPU::S_LOAD_DWORD_IMM_si, Convert__Reg1_0__Reg1_1__SMRDOffset81_2__CPol1_3, AMFBS_isGFX6GFX7, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMRDOffset8, MCK_CPol }, },
  { 19830 /* s_load_dword */, AMDGPU::S_LOAD_DWORD_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19830 /* s_load_dword */, AMDGPU::S_LOAD_DWORD_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19830 /* s_load_dword */, AMDGPU::S_LOAD_DWORD_IMM_ci, Convert__Reg1_0__Reg1_1__SMRDLiteralOffset1_2__CPol1_3, AMFBS_isGFX7Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMRDLiteralOffset, MCK_CPol }, },
  { 19830 /* s_load_dword */, AMDGPU::S_LOAD_DWORD_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 19830 /* s_load_dword */, AMDGPU::S_LOAD_DWORD_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 19843 /* s_load_dwordx16 */, AMDGPU::S_LOAD_DWORDX16_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX10Only, { MCK_SReg_512, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 19843 /* s_load_dwordx16 */, AMDGPU::S_LOAD_DWORDX16_SGPR_si, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX6GFX7, { MCK_SReg_512, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 19843 /* s_load_dwordx16 */, AMDGPU::S_LOAD_DWORDX16_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX8GFX9, { MCK_SReg_512, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 19843 /* s_load_dwordx16 */, AMDGPU::S_LOAD_DWORDX16_IMM_si, Convert__Reg1_0__Reg1_1__SMRDOffset81_2__CPol1_3, AMFBS_isGFX6GFX7, { MCK_SReg_512, MCK_SReg_64, MCK_SMRDOffset8, MCK_CPol }, },
  { 19843 /* s_load_dwordx16 */, AMDGPU::S_LOAD_DWORDX16_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX10Only, { MCK_SReg_512, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19843 /* s_load_dwordx16 */, AMDGPU::S_LOAD_DWORDX16_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX8GFX9, { MCK_SReg_512, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19843 /* s_load_dwordx16 */, AMDGPU::S_LOAD_DWORDX16_IMM_ci, Convert__Reg1_0__Reg1_1__SMRDLiteralOffset1_2__CPol1_3, AMFBS_isGFX7Only, { MCK_SReg_512, MCK_SReg_64, MCK_SMRDLiteralOffset, MCK_CPol }, },
  { 19843 /* s_load_dwordx16 */, AMDGPU::S_LOAD_DWORDX16_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX10Only, { MCK_SReg_512, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 19843 /* s_load_dwordx16 */, AMDGPU::S_LOAD_DWORDX16_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX9Only, { MCK_SReg_512, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 19859 /* s_load_dwordx2 */, AMDGPU::S_LOAD_DWORDX2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 19859 /* s_load_dwordx2 */, AMDGPU::S_LOAD_DWORDX2_SGPR_si, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX6GFX7, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 19859 /* s_load_dwordx2 */, AMDGPU::S_LOAD_DWORDX2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 19859 /* s_load_dwordx2 */, AMDGPU::S_LOAD_DWORDX2_IMM_si, Convert__Reg1_0__Reg1_1__SMRDOffset81_2__CPol1_3, AMFBS_isGFX6GFX7, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMRDOffset8, MCK_CPol }, },
  { 19859 /* s_load_dwordx2 */, AMDGPU::S_LOAD_DWORDX2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19859 /* s_load_dwordx2 */, AMDGPU::S_LOAD_DWORDX2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19859 /* s_load_dwordx2 */, AMDGPU::S_LOAD_DWORDX2_IMM_ci, Convert__Reg1_0__Reg1_1__SMRDLiteralOffset1_2__CPol1_3, AMFBS_isGFX7Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMRDLiteralOffset, MCK_CPol }, },
  { 19859 /* s_load_dwordx2 */, AMDGPU::S_LOAD_DWORDX2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 19859 /* s_load_dwordx2 */, AMDGPU::S_LOAD_DWORDX2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 19874 /* s_load_dwordx4 */, AMDGPU::S_LOAD_DWORDX4_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX10Only, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 19874 /* s_load_dwordx4 */, AMDGPU::S_LOAD_DWORDX4_SGPR_si, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX6GFX7, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 19874 /* s_load_dwordx4 */, AMDGPU::S_LOAD_DWORDX4_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX8GFX9, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 19874 /* s_load_dwordx4 */, AMDGPU::S_LOAD_DWORDX4_IMM_si, Convert__Reg1_0__Reg1_1__SMRDOffset81_2__CPol1_3, AMFBS_isGFX6GFX7, { MCK_SReg_128, MCK_SReg_64, MCK_SMRDOffset8, MCK_CPol }, },
  { 19874 /* s_load_dwordx4 */, AMDGPU::S_LOAD_DWORDX4_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX10Only, { MCK_SReg_128, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19874 /* s_load_dwordx4 */, AMDGPU::S_LOAD_DWORDX4_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX8GFX9, { MCK_SReg_128, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19874 /* s_load_dwordx4 */, AMDGPU::S_LOAD_DWORDX4_IMM_ci, Convert__Reg1_0__Reg1_1__SMRDLiteralOffset1_2__CPol1_3, AMFBS_isGFX7Only, { MCK_SReg_128, MCK_SReg_64, MCK_SMRDLiteralOffset, MCK_CPol }, },
  { 19874 /* s_load_dwordx4 */, AMDGPU::S_LOAD_DWORDX4_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX10Only, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 19874 /* s_load_dwordx4 */, AMDGPU::S_LOAD_DWORDX4_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX9Only, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 19889 /* s_load_dwordx8 */, AMDGPU::S_LOAD_DWORDX8_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX10Only, { MCK_SReg_256, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 19889 /* s_load_dwordx8 */, AMDGPU::S_LOAD_DWORDX8_SGPR_si, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX6GFX7, { MCK_SReg_256, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 19889 /* s_load_dwordx8 */, AMDGPU::S_LOAD_DWORDX8_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_isGFX8GFX9, { MCK_SReg_256, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 19889 /* s_load_dwordx8 */, AMDGPU::S_LOAD_DWORDX8_IMM_si, Convert__Reg1_0__Reg1_1__SMRDOffset81_2__CPol1_3, AMFBS_isGFX6GFX7, { MCK_SReg_256, MCK_SReg_64, MCK_SMRDOffset8, MCK_CPol }, },
  { 19889 /* s_load_dwordx8 */, AMDGPU::S_LOAD_DWORDX8_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX10Only, { MCK_SReg_256, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19889 /* s_load_dwordx8 */, AMDGPU::S_LOAD_DWORDX8_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX8GFX9, { MCK_SReg_256, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19889 /* s_load_dwordx8 */, AMDGPU::S_LOAD_DWORDX8_IMM_ci, Convert__Reg1_0__Reg1_1__SMRDLiteralOffset1_2__CPol1_3, AMFBS_isGFX7Only, { MCK_SReg_256, MCK_SReg_64, MCK_SMRDLiteralOffset, MCK_CPol }, },
  { 19889 /* s_load_dwordx8 */, AMDGPU::S_LOAD_DWORDX8_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX10Only, { MCK_SReg_256, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 19889 /* s_load_dwordx8 */, AMDGPU::S_LOAD_DWORDX8_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX9Only, { MCK_SReg_256, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 19904 /* s_load_i16 */, AMDGPU::S_LOAD_I16_IMM_gfx12, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX12Plus, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19904 /* s_load_i16 */, AMDGPU::S_LOAD_I16_SGPR_IMM_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX12Plus, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_OptSMEMOffsetMod, MCK_CPol }, },
  { 19915 /* s_load_i8 */, AMDGPU::S_LOAD_I8_IMM_gfx12, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX12Plus, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19915 /* s_load_i8 */, AMDGPU::S_LOAD_I8_SGPR_IMM_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX12Plus, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_OptSMEMOffsetMod, MCK_CPol }, },
  { 19925 /* s_load_u16 */, AMDGPU::S_LOAD_U16_IMM_gfx12, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX12Plus, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19925 /* s_load_u16 */, AMDGPU::S_LOAD_U16_SGPR_IMM_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX12Plus, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_OptSMEMOffsetMod, MCK_CPol }, },
  { 19936 /* s_load_u8 */, AMDGPU::S_LOAD_U8_IMM_gfx12, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_isGFX12Plus, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 19936 /* s_load_u8 */, AMDGPU::S_LOAD_U8_SGPR_IMM_gfx12, Convert__Reg1_0__Reg1_1__Reg1_2__OptSMEMOffsetMod1_3__CPol1_4, AMFBS_isGFX12Plus, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_OptSMEMOffsetMod, MCK_CPol }, },
  { 19946 /* s_lshl1_add_u32 */, AMDGPU::S_LSHL1_ADD_U32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 19946 /* s_lshl1_add_u32 */, AMDGPU::S_LSHL1_ADD_U32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 19946 /* s_lshl1_add_u32 */, AMDGPU::S_LSHL1_ADD_U32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 19946 /* s_lshl1_add_u32 */, AMDGPU::S_LSHL1_ADD_U32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 19962 /* s_lshl2_add_u32 */, AMDGPU::S_LSHL2_ADD_U32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 19962 /* s_lshl2_add_u32 */, AMDGPU::S_LSHL2_ADD_U32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 19962 /* s_lshl2_add_u32 */, AMDGPU::S_LSHL2_ADD_U32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 19962 /* s_lshl2_add_u32 */, AMDGPU::S_LSHL2_ADD_U32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 19978 /* s_lshl3_add_u32 */, AMDGPU::S_LSHL3_ADD_U32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 19978 /* s_lshl3_add_u32 */, AMDGPU::S_LSHL3_ADD_U32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 19978 /* s_lshl3_add_u32 */, AMDGPU::S_LSHL3_ADD_U32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 19978 /* s_lshl3_add_u32 */, AMDGPU::S_LSHL3_ADD_U32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 19994 /* s_lshl4_add_u32 */, AMDGPU::S_LSHL4_ADD_U32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 19994 /* s_lshl4_add_u32 */, AMDGPU::S_LSHL4_ADD_U32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 19994 /* s_lshl4_add_u32 */, AMDGPU::S_LSHL4_ADD_U32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 19994 /* s_lshl4_add_u32 */, AMDGPU::S_LSHL4_ADD_U32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20010 /* s_lshl_b32 */, AMDGPU::S_LSHL_B32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20010 /* s_lshl_b32 */, AMDGPU::S_LSHL_B32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20010 /* s_lshl_b32 */, AMDGPU::S_LSHL_B32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20010 /* s_lshl_b32 */, AMDGPU::S_LSHL_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20010 /* s_lshl_b32 */, AMDGPU::S_LSHL_B32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20021 /* s_lshl_b64 */, AMDGPU::S_LSHL_B64_gfx10, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 20021 /* s_lshl_b64 */, AMDGPU::S_LSHL_B64_gfx11, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 20021 /* s_lshl_b64 */, AMDGPU::S_LSHL_B64_gfx12, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 20021 /* s_lshl_b64 */, AMDGPU::S_LSHL_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 20021 /* s_lshl_b64 */, AMDGPU::S_LSHL_B64_vi, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 20032 /* s_lshr_b32 */, AMDGPU::S_LSHR_B32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20032 /* s_lshr_b32 */, AMDGPU::S_LSHR_B32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20032 /* s_lshr_b32 */, AMDGPU::S_LSHR_B32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20032 /* s_lshr_b32 */, AMDGPU::S_LSHR_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20032 /* s_lshr_b32 */, AMDGPU::S_LSHR_B32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20043 /* s_lshr_b64 */, AMDGPU::S_LSHR_B64_gfx10, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 20043 /* s_lshr_b64 */, AMDGPU::S_LSHR_B64_gfx11, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 20043 /* s_lshr_b64 */, AMDGPU::S_LSHR_B64_gfx12, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 20043 /* s_lshr_b64 */, AMDGPU::S_LSHR_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 20043 /* s_lshr_b64 */, AMDGPU::S_LSHR_B64_vi, Convert__Reg1_0__SSrc_b641_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 20054 /* s_max_f16 */, AMDGPU::S_MAX_F16_gfx11, Convert__Reg1_0__SSrc_f161_1__SSrc_f161_2, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_f16, MCK_SSrc_f16 }, },
  { 20064 /* s_max_f32 */, AMDGPU::S_MAX_F32_gfx11, Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_f32, MCK_SSrc_f32 }, },
  { 20074 /* s_max_i32 */, AMDGPU::S_MAX_I32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20074 /* s_max_i32 */, AMDGPU::S_MAX_I32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20074 /* s_max_i32 */, AMDGPU::S_MAX_I32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20074 /* s_max_i32 */, AMDGPU::S_MAX_I32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20074 /* s_max_i32 */, AMDGPU::S_MAX_I32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20084 /* s_max_num_f16 */, AMDGPU::S_MAX_F16_gfx12, Convert__Reg1_0__SSrc_f161_1__SSrc_f161_2, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_f16, MCK_SSrc_f16 }, },
  { 20098 /* s_max_num_f32 */, AMDGPU::S_MAX_F32_gfx12, Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_f32, MCK_SSrc_f32 }, },
  { 20112 /* s_max_u32 */, AMDGPU::S_MAX_U32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20112 /* s_max_u32 */, AMDGPU::S_MAX_U32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20112 /* s_max_u32 */, AMDGPU::S_MAX_U32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20112 /* s_max_u32 */, AMDGPU::S_MAX_U32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20112 /* s_max_u32 */, AMDGPU::S_MAX_U32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20122 /* s_maximum_f16 */, AMDGPU::S_MAXIMUM_F16_gfx12, Convert__Reg1_0__SSrc_f161_1__SSrc_f161_2, AMFBS_isGFX12Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_f16, MCK_SSrc_f16 }, },
  { 20136 /* s_maximum_f32 */, AMDGPU::S_MAXIMUM_F32_gfx12, Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2, AMFBS_isGFX12Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_f32, MCK_SSrc_f32 }, },
  { 20150 /* s_memrealtime */, AMDGPU::S_MEMREALTIME_gfx10, Convert__Reg1_0, AMFBS_HasSMemRealTime_isGFX10Only, { MCK_SReg_64_XEXEC }, },
  { 20150 /* s_memrealtime */, AMDGPU::S_MEMREALTIME_vi, Convert__Reg1_0, AMFBS_HasSMemRealTime_isGFX8GFX9, { MCK_SReg_64_XEXEC }, },
  { 20164 /* s_memtime */, AMDGPU::S_MEMTIME_gfx10, Convert__Reg1_0, AMFBS_HasSMemTimeInst_isGFX10Only, { MCK_SReg_64_XEXEC }, },
  { 20164 /* s_memtime */, AMDGPU::S_MEMTIME_si, Convert__Reg1_0, AMFBS_HasSMemTimeInst_isGFX6GFX7, { MCK_SReg_64_XEXEC }, },
  { 20164 /* s_memtime */, AMDGPU::S_MEMTIME_vi, Convert__Reg1_0, AMFBS_HasSMemTimeInst_isGFX8GFX9, { MCK_SReg_64_XEXEC }, },
  { 20174 /* s_min_f16 */, AMDGPU::S_MIN_F16_gfx11, Convert__Reg1_0__SSrc_f161_1__SSrc_f161_2, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_f16, MCK_SSrc_f16 }, },
  { 20184 /* s_min_f32 */, AMDGPU::S_MIN_F32_gfx11, Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_f32, MCK_SSrc_f32 }, },
  { 20194 /* s_min_i32 */, AMDGPU::S_MIN_I32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20194 /* s_min_i32 */, AMDGPU::S_MIN_I32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20194 /* s_min_i32 */, AMDGPU::S_MIN_I32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20194 /* s_min_i32 */, AMDGPU::S_MIN_I32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20194 /* s_min_i32 */, AMDGPU::S_MIN_I32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20204 /* s_min_num_f16 */, AMDGPU::S_MIN_F16_gfx12, Convert__Reg1_0__SSrc_f161_1__SSrc_f161_2, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_f16, MCK_SSrc_f16 }, },
  { 20218 /* s_min_num_f32 */, AMDGPU::S_MIN_F32_gfx12, Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_f32, MCK_SSrc_f32 }, },
  { 20232 /* s_min_u32 */, AMDGPU::S_MIN_U32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20232 /* s_min_u32 */, AMDGPU::S_MIN_U32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20232 /* s_min_u32 */, AMDGPU::S_MIN_U32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20232 /* s_min_u32 */, AMDGPU::S_MIN_U32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20232 /* s_min_u32 */, AMDGPU::S_MIN_U32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20242 /* s_minimum_f16 */, AMDGPU::S_MINIMUM_F16_gfx12, Convert__Reg1_0__SSrc_f161_1__SSrc_f161_2, AMFBS_isGFX12Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_f16, MCK_SSrc_f16 }, },
  { 20256 /* s_minimum_f32 */, AMDGPU::S_MINIMUM_F32_gfx12, Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2, AMFBS_isGFX12Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_f32, MCK_SSrc_f32 }, },
  { 20270 /* s_monitor_sleep */, AMDGPU::S_MONITOR_SLEEP_gfx12, Convert__Imm1_0, AMFBS_isGFX1250Plus_isGFX12Only, { MCK_Imm }, },
  { 20286 /* s_mov_b32 */, AMDGPU::S_MOV_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20286 /* s_mov_b32 */, AMDGPU::S_MOV_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20286 /* s_mov_b32 */, AMDGPU::S_MOV_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20286 /* s_mov_b32 */, AMDGPU::S_MOV_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20286 /* s_mov_b32 */, AMDGPU::S_MOV_B32_vi, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20296 /* s_mov_b64 */, AMDGPU::S_MOV_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20296 /* s_mov_b64 */, AMDGPU::S_MOV_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20296 /* s_mov_b64 */, AMDGPU::S_MOV_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20296 /* s_mov_b64 */, AMDGPU::S_MOV_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20296 /* s_mov_b64 */, AMDGPU::S_MOV_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20306 /* s_movk_i32 */, AMDGPU::S_MOVK_I32_gfx10, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 20306 /* s_movk_i32 */, AMDGPU::S_MOVK_I32_gfx11, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 20306 /* s_movk_i32 */, AMDGPU::S_MOVK_I32_gfx12, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 20306 /* s_movk_i32 */, AMDGPU::S_MOVK_I32_gfx6_gfx7, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_S16Imm }, },
  { 20306 /* s_movk_i32 */, AMDGPU::S_MOVK_I32_vi, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_S16Imm }, },
  { 20317 /* s_movreld_b32 */, AMDGPU::S_MOVRELD_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20317 /* s_movreld_b32 */, AMDGPU::S_MOVRELD_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20317 /* s_movreld_b32 */, AMDGPU::S_MOVRELD_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20317 /* s_movreld_b32 */, AMDGPU::S_MOVRELD_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20317 /* s_movreld_b32 */, AMDGPU::S_MOVRELD_B32_vi, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20331 /* s_movreld_b64 */, AMDGPU::S_MOVRELD_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20331 /* s_movreld_b64 */, AMDGPU::S_MOVRELD_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20331 /* s_movreld_b64 */, AMDGPU::S_MOVRELD_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20331 /* s_movreld_b64 */, AMDGPU::S_MOVRELD_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20331 /* s_movreld_b64 */, AMDGPU::S_MOVRELD_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20345 /* s_movrels_b32 */, AMDGPU::S_MOVRELS_B32_gfx10, Convert__Reg1_0__Reg1_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SReg_32 }, },
  { 20345 /* s_movrels_b32 */, AMDGPU::S_MOVRELS_B32_gfx11, Convert__Reg1_0__Reg1_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SReg_32 }, },
  { 20345 /* s_movrels_b32 */, AMDGPU::S_MOVRELS_B32_gfx12, Convert__Reg1_0__Reg1_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SReg_32 }, },
  { 20345 /* s_movrels_b32 */, AMDGPU::S_MOVRELS_B32_gfx6_gfx7, Convert__Reg1_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SReg_32 }, },
  { 20345 /* s_movrels_b32 */, AMDGPU::S_MOVRELS_B32_vi, Convert__Reg1_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SReg_32 }, },
  { 20359 /* s_movrels_b64 */, AMDGPU::S_MOVRELS_B64_gfx10, Convert__Reg1_0__Reg1_1, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SReg_64 }, },
  { 20359 /* s_movrels_b64 */, AMDGPU::S_MOVRELS_B64_gfx11, Convert__Reg1_0__Reg1_1, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SReg_64 }, },
  { 20359 /* s_movrels_b64 */, AMDGPU::S_MOVRELS_B64_gfx12, Convert__Reg1_0__Reg1_1, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SReg_64 }, },
  { 20359 /* s_movrels_b64 */, AMDGPU::S_MOVRELS_B64_gfx6_gfx7, Convert__Reg1_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SReg_64 }, },
  { 20359 /* s_movrels_b64 */, AMDGPU::S_MOVRELS_B64_vi, Convert__Reg1_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SReg_64 }, },
  { 20373 /* s_movrelsd_2_b32 */, AMDGPU::S_MOVRELSD_2_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20373 /* s_movrelsd_2_b32 */, AMDGPU::S_MOVRELSD_2_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20373 /* s_movrelsd_2_b32 */, AMDGPU::S_MOVRELSD_2_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20390 /* s_mul_f16 */, AMDGPU::S_MUL_F16_gfx11, Convert__Reg1_0__SSrc_f161_1__SSrc_f161_2, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_f16, MCK_SSrc_f16 }, },
  { 20390 /* s_mul_f16 */, AMDGPU::S_MUL_F16_gfx12, Convert__Reg1_0__SSrc_f161_1__SSrc_f161_2, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_f16, MCK_SSrc_f16 }, },
  { 20400 /* s_mul_f32 */, AMDGPU::S_MUL_F32_gfx11, Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_f32, MCK_SSrc_f32 }, },
  { 20400 /* s_mul_f32 */, AMDGPU::S_MUL_F32_gfx12, Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_f32, MCK_SSrc_f32 }, },
  { 20410 /* s_mul_hi_i32 */, AMDGPU::S_MUL_HI_I32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20410 /* s_mul_hi_i32 */, AMDGPU::S_MUL_HI_I32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20410 /* s_mul_hi_i32 */, AMDGPU::S_MUL_HI_I32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20410 /* s_mul_hi_i32 */, AMDGPU::S_MUL_HI_I32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20423 /* s_mul_hi_u32 */, AMDGPU::S_MUL_HI_U32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20423 /* s_mul_hi_u32 */, AMDGPU::S_MUL_HI_U32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20423 /* s_mul_hi_u32 */, AMDGPU::S_MUL_HI_U32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20423 /* s_mul_hi_u32 */, AMDGPU::S_MUL_HI_U32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20436 /* s_mul_i32 */, AMDGPU::S_MUL_I32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20436 /* s_mul_i32 */, AMDGPU::S_MUL_I32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20436 /* s_mul_i32 */, AMDGPU::S_MUL_I32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20436 /* s_mul_i32 */, AMDGPU::S_MUL_I32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20436 /* s_mul_i32 */, AMDGPU::S_MUL_I32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20446 /* s_mul_u64 */, AMDGPU::S_MUL_U64_gfx12, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX12Plus_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 20456 /* s_mulk_i32 */, AMDGPU::S_MULK_I32_gfx10, Convert__Reg1_0__Tie0_1_1__S16Imm1_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 20456 /* s_mulk_i32 */, AMDGPU::S_MULK_I32_gfx11, Convert__Reg1_0__Tie0_1_1__S16Imm1_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 20456 /* s_mulk_i32 */, AMDGPU::S_MULK_I32_gfx12, Convert__Reg1_0__Tie0_1_1__S16Imm1_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 20456 /* s_mulk_i32 */, AMDGPU::S_MULK_I32_gfx6_gfx7, Convert__Reg1_0__Tie0_1_1__S16Imm1_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_S16Imm }, },
  { 20456 /* s_mulk_i32 */, AMDGPU::S_MULK_I32_vi, Convert__Reg1_0__Tie0_1_1__S16Imm1_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_S16Imm }, },
  { 20467 /* s_nand_b32 */, AMDGPU::S_NAND_B32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20467 /* s_nand_b32 */, AMDGPU::S_NAND_B32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20467 /* s_nand_b32 */, AMDGPU::S_NAND_B32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20467 /* s_nand_b32 */, AMDGPU::S_NAND_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20467 /* s_nand_b32 */, AMDGPU::S_NAND_B32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20478 /* s_nand_b64 */, AMDGPU::S_NAND_B64_gfx10, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 20478 /* s_nand_b64 */, AMDGPU::S_NAND_B64_gfx11, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 20478 /* s_nand_b64 */, AMDGPU::S_NAND_B64_gfx12, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 20478 /* s_nand_b64 */, AMDGPU::S_NAND_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 20478 /* s_nand_b64 */, AMDGPU::S_NAND_B64_vi, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 20489 /* s_nand_saveexec_b32 */, AMDGPU::S_NAND_SAVEEXEC_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20489 /* s_nand_saveexec_b32 */, AMDGPU::S_NAND_SAVEEXEC_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20489 /* s_nand_saveexec_b32 */, AMDGPU::S_NAND_SAVEEXEC_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20509 /* s_nand_saveexec_b64 */, AMDGPU::S_NAND_SAVEEXEC_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20509 /* s_nand_saveexec_b64 */, AMDGPU::S_NAND_SAVEEXEC_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20509 /* s_nand_saveexec_b64 */, AMDGPU::S_NAND_SAVEEXEC_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20509 /* s_nand_saveexec_b64 */, AMDGPU::S_NAND_SAVEEXEC_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20509 /* s_nand_saveexec_b64 */, AMDGPU::S_NAND_SAVEEXEC_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20529 /* s_nop */, AMDGPU::S_NOP_gfx10, Convert__Imm1_0, AMFBS_isGFX10Only, { MCK_Imm }, },
  { 20529 /* s_nop */, AMDGPU::S_NOP_gfx11, Convert__Imm1_0, AMFBS_isGFX11Only, { MCK_Imm }, },
  { 20529 /* s_nop */, AMDGPU::S_NOP_gfx12, Convert__Imm1_0, AMFBS_isGFX12Only, { MCK_Imm }, },
  { 20529 /* s_nop */, AMDGPU::S_NOP_gfx6_gfx7, Convert__Imm1_0, AMFBS_isGFX6GFX7, { MCK_Imm }, },
  { 20529 /* s_nop */, AMDGPU::S_NOP_vi, Convert__Imm1_0, AMFBS_isGFX8GFX9, { MCK_Imm }, },
  { 20535 /* s_nor_b32 */, AMDGPU::S_NOR_B32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20535 /* s_nor_b32 */, AMDGPU::S_NOR_B32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20535 /* s_nor_b32 */, AMDGPU::S_NOR_B32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20535 /* s_nor_b32 */, AMDGPU::S_NOR_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20535 /* s_nor_b32 */, AMDGPU::S_NOR_B32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20545 /* s_nor_b64 */, AMDGPU::S_NOR_B64_gfx10, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 20545 /* s_nor_b64 */, AMDGPU::S_NOR_B64_gfx11, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 20545 /* s_nor_b64 */, AMDGPU::S_NOR_B64_gfx12, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 20545 /* s_nor_b64 */, AMDGPU::S_NOR_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 20545 /* s_nor_b64 */, AMDGPU::S_NOR_B64_vi, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 20555 /* s_nor_saveexec_b32 */, AMDGPU::S_NOR_SAVEEXEC_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20555 /* s_nor_saveexec_b32 */, AMDGPU::S_NOR_SAVEEXEC_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20555 /* s_nor_saveexec_b32 */, AMDGPU::S_NOR_SAVEEXEC_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20574 /* s_nor_saveexec_b64 */, AMDGPU::S_NOR_SAVEEXEC_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20574 /* s_nor_saveexec_b64 */, AMDGPU::S_NOR_SAVEEXEC_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20574 /* s_nor_saveexec_b64 */, AMDGPU::S_NOR_SAVEEXEC_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20574 /* s_nor_saveexec_b64 */, AMDGPU::S_NOR_SAVEEXEC_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20574 /* s_nor_saveexec_b64 */, AMDGPU::S_NOR_SAVEEXEC_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20593 /* s_not_b32 */, AMDGPU::S_NOT_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20593 /* s_not_b32 */, AMDGPU::S_NOT_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20593 /* s_not_b32 */, AMDGPU::S_NOT_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20593 /* s_not_b32 */, AMDGPU::S_NOT_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20593 /* s_not_b32 */, AMDGPU::S_NOT_B32_vi, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20603 /* s_not_b64 */, AMDGPU::S_NOT_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20603 /* s_not_b64 */, AMDGPU::S_NOT_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20603 /* s_not_b64 */, AMDGPU::S_NOT_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20603 /* s_not_b64 */, AMDGPU::S_NOT_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20603 /* s_not_b64 */, AMDGPU::S_NOT_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20613 /* s_or_b32 */, AMDGPU::S_OR_B32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20613 /* s_or_b32 */, AMDGPU::S_OR_B32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20613 /* s_or_b32 */, AMDGPU::S_OR_B32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20613 /* s_or_b32 */, AMDGPU::S_OR_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20613 /* s_or_b32 */, AMDGPU::S_OR_B32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20622 /* s_or_b64 */, AMDGPU::S_OR_B64_gfx10, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 20622 /* s_or_b64 */, AMDGPU::S_OR_B64_gfx11, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 20622 /* s_or_b64 */, AMDGPU::S_OR_B64_gfx12, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 20622 /* s_or_b64 */, AMDGPU::S_OR_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 20622 /* s_or_b64 */, AMDGPU::S_OR_B64_vi, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 20631 /* s_or_not0_saveexec_b32 */, AMDGPU::S_ORN1_SAVEEXEC_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20631 /* s_or_not0_saveexec_b32 */, AMDGPU::S_ORN1_SAVEEXEC_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20654 /* s_or_not0_saveexec_b64 */, AMDGPU::S_ORN1_SAVEEXEC_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX9Plus_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20654 /* s_or_not0_saveexec_b64 */, AMDGPU::S_ORN1_SAVEEXEC_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX9Plus_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20677 /* s_or_not1_b32 */, AMDGPU::S_ORN2_B32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20677 /* s_or_not1_b32 */, AMDGPU::S_ORN2_B32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20691 /* s_or_not1_b64 */, AMDGPU::S_ORN2_B64_gfx11, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 20691 /* s_or_not1_b64 */, AMDGPU::S_ORN2_B64_gfx12, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 20705 /* s_or_not1_saveexec_b32 */, AMDGPU::S_ORN2_SAVEEXEC_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20705 /* s_or_not1_saveexec_b32 */, AMDGPU::S_ORN2_SAVEEXEC_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20728 /* s_or_not1_saveexec_b64 */, AMDGPU::S_ORN2_SAVEEXEC_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20728 /* s_or_not1_saveexec_b64 */, AMDGPU::S_ORN2_SAVEEXEC_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20751 /* s_or_saveexec_b32 */, AMDGPU::S_OR_SAVEEXEC_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20751 /* s_or_saveexec_b32 */, AMDGPU::S_OR_SAVEEXEC_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20751 /* s_or_saveexec_b32 */, AMDGPU::S_OR_SAVEEXEC_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20769 /* s_or_saveexec_b64 */, AMDGPU::S_OR_SAVEEXEC_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20769 /* s_or_saveexec_b64 */, AMDGPU::S_OR_SAVEEXEC_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20769 /* s_or_saveexec_b64 */, AMDGPU::S_OR_SAVEEXEC_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20769 /* s_or_saveexec_b64 */, AMDGPU::S_OR_SAVEEXEC_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20769 /* s_or_saveexec_b64 */, AMDGPU::S_OR_SAVEEXEC_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20787 /* s_orn1_saveexec_b32 */, AMDGPU::S_ORN1_SAVEEXEC_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20807 /* s_orn1_saveexec_b64 */, AMDGPU::S_ORN1_SAVEEXEC_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX9Plus_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20807 /* s_orn1_saveexec_b64 */, AMDGPU::S_ORN1_SAVEEXEC_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20827 /* s_orn2_b32 */, AMDGPU::S_ORN2_B32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20827 /* s_orn2_b32 */, AMDGPU::S_ORN2_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20827 /* s_orn2_b32 */, AMDGPU::S_ORN2_B32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20838 /* s_orn2_b64 */, AMDGPU::S_ORN2_B64_gfx10, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 20838 /* s_orn2_b64 */, AMDGPU::S_ORN2_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 20838 /* s_orn2_b64 */, AMDGPU::S_ORN2_B64_vi, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 20849 /* s_orn2_saveexec_b32 */, AMDGPU::S_ORN2_SAVEEXEC_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 20869 /* s_orn2_saveexec_b64 */, AMDGPU::S_ORN2_SAVEEXEC_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20869 /* s_orn2_saveexec_b64 */, AMDGPU::S_ORN2_SAVEEXEC_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20869 /* s_orn2_saveexec_b64 */, AMDGPU::S_ORN2_SAVEEXEC_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 20889 /* s_pack_hh_b32_b16 */, AMDGPU::S_PACK_HH_B32_B16_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20889 /* s_pack_hh_b32_b16 */, AMDGPU::S_PACK_HH_B32_B16_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20889 /* s_pack_hh_b32_b16 */, AMDGPU::S_PACK_HH_B32_B16_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20889 /* s_pack_hh_b32_b16 */, AMDGPU::S_PACK_HH_B32_B16_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20907 /* s_pack_hl_b32_b16 */, AMDGPU::S_PACK_HL_B32_B16_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20907 /* s_pack_hl_b32_b16 */, AMDGPU::S_PACK_HL_B32_B16_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20925 /* s_pack_lh_b32_b16 */, AMDGPU::S_PACK_LH_B32_B16_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20925 /* s_pack_lh_b32_b16 */, AMDGPU::S_PACK_LH_B32_B16_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20925 /* s_pack_lh_b32_b16 */, AMDGPU::S_PACK_LH_B32_B16_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20925 /* s_pack_lh_b32_b16 */, AMDGPU::S_PACK_LH_B32_B16_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20943 /* s_pack_ll_b32_b16 */, AMDGPU::S_PACK_LL_B32_B16_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20943 /* s_pack_ll_b32_b16 */, AMDGPU::S_PACK_LL_B32_B16_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20943 /* s_pack_ll_b32_b16 */, AMDGPU::S_PACK_LL_B32_B16_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20943 /* s_pack_ll_b32_b16 */, AMDGPU::S_PACK_LL_B32_B16_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 20961 /* s_prefetch_data */, AMDGPU::S_PREFETCH_DATA_gfx12, Convert__Reg1_0__SMEMOffset1_1__Reg1_2__Imm1_3, AMFBS_isGFX12Plus, { MCK_SReg_64, MCK_SMEMOffset, MCK_SReg_32, MCK_Imm }, },
  { 20977 /* s_prefetch_data_pc_rel */, AMDGPU::S_PREFETCH_DATA_PC_REL_gfx12, Convert__SMEMOffset1_0__Reg1_1__Imm1_2, AMFBS_isGFX12Plus, { MCK_SMEMOffset, MCK_SReg_32, MCK_Imm }, },
  { 21000 /* s_prefetch_inst */, AMDGPU::S_PREFETCH_INST_gfx12, Convert__Reg1_0__SMEMOffset1_1__Reg1_2__Imm1_3, AMFBS_isGFX12Plus, { MCK_SReg_64, MCK_SMEMOffset, MCK_SReg_32, MCK_Imm }, },
  { 21016 /* s_prefetch_inst_pc_rel */, AMDGPU::S_PREFETCH_INST_PC_REL_gfx12, Convert__SMEMOffset1_0__Reg1_1__Imm1_2, AMFBS_isGFX12Plus, { MCK_SMEMOffset, MCK_SReg_32, MCK_Imm }, },
  { 21039 /* s_quadmask_b32 */, AMDGPU::S_QUADMASK_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21039 /* s_quadmask_b32 */, AMDGPU::S_QUADMASK_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21039 /* s_quadmask_b32 */, AMDGPU::S_QUADMASK_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21039 /* s_quadmask_b32 */, AMDGPU::S_QUADMASK_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21039 /* s_quadmask_b32 */, AMDGPU::S_QUADMASK_B32_vi, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21054 /* s_quadmask_b64 */, AMDGPU::S_QUADMASK_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 21054 /* s_quadmask_b64 */, AMDGPU::S_QUADMASK_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 21054 /* s_quadmask_b64 */, AMDGPU::S_QUADMASK_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 21054 /* s_quadmask_b64 */, AMDGPU::S_QUADMASK_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 21054 /* s_quadmask_b64 */, AMDGPU::S_QUADMASK_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 21069 /* s_rfe_b64 */, AMDGPU::S_RFE_B64_gfx11, Convert__Reg1_0, AMFBS_isNotGFX1250Plus_isGFX11Only, { MCK_SReg_64 }, },
  { 21069 /* s_rfe_b64 */, AMDGPU::S_RFE_B64_gfx12, Convert__Reg1_0, AMFBS_isNotGFX1250Plus_isGFX12Only, { MCK_SReg_64 }, },
  { 21069 /* s_rfe_b64 */, AMDGPU::S_RFE_B64_gfx10, Convert__Reg1_0, AMFBS_isGFX10Only, { MCK_SReg_64 }, },
  { 21069 /* s_rfe_b64 */, AMDGPU::S_RFE_B64_gfx6_gfx7, Convert__Reg1_0, AMFBS_isGFX6GFX7, { MCK_SReg_64 }, },
  { 21069 /* s_rfe_b64 */, AMDGPU::S_RFE_B64_vi, Convert__Reg1_0, AMFBS_isGFX8GFX9, { MCK_SReg_64 }, },
  { 21079 /* s_rfe_i64 */, AMDGPU::S_RFE_B64_gfx1250, Convert__Reg1_0, AMFBS_isGFX125xOnly, { MCK_SReg_64 }, },
  { 21089 /* s_rfe_restore_b64 */, AMDGPU::S_RFE_RESTORE_B64_vi, Convert__SSrc_b641_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SSrc_b64, MCK_SSrc_b32 }, },
  { 21107 /* s_rndne_f16 */, AMDGPU::S_RNDNE_F16_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21107 /* s_rndne_f16 */, AMDGPU::S_RNDNE_F16_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21119 /* s_rndne_f32 */, AMDGPU::S_RNDNE_F32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21119 /* s_rndne_f32 */, AMDGPU::S_RNDNE_F32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21131 /* s_round_mode */, AMDGPU::S_ROUND_MODE_gfx10, Convert__S16Imm1_0, AMFBS_isGFX10Plus_isGFX10Only, { MCK_S16Imm }, },
  { 21131 /* s_round_mode */, AMDGPU::S_ROUND_MODE_gfx11, Convert__S16Imm1_0, AMFBS_isGFX10Plus_isGFX11Only, { MCK_S16Imm }, },
  { 21131 /* s_round_mode */, AMDGPU::S_ROUND_MODE_gfx12, Convert__S16Imm1_0, AMFBS_isGFX10Plus_isGFX12Only, { MCK_S16Imm }, },
  { 21144 /* s_scratch_load_dword */, AMDGPU::S_SCRATCH_LOAD_DWORD_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 21144 /* s_scratch_load_dword */, AMDGPU::S_SCRATCH_LOAD_DWORD_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 21144 /* s_scratch_load_dword */, AMDGPU::S_SCRATCH_LOAD_DWORD_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 21144 /* s_scratch_load_dword */, AMDGPU::S_SCRATCH_LOAD_DWORD_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 21144 /* s_scratch_load_dword */, AMDGPU::S_SCRATCH_LOAD_DWORD_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarFlatScratchInsts_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 21144 /* s_scratch_load_dword */, AMDGPU::S_SCRATCH_LOAD_DWORD_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarFlatScratchInsts_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 21165 /* s_scratch_load_dwordx2 */, AMDGPU::S_SCRATCH_LOAD_DWORDX2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 21165 /* s_scratch_load_dwordx2 */, AMDGPU::S_SCRATCH_LOAD_DWORDX2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 21165 /* s_scratch_load_dwordx2 */, AMDGPU::S_SCRATCH_LOAD_DWORDX2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 21165 /* s_scratch_load_dwordx2 */, AMDGPU::S_SCRATCH_LOAD_DWORDX2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 21165 /* s_scratch_load_dwordx2 */, AMDGPU::S_SCRATCH_LOAD_DWORDX2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarFlatScratchInsts_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 21165 /* s_scratch_load_dwordx2 */, AMDGPU::S_SCRATCH_LOAD_DWORDX2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarFlatScratchInsts_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 21188 /* s_scratch_load_dwordx4 */, AMDGPU::S_SCRATCH_LOAD_DWORDX4_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX10Only, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 21188 /* s_scratch_load_dwordx4 */, AMDGPU::S_SCRATCH_LOAD_DWORDX4_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX8GFX9, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 21188 /* s_scratch_load_dwordx4 */, AMDGPU::S_SCRATCH_LOAD_DWORDX4_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX10Only, { MCK_SReg_128, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 21188 /* s_scratch_load_dwordx4 */, AMDGPU::S_SCRATCH_LOAD_DWORDX4_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX8GFX9, { MCK_SReg_128, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 21188 /* s_scratch_load_dwordx4 */, AMDGPU::S_SCRATCH_LOAD_DWORDX4_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarFlatScratchInsts_isGFX10Only, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 21188 /* s_scratch_load_dwordx4 */, AMDGPU::S_SCRATCH_LOAD_DWORDX4_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarFlatScratchInsts_isGFX9Only, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 21211 /* s_scratch_store_dword */, AMDGPU::S_SCRATCH_STORE_DWORD_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 21211 /* s_scratch_store_dword */, AMDGPU::S_SCRATCH_STORE_DWORD_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 21211 /* s_scratch_store_dword */, AMDGPU::S_SCRATCH_STORE_DWORD_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 21211 /* s_scratch_store_dword */, AMDGPU::S_SCRATCH_STORE_DWORD_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 21211 /* s_scratch_store_dword */, AMDGPU::S_SCRATCH_STORE_DWORD_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarFlatScratchInsts_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 21211 /* s_scratch_store_dword */, AMDGPU::S_SCRATCH_STORE_DWORD_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarFlatScratchInsts_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 21233 /* s_scratch_store_dwordx2 */, AMDGPU::S_SCRATCH_STORE_DWORDX2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 21233 /* s_scratch_store_dwordx2 */, AMDGPU::S_SCRATCH_STORE_DWORDX2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 21233 /* s_scratch_store_dwordx2 */, AMDGPU::S_SCRATCH_STORE_DWORDX2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 21233 /* s_scratch_store_dwordx2 */, AMDGPU::S_SCRATCH_STORE_DWORDX2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 21233 /* s_scratch_store_dwordx2 */, AMDGPU::S_SCRATCH_STORE_DWORDX2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarFlatScratchInsts_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 21233 /* s_scratch_store_dwordx2 */, AMDGPU::S_SCRATCH_STORE_DWORDX2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarFlatScratchInsts_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 21257 /* s_scratch_store_dwordx4 */, AMDGPU::S_SCRATCH_STORE_DWORDX4_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX10Only, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 21257 /* s_scratch_store_dwordx4 */, AMDGPU::S_SCRATCH_STORE_DWORDX4_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX8GFX9, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 21257 /* s_scratch_store_dwordx4 */, AMDGPU::S_SCRATCH_STORE_DWORDX4_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX10Only, { MCK_SReg_128, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 21257 /* s_scratch_store_dwordx4 */, AMDGPU::S_SCRATCH_STORE_DWORDX4_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarFlatScratchInsts_isGFX8GFX9, { MCK_SReg_128, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 21257 /* s_scratch_store_dwordx4 */, AMDGPU::S_SCRATCH_STORE_DWORDX4_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarFlatScratchInsts_isGFX10Only, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 21257 /* s_scratch_store_dwordx4 */, AMDGPU::S_SCRATCH_STORE_DWORDX4_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarFlatScratchInsts_isGFX9Only, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 21281 /* s_sendmsg */, AMDGPU::S_SENDMSG_gfx10, Convert__SendMsg1_0, AMFBS_isGFX10Only, { MCK_SendMsg }, },
  { 21281 /* s_sendmsg */, AMDGPU::S_SENDMSG_gfx11, Convert__SendMsg1_0, AMFBS_isGFX11Only, { MCK_SendMsg }, },
  { 21281 /* s_sendmsg */, AMDGPU::S_SENDMSG_gfx12, Convert__SendMsg1_0, AMFBS_isGFX12Only, { MCK_SendMsg }, },
  { 21281 /* s_sendmsg */, AMDGPU::S_SENDMSG_gfx6_gfx7, Convert__SendMsg1_0, AMFBS_isGFX6GFX7, { MCK_SendMsg }, },
  { 21281 /* s_sendmsg */, AMDGPU::S_SENDMSG_vi, Convert__SendMsg1_0, AMFBS_isGFX8GFX9, { MCK_SendMsg }, },
  { 21291 /* s_sendmsg_rtn_b32 */, AMDGPU::S_SENDMSG_RTN_B32_gfx11, Convert__Reg1_0__SendMsg1_1, AMFBS_isGFX11Plus_isGFX11Only, { MCK_SReg_32, MCK_SendMsg }, },
  { 21291 /* s_sendmsg_rtn_b32 */, AMDGPU::S_SENDMSG_RTN_B32_gfx12, Convert__Reg1_0__SendMsg1_1, AMFBS_isGFX11Plus_isGFX12Only, { MCK_SReg_32, MCK_SendMsg }, },
  { 21309 /* s_sendmsg_rtn_b64 */, AMDGPU::S_SENDMSG_RTN_B64_gfx11, Convert__Reg1_0__SendMsg1_1, AMFBS_isGFX11Plus_isGFX11Only, { MCK_SReg_64, MCK_SendMsg }, },
  { 21309 /* s_sendmsg_rtn_b64 */, AMDGPU::S_SENDMSG_RTN_B64_gfx12, Convert__Reg1_0__SendMsg1_1, AMFBS_isGFX11Plus_isGFX12Only, { MCK_SReg_64, MCK_SendMsg }, },
  { 21327 /* s_sendmsghalt */, AMDGPU::S_SENDMSGHALT_gfx10, Convert__SendMsg1_0, AMFBS_isGFX10Only, { MCK_SendMsg }, },
  { 21327 /* s_sendmsghalt */, AMDGPU::S_SENDMSGHALT_gfx11, Convert__SendMsg1_0, AMFBS_isGFX11Only, { MCK_SendMsg }, },
  { 21327 /* s_sendmsghalt */, AMDGPU::S_SENDMSGHALT_gfx12, Convert__SendMsg1_0, AMFBS_isGFX12Only, { MCK_SendMsg }, },
  { 21327 /* s_sendmsghalt */, AMDGPU::S_SENDMSGHALT_gfx6_gfx7, Convert__SendMsg1_0, AMFBS_isGFX6GFX7, { MCK_SendMsg }, },
  { 21327 /* s_sendmsghalt */, AMDGPU::S_SENDMSGHALT_vi, Convert__SendMsg1_0, AMFBS_isGFX8GFX9, { MCK_SendMsg }, },
  { 21341 /* s_set_gpr_idx_idx */, AMDGPU::S_SET_GPR_IDX_IDX_vi, Convert__SSrc_b321_0, AMFBS_HasVGPRIndexMode_isGFX8GFX9, { MCK_SSrc_b32 }, },
  { 21359 /* s_set_gpr_idx_mode */, AMDGPU::S_SET_GPR_IDX_MODE_vi, Convert__GPRIdxMode1_0, AMFBS_HasVGPRIndexMode_isGFX8GFX9, { MCK_GPRIdxMode }, },
  { 21378 /* s_set_gpr_idx_off */, AMDGPU::S_SET_GPR_IDX_OFF_vi, Convert_NoOperands, AMFBS_HasVGPRIndexMode_isGFX8GFX9, {  }, },
  { 21396 /* s_set_gpr_idx_on */, AMDGPU::S_SET_GPR_IDX_ON_vi, Convert__SSrc_b321_0__GPRIdxMode1_1, AMFBS_HasVGPRIndexMode_isGFX8GFX9, { MCK_SSrc_b32, MCK_GPRIdxMode }, },
  { 21413 /* s_set_inst_prefetch_distance */, AMDGPU::S_INST_PREFETCH_gfx11, Convert__S16Imm1_0, AMFBS_isGFX10Plus_isGFX11Only, { MCK_S16Imm }, },
  { 21442 /* s_set_pc_i64 */, AMDGPU::S_SETPC_B64_gfx1250, Convert__Reg1_0, AMFBS_isGFX125xOnly, { MCK_SReg_64 }, },
  { 21455 /* s_set_vgpr_msb */, AMDGPU::S_SET_VGPR_MSB_gfx12, Convert__Imm1_0, AMFBS_Has1024AddressableVGPRs_isGFX12Only, { MCK_Imm }, },
  { 21470 /* s_sethalt */, AMDGPU::S_SETHALT_gfx10, Convert__Imm1_0, AMFBS_isGFX10Only, { MCK_Imm }, },
  { 21470 /* s_sethalt */, AMDGPU::S_SETHALT_gfx11, Convert__Imm1_0, AMFBS_isGFX11Only, { MCK_Imm }, },
  { 21470 /* s_sethalt */, AMDGPU::S_SETHALT_gfx12, Convert__Imm1_0, AMFBS_isGFX12Only, { MCK_Imm }, },
  { 21470 /* s_sethalt */, AMDGPU::S_SETHALT_gfx6_gfx7, Convert__Imm1_0, AMFBS_isGFX6GFX7, { MCK_Imm }, },
  { 21470 /* s_sethalt */, AMDGPU::S_SETHALT_vi, Convert__Imm1_0, AMFBS_isGFX8GFX9, { MCK_Imm }, },
  { 21480 /* s_setkill */, AMDGPU::S_SETKILL_gfx10, Convert__Imm1_0, AMFBS_isNotGFX1250Plus_isGFX10Only, { MCK_Imm }, },
  { 21480 /* s_setkill */, AMDGPU::S_SETKILL_gfx11, Convert__Imm1_0, AMFBS_isNotGFX1250Plus_isGFX11Only, { MCK_Imm }, },
  { 21480 /* s_setkill */, AMDGPU::S_SETKILL_gfx12, Convert__Imm1_0, AMFBS_isNotGFX1250Plus_isGFX12Only, { MCK_Imm }, },
  { 21480 /* s_setkill */, AMDGPU::S_SETKILL_gfx6_gfx7, Convert__Imm1_0, AMFBS_isNotGFX1250Plus_isGFX6GFX7, { MCK_Imm }, },
  { 21480 /* s_setkill */, AMDGPU::S_SETKILL_vi, Convert__Imm1_0, AMFBS_isNotGFX1250Plus_isGFX8GFX9, { MCK_Imm }, },
  { 21490 /* s_setpc_b64 */, AMDGPU::S_SETPC_B64_gfx11, Convert__Reg1_0, AMFBS_isNotGFX1250Plus_isGFX11Only, { MCK_SReg_64 }, },
  { 21490 /* s_setpc_b64 */, AMDGPU::S_SETPC_B64_gfx12, Convert__Reg1_0, AMFBS_isNotGFX1250Plus_isGFX12Only, { MCK_SReg_64 }, },
  { 21490 /* s_setpc_b64 */, AMDGPU::S_SETPC_B64_gfx10, Convert__Reg1_0, AMFBS_isGFX10Only, { MCK_SReg_64 }, },
  { 21490 /* s_setpc_b64 */, AMDGPU::S_SETPC_B64_gfx6_gfx7, Convert__Reg1_0, AMFBS_isGFX6GFX7, { MCK_SReg_64 }, },
  { 21490 /* s_setpc_b64 */, AMDGPU::S_SETPC_B64_vi, Convert__Reg1_0, AMFBS_isGFX8GFX9, { MCK_SReg_64 }, },
  { 21502 /* s_setprio */, AMDGPU::S_SETPRIO_gfx10, Convert__Imm1_0, AMFBS_isGFX10Only, { MCK_Imm }, },
  { 21502 /* s_setprio */, AMDGPU::S_SETPRIO_gfx11, Convert__Imm1_0, AMFBS_isGFX11Only, { MCK_Imm }, },
  { 21502 /* s_setprio */, AMDGPU::S_SETPRIO_gfx12, Convert__Imm1_0, AMFBS_isGFX12Only, { MCK_Imm }, },
  { 21502 /* s_setprio */, AMDGPU::S_SETPRIO_gfx6_gfx7, Convert__Imm1_0, AMFBS_isGFX6GFX7, { MCK_Imm }, },
  { 21502 /* s_setprio */, AMDGPU::S_SETPRIO_vi, Convert__Imm1_0, AMFBS_isGFX8GFX9, { MCK_Imm }, },
  { 21512 /* s_setprio_inc_wg */, AMDGPU::S_SETPRIO_INC_WG_gfx12, Convert__Imm1_0, AMFBS_HasSetPrioIncWgInst_isGFX12Only, { MCK_Imm }, },
  { 21529 /* s_setreg_b32 */, AMDGPU::S_SETREG_B32_gfx10, Convert__Reg1_1__Hwreg1_0, AMFBS_isGFX10Only, { MCK_Hwreg, MCK_SReg_32 }, },
  { 21529 /* s_setreg_b32 */, AMDGPU::S_SETREG_B32_gfx11, Convert__Reg1_1__Hwreg1_0, AMFBS_isGFX11Only, { MCK_Hwreg, MCK_SReg_32 }, },
  { 21529 /* s_setreg_b32 */, AMDGPU::S_SETREG_B32_gfx12, Convert__Reg1_1__Hwreg1_0, AMFBS_isGFX12Only, { MCK_Hwreg, MCK_SReg_32 }, },
  { 21529 /* s_setreg_b32 */, AMDGPU::S_SETREG_B32_gfx6_gfx7, Convert__Reg1_1__Hwreg1_0, AMFBS_isGFX6GFX7, { MCK_Hwreg, MCK_SReg_32 }, },
  { 21529 /* s_setreg_b32 */, AMDGPU::S_SETREG_B32_vi, Convert__Reg1_1__Hwreg1_0, AMFBS_isGFX8GFX9, { MCK_Hwreg, MCK_SReg_32 }, },
  { 21542 /* s_setreg_imm32_b32 */, AMDGPU::S_SETREG_IMM32_B32_gfx10, Convert__Imm1_1__Hwreg1_0, AMFBS_isGFX10Only, { MCK_Hwreg, MCK_Imm }, },
  { 21542 /* s_setreg_imm32_b32 */, AMDGPU::S_SETREG_IMM32_B32_gfx11, Convert__Imm1_1__Hwreg1_0, AMFBS_isGFX11Only, { MCK_Hwreg, MCK_Imm }, },
  { 21542 /* s_setreg_imm32_b32 */, AMDGPU::S_SETREG_IMM32_B32_gfx12, Convert__Imm1_1__Hwreg1_0, AMFBS_isGFX12Only, { MCK_Hwreg, MCK_Imm }, },
  { 21542 /* s_setreg_imm32_b32 */, AMDGPU::S_SETREG_IMM32_B32_gfx6_gfx7, Convert__Imm1_1__Hwreg1_0, AMFBS_isGFX6GFX7, { MCK_Hwreg, MCK_Imm }, },
  { 21542 /* s_setreg_imm32_b32 */, AMDGPU::S_SETREG_IMM32_B32_vi, Convert__Imm1_1__Hwreg1_0, AMFBS_isGFX8GFX9, { MCK_Hwreg, MCK_Imm }, },
  { 21561 /* s_setvskip */, AMDGPU::S_SETVSKIP_gfx6_gfx7, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX6GFX7GFX8GFX9_isGFX6GFX7, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 21561 /* s_setvskip */, AMDGPU::S_SETVSKIP_vi, Convert__SSrc_b321_0__SSrc_b321_1, AMFBS_isGFX6GFX7GFX8GFX9_isGFX8GFX9, { MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 21572 /* s_sext_i32_i16 */, AMDGPU::S_SEXT_I32_I16_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21572 /* s_sext_i32_i16 */, AMDGPU::S_SEXT_I32_I16_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21572 /* s_sext_i32_i16 */, AMDGPU::S_SEXT_I32_I16_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21572 /* s_sext_i32_i16 */, AMDGPU::S_SEXT_I32_I16_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21572 /* s_sext_i32_i16 */, AMDGPU::S_SEXT_I32_I16_vi, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21587 /* s_sext_i32_i8 */, AMDGPU::S_SEXT_I32_I8_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21587 /* s_sext_i32_i8 */, AMDGPU::S_SEXT_I32_I8_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21587 /* s_sext_i32_i8 */, AMDGPU::S_SEXT_I32_I8_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21587 /* s_sext_i32_i8 */, AMDGPU::S_SEXT_I32_I8_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21587 /* s_sext_i32_i8 */, AMDGPU::S_SEXT_I32_I8_vi, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21601 /* s_sleep */, AMDGPU::S_SLEEP_gfx10, Convert__Imm1_0, AMFBS_isGFX10Only, { MCK_Imm }, },
  { 21601 /* s_sleep */, AMDGPU::S_SLEEP_gfx11, Convert__Imm1_0, AMFBS_isGFX11Only, { MCK_Imm }, },
  { 21601 /* s_sleep */, AMDGPU::S_SLEEP_gfx12, Convert__Imm1_0, AMFBS_isGFX12Only, { MCK_Imm }, },
  { 21601 /* s_sleep */, AMDGPU::S_SLEEP_gfx6_gfx7, Convert__Imm1_0, AMFBS_isGFX6GFX7, { MCK_Imm }, },
  { 21601 /* s_sleep */, AMDGPU::S_SLEEP_vi, Convert__Imm1_0, AMFBS_isGFX8GFX9, { MCK_Imm }, },
  { 21609 /* s_sleep_var */, AMDGPU::S_SLEEP_VAR_gfx12, Convert__SSrc_b321_0, AMFBS_isGFX12Only, { MCK_SSrc_b32 }, },
  { 21621 /* s_store_dword */, AMDGPU::S_STORE_DWORD_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarStores_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 21621 /* s_store_dword */, AMDGPU::S_STORE_DWORD_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarStores_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 21621 /* s_store_dword */, AMDGPU::S_STORE_DWORD_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarStores_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 21621 /* s_store_dword */, AMDGPU::S_STORE_DWORD_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarStores_isGFX8GFX9, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 21621 /* s_store_dword */, AMDGPU::S_STORE_DWORD_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarStores_isGFX10Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 21621 /* s_store_dword */, AMDGPU::S_STORE_DWORD_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarStores_isGFX9Only, { MCK_SReg_32_XM0_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 21635 /* s_store_dwordx2 */, AMDGPU::S_STORE_DWORDX2_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarStores_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 21635 /* s_store_dwordx2 */, AMDGPU::S_STORE_DWORDX2_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarStores_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 21635 /* s_store_dwordx2 */, AMDGPU::S_STORE_DWORDX2_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarStores_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 21635 /* s_store_dwordx2 */, AMDGPU::S_STORE_DWORDX2_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarStores_isGFX8GFX9, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 21635 /* s_store_dwordx2 */, AMDGPU::S_STORE_DWORDX2_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarStores_isGFX10Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 21635 /* s_store_dwordx2 */, AMDGPU::S_STORE_DWORDX2_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarStores_isGFX9Only, { MCK_SReg_64_XEXEC, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 21651 /* s_store_dwordx4 */, AMDGPU::S_STORE_DWORDX4_SGPR_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarStores_isGFX10Only, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 21651 /* s_store_dwordx4 */, AMDGPU::S_STORE_DWORDX4_SGPR_vi, Convert__Reg1_0__Reg1_1__Reg1_2__CPol1_3, AMFBS_HasScalarStores_isGFX8GFX9, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_CPol }, },
  { 21651 /* s_store_dwordx4 */, AMDGPU::S_STORE_DWORDX4_IMM_gfx10, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarStores_isGFX10Only, { MCK_SReg_128, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 21651 /* s_store_dwordx4 */, AMDGPU::S_STORE_DWORDX4_IMM_vi, Convert__Reg1_0__Reg1_1__SMEMOffset1_2__CPol1_3, AMFBS_HasScalarStores_isGFX8GFX9, { MCK_SReg_128, MCK_SReg_64, MCK_SMEMOffset, MCK_CPol }, },
  { 21651 /* s_store_dwordx4 */, AMDGPU::S_STORE_DWORDX4_SGPR_IMM_gfx10, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarStores_isGFX10Only, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 21651 /* s_store_dwordx4 */, AMDGPU::S_STORE_DWORDX4_SGPR_IMM_gfx9, Convert__Reg1_0__Reg1_1__Reg1_2__SMEMOffsetMod1_3__CPol1_4, AMFBS_HasScalarStores_isGFX9Only, { MCK_SReg_128, MCK_SReg_64, MCK_SReg_32, MCK_SMEMOffsetMod, MCK_CPol }, },
  { 21667 /* s_sub_co_ci_u32 */, AMDGPU::S_SUBB_U32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 21683 /* s_sub_co_i32 */, AMDGPU::S_SUB_I32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 21696 /* s_sub_co_u32 */, AMDGPU::S_SUB_U32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 21709 /* s_sub_f16 */, AMDGPU::S_SUB_F16_gfx11, Convert__Reg1_0__SSrc_f161_1__SSrc_f161_2, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_f16, MCK_SSrc_f16 }, },
  { 21709 /* s_sub_f16 */, AMDGPU::S_SUB_F16_gfx12, Convert__Reg1_0__SSrc_f161_1__SSrc_f161_2, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_f16, MCK_SSrc_f16 }, },
  { 21719 /* s_sub_f32 */, AMDGPU::S_SUB_F32_gfx11, Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_f32, MCK_SSrc_f32 }, },
  { 21719 /* s_sub_f32 */, AMDGPU::S_SUB_F32_gfx12, Convert__Reg1_0__SSrc_f321_1__SSrc_f321_2, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_f32, MCK_SSrc_f32 }, },
  { 21729 /* s_sub_i32 */, AMDGPU::S_SUB_I32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 21729 /* s_sub_i32 */, AMDGPU::S_SUB_I32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 21729 /* s_sub_i32 */, AMDGPU::S_SUB_I32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 21729 /* s_sub_i32 */, AMDGPU::S_SUB_I32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 21739 /* s_sub_nc_u64 */, AMDGPU::S_SUB_U64_gfx12, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX12Plus_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 21752 /* s_sub_u32 */, AMDGPU::S_SUB_U32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 21752 /* s_sub_u32 */, AMDGPU::S_SUB_U32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 21752 /* s_sub_u32 */, AMDGPU::S_SUB_U32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 21752 /* s_sub_u32 */, AMDGPU::S_SUB_U32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 21762 /* s_subb_u32 */, AMDGPU::S_SUBB_U32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 21762 /* s_subb_u32 */, AMDGPU::S_SUBB_U32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 21762 /* s_subb_u32 */, AMDGPU::S_SUBB_U32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 21762 /* s_subb_u32 */, AMDGPU::S_SUBB_U32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 21773 /* s_subvector_loop_begin */, AMDGPU::S_SUBVECTOR_LOOP_BEGIN_gfx10, Convert__SOPPBrTarget1_1__Reg1_0, AMFBS_isGFX10GFX11_isGFX10Only, { MCK_SReg_32, MCK_SOPPBrTarget }, },
  { 21773 /* s_subvector_loop_begin */, AMDGPU::S_SUBVECTOR_LOOP_BEGIN_gfx11, Convert__SOPPBrTarget1_1__Reg1_0, AMFBS_isGFX10GFX11_isGFX11Only, { MCK_SReg_32, MCK_SOPPBrTarget }, },
  { 21796 /* s_subvector_loop_end */, AMDGPU::S_SUBVECTOR_LOOP_END_gfx10, Convert__SOPPBrTarget1_1__Reg1_0, AMFBS_isGFX10GFX11_isGFX10Only, { MCK_SReg_32, MCK_SOPPBrTarget }, },
  { 21796 /* s_subvector_loop_end */, AMDGPU::S_SUBVECTOR_LOOP_END_gfx11, Convert__SOPPBrTarget1_1__Reg1_0, AMFBS_isGFX10GFX11_isGFX11Only, { MCK_SReg_32, MCK_SOPPBrTarget }, },
  { 21817 /* s_swap_pc_i64 */, AMDGPU::S_SWAPPC_B64_gfx1250, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX125xOnly, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 21831 /* s_swappc_b64 */, AMDGPU::S_SWAPPC_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isNotGFX1250Plus_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 21831 /* s_swappc_b64 */, AMDGPU::S_SWAPPC_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isNotGFX1250Plus_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 21831 /* s_swappc_b64 */, AMDGPU::S_SWAPPC_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 21831 /* s_swappc_b64 */, AMDGPU::S_SWAPPC_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 21831 /* s_swappc_b64 */, AMDGPU::S_SWAPPC_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 21844 /* s_trap */, AMDGPU::S_TRAP_gfx10, Convert__Imm1_0, AMFBS_isGFX10Only, { MCK_Imm }, },
  { 21844 /* s_trap */, AMDGPU::S_TRAP_gfx11, Convert__Imm1_0, AMFBS_isGFX11Only, { MCK_Imm }, },
  { 21844 /* s_trap */, AMDGPU::S_TRAP_gfx12, Convert__Imm1_0, AMFBS_isGFX12Only, { MCK_Imm }, },
  { 21844 /* s_trap */, AMDGPU::S_TRAP_gfx6_gfx7, Convert__Imm1_0, AMFBS_isGFX6GFX7, { MCK_Imm }, },
  { 21844 /* s_trap */, AMDGPU::S_TRAP_vi, Convert__Imm1_0, AMFBS_isGFX8GFX9, { MCK_Imm }, },
  { 21851 /* s_trunc_f16 */, AMDGPU::S_TRUNC_F16_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21851 /* s_trunc_f16 */, AMDGPU::S_TRUNC_F16_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21863 /* s_trunc_f32 */, AMDGPU::S_TRUNC_F32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21863 /* s_trunc_f32 */, AMDGPU::S_TRUNC_F32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_HasSALUFloatInsts_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 21875 /* s_ttracedata */, AMDGPU::S_TTRACEDATA_gfx10, Convert_NoOperands, AMFBS_isGFX10Only, {  }, },
  { 21875 /* s_ttracedata */, AMDGPU::S_TTRACEDATA_gfx11, Convert_NoOperands, AMFBS_isGFX11Only, {  }, },
  { 21875 /* s_ttracedata */, AMDGPU::S_TTRACEDATA_gfx12, Convert_NoOperands, AMFBS_isGFX12Only, {  }, },
  { 21875 /* s_ttracedata */, AMDGPU::S_TTRACEDATA_gfx6_gfx7, Convert_NoOperands, AMFBS_isGFX6GFX7, {  }, },
  { 21875 /* s_ttracedata */, AMDGPU::S_TTRACEDATA_vi, Convert_NoOperands, AMFBS_isGFX8GFX9, {  }, },
  { 21888 /* s_ttracedata_imm */, AMDGPU::S_TTRACEDATA_IMM_gfx10, Convert__S16Imm1_0, AMFBS_isGFX10Plus_isGFX10Only, { MCK_S16Imm }, },
  { 21888 /* s_ttracedata_imm */, AMDGPU::S_TTRACEDATA_IMM_gfx11, Convert__S16Imm1_0, AMFBS_isGFX10Plus_isGFX11Only, { MCK_S16Imm }, },
  { 21888 /* s_ttracedata_imm */, AMDGPU::S_TTRACEDATA_IMM_gfx12, Convert__S16Imm1_0, AMFBS_isGFX10Plus_isGFX12Only, { MCK_S16Imm }, },
  { 21905 /* s_version */, AMDGPU::S_VERSION_gfx10, Convert__S16Imm1_0, AMFBS_isGFX10Plus_isGFX10Only, { MCK_S16Imm }, },
  { 21905 /* s_version */, AMDGPU::S_VERSION_gfx11, Convert__S16Imm1_0, AMFBS_isGFX10Plus_isGFX11Only, { MCK_S16Imm }, },
  { 21905 /* s_version */, AMDGPU::S_VERSION_gfx12, Convert__S16Imm1_0, AMFBS_isGFX10Plus_isGFX12Only, { MCK_S16Imm }, },
  { 21915 /* s_wait_alu */, AMDGPU::S_WAITCNT_DEPCTR_gfx12, Convert__DepCtr1_0, AMFBS_isGFX10Plus_isGFX12Only, { MCK_DepCtr }, },
  { 21926 /* s_wait_asynccnt */, AMDGPU::S_WAIT_ASYNCCNT_gfx12, Convert__S16Imm1_0, AMFBS_isGFX1250Plus_isGFX12Only, { MCK_S16Imm }, },
  { 21942 /* s_wait_bvhcnt */, AMDGPU::S_WAIT_BVHCNT_gfx12, Convert__S16Imm1_0, AMFBS_HasImageInsts_isGFX12Plus_isGFX12Only, { MCK_S16Imm }, },
  { 21956 /* s_wait_dscnt */, AMDGPU::S_WAIT_DSCNT_gfx12, Convert__S16Imm1_0, AMFBS_isGFX12Plus_isGFX12Only, { MCK_S16Imm }, },
  { 21969 /* s_wait_event */, AMDGPU::S_WAIT_EVENT_gfx11, Convert__S16Imm1_0, AMFBS_HasExportInsts_isGFX11Plus_isGFX11Only, { MCK_S16Imm }, },
  { 21969 /* s_wait_event */, AMDGPU::S_WAIT_EVENT_gfx12, Convert__S16Imm1_0, AMFBS_HasExportInsts_isGFX11Plus_isGFX12Only, { MCK_S16Imm }, },
  { 21982 /* s_wait_expcnt */, AMDGPU::S_WAIT_EXPCNT_gfx12, Convert__S16Imm1_0, AMFBS_HasExportInsts_isGFX12Plus_isGFX12Only, { MCK_S16Imm }, },
  { 21996 /* s_wait_idle */, AMDGPU::S_WAIT_IDLE_gfx10, Convert_NoOperands, AMFBS_isGFX10Plus_isGFX10Only, {  }, },
  { 21996 /* s_wait_idle */, AMDGPU::S_WAIT_IDLE_gfx11, Convert_NoOperands, AMFBS_isGFX10Plus_isGFX11Only, {  }, },
  { 21996 /* s_wait_idle */, AMDGPU::S_WAIT_IDLE_gfx12, Convert_NoOperands, AMFBS_isGFX10Plus_isGFX12Only, {  }, },
  { 22008 /* s_wait_kmcnt */, AMDGPU::S_WAIT_KMCNT_gfx12, Convert__S16Imm1_0, AMFBS_isGFX12Plus_isGFX12Only, { MCK_S16Imm }, },
  { 22021 /* s_wait_loadcnt */, AMDGPU::S_WAIT_LOADCNT_gfx12, Convert__S16Imm1_0, AMFBS_isGFX12Plus_isGFX12Only, { MCK_S16Imm }, },
  { 22036 /* s_wait_loadcnt_dscnt */, AMDGPU::S_WAIT_LOADCNT_DSCNT_gfx12, Convert__S16Imm1_0, AMFBS_isGFX12Plus_isGFX12Only, { MCK_S16Imm }, },
  { 22057 /* s_wait_samplecnt */, AMDGPU::S_WAIT_SAMPLECNT_gfx12, Convert__S16Imm1_0, AMFBS_HasImageInsts_isGFX12Plus_isGFX12Only, { MCK_S16Imm }, },
  { 22074 /* s_wait_storecnt */, AMDGPU::S_WAIT_STORECNT_gfx12, Convert__S16Imm1_0, AMFBS_isGFX12Plus_isGFX12Only, { MCK_S16Imm }, },
  { 22090 /* s_wait_storecnt_dscnt */, AMDGPU::S_WAIT_STORECNT_DSCNT_gfx12, Convert__S16Imm1_0, AMFBS_isGFX12Plus_isGFX12Only, { MCK_S16Imm }, },
  { 22112 /* s_wait_tensorcnt */, AMDGPU::S_WAIT_TENSORCNT_gfx12, Convert__S16Imm1_0, AMFBS_isGFX1250Plus_isGFX12Only, { MCK_S16Imm }, },
  { 22129 /* s_wait_xcnt */, AMDGPU::S_WAIT_XCNT_gfx12, Convert__S16Imm1_0, AMFBS_HasWaitXcnt_isGFX12Only, { MCK_S16Imm }, },
  { 22141 /* s_waitcnt */, AMDGPU::S_WAITCNT_gfx10, Convert__SWaitCnt1_0, AMFBS_isNotGFX1250Plus_isGFX10Only, { MCK_SWaitCnt }, },
  { 22141 /* s_waitcnt */, AMDGPU::S_WAITCNT_gfx11, Convert__SWaitCnt1_0, AMFBS_isNotGFX1250Plus_isGFX11Only, { MCK_SWaitCnt }, },
  { 22141 /* s_waitcnt */, AMDGPU::S_WAITCNT_gfx12, Convert__SWaitCnt1_0, AMFBS_isNotGFX1250Plus_isGFX12Only, { MCK_SWaitCnt }, },
  { 22141 /* s_waitcnt */, AMDGPU::S_WAITCNT_gfx6_gfx7, Convert__SWaitCnt1_0, AMFBS_isNotGFX1250Plus_isGFX6GFX7, { MCK_SWaitCnt }, },
  { 22141 /* s_waitcnt */, AMDGPU::S_WAITCNT_vi, Convert__SWaitCnt1_0, AMFBS_isNotGFX1250Plus_isGFX8GFX9, { MCK_SWaitCnt }, },
  { 22151 /* s_waitcnt_depctr */, AMDGPU::S_WAITCNT_DEPCTR_gfx10, Convert__DepCtr1_0, AMFBS_isGFX10Plus_isGFX10Only, { MCK_DepCtr }, },
  { 22151 /* s_waitcnt_depctr */, AMDGPU::S_WAITCNT_DEPCTR_gfx11, Convert__DepCtr1_0, AMFBS_isGFX10Plus_isGFX11Only, { MCK_DepCtr }, },
  { 22168 /* s_waitcnt_expcnt */, AMDGPU::S_WAITCNT_EXPCNT_gfx10, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX10GFX11_isGFX10Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 22168 /* s_waitcnt_expcnt */, AMDGPU::S_WAITCNT_EXPCNT_gfx11, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX10GFX11_isGFX11Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 22185 /* s_waitcnt_lgkmcnt */, AMDGPU::S_WAITCNT_LGKMCNT_gfx10, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX10GFX11_isGFX10Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 22185 /* s_waitcnt_lgkmcnt */, AMDGPU::S_WAITCNT_LGKMCNT_gfx11, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX10GFX11_isGFX11Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 22203 /* s_waitcnt_vmcnt */, AMDGPU::S_WAITCNT_VMCNT_gfx10, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX10GFX11_isGFX10Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 22203 /* s_waitcnt_vmcnt */, AMDGPU::S_WAITCNT_VMCNT_gfx11, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX10GFX11_isGFX11Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 22219 /* s_waitcnt_vscnt */, AMDGPU::S_WAITCNT_VSCNT_gfx10, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX10GFX11_isGFX10Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 22219 /* s_waitcnt_vscnt */, AMDGPU::S_WAITCNT_VSCNT_gfx11, Convert__Reg1_0__S16Imm1_1, AMFBS_isGFX10GFX11_isGFX11Only, { MCK_SReg_32, MCK_S16Imm }, },
  { 22235 /* s_wakeup */, AMDGPU::S_WAKEUP_gfx10, Convert_NoOperands, AMFBS_isGFX8Plus_isGFX10Only, {  }, },
  { 22235 /* s_wakeup */, AMDGPU::S_WAKEUP_gfx11, Convert_NoOperands, AMFBS_isGFX8Plus_isGFX11Only, {  }, },
  { 22235 /* s_wakeup */, AMDGPU::S_WAKEUP_gfx12, Convert_NoOperands, AMFBS_isGFX8Plus_isGFX12Only, {  }, },
  { 22235 /* s_wakeup */, AMDGPU::S_WAKEUP_vi, Convert_NoOperands, AMFBS_isGFX8Plus_isGFX8GFX9, {  }, },
  { 22244 /* s_wakeup_barrier */, AMDGPU::S_WAKEUP_BARRIER_M0_gfx12, Convert_NoOperands, AMFBS_HasSWakeupBarrier_isGFX12Only, { MCK_M0 }, },
  { 22244 /* s_wakeup_barrier */, AMDGPU::S_WAKEUP_BARRIER_IMM_gfx12, Convert__SplitBarrier1_0, AMFBS_HasSWakeupBarrier_isGFX12Only, { MCK_SplitBarrier }, },
  { 22261 /* s_wqm_b32 */, AMDGPU::S_WQM_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 22261 /* s_wqm_b32 */, AMDGPU::S_WQM_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 22261 /* s_wqm_b32 */, AMDGPU::S_WQM_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 22261 /* s_wqm_b32 */, AMDGPU::S_WQM_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 22261 /* s_wqm_b32 */, AMDGPU::S_WQM_B32_vi, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 22271 /* s_wqm_b64 */, AMDGPU::S_WQM_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 22271 /* s_wqm_b64 */, AMDGPU::S_WQM_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 22271 /* s_wqm_b64 */, AMDGPU::S_WQM_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 22271 /* s_wqm_b64 */, AMDGPU::S_WQM_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 22271 /* s_wqm_b64 */, AMDGPU::S_WQM_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 22281 /* s_xnor_b32 */, AMDGPU::S_XNOR_B32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 22281 /* s_xnor_b32 */, AMDGPU::S_XNOR_B32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 22281 /* s_xnor_b32 */, AMDGPU::S_XNOR_B32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 22281 /* s_xnor_b32 */, AMDGPU::S_XNOR_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 22281 /* s_xnor_b32 */, AMDGPU::S_XNOR_B32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 22292 /* s_xnor_b64 */, AMDGPU::S_XNOR_B64_gfx10, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 22292 /* s_xnor_b64 */, AMDGPU::S_XNOR_B64_gfx11, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 22292 /* s_xnor_b64 */, AMDGPU::S_XNOR_B64_gfx12, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 22292 /* s_xnor_b64 */, AMDGPU::S_XNOR_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 22292 /* s_xnor_b64 */, AMDGPU::S_XNOR_B64_vi, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 22303 /* s_xnor_saveexec_b32 */, AMDGPU::S_XNOR_SAVEEXEC_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 22303 /* s_xnor_saveexec_b32 */, AMDGPU::S_XNOR_SAVEEXEC_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 22303 /* s_xnor_saveexec_b32 */, AMDGPU::S_XNOR_SAVEEXEC_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 22323 /* s_xnor_saveexec_b64 */, AMDGPU::S_XNOR_SAVEEXEC_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 22323 /* s_xnor_saveexec_b64 */, AMDGPU::S_XNOR_SAVEEXEC_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 22323 /* s_xnor_saveexec_b64 */, AMDGPU::S_XNOR_SAVEEXEC_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 22323 /* s_xnor_saveexec_b64 */, AMDGPU::S_XNOR_SAVEEXEC_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 22323 /* s_xnor_saveexec_b64 */, AMDGPU::S_XNOR_SAVEEXEC_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 22343 /* s_xor_b32 */, AMDGPU::S_XOR_B32_gfx10, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 22343 /* s_xor_b32 */, AMDGPU::S_XOR_B32_gfx11, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 22343 /* s_xor_b32 */, AMDGPU::S_XOR_B32_gfx12, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 22343 /* s_xor_b32 */, AMDGPU::S_XOR_B32_gfx6_gfx7, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 22343 /* s_xor_b32 */, AMDGPU::S_XOR_B32_vi, Convert__Reg1_0__SSrc_b321_1__SSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 22353 /* s_xor_b64 */, AMDGPU::S_XOR_B64_gfx10, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 22353 /* s_xor_b64 */, AMDGPU::S_XOR_B64_gfx11, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 22353 /* s_xor_b64 */, AMDGPU::S_XOR_B64_gfx12, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 22353 /* s_xor_b64 */, AMDGPU::S_XOR_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 22353 /* s_xor_b64 */, AMDGPU::S_XOR_B64_vi, Convert__Reg1_0__SSrc_b641_1__SSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64, MCK_SSrc_b64 }, },
  { 22363 /* s_xor_saveexec_b32 */, AMDGPU::S_XOR_SAVEEXEC_B32_gfx10, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX10Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 22363 /* s_xor_saveexec_b32 */, AMDGPU::S_XOR_SAVEEXEC_B32_gfx11, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX11Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 22363 /* s_xor_saveexec_b32 */, AMDGPU::S_XOR_SAVEEXEC_B32_gfx12, Convert__Reg1_0__SSrc_b321_1, AMFBS_isGFX10Plus_isGFX12Only, { MCK_SReg_32, MCK_SSrc_b32 }, },
  { 22382 /* s_xor_saveexec_b64 */, AMDGPU::S_XOR_SAVEEXEC_B64_gfx10, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX10Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 22382 /* s_xor_saveexec_b64 */, AMDGPU::S_XOR_SAVEEXEC_B64_gfx11, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX11Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 22382 /* s_xor_saveexec_b64 */, AMDGPU::S_XOR_SAVEEXEC_B64_gfx12, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX12Only, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 22382 /* s_xor_saveexec_b64 */, AMDGPU::S_XOR_SAVEEXEC_B64_gfx6_gfx7, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX6GFX7, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 22382 /* s_xor_saveexec_b64 */, AMDGPU::S_XOR_SAVEEXEC_B64_vi, Convert__Reg1_0__SSrc_b641_1, AMFBS_isGFX8GFX9, { MCK_SReg_64, MCK_SSrc_b64 }, },
  { 22401 /* scratch_load_b128 */, AMDGPU::SCRATCH_LOAD_DWORDX4_ST_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22401 /* scratch_load_b128 */, AMDGPU::SCRATCH_LOAD_DWORDX4_ST_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22401 /* scratch_load_b128 */, AMDGPU::SCRATCH_LOAD_DWORDX4_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22401 /* scratch_load_b128 */, AMDGPU::SCRATCH_LOAD_DWORDX4_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22401 /* scratch_load_b128 */, AMDGPU::SCRATCH_LOAD_DWORDX4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22401 /* scratch_load_b128 */, AMDGPU::SCRATCH_LOAD_DWORDX4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22401 /* scratch_load_b128 */, AMDGPU::SCRATCH_LOAD_DWORDX4_SVS_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22401 /* scratch_load_b128 */, AMDGPU::SCRATCH_LOAD_DWORDX4_SVS_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22419 /* scratch_load_b32 */, AMDGPU::SCRATCH_LOAD_DWORD_ST_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22419 /* scratch_load_b32 */, AMDGPU::SCRATCH_LOAD_DWORD_ST_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22419 /* scratch_load_b32 */, AMDGPU::SCRATCH_LOAD_DWORD_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22419 /* scratch_load_b32 */, AMDGPU::SCRATCH_LOAD_DWORD_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22419 /* scratch_load_b32 */, AMDGPU::SCRATCH_LOAD_DWORD_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22419 /* scratch_load_b32 */, AMDGPU::SCRATCH_LOAD_DWORD_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22419 /* scratch_load_b32 */, AMDGPU::SCRATCH_LOAD_DWORD_SVS_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22419 /* scratch_load_b32 */, AMDGPU::SCRATCH_LOAD_DWORD_SVS_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22436 /* scratch_load_b64 */, AMDGPU::SCRATCH_LOAD_DWORDX2_ST_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22436 /* scratch_load_b64 */, AMDGPU::SCRATCH_LOAD_DWORDX2_ST_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22436 /* scratch_load_b64 */, AMDGPU::SCRATCH_LOAD_DWORDX2_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22436 /* scratch_load_b64 */, AMDGPU::SCRATCH_LOAD_DWORDX2_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22436 /* scratch_load_b64 */, AMDGPU::SCRATCH_LOAD_DWORDX2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22436 /* scratch_load_b64 */, AMDGPU::SCRATCH_LOAD_DWORDX2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22436 /* scratch_load_b64 */, AMDGPU::SCRATCH_LOAD_DWORDX2_SVS_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22436 /* scratch_load_b64 */, AMDGPU::SCRATCH_LOAD_DWORDX2_SVS_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22453 /* scratch_load_b96 */, AMDGPU::SCRATCH_LOAD_DWORDX3_ST_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22453 /* scratch_load_b96 */, AMDGPU::SCRATCH_LOAD_DWORDX3_ST_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22453 /* scratch_load_b96 */, AMDGPU::SCRATCH_LOAD_DWORDX3_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22453 /* scratch_load_b96 */, AMDGPU::SCRATCH_LOAD_DWORDX3_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22453 /* scratch_load_b96 */, AMDGPU::SCRATCH_LOAD_DWORDX3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22453 /* scratch_load_b96 */, AMDGPU::SCRATCH_LOAD_DWORDX3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22453 /* scratch_load_b96 */, AMDGPU::SCRATCH_LOAD_DWORDX3_SVS_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22453 /* scratch_load_b96 */, AMDGPU::SCRATCH_LOAD_DWORDX3_SVS_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22470 /* scratch_load_block */, AMDGPU::SCRATCH_LOAD_BLOCK_ST_gfx12, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22470 /* scratch_load_block */, AMDGPU::SCRATCH_LOAD_BLOCK_SADDR_gfx12, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22470 /* scratch_load_block */, AMDGPU::SCRATCH_LOAD_BLOCK_gfx12, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22470 /* scratch_load_block */, AMDGPU::SCRATCH_LOAD_BLOCK_SVS_gfx12, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22489 /* scratch_load_d16_b16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_ST_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22489 /* scratch_load_d16_b16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_ST_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22489 /* scratch_load_d16_b16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22489 /* scratch_load_d16_b16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22489 /* scratch_load_d16_b16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22489 /* scratch_load_d16_b16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22489 /* scratch_load_d16_b16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_SVS_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSVSMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22489 /* scratch_load_d16_b16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_SVS_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSVSMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22510 /* scratch_load_d16_hi_b16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_HI_ST_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22510 /* scratch_load_d16_hi_b16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_HI_ST_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22510 /* scratch_load_d16_hi_b16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_HI_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22510 /* scratch_load_d16_hi_b16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_HI_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22510 /* scratch_load_d16_hi_b16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_HI_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22510 /* scratch_load_d16_hi_b16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_HI_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22510 /* scratch_load_d16_hi_b16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_HI_SVS_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSVSMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22510 /* scratch_load_d16_hi_b16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_HI_SVS_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSVSMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22534 /* scratch_load_d16_hi_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_HI_ST_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22534 /* scratch_load_d16_hi_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_HI_ST_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22534 /* scratch_load_d16_hi_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_HI_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22534 /* scratch_load_d16_hi_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_HI_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22534 /* scratch_load_d16_hi_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_HI_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22534 /* scratch_load_d16_hi_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_HI_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22534 /* scratch_load_d16_hi_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_HI_SVS_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSVSMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22534 /* scratch_load_d16_hi_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_HI_SVS_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSVSMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22557 /* scratch_load_d16_hi_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_HI_ST_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22557 /* scratch_load_d16_hi_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_HI_ST_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22557 /* scratch_load_d16_hi_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_HI_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22557 /* scratch_load_d16_hi_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_HI_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22557 /* scratch_load_d16_hi_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_HI_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22557 /* scratch_load_d16_hi_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_HI_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22557 /* scratch_load_d16_hi_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_HI_SVS_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSVSMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22557 /* scratch_load_d16_hi_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_HI_SVS_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSVSMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22580 /* scratch_load_d16_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_ST_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22580 /* scratch_load_d16_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_ST_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22580 /* scratch_load_d16_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22580 /* scratch_load_d16_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22580 /* scratch_load_d16_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22580 /* scratch_load_d16_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22580 /* scratch_load_d16_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_SVS_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSVSMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22580 /* scratch_load_d16_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_SVS_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSVSMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22600 /* scratch_load_d16_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_ST_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22600 /* scratch_load_d16_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_ST_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22600 /* scratch_load_d16_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22600 /* scratch_load_d16_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22600 /* scratch_load_d16_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22600 /* scratch_load_d16_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22600 /* scratch_load_d16_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_SVS_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSVSMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22600 /* scratch_load_d16_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_SVS_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSVSMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22620 /* scratch_load_dword */, AMDGPU::SCRATCH_LOAD_LDS_DWORD_ST_gfx10, Convert__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 22620 /* scratch_load_dword */, AMDGPU::SCRATCH_LOAD_LDS_DWORD_SADDR_vi, Convert__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts_isGFX8GFX9, { MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 22620 /* scratch_load_dword */, AMDGPU::SCRATCH_LOAD_LDS_DWORD_SADDR_gfx10, Convert__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 22620 /* scratch_load_dword */, AMDGPU::SCRATCH_LOAD_LDS_DWORD_vi, Convert__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 22620 /* scratch_load_dword */, AMDGPU::SCRATCH_LOAD_LDS_DWORD_gfx10, Convert__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 22620 /* scratch_load_dword */, AMDGPU::SCRATCH_LOAD_DWORD_ST_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22620 /* scratch_load_dword */, AMDGPU::SCRATCH_LOAD_DWORD_ST_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22620 /* scratch_load_dword */, AMDGPU::SCRATCH_LOAD_DWORD_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22620 /* scratch_load_dword */, AMDGPU::SCRATCH_LOAD_DWORD_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22620 /* scratch_load_dword */, AMDGPU::SCRATCH_LOAD_DWORD_VE_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22620 /* scratch_load_dword */, AMDGPU::SCRATCH_LOAD_DWORD_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22620 /* scratch_load_dword */, AMDGPU::SCRATCH_LOAD_DWORD_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22620 /* scratch_load_dword */, AMDGPU::SCRATCH_LOAD_DWORD_SVS_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22639 /* scratch_load_dwordx2 */, AMDGPU::SCRATCH_LOAD_DWORDX2_ST_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22639 /* scratch_load_dwordx2 */, AMDGPU::SCRATCH_LOAD_DWORDX2_ST_gfx940, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22639 /* scratch_load_dwordx2 */, AMDGPU::SCRATCH_LOAD_DWORDX2_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22639 /* scratch_load_dwordx2 */, AMDGPU::SCRATCH_LOAD_DWORDX2_SADDR_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22639 /* scratch_load_dwordx2 */, AMDGPU::SCRATCH_LOAD_DWORDX2_VE_gfx940, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22639 /* scratch_load_dwordx2 */, AMDGPU::SCRATCH_LOAD_DWORDX2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22639 /* scratch_load_dwordx2 */, AMDGPU::SCRATCH_LOAD_DWORDX2_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22639 /* scratch_load_dwordx2 */, AMDGPU::SCRATCH_LOAD_DWORDX2_SVS_gfx940, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22660 /* scratch_load_dwordx3 */, AMDGPU::SCRATCH_LOAD_DWORDX3_ST_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22660 /* scratch_load_dwordx3 */, AMDGPU::SCRATCH_LOAD_DWORDX3_ST_gfx940, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22660 /* scratch_load_dwordx3 */, AMDGPU::SCRATCH_LOAD_DWORDX3_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22660 /* scratch_load_dwordx3 */, AMDGPU::SCRATCH_LOAD_DWORDX3_SADDR_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22660 /* scratch_load_dwordx3 */, AMDGPU::SCRATCH_LOAD_DWORDX3_VE_gfx940, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22660 /* scratch_load_dwordx3 */, AMDGPU::SCRATCH_LOAD_DWORDX3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22660 /* scratch_load_dwordx3 */, AMDGPU::SCRATCH_LOAD_DWORDX3_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22660 /* scratch_load_dwordx3 */, AMDGPU::SCRATCH_LOAD_DWORDX3_SVS_gfx940, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22681 /* scratch_load_dwordx4 */, AMDGPU::SCRATCH_LOAD_DWORDX4_ST_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22681 /* scratch_load_dwordx4 */, AMDGPU::SCRATCH_LOAD_DWORDX4_ST_gfx940, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22681 /* scratch_load_dwordx4 */, AMDGPU::SCRATCH_LOAD_DWORDX4_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22681 /* scratch_load_dwordx4 */, AMDGPU::SCRATCH_LOAD_DWORDX4_SADDR_vi, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22681 /* scratch_load_dwordx4 */, AMDGPU::SCRATCH_LOAD_DWORDX4_VE_gfx940, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22681 /* scratch_load_dwordx4 */, AMDGPU::SCRATCH_LOAD_DWORDX4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22681 /* scratch_load_dwordx4 */, AMDGPU::SCRATCH_LOAD_DWORDX4_vi, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22681 /* scratch_load_dwordx4 */, AMDGPU::SCRATCH_LOAD_DWORDX4_SVS_gfx940, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22702 /* scratch_load_i16 */, AMDGPU::SCRATCH_LOAD_SSHORT_ST_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22702 /* scratch_load_i16 */, AMDGPU::SCRATCH_LOAD_SSHORT_ST_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22702 /* scratch_load_i16 */, AMDGPU::SCRATCH_LOAD_SSHORT_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22702 /* scratch_load_i16 */, AMDGPU::SCRATCH_LOAD_SSHORT_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22702 /* scratch_load_i16 */, AMDGPU::SCRATCH_LOAD_SSHORT_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22702 /* scratch_load_i16 */, AMDGPU::SCRATCH_LOAD_SSHORT_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22702 /* scratch_load_i16 */, AMDGPU::SCRATCH_LOAD_SSHORT_SVS_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22702 /* scratch_load_i16 */, AMDGPU::SCRATCH_LOAD_SSHORT_SVS_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22719 /* scratch_load_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_ST_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22719 /* scratch_load_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_ST_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22719 /* scratch_load_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22719 /* scratch_load_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22719 /* scratch_load_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22719 /* scratch_load_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22719 /* scratch_load_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_SVS_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22719 /* scratch_load_i8 */, AMDGPU::SCRATCH_LOAD_SBYTE_SVS_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22735 /* scratch_load_lds_dword */, AMDGPU::SCRATCH_LOAD_LDS_DWORD_ST_gfx940, Convert__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22735 /* scratch_load_lds_dword */, AMDGPU::SCRATCH_LOAD_LDS_DWORD_SADDR_gfx940, Convert__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22735 /* scratch_load_lds_dword */, AMDGPU::SCRATCH_LOAD_LDS_DWORD_gfx940, Convert__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22735 /* scratch_load_lds_dword */, AMDGPU::SCRATCH_LOAD_LDS_DWORD_SVS_gfx940, Convert__Reg1_0__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22758 /* scratch_load_lds_sbyte */, AMDGPU::SCRATCH_LOAD_LDS_SBYTE_ST_gfx940, Convert__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22758 /* scratch_load_lds_sbyte */, AMDGPU::SCRATCH_LOAD_LDS_SBYTE_SADDR_gfx940, Convert__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22758 /* scratch_load_lds_sbyte */, AMDGPU::SCRATCH_LOAD_LDS_SBYTE_gfx940, Convert__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22758 /* scratch_load_lds_sbyte */, AMDGPU::SCRATCH_LOAD_LDS_SBYTE_SVS_gfx940, Convert__Reg1_0__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22781 /* scratch_load_lds_sshort */, AMDGPU::SCRATCH_LOAD_LDS_SSHORT_ST_gfx940, Convert__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22781 /* scratch_load_lds_sshort */, AMDGPU::SCRATCH_LOAD_LDS_SSHORT_SADDR_gfx940, Convert__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22781 /* scratch_load_lds_sshort */, AMDGPU::SCRATCH_LOAD_LDS_SSHORT_gfx940, Convert__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22781 /* scratch_load_lds_sshort */, AMDGPU::SCRATCH_LOAD_LDS_SSHORT_SVS_gfx940, Convert__Reg1_0__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22805 /* scratch_load_lds_ubyte */, AMDGPU::SCRATCH_LOAD_LDS_UBYTE_ST_gfx940, Convert__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22805 /* scratch_load_lds_ubyte */, AMDGPU::SCRATCH_LOAD_LDS_UBYTE_SADDR_gfx940, Convert__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22805 /* scratch_load_lds_ubyte */, AMDGPU::SCRATCH_LOAD_LDS_UBYTE_gfx940, Convert__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22805 /* scratch_load_lds_ubyte */, AMDGPU::SCRATCH_LOAD_LDS_UBYTE_SVS_gfx940, Convert__Reg1_0__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22828 /* scratch_load_lds_ushort */, AMDGPU::SCRATCH_LOAD_LDS_USHORT_ST_gfx940, Convert__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22828 /* scratch_load_lds_ushort */, AMDGPU::SCRATCH_LOAD_LDS_USHORT_SADDR_gfx940, Convert__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22828 /* scratch_load_lds_ushort */, AMDGPU::SCRATCH_LOAD_LDS_USHORT_gfx940, Convert__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22828 /* scratch_load_lds_ushort */, AMDGPU::SCRATCH_LOAD_LDS_USHORT_SVS_gfx940, Convert__Reg1_0__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22852 /* scratch_load_sbyte */, AMDGPU::SCRATCH_LOAD_LDS_SBYTE_ST_gfx10, Convert__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 22852 /* scratch_load_sbyte */, AMDGPU::SCRATCH_LOAD_LDS_SBYTE_SADDR_vi, Convert__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts_isGFX8GFX9, { MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 22852 /* scratch_load_sbyte */, AMDGPU::SCRATCH_LOAD_LDS_SBYTE_SADDR_gfx10, Convert__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 22852 /* scratch_load_sbyte */, AMDGPU::SCRATCH_LOAD_LDS_SBYTE_vi, Convert__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 22852 /* scratch_load_sbyte */, AMDGPU::SCRATCH_LOAD_LDS_SBYTE_gfx10, Convert__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 22852 /* scratch_load_sbyte */, AMDGPU::SCRATCH_LOAD_SBYTE_ST_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22852 /* scratch_load_sbyte */, AMDGPU::SCRATCH_LOAD_SBYTE_ST_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22852 /* scratch_load_sbyte */, AMDGPU::SCRATCH_LOAD_SBYTE_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22852 /* scratch_load_sbyte */, AMDGPU::SCRATCH_LOAD_SBYTE_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22852 /* scratch_load_sbyte */, AMDGPU::SCRATCH_LOAD_SBYTE_VE_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22852 /* scratch_load_sbyte */, AMDGPU::SCRATCH_LOAD_SBYTE_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22852 /* scratch_load_sbyte */, AMDGPU::SCRATCH_LOAD_SBYTE_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22852 /* scratch_load_sbyte */, AMDGPU::SCRATCH_LOAD_SBYTE_SVS_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22871 /* scratch_load_sbyte_d16 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_ST_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22871 /* scratch_load_sbyte_d16 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_ST_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22871 /* scratch_load_sbyte_d16 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22871 /* scratch_load_sbyte_d16 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22871 /* scratch_load_sbyte_d16 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_VE_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22871 /* scratch_load_sbyte_d16 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22871 /* scratch_load_sbyte_d16 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22871 /* scratch_load_sbyte_d16 */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_SVS_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSVSMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22894 /* scratch_load_sbyte_d16_hi */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_HI_ST_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22894 /* scratch_load_sbyte_d16_hi */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_HI_ST_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22894 /* scratch_load_sbyte_d16_hi */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_HI_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22894 /* scratch_load_sbyte_d16_hi */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_HI_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22894 /* scratch_load_sbyte_d16_hi */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_HI_VE_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22894 /* scratch_load_sbyte_d16_hi */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_HI_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22894 /* scratch_load_sbyte_d16_hi */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_HI_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22894 /* scratch_load_sbyte_d16_hi */, AMDGPU::SCRATCH_LOAD_SBYTE_D16_HI_SVS_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSVSMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22920 /* scratch_load_short_d16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_ST_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22920 /* scratch_load_short_d16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_ST_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22920 /* scratch_load_short_d16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22920 /* scratch_load_short_d16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22920 /* scratch_load_short_d16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_VE_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22920 /* scratch_load_short_d16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22920 /* scratch_load_short_d16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22920 /* scratch_load_short_d16 */, AMDGPU::SCRATCH_LOAD_SHORT_D16_SVS_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSVSMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22943 /* scratch_load_short_d16_hi */, AMDGPU::SCRATCH_LOAD_SHORT_D16_HI_ST_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22943 /* scratch_load_short_d16_hi */, AMDGPU::SCRATCH_LOAD_SHORT_D16_HI_ST_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22943 /* scratch_load_short_d16_hi */, AMDGPU::SCRATCH_LOAD_SHORT_D16_HI_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22943 /* scratch_load_short_d16_hi */, AMDGPU::SCRATCH_LOAD_SHORT_D16_HI_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22943 /* scratch_load_short_d16_hi */, AMDGPU::SCRATCH_LOAD_SHORT_D16_HI_VE_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22943 /* scratch_load_short_d16_hi */, AMDGPU::SCRATCH_LOAD_SHORT_D16_HI_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22943 /* scratch_load_short_d16_hi */, AMDGPU::SCRATCH_LOAD_SHORT_D16_HI_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22943 /* scratch_load_short_d16_hi */, AMDGPU::SCRATCH_LOAD_SHORT_D16_HI_SVS_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSVSMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22969 /* scratch_load_sshort */, AMDGPU::SCRATCH_LOAD_LDS_SSHORT_ST_gfx10, Convert__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 22969 /* scratch_load_sshort */, AMDGPU::SCRATCH_LOAD_LDS_SSHORT_SADDR_vi, Convert__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts_isGFX8GFX9, { MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 22969 /* scratch_load_sshort */, AMDGPU::SCRATCH_LOAD_LDS_SSHORT_SADDR_gfx10, Convert__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 22969 /* scratch_load_sshort */, AMDGPU::SCRATCH_LOAD_LDS_SSHORT_vi, Convert__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 22969 /* scratch_load_sshort */, AMDGPU::SCRATCH_LOAD_LDS_SSHORT_gfx10, Convert__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 22969 /* scratch_load_sshort */, AMDGPU::SCRATCH_LOAD_SSHORT_ST_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22969 /* scratch_load_sshort */, AMDGPU::SCRATCH_LOAD_SSHORT_ST_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22969 /* scratch_load_sshort */, AMDGPU::SCRATCH_LOAD_SSHORT_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22969 /* scratch_load_sshort */, AMDGPU::SCRATCH_LOAD_SSHORT_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22969 /* scratch_load_sshort */, AMDGPU::SCRATCH_LOAD_SSHORT_VE_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22969 /* scratch_load_sshort */, AMDGPU::SCRATCH_LOAD_SSHORT_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22969 /* scratch_load_sshort */, AMDGPU::SCRATCH_LOAD_SSHORT_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22969 /* scratch_load_sshort */, AMDGPU::SCRATCH_LOAD_SSHORT_SVS_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22989 /* scratch_load_u16 */, AMDGPU::SCRATCH_LOAD_USHORT_ST_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22989 /* scratch_load_u16 */, AMDGPU::SCRATCH_LOAD_USHORT_ST_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22989 /* scratch_load_u16 */, AMDGPU::SCRATCH_LOAD_USHORT_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22989 /* scratch_load_u16 */, AMDGPU::SCRATCH_LOAD_USHORT_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22989 /* scratch_load_u16 */, AMDGPU::SCRATCH_LOAD_USHORT_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22989 /* scratch_load_u16 */, AMDGPU::SCRATCH_LOAD_USHORT_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 22989 /* scratch_load_u16 */, AMDGPU::SCRATCH_LOAD_USHORT_SVS_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 22989 /* scratch_load_u16 */, AMDGPU::SCRATCH_LOAD_USHORT_SVS_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23006 /* scratch_load_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_ST_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23006 /* scratch_load_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_ST_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23006 /* scratch_load_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23006 /* scratch_load_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23006 /* scratch_load_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23006 /* scratch_load_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23006 /* scratch_load_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_SVS_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23006 /* scratch_load_u8 */, AMDGPU::SCRATCH_LOAD_UBYTE_SVS_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23022 /* scratch_load_ubyte */, AMDGPU::SCRATCH_LOAD_LDS_UBYTE_ST_gfx10, Convert__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 23022 /* scratch_load_ubyte */, AMDGPU::SCRATCH_LOAD_LDS_UBYTE_SADDR_vi, Convert__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts_isGFX8GFX9, { MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 23022 /* scratch_load_ubyte */, AMDGPU::SCRATCH_LOAD_LDS_UBYTE_SADDR_gfx10, Convert__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 23022 /* scratch_load_ubyte */, AMDGPU::SCRATCH_LOAD_LDS_UBYTE_vi, Convert__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 23022 /* scratch_load_ubyte */, AMDGPU::SCRATCH_LOAD_LDS_UBYTE_gfx10, Convert__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 23022 /* scratch_load_ubyte */, AMDGPU::SCRATCH_LOAD_UBYTE_ST_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23022 /* scratch_load_ubyte */, AMDGPU::SCRATCH_LOAD_UBYTE_ST_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23022 /* scratch_load_ubyte */, AMDGPU::SCRATCH_LOAD_UBYTE_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23022 /* scratch_load_ubyte */, AMDGPU::SCRATCH_LOAD_UBYTE_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23022 /* scratch_load_ubyte */, AMDGPU::SCRATCH_LOAD_UBYTE_VE_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23022 /* scratch_load_ubyte */, AMDGPU::SCRATCH_LOAD_UBYTE_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23022 /* scratch_load_ubyte */, AMDGPU::SCRATCH_LOAD_UBYTE_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23022 /* scratch_load_ubyte */, AMDGPU::SCRATCH_LOAD_UBYTE_SVS_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23041 /* scratch_load_ubyte_d16 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_ST_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23041 /* scratch_load_ubyte_d16 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_ST_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23041 /* scratch_load_ubyte_d16 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23041 /* scratch_load_ubyte_d16 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23041 /* scratch_load_ubyte_d16 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_VE_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23041 /* scratch_load_ubyte_d16 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23041 /* scratch_load_ubyte_d16 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23041 /* scratch_load_ubyte_d16 */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_SVS_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSVSMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23064 /* scratch_load_ubyte_d16_hi */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_HI_ST_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23064 /* scratch_load_ubyte_d16_hi */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_HI_ST_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSTMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23064 /* scratch_load_ubyte_d16_hi */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_HI_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23064 /* scratch_load_ubyte_d16_hi */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_HI_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23064 /* scratch_load_ubyte_d16_hi */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_HI_VE_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23064 /* scratch_load_ubyte_d16_hi */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_HI_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23064 /* scratch_load_ubyte_d16_hi */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_HI_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23064 /* scratch_load_ubyte_d16_hi */, AMDGPU::SCRATCH_LOAD_UBYTE_D16_HI_SVS_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4__imm_95_0, AMFBS_HasFlatScratchSVSMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23090 /* scratch_load_ushort */, AMDGPU::SCRATCH_LOAD_LDS_USHORT_ST_gfx10, Convert__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 23090 /* scratch_load_ushort */, AMDGPU::SCRATCH_LOAD_LDS_USHORT_SADDR_vi, Convert__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts_isGFX8GFX9, { MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 23090 /* scratch_load_ushort */, AMDGPU::SCRATCH_LOAD_LDS_USHORT_SADDR_gfx10, Convert__Reg1_1__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 23090 /* scratch_load_ushort */, AMDGPU::SCRATCH_LOAD_LDS_USHORT_vi, Convert__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 23090 /* scratch_load_ushort */, AMDGPU::SCRATCH_LOAD_LDS_USHORT_gfx10, Convert__Reg1_0__FlatOffset1_2__CPol1_3, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol, MCK_lds }, },
  { 23090 /* scratch_load_ushort */, AMDGPU::SCRATCH_LOAD_USHORT_ST_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23090 /* scratch_load_ushort */, AMDGPU::SCRATCH_LOAD_USHORT_ST_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23090 /* scratch_load_ushort */, AMDGPU::SCRATCH_LOAD_USHORT_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23090 /* scratch_load_ushort */, AMDGPU::SCRATCH_LOAD_USHORT_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX8GFX9, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23090 /* scratch_load_ushort */, AMDGPU::SCRATCH_LOAD_USHORT_VE_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23090 /* scratch_load_ushort */, AMDGPU::SCRATCH_LOAD_USHORT_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23090 /* scratch_load_ushort */, AMDGPU::SCRATCH_LOAD_USHORT_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23090 /* scratch_load_ushort */, AMDGPU::SCRATCH_LOAD_USHORT_SVS_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX940Plus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23110 /* scratch_store_b128 */, AMDGPU::SCRATCH_STORE_DWORDX4_ST_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX11Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23110 /* scratch_store_b128 */, AMDGPU::SCRATCH_STORE_DWORDX4_ST_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX12Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23110 /* scratch_store_b128 */, AMDGPU::SCRATCH_STORE_DWORDX4_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23110 /* scratch_store_b128 */, AMDGPU::SCRATCH_STORE_DWORDX4_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23110 /* scratch_store_b128 */, AMDGPU::SCRATCH_STORE_DWORDX4_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23110 /* scratch_store_b128 */, AMDGPU::SCRATCH_STORE_DWORDX4_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23110 /* scratch_store_b128 */, AMDGPU::SCRATCH_STORE_DWORDX4_SVS_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23110 /* scratch_store_b128 */, AMDGPU::SCRATCH_STORE_DWORDX4_SVS_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23129 /* scratch_store_b16 */, AMDGPU::SCRATCH_STORE_SHORT_ST_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX11Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23129 /* scratch_store_b16 */, AMDGPU::SCRATCH_STORE_SHORT_ST_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX12Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23129 /* scratch_store_b16 */, AMDGPU::SCRATCH_STORE_SHORT_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23129 /* scratch_store_b16 */, AMDGPU::SCRATCH_STORE_SHORT_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23129 /* scratch_store_b16 */, AMDGPU::SCRATCH_STORE_SHORT_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23129 /* scratch_store_b16 */, AMDGPU::SCRATCH_STORE_SHORT_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23129 /* scratch_store_b16 */, AMDGPU::SCRATCH_STORE_SHORT_SVS_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23129 /* scratch_store_b16 */, AMDGPU::SCRATCH_STORE_SHORT_SVS_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23147 /* scratch_store_b32 */, AMDGPU::SCRATCH_STORE_DWORD_ST_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX11Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23147 /* scratch_store_b32 */, AMDGPU::SCRATCH_STORE_DWORD_ST_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX12Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23147 /* scratch_store_b32 */, AMDGPU::SCRATCH_STORE_DWORD_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23147 /* scratch_store_b32 */, AMDGPU::SCRATCH_STORE_DWORD_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23147 /* scratch_store_b32 */, AMDGPU::SCRATCH_STORE_DWORD_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23147 /* scratch_store_b32 */, AMDGPU::SCRATCH_STORE_DWORD_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23147 /* scratch_store_b32 */, AMDGPU::SCRATCH_STORE_DWORD_SVS_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23147 /* scratch_store_b32 */, AMDGPU::SCRATCH_STORE_DWORD_SVS_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23165 /* scratch_store_b64 */, AMDGPU::SCRATCH_STORE_DWORDX2_ST_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX11Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23165 /* scratch_store_b64 */, AMDGPU::SCRATCH_STORE_DWORDX2_ST_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX12Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23165 /* scratch_store_b64 */, AMDGPU::SCRATCH_STORE_DWORDX2_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23165 /* scratch_store_b64 */, AMDGPU::SCRATCH_STORE_DWORDX2_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23165 /* scratch_store_b64 */, AMDGPU::SCRATCH_STORE_DWORDX2_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23165 /* scratch_store_b64 */, AMDGPU::SCRATCH_STORE_DWORDX2_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23165 /* scratch_store_b64 */, AMDGPU::SCRATCH_STORE_DWORDX2_SVS_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23165 /* scratch_store_b64 */, AMDGPU::SCRATCH_STORE_DWORDX2_SVS_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23183 /* scratch_store_b8 */, AMDGPU::SCRATCH_STORE_BYTE_ST_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX11Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23183 /* scratch_store_b8 */, AMDGPU::SCRATCH_STORE_BYTE_ST_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX12Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23183 /* scratch_store_b8 */, AMDGPU::SCRATCH_STORE_BYTE_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23183 /* scratch_store_b8 */, AMDGPU::SCRATCH_STORE_BYTE_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23183 /* scratch_store_b8 */, AMDGPU::SCRATCH_STORE_BYTE_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23183 /* scratch_store_b8 */, AMDGPU::SCRATCH_STORE_BYTE_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23183 /* scratch_store_b8 */, AMDGPU::SCRATCH_STORE_BYTE_SVS_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23183 /* scratch_store_b8 */, AMDGPU::SCRATCH_STORE_BYTE_SVS_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23200 /* scratch_store_b96 */, AMDGPU::SCRATCH_STORE_DWORDX3_ST_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX11Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23200 /* scratch_store_b96 */, AMDGPU::SCRATCH_STORE_DWORDX3_ST_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX12Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23200 /* scratch_store_b96 */, AMDGPU::SCRATCH_STORE_DWORDX3_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23200 /* scratch_store_b96 */, AMDGPU::SCRATCH_STORE_DWORDX3_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23200 /* scratch_store_b96 */, AMDGPU::SCRATCH_STORE_DWORDX3_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23200 /* scratch_store_b96 */, AMDGPU::SCRATCH_STORE_DWORDX3_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23200 /* scratch_store_b96 */, AMDGPU::SCRATCH_STORE_DWORDX3_SVS_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23200 /* scratch_store_b96 */, AMDGPU::SCRATCH_STORE_DWORDX3_SVS_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23218 /* scratch_store_block */, AMDGPU::SCRATCH_STORE_BLOCK_ST_gfx12, Convert__RegByHwMode_VReg_1024_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX12Only, { MCK_off, MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23218 /* scratch_store_block */, AMDGPU::SCRATCH_STORE_BLOCK_SADDR_gfx12, Convert__RegByHwMode_VReg_1024_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX12Only, { MCK_off, MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23218 /* scratch_store_block */, AMDGPU::SCRATCH_STORE_BLOCK_gfx12, Convert__RegByHwMode_VReg_1024_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23218 /* scratch_store_block */, AMDGPU::SCRATCH_STORE_BLOCK_SVS_gfx12, Convert__RegByHwMode_VReg_1024_AlignTarget1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23238 /* scratch_store_byte */, AMDGPU::SCRATCH_STORE_BYTE_ST_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX10Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23238 /* scratch_store_byte */, AMDGPU::SCRATCH_STORE_BYTE_ST_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX940Plus, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23238 /* scratch_store_byte */, AMDGPU::SCRATCH_STORE_BYTE_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23238 /* scratch_store_byte */, AMDGPU::SCRATCH_STORE_BYTE_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX8GFX9, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23238 /* scratch_store_byte */, AMDGPU::SCRATCH_STORE_BYTE_VE_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23238 /* scratch_store_byte */, AMDGPU::SCRATCH_STORE_BYTE_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23238 /* scratch_store_byte */, AMDGPU::SCRATCH_STORE_BYTE_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23238 /* scratch_store_byte */, AMDGPU::SCRATCH_STORE_BYTE_SVS_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23257 /* scratch_store_byte_d16_hi */, AMDGPU::SCRATCH_STORE_BYTE_D16_HI_ST_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX10Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23257 /* scratch_store_byte_d16_hi */, AMDGPU::SCRATCH_STORE_BYTE_D16_HI_ST_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX940Plus, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23257 /* scratch_store_byte_d16_hi */, AMDGPU::SCRATCH_STORE_BYTE_D16_HI_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23257 /* scratch_store_byte_d16_hi */, AMDGPU::SCRATCH_STORE_BYTE_D16_HI_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX8GFX9, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23257 /* scratch_store_byte_d16_hi */, AMDGPU::SCRATCH_STORE_BYTE_D16_HI_VE_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23257 /* scratch_store_byte_d16_hi */, AMDGPU::SCRATCH_STORE_BYTE_D16_HI_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23257 /* scratch_store_byte_d16_hi */, AMDGPU::SCRATCH_STORE_BYTE_D16_HI_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23257 /* scratch_store_byte_d16_hi */, AMDGPU::SCRATCH_STORE_BYTE_D16_HI_SVS_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23283 /* scratch_store_d16_hi_b16 */, AMDGPU::SCRATCH_STORE_SHORT_D16_HI_ST_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX11Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23283 /* scratch_store_d16_hi_b16 */, AMDGPU::SCRATCH_STORE_SHORT_D16_HI_ST_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX12Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23283 /* scratch_store_d16_hi_b16 */, AMDGPU::SCRATCH_STORE_SHORT_D16_HI_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23283 /* scratch_store_d16_hi_b16 */, AMDGPU::SCRATCH_STORE_SHORT_D16_HI_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23283 /* scratch_store_d16_hi_b16 */, AMDGPU::SCRATCH_STORE_SHORT_D16_HI_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23283 /* scratch_store_d16_hi_b16 */, AMDGPU::SCRATCH_STORE_SHORT_D16_HI_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23283 /* scratch_store_d16_hi_b16 */, AMDGPU::SCRATCH_STORE_SHORT_D16_HI_SVS_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23283 /* scratch_store_d16_hi_b16 */, AMDGPU::SCRATCH_STORE_SHORT_D16_HI_SVS_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23308 /* scratch_store_d16_hi_b8 */, AMDGPU::SCRATCH_STORE_BYTE_D16_HI_ST_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX11Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23308 /* scratch_store_d16_hi_b8 */, AMDGPU::SCRATCH_STORE_BYTE_D16_HI_ST_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX12Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23308 /* scratch_store_d16_hi_b8 */, AMDGPU::SCRATCH_STORE_BYTE_D16_HI_SADDR_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23308 /* scratch_store_d16_hi_b8 */, AMDGPU::SCRATCH_STORE_BYTE_D16_HI_SADDR_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23308 /* scratch_store_d16_hi_b8 */, AMDGPU::SCRATCH_STORE_BYTE_D16_HI_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23308 /* scratch_store_d16_hi_b8 */, AMDGPU::SCRATCH_STORE_BYTE_D16_HI_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23308 /* scratch_store_d16_hi_b8 */, AMDGPU::SCRATCH_STORE_BYTE_D16_HI_SVS_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX11Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23308 /* scratch_store_d16_hi_b8 */, AMDGPU::SCRATCH_STORE_BYTE_D16_HI_SVS_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX12Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23332 /* scratch_store_dword */, AMDGPU::SCRATCH_STORE_DWORD_ST_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX10Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23332 /* scratch_store_dword */, AMDGPU::SCRATCH_STORE_DWORD_ST_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX940Plus, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23332 /* scratch_store_dword */, AMDGPU::SCRATCH_STORE_DWORD_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23332 /* scratch_store_dword */, AMDGPU::SCRATCH_STORE_DWORD_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX8GFX9, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23332 /* scratch_store_dword */, AMDGPU::SCRATCH_STORE_DWORD_VE_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23332 /* scratch_store_dword */, AMDGPU::SCRATCH_STORE_DWORD_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23332 /* scratch_store_dword */, AMDGPU::SCRATCH_STORE_DWORD_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23332 /* scratch_store_dword */, AMDGPU::SCRATCH_STORE_DWORD_SVS_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23352 /* scratch_store_dwordx2 */, AMDGPU::SCRATCH_STORE_DWORDX2_ST_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX10Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23352 /* scratch_store_dwordx2 */, AMDGPU::SCRATCH_STORE_DWORDX2_ST_gfx940, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX940Plus, { MCK_off, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23352 /* scratch_store_dwordx2 */, AMDGPU::SCRATCH_STORE_DWORDX2_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23352 /* scratch_store_dwordx2 */, AMDGPU::SCRATCH_STORE_DWORDX2_SADDR_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX8GFX9, { MCK_off, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23352 /* scratch_store_dwordx2 */, AMDGPU::SCRATCH_STORE_DWORDX2_VE_gfx940, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23352 /* scratch_store_dwordx2 */, AMDGPU::SCRATCH_STORE_DWORDX2_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23352 /* scratch_store_dwordx2 */, AMDGPU::SCRATCH_STORE_DWORDX2_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23352 /* scratch_store_dwordx2 */, AMDGPU::SCRATCH_STORE_DWORDX2_SVS_gfx940, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23374 /* scratch_store_dwordx3 */, AMDGPU::SCRATCH_STORE_DWORDX3_ST_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX10Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23374 /* scratch_store_dwordx3 */, AMDGPU::SCRATCH_STORE_DWORDX3_ST_gfx940, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX940Plus, { MCK_off, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23374 /* scratch_store_dwordx3 */, AMDGPU::SCRATCH_STORE_DWORDX3_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23374 /* scratch_store_dwordx3 */, AMDGPU::SCRATCH_STORE_DWORDX3_SADDR_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX8GFX9, { MCK_off, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23374 /* scratch_store_dwordx3 */, AMDGPU::SCRATCH_STORE_DWORDX3_VE_gfx940, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23374 /* scratch_store_dwordx3 */, AMDGPU::SCRATCH_STORE_DWORDX3_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23374 /* scratch_store_dwordx3 */, AMDGPU::SCRATCH_STORE_DWORDX3_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23374 /* scratch_store_dwordx3 */, AMDGPU::SCRATCH_STORE_DWORDX3_SVS_gfx940, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23396 /* scratch_store_dwordx4 */, AMDGPU::SCRATCH_STORE_DWORDX4_ST_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX10Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23396 /* scratch_store_dwordx4 */, AMDGPU::SCRATCH_STORE_DWORDX4_ST_gfx940, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX940Plus, { MCK_off, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23396 /* scratch_store_dwordx4 */, AMDGPU::SCRATCH_STORE_DWORDX4_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23396 /* scratch_store_dwordx4 */, AMDGPU::SCRATCH_STORE_DWORDX4_SADDR_vi, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX8GFX9, { MCK_off, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23396 /* scratch_store_dwordx4 */, AMDGPU::SCRATCH_STORE_DWORDX4_VE_gfx940, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23396 /* scratch_store_dwordx4 */, AMDGPU::SCRATCH_STORE_DWORDX4_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23396 /* scratch_store_dwordx4 */, AMDGPU::SCRATCH_STORE_DWORDX4_vi, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23396 /* scratch_store_dwordx4 */, AMDGPU::SCRATCH_STORE_DWORDX4_SVS_gfx940, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23418 /* scratch_store_short */, AMDGPU::SCRATCH_STORE_SHORT_ST_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX10Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23418 /* scratch_store_short */, AMDGPU::SCRATCH_STORE_SHORT_ST_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX940Plus, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23418 /* scratch_store_short */, AMDGPU::SCRATCH_STORE_SHORT_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23418 /* scratch_store_short */, AMDGPU::SCRATCH_STORE_SHORT_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX8GFX9, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23418 /* scratch_store_short */, AMDGPU::SCRATCH_STORE_SHORT_VE_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23418 /* scratch_store_short */, AMDGPU::SCRATCH_STORE_SHORT_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23418 /* scratch_store_short */, AMDGPU::SCRATCH_STORE_SHORT_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23418 /* scratch_store_short */, AMDGPU::SCRATCH_STORE_SHORT_SVS_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23438 /* scratch_store_short_d16_hi */, AMDGPU::SCRATCH_STORE_SHORT_D16_HI_ST_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX10Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23438 /* scratch_store_short_d16_hi */, AMDGPU::SCRATCH_STORE_SHORT_D16_HI_ST_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_1__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSTMode_isGFX940Plus, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23438 /* scratch_store_short_d16_hi */, AMDGPU::SCRATCH_STORE_SHORT_D16_HI_SADDR_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23438 /* scratch_store_short_d16_hi */, AMDGPU::SCRATCH_STORE_SHORT_D16_HI_SADDR_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX8GFX9, { MCK_off, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23438 /* scratch_store_short_d16_hi */, AMDGPU::SCRATCH_STORE_SHORT_D16_HI_VE_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23438 /* scratch_store_short_d16_hi */, AMDGPU::SCRATCH_STORE_SHORT_D16_HI_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23438 /* scratch_store_short_d16_hi */, AMDGPU::SCRATCH_STORE_SHORT_D16_HI_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__FlatOffset1_3__CPol1_4, AMFBS_isGFX8GFX9NotGFX940_HasFlatScratchInsts, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_FlatOffset, MCK_CPol }, },
  { 23438 /* scratch_store_short_d16_hi */, AMDGPU::SCRATCH_STORE_SHORT_D16_HI_SVS_gfx940, Convert__RegByHwMode_AV_LdSt_32_Target1_1__Reg1_0__Reg1_2__FlatOffset1_3__CPol1_4, AMFBS_HasFlatScratchSVSMode_isGFX940Plus, { MCK_VGPR_32, MCK_RegByHwMode_AV_LdSt_32_Target, MCK_SReg_32_XEXEC_HI, MCK_FlatOffset, MCK_CPol }, },
  { 23465 /* tbuffer_load_d16_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_VBUFFER_OFFSET_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 23465 /* tbuffer_load_d16_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_OFFSET_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23465 /* tbuffer_load_d16_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_VBUFFER_IDXEN_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23465 /* tbuffer_load_d16_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_VBUFFER_OFFEN_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23465 /* tbuffer_load_d16_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_IDXEN_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23465 /* tbuffer_load_d16_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_OFFEN_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23465 /* tbuffer_load_d16_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_VBUFFER_BOTHEN_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23465 /* tbuffer_load_d16_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_BOTHEN_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23491 /* tbuffer_load_d16_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_VBUFFER_OFFSET_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 23491 /* tbuffer_load_d16_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_OFFSET_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23491 /* tbuffer_load_d16_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_VBUFFER_IDXEN_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23491 /* tbuffer_load_d16_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_VBUFFER_OFFEN_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23491 /* tbuffer_load_d16_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_IDXEN_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23491 /* tbuffer_load_d16_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_OFFEN_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23491 /* tbuffer_load_d16_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_VBUFFER_BOTHEN_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23491 /* tbuffer_load_d16_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_BOTHEN_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23518 /* tbuffer_load_d16_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_VBUFFER_OFFSET_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 23518 /* tbuffer_load_d16_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_OFFSET_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23518 /* tbuffer_load_d16_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_VBUFFER_IDXEN_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23518 /* tbuffer_load_d16_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_VBUFFER_OFFEN_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23518 /* tbuffer_load_d16_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_IDXEN_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23518 /* tbuffer_load_d16_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_OFFEN_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23518 /* tbuffer_load_d16_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_VBUFFER_BOTHEN_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23518 /* tbuffer_load_d16_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_BOTHEN_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23546 /* tbuffer_load_d16_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_VBUFFER_OFFSET_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 23546 /* tbuffer_load_d16_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_OFFSET_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23546 /* tbuffer_load_d16_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_VBUFFER_IDXEN_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23546 /* tbuffer_load_d16_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_VBUFFER_OFFEN_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23546 /* tbuffer_load_d16_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_IDXEN_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23546 /* tbuffer_load_d16_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_OFFEN_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23546 /* tbuffer_load_d16_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_VBUFFER_BOTHEN_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23546 /* tbuffer_load_d16_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_BOTHEN_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23575 /* tbuffer_load_format_d16_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_OFFSET_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23575 /* tbuffer_load_format_d16_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_OFFSET_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23575 /* tbuffer_load_format_d16_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_OFFSET_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23575 /* tbuffer_load_format_d16_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_gfx80_OFFSET_gfx80, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23575 /* tbuffer_load_format_d16_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_IDXEN_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23575 /* tbuffer_load_format_d16_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_IDXEN_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23575 /* tbuffer_load_format_d16_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_IDXEN_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23575 /* tbuffer_load_format_d16_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_gfx80_IDXEN_gfx80, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23575 /* tbuffer_load_format_d16_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_OFFEN_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23575 /* tbuffer_load_format_d16_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_OFFEN_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23575 /* tbuffer_load_format_d16_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_OFFEN_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23575 /* tbuffer_load_format_d16_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_gfx80_OFFEN_gfx80, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23575 /* tbuffer_load_format_d16_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_BOTHEN_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23575 /* tbuffer_load_format_d16_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_BOTHEN_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23575 /* tbuffer_load_format_d16_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_BOTHEN_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23575 /* tbuffer_load_format_d16_x */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_X_gfx80_BOTHEN_gfx80, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23601 /* tbuffer_load_format_d16_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_OFFSET_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23601 /* tbuffer_load_format_d16_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_OFFSET_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23601 /* tbuffer_load_format_d16_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_OFFSET_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23601 /* tbuffer_load_format_d16_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_gfx80_OFFSET_gfx80, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23601 /* tbuffer_load_format_d16_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_IDXEN_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23601 /* tbuffer_load_format_d16_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_IDXEN_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23601 /* tbuffer_load_format_d16_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_IDXEN_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23601 /* tbuffer_load_format_d16_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_OFFEN_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23601 /* tbuffer_load_format_d16_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_OFFEN_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23601 /* tbuffer_load_format_d16_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_OFFEN_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23601 /* tbuffer_load_format_d16_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_gfx80_IDXEN_gfx80, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23601 /* tbuffer_load_format_d16_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_gfx80_OFFEN_gfx80, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23601 /* tbuffer_load_format_d16_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_BOTHEN_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23601 /* tbuffer_load_format_d16_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_BOTHEN_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23601 /* tbuffer_load_format_d16_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_BOTHEN_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23601 /* tbuffer_load_format_d16_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XY_gfx80_BOTHEN_gfx80, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23628 /* tbuffer_load_format_d16_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_OFFSET_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23628 /* tbuffer_load_format_d16_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_OFFSET_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23628 /* tbuffer_load_format_d16_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_OFFSET_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23628 /* tbuffer_load_format_d16_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_gfx80_OFFSET_gfx80, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23628 /* tbuffer_load_format_d16_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_IDXEN_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23628 /* tbuffer_load_format_d16_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_IDXEN_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23628 /* tbuffer_load_format_d16_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_IDXEN_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23628 /* tbuffer_load_format_d16_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_OFFEN_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23628 /* tbuffer_load_format_d16_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_OFFEN_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23628 /* tbuffer_load_format_d16_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_OFFEN_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23628 /* tbuffer_load_format_d16_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_gfx80_IDXEN_gfx80, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23628 /* tbuffer_load_format_d16_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_gfx80_OFFEN_gfx80, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23628 /* tbuffer_load_format_d16_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_BOTHEN_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23628 /* tbuffer_load_format_d16_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_BOTHEN_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23628 /* tbuffer_load_format_d16_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_BOTHEN_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23628 /* tbuffer_load_format_d16_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZ_gfx80_BOTHEN_gfx80, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23656 /* tbuffer_load_format_d16_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_OFFSET_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23656 /* tbuffer_load_format_d16_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_OFFSET_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23656 /* tbuffer_load_format_d16_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_OFFSET_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23656 /* tbuffer_load_format_d16_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_gfx80_OFFSET_gfx80, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23656 /* tbuffer_load_format_d16_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_IDXEN_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23656 /* tbuffer_load_format_d16_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_IDXEN_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23656 /* tbuffer_load_format_d16_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_IDXEN_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23656 /* tbuffer_load_format_d16_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_OFFEN_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23656 /* tbuffer_load_format_d16_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_OFFEN_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23656 /* tbuffer_load_format_d16_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_OFFEN_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23656 /* tbuffer_load_format_d16_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_gfx80_IDXEN_gfx80, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23656 /* tbuffer_load_format_d16_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_gfx80_OFFEN_gfx80, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23656 /* tbuffer_load_format_d16_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_BOTHEN_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23656 /* tbuffer_load_format_d16_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_BOTHEN_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23656 /* tbuffer_load_format_d16_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_BOTHEN_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23656 /* tbuffer_load_format_d16_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_D16_XYZW_gfx80_BOTHEN_gfx80, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_VBUFFER_OFFSET_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_OFFSET_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_OFFSET_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_OFFSET_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_OFFSET_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_OFFSET_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_ADDR64_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_VBUFFER_IDXEN_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_VBUFFER_OFFEN_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_IDXEN_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_IDXEN_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_IDXEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_IDXEN_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_IDXEN_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_OFFEN_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_OFFEN_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_OFFEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_OFFEN_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_OFFEN_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_VBUFFER_BOTHEN_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_BOTHEN_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_BOTHEN_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_BOTHEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_BOTHEN_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23685 /* tbuffer_load_format_x */, AMDGPU::TBUFFER_LOAD_FORMAT_X_BOTHEN_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_VBUFFER_OFFSET_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_OFFSET_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_OFFSET_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_OFFSET_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_OFFSET_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_OFFSET_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_ADDR64_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_VBUFFER_IDXEN_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_VBUFFER_OFFEN_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_IDXEN_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_IDXEN_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_IDXEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_IDXEN_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_IDXEN_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_OFFEN_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_OFFEN_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_OFFEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_OFFEN_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_OFFEN_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_VBUFFER_BOTHEN_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_BOTHEN_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_BOTHEN_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_BOTHEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_BOTHEN_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23707 /* tbuffer_load_format_xy */, AMDGPU::TBUFFER_LOAD_FORMAT_XY_BOTHEN_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_VBUFFER_OFFSET_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_OFFSET_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_OFFSET_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_OFFSET_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_OFFSET_gfx90a, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_OFFSET_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_ADDR64_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_VBUFFER_IDXEN_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_VBUFFER_OFFEN_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_IDXEN_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_IDXEN_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_IDXEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_IDXEN_gfx90a, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_IDXEN_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_OFFEN_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_OFFEN_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_OFFEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_OFFEN_gfx90a, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_OFFEN_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_VBUFFER_BOTHEN_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_BOTHEN_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_BOTHEN_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_BOTHEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_BOTHEN_gfx90a, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23730 /* tbuffer_load_format_xyz */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZ_BOTHEN_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_VBUFFER_OFFSET_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_OFFSET_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_OFFSET_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_OFFSET_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_OFFSET_gfx90a, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_OFFSET_vi, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_ADDR64_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_VBUFFER_IDXEN_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_VBUFFER_OFFEN_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_IDXEN_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_IDXEN_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_IDXEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_IDXEN_gfx90a, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_IDXEN_vi, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_OFFEN_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_OFFEN_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_OFFEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_OFFEN_gfx90a, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_OFFEN_vi, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_VBUFFER_BOTHEN_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_BOTHEN_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_BOTHEN_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_BOTHEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_BOTHEN_gfx90a, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23754 /* tbuffer_load_format_xyzw */, AMDGPU::TBUFFER_LOAD_FORMAT_XYZW_BOTHEN_vi, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23779 /* tbuffer_store_d16_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_VBUFFER_OFFSET_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 23779 /* tbuffer_store_d16_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_OFFSET_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23779 /* tbuffer_store_d16_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_VBUFFER_IDXEN_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23779 /* tbuffer_store_d16_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_VBUFFER_OFFEN_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23779 /* tbuffer_store_d16_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_IDXEN_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23779 /* tbuffer_store_d16_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_OFFEN_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23779 /* tbuffer_store_d16_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_VBUFFER_BOTHEN_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23779 /* tbuffer_store_d16_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_BOTHEN_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23806 /* tbuffer_store_d16_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_VBUFFER_OFFSET_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 23806 /* tbuffer_store_d16_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_OFFSET_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23806 /* tbuffer_store_d16_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_VBUFFER_IDXEN_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23806 /* tbuffer_store_d16_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_VBUFFER_OFFEN_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23806 /* tbuffer_store_d16_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_IDXEN_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23806 /* tbuffer_store_d16_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_OFFEN_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23806 /* tbuffer_store_d16_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_VBUFFER_BOTHEN_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23806 /* tbuffer_store_d16_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_BOTHEN_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23834 /* tbuffer_store_d16_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_VBUFFER_OFFSET_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 23834 /* tbuffer_store_d16_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_OFFSET_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23834 /* tbuffer_store_d16_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_VBUFFER_IDXEN_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23834 /* tbuffer_store_d16_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_VBUFFER_OFFEN_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23834 /* tbuffer_store_d16_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_IDXEN_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23834 /* tbuffer_store_d16_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_OFFEN_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23834 /* tbuffer_store_d16_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_VBUFFER_BOTHEN_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23834 /* tbuffer_store_d16_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_BOTHEN_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23863 /* tbuffer_store_d16_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_VBUFFER_OFFSET_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 23863 /* tbuffer_store_d16_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_OFFSET_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23863 /* tbuffer_store_d16_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_VBUFFER_IDXEN_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23863 /* tbuffer_store_d16_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_VBUFFER_OFFEN_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23863 /* tbuffer_store_d16_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_IDXEN_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23863 /* tbuffer_store_d16_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_OFFEN_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23863 /* tbuffer_store_d16_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_VBUFFER_BOTHEN_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23863 /* tbuffer_store_d16_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_BOTHEN_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23893 /* tbuffer_store_format_d16_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_OFFSET_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23893 /* tbuffer_store_format_d16_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_OFFSET_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23893 /* tbuffer_store_format_d16_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_OFFSET_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23893 /* tbuffer_store_format_d16_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_gfx80_OFFSET_gfx80, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23893 /* tbuffer_store_format_d16_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_IDXEN_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23893 /* tbuffer_store_format_d16_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_IDXEN_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23893 /* tbuffer_store_format_d16_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_IDXEN_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23893 /* tbuffer_store_format_d16_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_gfx80_IDXEN_gfx80, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23893 /* tbuffer_store_format_d16_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_OFFEN_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23893 /* tbuffer_store_format_d16_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_OFFEN_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23893 /* tbuffer_store_format_d16_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_OFFEN_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23893 /* tbuffer_store_format_d16_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_gfx80_OFFEN_gfx80, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23893 /* tbuffer_store_format_d16_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_BOTHEN_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23893 /* tbuffer_store_format_d16_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_BOTHEN_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23893 /* tbuffer_store_format_d16_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_BOTHEN_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23893 /* tbuffer_store_format_d16_x */, AMDGPU::TBUFFER_STORE_FORMAT_D16_X_gfx80_BOTHEN_gfx80, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23920 /* tbuffer_store_format_d16_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_OFFSET_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23920 /* tbuffer_store_format_d16_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_OFFSET_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23920 /* tbuffer_store_format_d16_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_OFFSET_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23920 /* tbuffer_store_format_d16_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_gfx80_OFFSET_gfx80, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23920 /* tbuffer_store_format_d16_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_IDXEN_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23920 /* tbuffer_store_format_d16_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_IDXEN_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23920 /* tbuffer_store_format_d16_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_IDXEN_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23920 /* tbuffer_store_format_d16_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_OFFEN_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23920 /* tbuffer_store_format_d16_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_OFFEN_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23920 /* tbuffer_store_format_d16_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_OFFEN_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23920 /* tbuffer_store_format_d16_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_gfx80_IDXEN_gfx80, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23920 /* tbuffer_store_format_d16_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_gfx80_OFFEN_gfx80, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23920 /* tbuffer_store_format_d16_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_BOTHEN_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23920 /* tbuffer_store_format_d16_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_BOTHEN_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23920 /* tbuffer_store_format_d16_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_BOTHEN_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23920 /* tbuffer_store_format_d16_xy */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XY_gfx80_BOTHEN_gfx80, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23948 /* tbuffer_store_format_d16_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_OFFSET_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23948 /* tbuffer_store_format_d16_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_OFFSET_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23948 /* tbuffer_store_format_d16_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_OFFSET_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23948 /* tbuffer_store_format_d16_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_gfx80_OFFSET_gfx80, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23948 /* tbuffer_store_format_d16_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_IDXEN_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23948 /* tbuffer_store_format_d16_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_IDXEN_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23948 /* tbuffer_store_format_d16_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_IDXEN_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23948 /* tbuffer_store_format_d16_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_OFFEN_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23948 /* tbuffer_store_format_d16_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_OFFEN_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23948 /* tbuffer_store_format_d16_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_OFFEN_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23948 /* tbuffer_store_format_d16_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_gfx80_IDXEN_gfx80, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23948 /* tbuffer_store_format_d16_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_gfx80_OFFEN_gfx80, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23948 /* tbuffer_store_format_d16_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_BOTHEN_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23948 /* tbuffer_store_format_d16_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_BOTHEN_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23948 /* tbuffer_store_format_d16_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_BOTHEN_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23948 /* tbuffer_store_format_d16_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZ_gfx80_BOTHEN_gfx80, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23977 /* tbuffer_store_format_d16_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_OFFSET_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23977 /* tbuffer_store_format_d16_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_OFFSET_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23977 /* tbuffer_store_format_d16_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_OFFSET_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23977 /* tbuffer_store_format_d16_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_gfx80_OFFSET_gfx80, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 23977 /* tbuffer_store_format_d16_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_IDXEN_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23977 /* tbuffer_store_format_d16_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_IDXEN_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23977 /* tbuffer_store_format_d16_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_IDXEN_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23977 /* tbuffer_store_format_d16_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_OFFEN_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23977 /* tbuffer_store_format_d16_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_OFFEN_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23977 /* tbuffer_store_format_d16_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_OFFEN_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23977 /* tbuffer_store_format_d16_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_gfx80_IDXEN_gfx80, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 23977 /* tbuffer_store_format_d16_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_gfx80_OFFEN_gfx80, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23977 /* tbuffer_store_format_d16_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_BOTHEN_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23977 /* tbuffer_store_format_d16_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_BOTHEN_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23977 /* tbuffer_store_format_d16_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_BOTHEN_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasPackedD16VMem_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 23977 /* tbuffer_store_format_d16_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_D16_XYZW_gfx80_BOTHEN_gfx80, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_HasUnpackedD16VMem, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_VBUFFER_OFFSET_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_OFFSET_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_OFFSET_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_OFFSET_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_OFFSET_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_OFFSET_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_ADDR64_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_VBUFFER_IDXEN_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_VBUFFER_OFFEN_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_IDXEN_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_IDXEN_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_IDXEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_IDXEN_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_IDXEN_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_OFFEN_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_OFFEN_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_OFFEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_OFFEN_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_OFFEN_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_VBUFFER_BOTHEN_gfx12, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_BOTHEN_gfx10, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_BOTHEN_gfx11, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_BOTHEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_BOTHEN_gfx90a, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24007 /* tbuffer_store_format_x */, AMDGPU::TBUFFER_STORE_FORMAT_X_BOTHEN_vi, Convert__RegByHwMode_AV_LdSt_32_Target1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_32_Target, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_VBUFFER_OFFSET_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_OFFSET_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_OFFSET_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_OFFSET_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_OFFSET_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_OFFSET_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_ADDR64_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_VBUFFER_IDXEN_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_VBUFFER_OFFEN_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_IDXEN_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_IDXEN_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_IDXEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_IDXEN_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_IDXEN_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_OFFEN_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_OFFEN_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_OFFEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_OFFEN_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_OFFEN_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_VBUFFER_BOTHEN_gfx12, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_BOTHEN_gfx10, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_BOTHEN_gfx11, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_BOTHEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_BOTHEN_gfx90a, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24030 /* tbuffer_store_format_xy */, AMDGPU::TBUFFER_STORE_FORMAT_XY_BOTHEN_vi, Convert__RegByHwMode_AV_LdSt_64_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_64_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_VBUFFER_OFFSET_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_OFFSET_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_OFFSET_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_OFFSET_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_OFFSET_gfx90a, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_OFFSET_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_ADDR64_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_VBUFFER_IDXEN_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_VBUFFER_OFFEN_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_IDXEN_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_IDXEN_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_IDXEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_IDXEN_gfx90a, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_IDXEN_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_OFFEN_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_OFFEN_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_OFFEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_OFFEN_gfx90a, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_OFFEN_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_VBUFFER_BOTHEN_gfx12, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_BOTHEN_gfx10, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_BOTHEN_gfx11, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_BOTHEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_BOTHEN_gfx90a, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24054 /* tbuffer_store_format_xyz */, AMDGPU::TBUFFER_STORE_FORMAT_XYZ_BOTHEN_vi, Convert__RegByHwMode_AV_LdSt_96_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_96_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_VBUFFER_OFFSET_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__Reg1_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_OFFSET_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_OFFSET_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_OFFSET_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_OFFSET_gfx90a, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_OFFSET_vi, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_2__SCSrc_b321_4__Offset1_5__FORMAT1_3__CPol1_6__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_off, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_ADDR64_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_addr64, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_VBUFFER_IDXEN_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_VBUFFER_OFFEN_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_IDXEN_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_IDXEN_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_IDXEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_IDXEN_gfx90a, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_IDXEN_vi, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_OFFEN_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_OFFEN_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_OFFEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_OFFEN_gfx90a, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_OFFEN_vi, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_6__FORMAT1_3__CPol1_7__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VGPR_32, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_VBUFFER_BOTHEN_gfx12, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__Reg1_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX12Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SReg_32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_BOTHEN_gfx10, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX10Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_BOTHEN_gfx11, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX11Only, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_BOTHEN_gfx6_gfx7, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX6GFX7, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_BOTHEN_gfx90a, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX90APlus, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24079 /* tbuffer_store_format_xyzw */, AMDGPU::TBUFFER_STORE_FORMAT_XYZW_BOTHEN_vi, Convert__RegByHwMode_AV_LdSt_128_AlignTarget1_0__Reg1_1__Reg1_2__SCSrc_b321_4__Offset1_7__FORMAT1_3__CPol1_8__imm_95_0, AMFBS_HasMTBUFInsts_isGFX8GFX9NotGFX90A, { MCK_RegByHwMode_AV_LdSt_128_AlignTarget, MCK_VReg_64, MCK_SReg_128_XNULL, MCK_FORMAT, MCK_SCSrc_b32, MCK_idxen, MCK_offen, MCK_Offset, MCK_CPol }, },
  { 24105 /* tensor_load_to_lds */, AMDGPU::TENSOR_LOAD_TO_LDS_D2_gfx1250, Convert__Reg1_0__Reg1_1__R128A161_2__CPol1_3, AMFBS_isGFX1250Plus, { MCK_SReg_128_XNULL, MCK_SReg_256_XNULL, MCK_R128A16, MCK_CPol }, },
  { 24105 /* tensor_load_to_lds */, AMDGPU::TENSOR_LOAD_TO_LDS_gfx1250, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__R128A161_4__CPol1_5, AMFBS_isGFX1250Plus, { MCK_SReg_128_XNULL, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_SReg_128_XNULL, MCK_R128A16, MCK_CPol }, },
  { 24124 /* tensor_save */, AMDGPU::TENSOR_SAVE_gfx1250, Convert__Reg1_0__FlatOffset1_1__CPol1_2, AMFBS_HasMcastLoadInsts_isGFX125xOnly, { MCK_SReg_64, MCK_FlatOffset, MCK_CPol }, },
  { 24136 /* tensor_stop */, AMDGPU::TENSOR_STOP_gfx1250, Convert__CPol1_0, AMFBS_HasMcastLoadInsts_isGFX125xOnly, { MCK_CPol }, },
  { 24148 /* tensor_store_from_lds */, AMDGPU::TENSOR_STORE_FROM_LDS_D2_gfx1250, Convert__Reg1_0__Reg1_1__R128A161_2__CPol1_3, AMFBS_isGFX1250Plus, { MCK_SReg_128_XNULL, MCK_SReg_256_XNULL, MCK_R128A16, MCK_CPol }, },
  { 24148 /* tensor_store_from_lds */, AMDGPU::TENSOR_STORE_FROM_LDS_gfx1250, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__R128A161_4__CPol1_5, AMFBS_isGFX1250Plus, { MCK_SReg_128_XNULL, MCK_SReg_256_XNULL, MCK_SReg_128_XNULL, MCK_SReg_128_XNULL, MCK_R128A16, MCK_CPol }, },
  { 24170 /* v_accvgpr_mov_b32 */, AMDGPU::V_ACCVGPR_MOV_B32_vi, Convert__Reg1_0__Reg1_1, AMFBS_isGFX90APlus_isGFX8GFX9, { MCK_AGPR_32, MCK_AGPR_32 }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_e32_gfx12, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX12Plus_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_e32_gfx11, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX11Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_e32_gfx10, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX10Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_e32_gfx12, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX12Plus_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC_LO }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_e32_gfx11, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC_LO }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_e32_gfx10, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX10Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC_LO }, },
  { 24254 /* v_add_co_u32 */, AMDGPU::V_ADD_CO_U32_e32_gfx9, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX9Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24254 /* v_add_co_u32 */, AMDGPU::V_ADD_CO_U32_e32_gfx9, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX9Only_isWave64, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24254 /* v_add_co_u32 */, AMDGPU::V_ADD_CO_U32_e32_gfx9, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24254 /* v_add_co_u32 */, AMDGPU::V_ADD_I32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX6GFX7_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 24254 /* v_add_co_u32 */, AMDGPU::V_ADD_I32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX6GFX7_isWave32, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC_LO }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1__Reg1_2, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1__Reg1_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24287 /* v_add_f64 */, AMDGPU::V_ADD_F64_e32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 24307 /* v_add_i32 */, AMDGPU::V_ADD_I32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24427 /* v_add_nc_u32 */, AMDGPU::V_ADD_NC_U32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_HasAddNoCarryInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24427 /* v_add_nc_u32 */, AMDGPU::V_ADD_NC_U32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_HasAddNoCarryInsts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24427 /* v_add_nc_u32 */, AMDGPU::V_ADD_NC_U32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_HasAddNoCarryInsts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24440 /* v_add_nc_u64 */, AMDGPU::V_ADD_U64_e32_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_HasAddSubU64Insts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 24453 /* v_add_u16 */, AMDGPU::V_ADD_U16_e32_vi, Convert__Reg1_0__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 24463 /* v_add_u32 */, AMDGPU::V_ADD_U32_e32_gfx9, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_HasAddNoCarryInsts_isGFX9Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24463 /* v_add_u32 */, AMDGPU::V_ADD_U32_e32_vi, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24473 /* v_addc_co_u32 */, AMDGPU::V_ADDC_CO_U32_e32_gfx9, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX9Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 24473 /* v_addc_co_u32 */, AMDGPU::V_ADDC_CO_U32_e32_gfx9, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 24473 /* v_addc_co_u32 */, AMDGPU::V_ADDC_CO_U32_e32_gfx9, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX9Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC_LO }, },
  { 24487 /* v_addc_u32 */, AMDGPU::V_ADDC_U32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 24487 /* v_addc_u32 */, AMDGPU::V_ADDC_U32_e32_vi, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_e32_vi, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24562 /* v_ashr_i32 */, AMDGPU::V_ASHR_I32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24618 /* v_ashrrev_i16 */, AMDGPU::V_ASHRREV_I16_e32_vi, Convert__Reg1_0__VSrc_b161_1__Reg1_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_e32_vi, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24660 /* v_bcnt_u32_b32 */, AMDGPU::V_BCNT_U32_B32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24705 /* v_bfm_b32 */, AMDGPU::V_BFM_B32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_e32_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 24775 /* v_ceil_f64 */, AMDGPU::V_CEIL_F64_e32_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX7Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 24775 /* v_ceil_f64 */, AMDGPU::V_CEIL_F64_e32_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX7Plus_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 24775 /* v_ceil_f64 */, AMDGPU::V_CEIL_F64_e32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX7Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 24775 /* v_ceil_f64 */, AMDGPU::V_CEIL_F64_e32_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX7Plus_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 24775 /* v_ceil_f64 */, AMDGPU::V_CEIL_F64_e32_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 24786 /* v_clrexcp */, AMDGPU::V_CLREXCP_e32_gfx10, Convert_NoOperands, AMFBS_isGFX10Only, {  }, },
  { 24786 /* v_clrexcp */, AMDGPU::V_CLREXCP_e32_gfx6_gfx7, Convert_NoOperands, AMFBS_isGFX6GFX7, {  }, },
  { 24786 /* v_clrexcp */, AMDGPU::V_CLREXCP_e32_vi, Convert_NoOperands, AMFBS_isGFX8GFX9, {  }, },
  { 24796 /* v_cls_i32 */, AMDGPU::V_CLS_I32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 24796 /* v_cls_i32 */, AMDGPU::V_CLS_I32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 24806 /* v_clz_i32_u32 */, AMDGPU::V_CLZ_I32_U32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 24806 /* v_clz_i32_u32 */, AMDGPU::V_CLZ_I32_U32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 24820 /* V_CMP_CLASS_F16 */, AMDGPU::V_CMP_CLASS_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 24820 /* V_CMP_CLASS_F16 */, AMDGPU::V_CMP_CLASS_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 24820 /* V_CMP_CLASS_F16 */, AMDGPU::V_CMP_CLASS_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 24820 /* V_CMP_CLASS_F16 */, AMDGPU::V_CMP_CLASS_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 24820 /* V_CMP_CLASS_F16 */, AMDGPU::V_CMP_CLASS_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 24820 /* V_CMP_CLASS_F16 */, AMDGPU::V_CMP_CLASS_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 24836 /* v_cmp_class_f16_e32 */, AMDGPU::V_CMP_CLASS_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 24836 /* v_cmp_class_f16_e32 */, AMDGPU::V_CMP_CLASS_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 24836 /* v_cmp_class_f16_e32 */, AMDGPU::V_CMP_CLASS_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 24836 /* v_cmp_class_f16_e32 */, AMDGPU::V_CMP_CLASS_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 24836 /* v_cmp_class_f16_e32 */, AMDGPU::V_CMP_CLASS_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 24836 /* v_cmp_class_f16_e32 */, AMDGPU::V_CMP_CLASS_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 24856 /* V_CMP_CLASS_F32 */, AMDGPU::V_CMP_CLASS_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24856 /* V_CMP_CLASS_F32 */, AMDGPU::V_CMP_CLASS_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24856 /* V_CMP_CLASS_F32 */, AMDGPU::V_CMP_CLASS_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24856 /* V_CMP_CLASS_F32 */, AMDGPU::V_CMP_CLASS_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24856 /* V_CMP_CLASS_F32 */, AMDGPU::V_CMP_CLASS_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24856 /* V_CMP_CLASS_F32 */, AMDGPU::V_CMP_CLASS_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24856 /* V_CMP_CLASS_F32 */, AMDGPU::V_CMP_CLASS_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24856 /* V_CMP_CLASS_F32 */, AMDGPU::V_CMP_CLASS_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24856 /* V_CMP_CLASS_F32 */, AMDGPU::V_CMP_CLASS_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24856 /* V_CMP_CLASS_F32 */, AMDGPU::V_CMP_CLASS_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24856 /* V_CMP_CLASS_F32 */, AMDGPU::V_CMP_CLASS_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24856 /* V_CMP_CLASS_F32 */, AMDGPU::V_CMP_CLASS_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24856 /* V_CMP_CLASS_F32 */, AMDGPU::V_CMP_CLASS_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24856 /* V_CMP_CLASS_F32 */, AMDGPU::V_CMP_CLASS_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24856 /* V_CMP_CLASS_F32 */, AMDGPU::V_CMP_CLASS_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24872 /* v_cmp_class_f32_e32 */, AMDGPU::V_CMP_CLASS_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24872 /* v_cmp_class_f32_e32 */, AMDGPU::V_CMP_CLASS_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24872 /* v_cmp_class_f32_e32 */, AMDGPU::V_CMP_CLASS_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24872 /* v_cmp_class_f32_e32 */, AMDGPU::V_CMP_CLASS_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24872 /* v_cmp_class_f32_e32 */, AMDGPU::V_CMP_CLASS_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24892 /* V_CMP_CLASS_F64 */, AMDGPU::V_CMP_CLASS_F64_e32_gfx11, Convert__VSrc_f641_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 24892 /* V_CMP_CLASS_F64 */, AMDGPU::V_CMP_CLASS_F64_e32_gfx12, Convert__VSrc_f641_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 24892 /* V_CMP_CLASS_F64 */, AMDGPU::V_CMP_CLASS_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 24892 /* V_CMP_CLASS_F64 */, AMDGPU::V_CMP_CLASS_F64_e32_gfx10, Convert__VSrc_f641_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 24892 /* V_CMP_CLASS_F64 */, AMDGPU::V_CMP_CLASS_F64_e32_vi, Convert__VSrc_f641_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 24892 /* V_CMP_CLASS_F64 */, AMDGPU::V_CMP_CLASS_F64_e32_gfx11, Convert__VSrc_f641_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 24892 /* V_CMP_CLASS_F64 */, AMDGPU::V_CMP_CLASS_F64_e32_gfx12, Convert__VSrc_f641_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 24892 /* V_CMP_CLASS_F64 */, AMDGPU::V_CMP_CLASS_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 24892 /* V_CMP_CLASS_F64 */, AMDGPU::V_CMP_CLASS_F64_e32_gfx10, Convert__VSrc_f641_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 24892 /* V_CMP_CLASS_F64 */, AMDGPU::V_CMP_CLASS_F64_e32_vi, Convert__VSrc_f641_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 24892 /* V_CMP_CLASS_F64 */, AMDGPU::V_CMP_CLASS_F64_e32_gfx11, Convert__VSrc_f641_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 24892 /* V_CMP_CLASS_F64 */, AMDGPU::V_CMP_CLASS_F64_e32_gfx12, Convert__VSrc_f641_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 24892 /* V_CMP_CLASS_F64 */, AMDGPU::V_CMP_CLASS_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 24892 /* V_CMP_CLASS_F64 */, AMDGPU::V_CMP_CLASS_F64_e32_gfx10, Convert__VSrc_f641_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 24892 /* V_CMP_CLASS_F64 */, AMDGPU::V_CMP_CLASS_F64_e32_vi, Convert__VSrc_f641_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 24908 /* v_cmp_class_f64_e32 */, AMDGPU::V_CMP_CLASS_F64_e32_gfx10, Convert__VSrc_f641_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 24908 /* v_cmp_class_f64_e32 */, AMDGPU::V_CMP_CLASS_F64_e32_gfx11, Convert__VSrc_f641_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 24908 /* v_cmp_class_f64_e32 */, AMDGPU::V_CMP_CLASS_F64_e32_gfx12, Convert__VSrc_f641_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 24908 /* v_cmp_class_f64_e32 */, AMDGPU::V_CMP_CLASS_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 24908 /* v_cmp_class_f64_e32 */, AMDGPU::V_CMP_CLASS_F64_e32_vi, Convert__VSrc_f641_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 24928 /* V_CMP_EQ_F16 */, AMDGPU::V_CMP_EQ_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 24928 /* V_CMP_EQ_F16 */, AMDGPU::V_CMP_EQ_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 24928 /* V_CMP_EQ_F16 */, AMDGPU::V_CMP_EQ_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 24928 /* V_CMP_EQ_F16 */, AMDGPU::V_CMP_EQ_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 24928 /* V_CMP_EQ_F16 */, AMDGPU::V_CMP_EQ_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 24928 /* V_CMP_EQ_F16 */, AMDGPU::V_CMP_EQ_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 24941 /* v_cmp_eq_f16_e32 */, AMDGPU::V_CMP_EQ_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 24941 /* v_cmp_eq_f16_e32 */, AMDGPU::V_CMP_EQ_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 24941 /* v_cmp_eq_f16_e32 */, AMDGPU::V_CMP_EQ_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 24941 /* v_cmp_eq_f16_e32 */, AMDGPU::V_CMP_EQ_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 24941 /* v_cmp_eq_f16_e32 */, AMDGPU::V_CMP_EQ_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 24941 /* v_cmp_eq_f16_e32 */, AMDGPU::V_CMP_EQ_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 24958 /* V_CMP_EQ_F32 */, AMDGPU::V_CMP_EQ_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24958 /* V_CMP_EQ_F32 */, AMDGPU::V_CMP_EQ_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24958 /* V_CMP_EQ_F32 */, AMDGPU::V_CMP_EQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24958 /* V_CMP_EQ_F32 */, AMDGPU::V_CMP_EQ_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24958 /* V_CMP_EQ_F32 */, AMDGPU::V_CMP_EQ_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24958 /* V_CMP_EQ_F32 */, AMDGPU::V_CMP_EQ_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24958 /* V_CMP_EQ_F32 */, AMDGPU::V_CMP_EQ_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24958 /* V_CMP_EQ_F32 */, AMDGPU::V_CMP_EQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24958 /* V_CMP_EQ_F32 */, AMDGPU::V_CMP_EQ_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24958 /* V_CMP_EQ_F32 */, AMDGPU::V_CMP_EQ_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24958 /* V_CMP_EQ_F32 */, AMDGPU::V_CMP_EQ_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24958 /* V_CMP_EQ_F32 */, AMDGPU::V_CMP_EQ_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24958 /* V_CMP_EQ_F32 */, AMDGPU::V_CMP_EQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24958 /* V_CMP_EQ_F32 */, AMDGPU::V_CMP_EQ_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24958 /* V_CMP_EQ_F32 */, AMDGPU::V_CMP_EQ_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24971 /* v_cmp_eq_f32_e32 */, AMDGPU::V_CMP_EQ_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24971 /* v_cmp_eq_f32_e32 */, AMDGPU::V_CMP_EQ_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24971 /* v_cmp_eq_f32_e32 */, AMDGPU::V_CMP_EQ_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24971 /* v_cmp_eq_f32_e32 */, AMDGPU::V_CMP_EQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24971 /* v_cmp_eq_f32_e32 */, AMDGPU::V_CMP_EQ_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 24988 /* V_CMP_EQ_F64 */, AMDGPU::V_CMP_EQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 24988 /* V_CMP_EQ_F64 */, AMDGPU::V_CMP_EQ_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 24988 /* V_CMP_EQ_F64 */, AMDGPU::V_CMP_EQ_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 24988 /* V_CMP_EQ_F64 */, AMDGPU::V_CMP_EQ_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 24988 /* V_CMP_EQ_F64 */, AMDGPU::V_CMP_EQ_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 24988 /* V_CMP_EQ_F64 */, AMDGPU::V_CMP_EQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 24988 /* V_CMP_EQ_F64 */, AMDGPU::V_CMP_EQ_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 24988 /* V_CMP_EQ_F64 */, AMDGPU::V_CMP_EQ_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 24988 /* V_CMP_EQ_F64 */, AMDGPU::V_CMP_EQ_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 24988 /* V_CMP_EQ_F64 */, AMDGPU::V_CMP_EQ_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 24988 /* V_CMP_EQ_F64 */, AMDGPU::V_CMP_EQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 24988 /* V_CMP_EQ_F64 */, AMDGPU::V_CMP_EQ_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 24988 /* V_CMP_EQ_F64 */, AMDGPU::V_CMP_EQ_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 24988 /* V_CMP_EQ_F64 */, AMDGPU::V_CMP_EQ_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 24988 /* V_CMP_EQ_F64 */, AMDGPU::V_CMP_EQ_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25001 /* v_cmp_eq_f64_e32 */, AMDGPU::V_CMP_EQ_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25001 /* v_cmp_eq_f64_e32 */, AMDGPU::V_CMP_EQ_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25001 /* v_cmp_eq_f64_e32 */, AMDGPU::V_CMP_EQ_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25001 /* v_cmp_eq_f64_e32 */, AMDGPU::V_CMP_EQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25001 /* v_cmp_eq_f64_e32 */, AMDGPU::V_CMP_EQ_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25018 /* V_CMP_EQ_I16 */, AMDGPU::V_CMP_EQ_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25018 /* V_CMP_EQ_I16 */, AMDGPU::V_CMP_EQ_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25018 /* V_CMP_EQ_I16 */, AMDGPU::V_CMP_EQ_I16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25018 /* V_CMP_EQ_I16 */, AMDGPU::V_CMP_EQ_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25018 /* V_CMP_EQ_I16 */, AMDGPU::V_CMP_EQ_I16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25018 /* V_CMP_EQ_I16 */, AMDGPU::V_CMP_EQ_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25031 /* v_cmp_eq_i16_e32 */, AMDGPU::V_CMP_EQ_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25031 /* v_cmp_eq_i16_e32 */, AMDGPU::V_CMP_EQ_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25031 /* v_cmp_eq_i16_e32 */, AMDGPU::V_CMP_EQ_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25031 /* v_cmp_eq_i16_e32 */, AMDGPU::V_CMP_EQ_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25031 /* v_cmp_eq_i16_e32 */, AMDGPU::V_CMP_EQ_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25031 /* v_cmp_eq_i16_e32 */, AMDGPU::V_CMP_EQ_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25048 /* V_CMP_EQ_I32 */, AMDGPU::V_CMP_EQ_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25048 /* V_CMP_EQ_I32 */, AMDGPU::V_CMP_EQ_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25048 /* V_CMP_EQ_I32 */, AMDGPU::V_CMP_EQ_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25048 /* V_CMP_EQ_I32 */, AMDGPU::V_CMP_EQ_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25048 /* V_CMP_EQ_I32 */, AMDGPU::V_CMP_EQ_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25048 /* V_CMP_EQ_I32 */, AMDGPU::V_CMP_EQ_I32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25048 /* V_CMP_EQ_I32 */, AMDGPU::V_CMP_EQ_I32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25048 /* V_CMP_EQ_I32 */, AMDGPU::V_CMP_EQ_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25048 /* V_CMP_EQ_I32 */, AMDGPU::V_CMP_EQ_I32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25048 /* V_CMP_EQ_I32 */, AMDGPU::V_CMP_EQ_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25048 /* V_CMP_EQ_I32 */, AMDGPU::V_CMP_EQ_I32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25048 /* V_CMP_EQ_I32 */, AMDGPU::V_CMP_EQ_I32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25048 /* V_CMP_EQ_I32 */, AMDGPU::V_CMP_EQ_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25048 /* V_CMP_EQ_I32 */, AMDGPU::V_CMP_EQ_I32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25048 /* V_CMP_EQ_I32 */, AMDGPU::V_CMP_EQ_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25061 /* v_cmp_eq_i32_e32 */, AMDGPU::V_CMP_EQ_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25061 /* v_cmp_eq_i32_e32 */, AMDGPU::V_CMP_EQ_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25061 /* v_cmp_eq_i32_e32 */, AMDGPU::V_CMP_EQ_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25061 /* v_cmp_eq_i32_e32 */, AMDGPU::V_CMP_EQ_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25061 /* v_cmp_eq_i32_e32 */, AMDGPU::V_CMP_EQ_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25078 /* V_CMP_EQ_I64 */, AMDGPU::V_CMP_EQ_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25078 /* V_CMP_EQ_I64 */, AMDGPU::V_CMP_EQ_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25078 /* V_CMP_EQ_I64 */, AMDGPU::V_CMP_EQ_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25078 /* V_CMP_EQ_I64 */, AMDGPU::V_CMP_EQ_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25078 /* V_CMP_EQ_I64 */, AMDGPU::V_CMP_EQ_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25078 /* V_CMP_EQ_I64 */, AMDGPU::V_CMP_EQ_I64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25078 /* V_CMP_EQ_I64 */, AMDGPU::V_CMP_EQ_I64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25078 /* V_CMP_EQ_I64 */, AMDGPU::V_CMP_EQ_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25078 /* V_CMP_EQ_I64 */, AMDGPU::V_CMP_EQ_I64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25078 /* V_CMP_EQ_I64 */, AMDGPU::V_CMP_EQ_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25078 /* V_CMP_EQ_I64 */, AMDGPU::V_CMP_EQ_I64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25078 /* V_CMP_EQ_I64 */, AMDGPU::V_CMP_EQ_I64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25078 /* V_CMP_EQ_I64 */, AMDGPU::V_CMP_EQ_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25078 /* V_CMP_EQ_I64 */, AMDGPU::V_CMP_EQ_I64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25078 /* V_CMP_EQ_I64 */, AMDGPU::V_CMP_EQ_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25091 /* v_cmp_eq_i64_e32 */, AMDGPU::V_CMP_EQ_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25091 /* v_cmp_eq_i64_e32 */, AMDGPU::V_CMP_EQ_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25091 /* v_cmp_eq_i64_e32 */, AMDGPU::V_CMP_EQ_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25091 /* v_cmp_eq_i64_e32 */, AMDGPU::V_CMP_EQ_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25091 /* v_cmp_eq_i64_e32 */, AMDGPU::V_CMP_EQ_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25108 /* V_CMP_EQ_U16 */, AMDGPU::V_CMP_EQ_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25108 /* V_CMP_EQ_U16 */, AMDGPU::V_CMP_EQ_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25108 /* V_CMP_EQ_U16 */, AMDGPU::V_CMP_EQ_U16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25108 /* V_CMP_EQ_U16 */, AMDGPU::V_CMP_EQ_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25108 /* V_CMP_EQ_U16 */, AMDGPU::V_CMP_EQ_U16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25108 /* V_CMP_EQ_U16 */, AMDGPU::V_CMP_EQ_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25121 /* v_cmp_eq_u16_e32 */, AMDGPU::V_CMP_EQ_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25121 /* v_cmp_eq_u16_e32 */, AMDGPU::V_CMP_EQ_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25121 /* v_cmp_eq_u16_e32 */, AMDGPU::V_CMP_EQ_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25121 /* v_cmp_eq_u16_e32 */, AMDGPU::V_CMP_EQ_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25121 /* v_cmp_eq_u16_e32 */, AMDGPU::V_CMP_EQ_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25121 /* v_cmp_eq_u16_e32 */, AMDGPU::V_CMP_EQ_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25138 /* V_CMP_EQ_U32 */, AMDGPU::V_CMP_EQ_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25138 /* V_CMP_EQ_U32 */, AMDGPU::V_CMP_EQ_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25138 /* V_CMP_EQ_U32 */, AMDGPU::V_CMP_EQ_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25138 /* V_CMP_EQ_U32 */, AMDGPU::V_CMP_EQ_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25138 /* V_CMP_EQ_U32 */, AMDGPU::V_CMP_EQ_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25138 /* V_CMP_EQ_U32 */, AMDGPU::V_CMP_EQ_U32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25138 /* V_CMP_EQ_U32 */, AMDGPU::V_CMP_EQ_U32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25138 /* V_CMP_EQ_U32 */, AMDGPU::V_CMP_EQ_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25138 /* V_CMP_EQ_U32 */, AMDGPU::V_CMP_EQ_U32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25138 /* V_CMP_EQ_U32 */, AMDGPU::V_CMP_EQ_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25138 /* V_CMP_EQ_U32 */, AMDGPU::V_CMP_EQ_U32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25138 /* V_CMP_EQ_U32 */, AMDGPU::V_CMP_EQ_U32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25138 /* V_CMP_EQ_U32 */, AMDGPU::V_CMP_EQ_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25138 /* V_CMP_EQ_U32 */, AMDGPU::V_CMP_EQ_U32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25138 /* V_CMP_EQ_U32 */, AMDGPU::V_CMP_EQ_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25151 /* v_cmp_eq_u32_e32 */, AMDGPU::V_CMP_EQ_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25151 /* v_cmp_eq_u32_e32 */, AMDGPU::V_CMP_EQ_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25151 /* v_cmp_eq_u32_e32 */, AMDGPU::V_CMP_EQ_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25151 /* v_cmp_eq_u32_e32 */, AMDGPU::V_CMP_EQ_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25151 /* v_cmp_eq_u32_e32 */, AMDGPU::V_CMP_EQ_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25168 /* V_CMP_EQ_U64 */, AMDGPU::V_CMP_EQ_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25168 /* V_CMP_EQ_U64 */, AMDGPU::V_CMP_EQ_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25168 /* V_CMP_EQ_U64 */, AMDGPU::V_CMP_EQ_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25168 /* V_CMP_EQ_U64 */, AMDGPU::V_CMP_EQ_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25168 /* V_CMP_EQ_U64 */, AMDGPU::V_CMP_EQ_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25168 /* V_CMP_EQ_U64 */, AMDGPU::V_CMP_EQ_U64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25168 /* V_CMP_EQ_U64 */, AMDGPU::V_CMP_EQ_U64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25168 /* V_CMP_EQ_U64 */, AMDGPU::V_CMP_EQ_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25168 /* V_CMP_EQ_U64 */, AMDGPU::V_CMP_EQ_U64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25168 /* V_CMP_EQ_U64 */, AMDGPU::V_CMP_EQ_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25168 /* V_CMP_EQ_U64 */, AMDGPU::V_CMP_EQ_U64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25168 /* V_CMP_EQ_U64 */, AMDGPU::V_CMP_EQ_U64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25168 /* V_CMP_EQ_U64 */, AMDGPU::V_CMP_EQ_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25168 /* V_CMP_EQ_U64 */, AMDGPU::V_CMP_EQ_U64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25168 /* V_CMP_EQ_U64 */, AMDGPU::V_CMP_EQ_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25181 /* v_cmp_eq_u64_e32 */, AMDGPU::V_CMP_EQ_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25181 /* v_cmp_eq_u64_e32 */, AMDGPU::V_CMP_EQ_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25181 /* v_cmp_eq_u64_e32 */, AMDGPU::V_CMP_EQ_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25181 /* v_cmp_eq_u64_e32 */, AMDGPU::V_CMP_EQ_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25181 /* v_cmp_eq_u64_e32 */, AMDGPU::V_CMP_EQ_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25198 /* V_CMP_F_F16 */, AMDGPU::V_CMP_F_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25198 /* V_CMP_F_F16 */, AMDGPU::V_CMP_F_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25198 /* V_CMP_F_F16 */, AMDGPU::V_CMP_F_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25198 /* V_CMP_F_F16 */, AMDGPU::V_CMP_F_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25198 /* V_CMP_F_F16 */, AMDGPU::V_CMP_F_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25198 /* V_CMP_F_F16 */, AMDGPU::V_CMP_F_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25210 /* v_cmp_f_f16_e32 */, AMDGPU::V_CMP_F_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25210 /* v_cmp_f_f16_e32 */, AMDGPU::V_CMP_F_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25210 /* v_cmp_f_f16_e32 */, AMDGPU::V_CMP_F_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25210 /* v_cmp_f_f16_e32 */, AMDGPU::V_CMP_F_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25226 /* V_CMP_F_F32 */, AMDGPU::V_CMP_F_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25226 /* V_CMP_F_F32 */, AMDGPU::V_CMP_F_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25226 /* V_CMP_F_F32 */, AMDGPU::V_CMP_F_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25226 /* V_CMP_F_F32 */, AMDGPU::V_CMP_F_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25226 /* V_CMP_F_F32 */, AMDGPU::V_CMP_F_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25226 /* V_CMP_F_F32 */, AMDGPU::V_CMP_F_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25226 /* V_CMP_F_F32 */, AMDGPU::V_CMP_F_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25226 /* V_CMP_F_F32 */, AMDGPU::V_CMP_F_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25226 /* V_CMP_F_F32 */, AMDGPU::V_CMP_F_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25226 /* V_CMP_F_F32 */, AMDGPU::V_CMP_F_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25226 /* V_CMP_F_F32 */, AMDGPU::V_CMP_F_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25226 /* V_CMP_F_F32 */, AMDGPU::V_CMP_F_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25238 /* v_cmp_f_f32_e32 */, AMDGPU::V_CMP_F_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25238 /* v_cmp_f_f32_e32 */, AMDGPU::V_CMP_F_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25238 /* v_cmp_f_f32_e32 */, AMDGPU::V_CMP_F_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25238 /* v_cmp_f_f32_e32 */, AMDGPU::V_CMP_F_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25254 /* V_CMP_F_F64 */, AMDGPU::V_CMP_F_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25254 /* V_CMP_F_F64 */, AMDGPU::V_CMP_F_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25254 /* V_CMP_F_F64 */, AMDGPU::V_CMP_F_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25254 /* V_CMP_F_F64 */, AMDGPU::V_CMP_F_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25254 /* V_CMP_F_F64 */, AMDGPU::V_CMP_F_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25254 /* V_CMP_F_F64 */, AMDGPU::V_CMP_F_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25254 /* V_CMP_F_F64 */, AMDGPU::V_CMP_F_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25254 /* V_CMP_F_F64 */, AMDGPU::V_CMP_F_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25254 /* V_CMP_F_F64 */, AMDGPU::V_CMP_F_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25254 /* V_CMP_F_F64 */, AMDGPU::V_CMP_F_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25254 /* V_CMP_F_F64 */, AMDGPU::V_CMP_F_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25254 /* V_CMP_F_F64 */, AMDGPU::V_CMP_F_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25266 /* v_cmp_f_f64_e32 */, AMDGPU::V_CMP_F_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25266 /* v_cmp_f_f64_e32 */, AMDGPU::V_CMP_F_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25266 /* v_cmp_f_f64_e32 */, AMDGPU::V_CMP_F_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25266 /* v_cmp_f_f64_e32 */, AMDGPU::V_CMP_F_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25282 /* V_CMP_F_I16 */, AMDGPU::V_CMP_F_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25282 /* V_CMP_F_I16 */, AMDGPU::V_CMP_F_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25282 /* V_CMP_F_I16 */, AMDGPU::V_CMP_F_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25294 /* v_cmp_f_i16_e32 */, AMDGPU::V_CMP_F_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25310 /* V_CMP_F_I32 */, AMDGPU::V_CMP_F_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25310 /* V_CMP_F_I32 */, AMDGPU::V_CMP_F_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25310 /* V_CMP_F_I32 */, AMDGPU::V_CMP_F_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25310 /* V_CMP_F_I32 */, AMDGPU::V_CMP_F_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25310 /* V_CMP_F_I32 */, AMDGPU::V_CMP_F_I32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25310 /* V_CMP_F_I32 */, AMDGPU::V_CMP_F_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25310 /* V_CMP_F_I32 */, AMDGPU::V_CMP_F_I32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25310 /* V_CMP_F_I32 */, AMDGPU::V_CMP_F_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25310 /* V_CMP_F_I32 */, AMDGPU::V_CMP_F_I32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25310 /* V_CMP_F_I32 */, AMDGPU::V_CMP_F_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25310 /* V_CMP_F_I32 */, AMDGPU::V_CMP_F_I32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25310 /* V_CMP_F_I32 */, AMDGPU::V_CMP_F_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25322 /* v_cmp_f_i32_e32 */, AMDGPU::V_CMP_F_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25322 /* v_cmp_f_i32_e32 */, AMDGPU::V_CMP_F_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25322 /* v_cmp_f_i32_e32 */, AMDGPU::V_CMP_F_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25322 /* v_cmp_f_i32_e32 */, AMDGPU::V_CMP_F_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25338 /* V_CMP_F_I64 */, AMDGPU::V_CMP_F_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25338 /* V_CMP_F_I64 */, AMDGPU::V_CMP_F_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25338 /* V_CMP_F_I64 */, AMDGPU::V_CMP_F_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25338 /* V_CMP_F_I64 */, AMDGPU::V_CMP_F_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25338 /* V_CMP_F_I64 */, AMDGPU::V_CMP_F_I64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25338 /* V_CMP_F_I64 */, AMDGPU::V_CMP_F_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25338 /* V_CMP_F_I64 */, AMDGPU::V_CMP_F_I64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25338 /* V_CMP_F_I64 */, AMDGPU::V_CMP_F_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25338 /* V_CMP_F_I64 */, AMDGPU::V_CMP_F_I64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25338 /* V_CMP_F_I64 */, AMDGPU::V_CMP_F_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25338 /* V_CMP_F_I64 */, AMDGPU::V_CMP_F_I64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25338 /* V_CMP_F_I64 */, AMDGPU::V_CMP_F_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25350 /* v_cmp_f_i64_e32 */, AMDGPU::V_CMP_F_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25350 /* v_cmp_f_i64_e32 */, AMDGPU::V_CMP_F_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25350 /* v_cmp_f_i64_e32 */, AMDGPU::V_CMP_F_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25350 /* v_cmp_f_i64_e32 */, AMDGPU::V_CMP_F_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25366 /* V_CMP_F_U16 */, AMDGPU::V_CMP_F_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25366 /* V_CMP_F_U16 */, AMDGPU::V_CMP_F_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25366 /* V_CMP_F_U16 */, AMDGPU::V_CMP_F_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25378 /* v_cmp_f_u16_e32 */, AMDGPU::V_CMP_F_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25394 /* V_CMP_F_U32 */, AMDGPU::V_CMP_F_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25394 /* V_CMP_F_U32 */, AMDGPU::V_CMP_F_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25394 /* V_CMP_F_U32 */, AMDGPU::V_CMP_F_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25394 /* V_CMP_F_U32 */, AMDGPU::V_CMP_F_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25394 /* V_CMP_F_U32 */, AMDGPU::V_CMP_F_U32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25394 /* V_CMP_F_U32 */, AMDGPU::V_CMP_F_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25394 /* V_CMP_F_U32 */, AMDGPU::V_CMP_F_U32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25394 /* V_CMP_F_U32 */, AMDGPU::V_CMP_F_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25394 /* V_CMP_F_U32 */, AMDGPU::V_CMP_F_U32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25394 /* V_CMP_F_U32 */, AMDGPU::V_CMP_F_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25394 /* V_CMP_F_U32 */, AMDGPU::V_CMP_F_U32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25394 /* V_CMP_F_U32 */, AMDGPU::V_CMP_F_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25406 /* v_cmp_f_u32_e32 */, AMDGPU::V_CMP_F_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25406 /* v_cmp_f_u32_e32 */, AMDGPU::V_CMP_F_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25406 /* v_cmp_f_u32_e32 */, AMDGPU::V_CMP_F_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25406 /* v_cmp_f_u32_e32 */, AMDGPU::V_CMP_F_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25422 /* V_CMP_F_U64 */, AMDGPU::V_CMP_F_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25422 /* V_CMP_F_U64 */, AMDGPU::V_CMP_F_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25422 /* V_CMP_F_U64 */, AMDGPU::V_CMP_F_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25422 /* V_CMP_F_U64 */, AMDGPU::V_CMP_F_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25422 /* V_CMP_F_U64 */, AMDGPU::V_CMP_F_U64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25422 /* V_CMP_F_U64 */, AMDGPU::V_CMP_F_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25422 /* V_CMP_F_U64 */, AMDGPU::V_CMP_F_U64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25422 /* V_CMP_F_U64 */, AMDGPU::V_CMP_F_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25422 /* V_CMP_F_U64 */, AMDGPU::V_CMP_F_U64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25422 /* V_CMP_F_U64 */, AMDGPU::V_CMP_F_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25422 /* V_CMP_F_U64 */, AMDGPU::V_CMP_F_U64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25422 /* V_CMP_F_U64 */, AMDGPU::V_CMP_F_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25434 /* v_cmp_f_u64_e32 */, AMDGPU::V_CMP_F_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25434 /* v_cmp_f_u64_e32 */, AMDGPU::V_CMP_F_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25434 /* v_cmp_f_u64_e32 */, AMDGPU::V_CMP_F_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25434 /* v_cmp_f_u64_e32 */, AMDGPU::V_CMP_F_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25450 /* V_CMP_GE_F16 */, AMDGPU::V_CMP_GE_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25450 /* V_CMP_GE_F16 */, AMDGPU::V_CMP_GE_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25450 /* V_CMP_GE_F16 */, AMDGPU::V_CMP_GE_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25450 /* V_CMP_GE_F16 */, AMDGPU::V_CMP_GE_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25450 /* V_CMP_GE_F16 */, AMDGPU::V_CMP_GE_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25450 /* V_CMP_GE_F16 */, AMDGPU::V_CMP_GE_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25463 /* v_cmp_ge_f16_e32 */, AMDGPU::V_CMP_GE_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25463 /* v_cmp_ge_f16_e32 */, AMDGPU::V_CMP_GE_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25463 /* v_cmp_ge_f16_e32 */, AMDGPU::V_CMP_GE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25463 /* v_cmp_ge_f16_e32 */, AMDGPU::V_CMP_GE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25463 /* v_cmp_ge_f16_e32 */, AMDGPU::V_CMP_GE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25463 /* v_cmp_ge_f16_e32 */, AMDGPU::V_CMP_GE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25480 /* V_CMP_GE_F32 */, AMDGPU::V_CMP_GE_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25480 /* V_CMP_GE_F32 */, AMDGPU::V_CMP_GE_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25480 /* V_CMP_GE_F32 */, AMDGPU::V_CMP_GE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25480 /* V_CMP_GE_F32 */, AMDGPU::V_CMP_GE_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25480 /* V_CMP_GE_F32 */, AMDGPU::V_CMP_GE_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25480 /* V_CMP_GE_F32 */, AMDGPU::V_CMP_GE_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25480 /* V_CMP_GE_F32 */, AMDGPU::V_CMP_GE_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25480 /* V_CMP_GE_F32 */, AMDGPU::V_CMP_GE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25480 /* V_CMP_GE_F32 */, AMDGPU::V_CMP_GE_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25480 /* V_CMP_GE_F32 */, AMDGPU::V_CMP_GE_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25480 /* V_CMP_GE_F32 */, AMDGPU::V_CMP_GE_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25480 /* V_CMP_GE_F32 */, AMDGPU::V_CMP_GE_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25480 /* V_CMP_GE_F32 */, AMDGPU::V_CMP_GE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25480 /* V_CMP_GE_F32 */, AMDGPU::V_CMP_GE_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25480 /* V_CMP_GE_F32 */, AMDGPU::V_CMP_GE_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25493 /* v_cmp_ge_f32_e32 */, AMDGPU::V_CMP_GE_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25493 /* v_cmp_ge_f32_e32 */, AMDGPU::V_CMP_GE_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25493 /* v_cmp_ge_f32_e32 */, AMDGPU::V_CMP_GE_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25493 /* v_cmp_ge_f32_e32 */, AMDGPU::V_CMP_GE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25493 /* v_cmp_ge_f32_e32 */, AMDGPU::V_CMP_GE_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25510 /* V_CMP_GE_F64 */, AMDGPU::V_CMP_GE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25510 /* V_CMP_GE_F64 */, AMDGPU::V_CMP_GE_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25510 /* V_CMP_GE_F64 */, AMDGPU::V_CMP_GE_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25510 /* V_CMP_GE_F64 */, AMDGPU::V_CMP_GE_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25510 /* V_CMP_GE_F64 */, AMDGPU::V_CMP_GE_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25510 /* V_CMP_GE_F64 */, AMDGPU::V_CMP_GE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25510 /* V_CMP_GE_F64 */, AMDGPU::V_CMP_GE_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25510 /* V_CMP_GE_F64 */, AMDGPU::V_CMP_GE_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25510 /* V_CMP_GE_F64 */, AMDGPU::V_CMP_GE_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25510 /* V_CMP_GE_F64 */, AMDGPU::V_CMP_GE_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25510 /* V_CMP_GE_F64 */, AMDGPU::V_CMP_GE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25510 /* V_CMP_GE_F64 */, AMDGPU::V_CMP_GE_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25510 /* V_CMP_GE_F64 */, AMDGPU::V_CMP_GE_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25510 /* V_CMP_GE_F64 */, AMDGPU::V_CMP_GE_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25510 /* V_CMP_GE_F64 */, AMDGPU::V_CMP_GE_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25523 /* v_cmp_ge_f64_e32 */, AMDGPU::V_CMP_GE_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25523 /* v_cmp_ge_f64_e32 */, AMDGPU::V_CMP_GE_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25523 /* v_cmp_ge_f64_e32 */, AMDGPU::V_CMP_GE_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25523 /* v_cmp_ge_f64_e32 */, AMDGPU::V_CMP_GE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25523 /* v_cmp_ge_f64_e32 */, AMDGPU::V_CMP_GE_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25540 /* V_CMP_GE_I16 */, AMDGPU::V_CMP_GE_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25540 /* V_CMP_GE_I16 */, AMDGPU::V_CMP_GE_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25540 /* V_CMP_GE_I16 */, AMDGPU::V_CMP_GE_I16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25540 /* V_CMP_GE_I16 */, AMDGPU::V_CMP_GE_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25540 /* V_CMP_GE_I16 */, AMDGPU::V_CMP_GE_I16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25540 /* V_CMP_GE_I16 */, AMDGPU::V_CMP_GE_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25553 /* v_cmp_ge_i16_e32 */, AMDGPU::V_CMP_GE_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25553 /* v_cmp_ge_i16_e32 */, AMDGPU::V_CMP_GE_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25553 /* v_cmp_ge_i16_e32 */, AMDGPU::V_CMP_GE_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25553 /* v_cmp_ge_i16_e32 */, AMDGPU::V_CMP_GE_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25553 /* v_cmp_ge_i16_e32 */, AMDGPU::V_CMP_GE_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25553 /* v_cmp_ge_i16_e32 */, AMDGPU::V_CMP_GE_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25570 /* V_CMP_GE_I32 */, AMDGPU::V_CMP_GE_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25570 /* V_CMP_GE_I32 */, AMDGPU::V_CMP_GE_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25570 /* V_CMP_GE_I32 */, AMDGPU::V_CMP_GE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25570 /* V_CMP_GE_I32 */, AMDGPU::V_CMP_GE_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25570 /* V_CMP_GE_I32 */, AMDGPU::V_CMP_GE_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25570 /* V_CMP_GE_I32 */, AMDGPU::V_CMP_GE_I32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25570 /* V_CMP_GE_I32 */, AMDGPU::V_CMP_GE_I32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25570 /* V_CMP_GE_I32 */, AMDGPU::V_CMP_GE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25570 /* V_CMP_GE_I32 */, AMDGPU::V_CMP_GE_I32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25570 /* V_CMP_GE_I32 */, AMDGPU::V_CMP_GE_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25570 /* V_CMP_GE_I32 */, AMDGPU::V_CMP_GE_I32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25570 /* V_CMP_GE_I32 */, AMDGPU::V_CMP_GE_I32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25570 /* V_CMP_GE_I32 */, AMDGPU::V_CMP_GE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25570 /* V_CMP_GE_I32 */, AMDGPU::V_CMP_GE_I32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25570 /* V_CMP_GE_I32 */, AMDGPU::V_CMP_GE_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25583 /* v_cmp_ge_i32_e32 */, AMDGPU::V_CMP_GE_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25583 /* v_cmp_ge_i32_e32 */, AMDGPU::V_CMP_GE_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25583 /* v_cmp_ge_i32_e32 */, AMDGPU::V_CMP_GE_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25583 /* v_cmp_ge_i32_e32 */, AMDGPU::V_CMP_GE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25583 /* v_cmp_ge_i32_e32 */, AMDGPU::V_CMP_GE_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25600 /* V_CMP_GE_I64 */, AMDGPU::V_CMP_GE_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25600 /* V_CMP_GE_I64 */, AMDGPU::V_CMP_GE_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25600 /* V_CMP_GE_I64 */, AMDGPU::V_CMP_GE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25600 /* V_CMP_GE_I64 */, AMDGPU::V_CMP_GE_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25600 /* V_CMP_GE_I64 */, AMDGPU::V_CMP_GE_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25600 /* V_CMP_GE_I64 */, AMDGPU::V_CMP_GE_I64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25600 /* V_CMP_GE_I64 */, AMDGPU::V_CMP_GE_I64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25600 /* V_CMP_GE_I64 */, AMDGPU::V_CMP_GE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25600 /* V_CMP_GE_I64 */, AMDGPU::V_CMP_GE_I64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25600 /* V_CMP_GE_I64 */, AMDGPU::V_CMP_GE_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25600 /* V_CMP_GE_I64 */, AMDGPU::V_CMP_GE_I64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25600 /* V_CMP_GE_I64 */, AMDGPU::V_CMP_GE_I64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25600 /* V_CMP_GE_I64 */, AMDGPU::V_CMP_GE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25600 /* V_CMP_GE_I64 */, AMDGPU::V_CMP_GE_I64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25600 /* V_CMP_GE_I64 */, AMDGPU::V_CMP_GE_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25613 /* v_cmp_ge_i64_e32 */, AMDGPU::V_CMP_GE_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25613 /* v_cmp_ge_i64_e32 */, AMDGPU::V_CMP_GE_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25613 /* v_cmp_ge_i64_e32 */, AMDGPU::V_CMP_GE_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25613 /* v_cmp_ge_i64_e32 */, AMDGPU::V_CMP_GE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25613 /* v_cmp_ge_i64_e32 */, AMDGPU::V_CMP_GE_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25630 /* V_CMP_GE_U16 */, AMDGPU::V_CMP_GE_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25630 /* V_CMP_GE_U16 */, AMDGPU::V_CMP_GE_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25630 /* V_CMP_GE_U16 */, AMDGPU::V_CMP_GE_U16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25630 /* V_CMP_GE_U16 */, AMDGPU::V_CMP_GE_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25630 /* V_CMP_GE_U16 */, AMDGPU::V_CMP_GE_U16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25630 /* V_CMP_GE_U16 */, AMDGPU::V_CMP_GE_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25643 /* v_cmp_ge_u16_e32 */, AMDGPU::V_CMP_GE_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25643 /* v_cmp_ge_u16_e32 */, AMDGPU::V_CMP_GE_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25643 /* v_cmp_ge_u16_e32 */, AMDGPU::V_CMP_GE_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25643 /* v_cmp_ge_u16_e32 */, AMDGPU::V_CMP_GE_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25643 /* v_cmp_ge_u16_e32 */, AMDGPU::V_CMP_GE_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25643 /* v_cmp_ge_u16_e32 */, AMDGPU::V_CMP_GE_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25660 /* V_CMP_GE_U32 */, AMDGPU::V_CMP_GE_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25660 /* V_CMP_GE_U32 */, AMDGPU::V_CMP_GE_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25660 /* V_CMP_GE_U32 */, AMDGPU::V_CMP_GE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25660 /* V_CMP_GE_U32 */, AMDGPU::V_CMP_GE_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25660 /* V_CMP_GE_U32 */, AMDGPU::V_CMP_GE_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25660 /* V_CMP_GE_U32 */, AMDGPU::V_CMP_GE_U32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25660 /* V_CMP_GE_U32 */, AMDGPU::V_CMP_GE_U32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25660 /* V_CMP_GE_U32 */, AMDGPU::V_CMP_GE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25660 /* V_CMP_GE_U32 */, AMDGPU::V_CMP_GE_U32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25660 /* V_CMP_GE_U32 */, AMDGPU::V_CMP_GE_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25660 /* V_CMP_GE_U32 */, AMDGPU::V_CMP_GE_U32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25660 /* V_CMP_GE_U32 */, AMDGPU::V_CMP_GE_U32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25660 /* V_CMP_GE_U32 */, AMDGPU::V_CMP_GE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25660 /* V_CMP_GE_U32 */, AMDGPU::V_CMP_GE_U32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25660 /* V_CMP_GE_U32 */, AMDGPU::V_CMP_GE_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25673 /* v_cmp_ge_u32_e32 */, AMDGPU::V_CMP_GE_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25673 /* v_cmp_ge_u32_e32 */, AMDGPU::V_CMP_GE_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25673 /* v_cmp_ge_u32_e32 */, AMDGPU::V_CMP_GE_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25673 /* v_cmp_ge_u32_e32 */, AMDGPU::V_CMP_GE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25673 /* v_cmp_ge_u32_e32 */, AMDGPU::V_CMP_GE_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25690 /* V_CMP_GE_U64 */, AMDGPU::V_CMP_GE_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25690 /* V_CMP_GE_U64 */, AMDGPU::V_CMP_GE_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25690 /* V_CMP_GE_U64 */, AMDGPU::V_CMP_GE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25690 /* V_CMP_GE_U64 */, AMDGPU::V_CMP_GE_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25690 /* V_CMP_GE_U64 */, AMDGPU::V_CMP_GE_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25690 /* V_CMP_GE_U64 */, AMDGPU::V_CMP_GE_U64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25690 /* V_CMP_GE_U64 */, AMDGPU::V_CMP_GE_U64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25690 /* V_CMP_GE_U64 */, AMDGPU::V_CMP_GE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25690 /* V_CMP_GE_U64 */, AMDGPU::V_CMP_GE_U64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25690 /* V_CMP_GE_U64 */, AMDGPU::V_CMP_GE_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25690 /* V_CMP_GE_U64 */, AMDGPU::V_CMP_GE_U64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25690 /* V_CMP_GE_U64 */, AMDGPU::V_CMP_GE_U64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25690 /* V_CMP_GE_U64 */, AMDGPU::V_CMP_GE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25690 /* V_CMP_GE_U64 */, AMDGPU::V_CMP_GE_U64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25690 /* V_CMP_GE_U64 */, AMDGPU::V_CMP_GE_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25703 /* v_cmp_ge_u64_e32 */, AMDGPU::V_CMP_GE_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25703 /* v_cmp_ge_u64_e32 */, AMDGPU::V_CMP_GE_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25703 /* v_cmp_ge_u64_e32 */, AMDGPU::V_CMP_GE_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25703 /* v_cmp_ge_u64_e32 */, AMDGPU::V_CMP_GE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25703 /* v_cmp_ge_u64_e32 */, AMDGPU::V_CMP_GE_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25720 /* V_CMP_GT_F16 */, AMDGPU::V_CMP_GT_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25720 /* V_CMP_GT_F16 */, AMDGPU::V_CMP_GT_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25720 /* V_CMP_GT_F16 */, AMDGPU::V_CMP_GT_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25720 /* V_CMP_GT_F16 */, AMDGPU::V_CMP_GT_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25720 /* V_CMP_GT_F16 */, AMDGPU::V_CMP_GT_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25720 /* V_CMP_GT_F16 */, AMDGPU::V_CMP_GT_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25733 /* v_cmp_gt_f16_e32 */, AMDGPU::V_CMP_GT_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25733 /* v_cmp_gt_f16_e32 */, AMDGPU::V_CMP_GT_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25733 /* v_cmp_gt_f16_e32 */, AMDGPU::V_CMP_GT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25733 /* v_cmp_gt_f16_e32 */, AMDGPU::V_CMP_GT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25733 /* v_cmp_gt_f16_e32 */, AMDGPU::V_CMP_GT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25733 /* v_cmp_gt_f16_e32 */, AMDGPU::V_CMP_GT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25750 /* V_CMP_GT_F32 */, AMDGPU::V_CMP_GT_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25750 /* V_CMP_GT_F32 */, AMDGPU::V_CMP_GT_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25750 /* V_CMP_GT_F32 */, AMDGPU::V_CMP_GT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25750 /* V_CMP_GT_F32 */, AMDGPU::V_CMP_GT_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25750 /* V_CMP_GT_F32 */, AMDGPU::V_CMP_GT_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25750 /* V_CMP_GT_F32 */, AMDGPU::V_CMP_GT_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25750 /* V_CMP_GT_F32 */, AMDGPU::V_CMP_GT_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25750 /* V_CMP_GT_F32 */, AMDGPU::V_CMP_GT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25750 /* V_CMP_GT_F32 */, AMDGPU::V_CMP_GT_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25750 /* V_CMP_GT_F32 */, AMDGPU::V_CMP_GT_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25750 /* V_CMP_GT_F32 */, AMDGPU::V_CMP_GT_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25750 /* V_CMP_GT_F32 */, AMDGPU::V_CMP_GT_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25750 /* V_CMP_GT_F32 */, AMDGPU::V_CMP_GT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25750 /* V_CMP_GT_F32 */, AMDGPU::V_CMP_GT_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25750 /* V_CMP_GT_F32 */, AMDGPU::V_CMP_GT_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25763 /* v_cmp_gt_f32_e32 */, AMDGPU::V_CMP_GT_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25763 /* v_cmp_gt_f32_e32 */, AMDGPU::V_CMP_GT_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25763 /* v_cmp_gt_f32_e32 */, AMDGPU::V_CMP_GT_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25763 /* v_cmp_gt_f32_e32 */, AMDGPU::V_CMP_GT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25763 /* v_cmp_gt_f32_e32 */, AMDGPU::V_CMP_GT_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 25780 /* V_CMP_GT_F64 */, AMDGPU::V_CMP_GT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25780 /* V_CMP_GT_F64 */, AMDGPU::V_CMP_GT_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25780 /* V_CMP_GT_F64 */, AMDGPU::V_CMP_GT_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25780 /* V_CMP_GT_F64 */, AMDGPU::V_CMP_GT_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25780 /* V_CMP_GT_F64 */, AMDGPU::V_CMP_GT_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25780 /* V_CMP_GT_F64 */, AMDGPU::V_CMP_GT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25780 /* V_CMP_GT_F64 */, AMDGPU::V_CMP_GT_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25780 /* V_CMP_GT_F64 */, AMDGPU::V_CMP_GT_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25780 /* V_CMP_GT_F64 */, AMDGPU::V_CMP_GT_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25780 /* V_CMP_GT_F64 */, AMDGPU::V_CMP_GT_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25780 /* V_CMP_GT_F64 */, AMDGPU::V_CMP_GT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25780 /* V_CMP_GT_F64 */, AMDGPU::V_CMP_GT_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25780 /* V_CMP_GT_F64 */, AMDGPU::V_CMP_GT_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25780 /* V_CMP_GT_F64 */, AMDGPU::V_CMP_GT_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25780 /* V_CMP_GT_F64 */, AMDGPU::V_CMP_GT_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25793 /* v_cmp_gt_f64_e32 */, AMDGPU::V_CMP_GT_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25793 /* v_cmp_gt_f64_e32 */, AMDGPU::V_CMP_GT_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25793 /* v_cmp_gt_f64_e32 */, AMDGPU::V_CMP_GT_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25793 /* v_cmp_gt_f64_e32 */, AMDGPU::V_CMP_GT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25793 /* v_cmp_gt_f64_e32 */, AMDGPU::V_CMP_GT_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25810 /* V_CMP_GT_I16 */, AMDGPU::V_CMP_GT_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25810 /* V_CMP_GT_I16 */, AMDGPU::V_CMP_GT_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25810 /* V_CMP_GT_I16 */, AMDGPU::V_CMP_GT_I16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25810 /* V_CMP_GT_I16 */, AMDGPU::V_CMP_GT_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25810 /* V_CMP_GT_I16 */, AMDGPU::V_CMP_GT_I16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25810 /* V_CMP_GT_I16 */, AMDGPU::V_CMP_GT_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25823 /* v_cmp_gt_i16_e32 */, AMDGPU::V_CMP_GT_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25823 /* v_cmp_gt_i16_e32 */, AMDGPU::V_CMP_GT_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25823 /* v_cmp_gt_i16_e32 */, AMDGPU::V_CMP_GT_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25823 /* v_cmp_gt_i16_e32 */, AMDGPU::V_CMP_GT_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25823 /* v_cmp_gt_i16_e32 */, AMDGPU::V_CMP_GT_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25823 /* v_cmp_gt_i16_e32 */, AMDGPU::V_CMP_GT_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25840 /* V_CMP_GT_I32 */, AMDGPU::V_CMP_GT_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25840 /* V_CMP_GT_I32 */, AMDGPU::V_CMP_GT_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25840 /* V_CMP_GT_I32 */, AMDGPU::V_CMP_GT_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25840 /* V_CMP_GT_I32 */, AMDGPU::V_CMP_GT_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25840 /* V_CMP_GT_I32 */, AMDGPU::V_CMP_GT_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25840 /* V_CMP_GT_I32 */, AMDGPU::V_CMP_GT_I32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25840 /* V_CMP_GT_I32 */, AMDGPU::V_CMP_GT_I32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25840 /* V_CMP_GT_I32 */, AMDGPU::V_CMP_GT_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25840 /* V_CMP_GT_I32 */, AMDGPU::V_CMP_GT_I32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25840 /* V_CMP_GT_I32 */, AMDGPU::V_CMP_GT_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25840 /* V_CMP_GT_I32 */, AMDGPU::V_CMP_GT_I32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25840 /* V_CMP_GT_I32 */, AMDGPU::V_CMP_GT_I32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25840 /* V_CMP_GT_I32 */, AMDGPU::V_CMP_GT_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25840 /* V_CMP_GT_I32 */, AMDGPU::V_CMP_GT_I32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25840 /* V_CMP_GT_I32 */, AMDGPU::V_CMP_GT_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25853 /* v_cmp_gt_i32_e32 */, AMDGPU::V_CMP_GT_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25853 /* v_cmp_gt_i32_e32 */, AMDGPU::V_CMP_GT_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25853 /* v_cmp_gt_i32_e32 */, AMDGPU::V_CMP_GT_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25853 /* v_cmp_gt_i32_e32 */, AMDGPU::V_CMP_GT_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25853 /* v_cmp_gt_i32_e32 */, AMDGPU::V_CMP_GT_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25870 /* V_CMP_GT_I64 */, AMDGPU::V_CMP_GT_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25870 /* V_CMP_GT_I64 */, AMDGPU::V_CMP_GT_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25870 /* V_CMP_GT_I64 */, AMDGPU::V_CMP_GT_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25870 /* V_CMP_GT_I64 */, AMDGPU::V_CMP_GT_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25870 /* V_CMP_GT_I64 */, AMDGPU::V_CMP_GT_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25870 /* V_CMP_GT_I64 */, AMDGPU::V_CMP_GT_I64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25870 /* V_CMP_GT_I64 */, AMDGPU::V_CMP_GT_I64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25870 /* V_CMP_GT_I64 */, AMDGPU::V_CMP_GT_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25870 /* V_CMP_GT_I64 */, AMDGPU::V_CMP_GT_I64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25870 /* V_CMP_GT_I64 */, AMDGPU::V_CMP_GT_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25870 /* V_CMP_GT_I64 */, AMDGPU::V_CMP_GT_I64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25870 /* V_CMP_GT_I64 */, AMDGPU::V_CMP_GT_I64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25870 /* V_CMP_GT_I64 */, AMDGPU::V_CMP_GT_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25870 /* V_CMP_GT_I64 */, AMDGPU::V_CMP_GT_I64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25870 /* V_CMP_GT_I64 */, AMDGPU::V_CMP_GT_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25883 /* v_cmp_gt_i64_e32 */, AMDGPU::V_CMP_GT_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25883 /* v_cmp_gt_i64_e32 */, AMDGPU::V_CMP_GT_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25883 /* v_cmp_gt_i64_e32 */, AMDGPU::V_CMP_GT_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25883 /* v_cmp_gt_i64_e32 */, AMDGPU::V_CMP_GT_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25883 /* v_cmp_gt_i64_e32 */, AMDGPU::V_CMP_GT_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25900 /* V_CMP_GT_U16 */, AMDGPU::V_CMP_GT_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25900 /* V_CMP_GT_U16 */, AMDGPU::V_CMP_GT_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25900 /* V_CMP_GT_U16 */, AMDGPU::V_CMP_GT_U16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25900 /* V_CMP_GT_U16 */, AMDGPU::V_CMP_GT_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25900 /* V_CMP_GT_U16 */, AMDGPU::V_CMP_GT_U16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25900 /* V_CMP_GT_U16 */, AMDGPU::V_CMP_GT_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25913 /* v_cmp_gt_u16_e32 */, AMDGPU::V_CMP_GT_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25913 /* v_cmp_gt_u16_e32 */, AMDGPU::V_CMP_GT_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 25913 /* v_cmp_gt_u16_e32 */, AMDGPU::V_CMP_GT_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25913 /* v_cmp_gt_u16_e32 */, AMDGPU::V_CMP_GT_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25913 /* v_cmp_gt_u16_e32 */, AMDGPU::V_CMP_GT_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25913 /* v_cmp_gt_u16_e32 */, AMDGPU::V_CMP_GT_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25930 /* V_CMP_GT_U32 */, AMDGPU::V_CMP_GT_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25930 /* V_CMP_GT_U32 */, AMDGPU::V_CMP_GT_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25930 /* V_CMP_GT_U32 */, AMDGPU::V_CMP_GT_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25930 /* V_CMP_GT_U32 */, AMDGPU::V_CMP_GT_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25930 /* V_CMP_GT_U32 */, AMDGPU::V_CMP_GT_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25930 /* V_CMP_GT_U32 */, AMDGPU::V_CMP_GT_U32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25930 /* V_CMP_GT_U32 */, AMDGPU::V_CMP_GT_U32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25930 /* V_CMP_GT_U32 */, AMDGPU::V_CMP_GT_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25930 /* V_CMP_GT_U32 */, AMDGPU::V_CMP_GT_U32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25930 /* V_CMP_GT_U32 */, AMDGPU::V_CMP_GT_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25930 /* V_CMP_GT_U32 */, AMDGPU::V_CMP_GT_U32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25930 /* V_CMP_GT_U32 */, AMDGPU::V_CMP_GT_U32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25930 /* V_CMP_GT_U32 */, AMDGPU::V_CMP_GT_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25930 /* V_CMP_GT_U32 */, AMDGPU::V_CMP_GT_U32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25930 /* V_CMP_GT_U32 */, AMDGPU::V_CMP_GT_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25943 /* v_cmp_gt_u32_e32 */, AMDGPU::V_CMP_GT_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25943 /* v_cmp_gt_u32_e32 */, AMDGPU::V_CMP_GT_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25943 /* v_cmp_gt_u32_e32 */, AMDGPU::V_CMP_GT_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25943 /* v_cmp_gt_u32_e32 */, AMDGPU::V_CMP_GT_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25943 /* v_cmp_gt_u32_e32 */, AMDGPU::V_CMP_GT_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 25960 /* V_CMP_GT_U64 */, AMDGPU::V_CMP_GT_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25960 /* V_CMP_GT_U64 */, AMDGPU::V_CMP_GT_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25960 /* V_CMP_GT_U64 */, AMDGPU::V_CMP_GT_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25960 /* V_CMP_GT_U64 */, AMDGPU::V_CMP_GT_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25960 /* V_CMP_GT_U64 */, AMDGPU::V_CMP_GT_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25960 /* V_CMP_GT_U64 */, AMDGPU::V_CMP_GT_U64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25960 /* V_CMP_GT_U64 */, AMDGPU::V_CMP_GT_U64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25960 /* V_CMP_GT_U64 */, AMDGPU::V_CMP_GT_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25960 /* V_CMP_GT_U64 */, AMDGPU::V_CMP_GT_U64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25960 /* V_CMP_GT_U64 */, AMDGPU::V_CMP_GT_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25960 /* V_CMP_GT_U64 */, AMDGPU::V_CMP_GT_U64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25960 /* V_CMP_GT_U64 */, AMDGPU::V_CMP_GT_U64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25960 /* V_CMP_GT_U64 */, AMDGPU::V_CMP_GT_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25960 /* V_CMP_GT_U64 */, AMDGPU::V_CMP_GT_U64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25960 /* V_CMP_GT_U64 */, AMDGPU::V_CMP_GT_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25973 /* v_cmp_gt_u64_e32 */, AMDGPU::V_CMP_GT_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25973 /* v_cmp_gt_u64_e32 */, AMDGPU::V_CMP_GT_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25973 /* v_cmp_gt_u64_e32 */, AMDGPU::V_CMP_GT_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25973 /* v_cmp_gt_u64_e32 */, AMDGPU::V_CMP_GT_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25973 /* v_cmp_gt_u64_e32 */, AMDGPU::V_CMP_GT_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 25990 /* V_CMP_LE_F16 */, AMDGPU::V_CMP_LE_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25990 /* V_CMP_LE_F16 */, AMDGPU::V_CMP_LE_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25990 /* V_CMP_LE_F16 */, AMDGPU::V_CMP_LE_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25990 /* V_CMP_LE_F16 */, AMDGPU::V_CMP_LE_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25990 /* V_CMP_LE_F16 */, AMDGPU::V_CMP_LE_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25990 /* V_CMP_LE_F16 */, AMDGPU::V_CMP_LE_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26003 /* v_cmp_le_f16_e32 */, AMDGPU::V_CMP_LE_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26003 /* v_cmp_le_f16_e32 */, AMDGPU::V_CMP_LE_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26003 /* v_cmp_le_f16_e32 */, AMDGPU::V_CMP_LE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26003 /* v_cmp_le_f16_e32 */, AMDGPU::V_CMP_LE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26003 /* v_cmp_le_f16_e32 */, AMDGPU::V_CMP_LE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26003 /* v_cmp_le_f16_e32 */, AMDGPU::V_CMP_LE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26020 /* V_CMP_LE_F32 */, AMDGPU::V_CMP_LE_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26020 /* V_CMP_LE_F32 */, AMDGPU::V_CMP_LE_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26020 /* V_CMP_LE_F32 */, AMDGPU::V_CMP_LE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26020 /* V_CMP_LE_F32 */, AMDGPU::V_CMP_LE_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26020 /* V_CMP_LE_F32 */, AMDGPU::V_CMP_LE_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26020 /* V_CMP_LE_F32 */, AMDGPU::V_CMP_LE_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26020 /* V_CMP_LE_F32 */, AMDGPU::V_CMP_LE_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26020 /* V_CMP_LE_F32 */, AMDGPU::V_CMP_LE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26020 /* V_CMP_LE_F32 */, AMDGPU::V_CMP_LE_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26020 /* V_CMP_LE_F32 */, AMDGPU::V_CMP_LE_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26020 /* V_CMP_LE_F32 */, AMDGPU::V_CMP_LE_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26020 /* V_CMP_LE_F32 */, AMDGPU::V_CMP_LE_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26020 /* V_CMP_LE_F32 */, AMDGPU::V_CMP_LE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26020 /* V_CMP_LE_F32 */, AMDGPU::V_CMP_LE_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26020 /* V_CMP_LE_F32 */, AMDGPU::V_CMP_LE_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26033 /* v_cmp_le_f32_e32 */, AMDGPU::V_CMP_LE_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26033 /* v_cmp_le_f32_e32 */, AMDGPU::V_CMP_LE_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26033 /* v_cmp_le_f32_e32 */, AMDGPU::V_CMP_LE_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26033 /* v_cmp_le_f32_e32 */, AMDGPU::V_CMP_LE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26033 /* v_cmp_le_f32_e32 */, AMDGPU::V_CMP_LE_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26050 /* V_CMP_LE_F64 */, AMDGPU::V_CMP_LE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26050 /* V_CMP_LE_F64 */, AMDGPU::V_CMP_LE_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26050 /* V_CMP_LE_F64 */, AMDGPU::V_CMP_LE_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26050 /* V_CMP_LE_F64 */, AMDGPU::V_CMP_LE_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26050 /* V_CMP_LE_F64 */, AMDGPU::V_CMP_LE_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26050 /* V_CMP_LE_F64 */, AMDGPU::V_CMP_LE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26050 /* V_CMP_LE_F64 */, AMDGPU::V_CMP_LE_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26050 /* V_CMP_LE_F64 */, AMDGPU::V_CMP_LE_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26050 /* V_CMP_LE_F64 */, AMDGPU::V_CMP_LE_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26050 /* V_CMP_LE_F64 */, AMDGPU::V_CMP_LE_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26050 /* V_CMP_LE_F64 */, AMDGPU::V_CMP_LE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26050 /* V_CMP_LE_F64 */, AMDGPU::V_CMP_LE_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26050 /* V_CMP_LE_F64 */, AMDGPU::V_CMP_LE_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26050 /* V_CMP_LE_F64 */, AMDGPU::V_CMP_LE_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26050 /* V_CMP_LE_F64 */, AMDGPU::V_CMP_LE_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26063 /* v_cmp_le_f64_e32 */, AMDGPU::V_CMP_LE_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26063 /* v_cmp_le_f64_e32 */, AMDGPU::V_CMP_LE_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26063 /* v_cmp_le_f64_e32 */, AMDGPU::V_CMP_LE_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26063 /* v_cmp_le_f64_e32 */, AMDGPU::V_CMP_LE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26063 /* v_cmp_le_f64_e32 */, AMDGPU::V_CMP_LE_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26080 /* V_CMP_LE_I16 */, AMDGPU::V_CMP_LE_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26080 /* V_CMP_LE_I16 */, AMDGPU::V_CMP_LE_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26080 /* V_CMP_LE_I16 */, AMDGPU::V_CMP_LE_I16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26080 /* V_CMP_LE_I16 */, AMDGPU::V_CMP_LE_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26080 /* V_CMP_LE_I16 */, AMDGPU::V_CMP_LE_I16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26080 /* V_CMP_LE_I16 */, AMDGPU::V_CMP_LE_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26093 /* v_cmp_le_i16_e32 */, AMDGPU::V_CMP_LE_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26093 /* v_cmp_le_i16_e32 */, AMDGPU::V_CMP_LE_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26093 /* v_cmp_le_i16_e32 */, AMDGPU::V_CMP_LE_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26093 /* v_cmp_le_i16_e32 */, AMDGPU::V_CMP_LE_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26093 /* v_cmp_le_i16_e32 */, AMDGPU::V_CMP_LE_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26093 /* v_cmp_le_i16_e32 */, AMDGPU::V_CMP_LE_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26110 /* V_CMP_LE_I32 */, AMDGPU::V_CMP_LE_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26110 /* V_CMP_LE_I32 */, AMDGPU::V_CMP_LE_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26110 /* V_CMP_LE_I32 */, AMDGPU::V_CMP_LE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26110 /* V_CMP_LE_I32 */, AMDGPU::V_CMP_LE_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26110 /* V_CMP_LE_I32 */, AMDGPU::V_CMP_LE_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26110 /* V_CMP_LE_I32 */, AMDGPU::V_CMP_LE_I32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26110 /* V_CMP_LE_I32 */, AMDGPU::V_CMP_LE_I32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26110 /* V_CMP_LE_I32 */, AMDGPU::V_CMP_LE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26110 /* V_CMP_LE_I32 */, AMDGPU::V_CMP_LE_I32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26110 /* V_CMP_LE_I32 */, AMDGPU::V_CMP_LE_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26110 /* V_CMP_LE_I32 */, AMDGPU::V_CMP_LE_I32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26110 /* V_CMP_LE_I32 */, AMDGPU::V_CMP_LE_I32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26110 /* V_CMP_LE_I32 */, AMDGPU::V_CMP_LE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26110 /* V_CMP_LE_I32 */, AMDGPU::V_CMP_LE_I32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26110 /* V_CMP_LE_I32 */, AMDGPU::V_CMP_LE_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26123 /* v_cmp_le_i32_e32 */, AMDGPU::V_CMP_LE_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26123 /* v_cmp_le_i32_e32 */, AMDGPU::V_CMP_LE_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26123 /* v_cmp_le_i32_e32 */, AMDGPU::V_CMP_LE_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26123 /* v_cmp_le_i32_e32 */, AMDGPU::V_CMP_LE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26123 /* v_cmp_le_i32_e32 */, AMDGPU::V_CMP_LE_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26140 /* V_CMP_LE_I64 */, AMDGPU::V_CMP_LE_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26140 /* V_CMP_LE_I64 */, AMDGPU::V_CMP_LE_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26140 /* V_CMP_LE_I64 */, AMDGPU::V_CMP_LE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26140 /* V_CMP_LE_I64 */, AMDGPU::V_CMP_LE_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26140 /* V_CMP_LE_I64 */, AMDGPU::V_CMP_LE_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26140 /* V_CMP_LE_I64 */, AMDGPU::V_CMP_LE_I64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26140 /* V_CMP_LE_I64 */, AMDGPU::V_CMP_LE_I64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26140 /* V_CMP_LE_I64 */, AMDGPU::V_CMP_LE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26140 /* V_CMP_LE_I64 */, AMDGPU::V_CMP_LE_I64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26140 /* V_CMP_LE_I64 */, AMDGPU::V_CMP_LE_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26140 /* V_CMP_LE_I64 */, AMDGPU::V_CMP_LE_I64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26140 /* V_CMP_LE_I64 */, AMDGPU::V_CMP_LE_I64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26140 /* V_CMP_LE_I64 */, AMDGPU::V_CMP_LE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26140 /* V_CMP_LE_I64 */, AMDGPU::V_CMP_LE_I64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26140 /* V_CMP_LE_I64 */, AMDGPU::V_CMP_LE_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26153 /* v_cmp_le_i64_e32 */, AMDGPU::V_CMP_LE_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26153 /* v_cmp_le_i64_e32 */, AMDGPU::V_CMP_LE_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26153 /* v_cmp_le_i64_e32 */, AMDGPU::V_CMP_LE_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26153 /* v_cmp_le_i64_e32 */, AMDGPU::V_CMP_LE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26153 /* v_cmp_le_i64_e32 */, AMDGPU::V_CMP_LE_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26170 /* V_CMP_LE_U16 */, AMDGPU::V_CMP_LE_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26170 /* V_CMP_LE_U16 */, AMDGPU::V_CMP_LE_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26170 /* V_CMP_LE_U16 */, AMDGPU::V_CMP_LE_U16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26170 /* V_CMP_LE_U16 */, AMDGPU::V_CMP_LE_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26170 /* V_CMP_LE_U16 */, AMDGPU::V_CMP_LE_U16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26170 /* V_CMP_LE_U16 */, AMDGPU::V_CMP_LE_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26183 /* v_cmp_le_u16_e32 */, AMDGPU::V_CMP_LE_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26183 /* v_cmp_le_u16_e32 */, AMDGPU::V_CMP_LE_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26183 /* v_cmp_le_u16_e32 */, AMDGPU::V_CMP_LE_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26183 /* v_cmp_le_u16_e32 */, AMDGPU::V_CMP_LE_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26183 /* v_cmp_le_u16_e32 */, AMDGPU::V_CMP_LE_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26183 /* v_cmp_le_u16_e32 */, AMDGPU::V_CMP_LE_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26200 /* V_CMP_LE_U32 */, AMDGPU::V_CMP_LE_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26200 /* V_CMP_LE_U32 */, AMDGPU::V_CMP_LE_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26200 /* V_CMP_LE_U32 */, AMDGPU::V_CMP_LE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26200 /* V_CMP_LE_U32 */, AMDGPU::V_CMP_LE_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26200 /* V_CMP_LE_U32 */, AMDGPU::V_CMP_LE_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26200 /* V_CMP_LE_U32 */, AMDGPU::V_CMP_LE_U32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26200 /* V_CMP_LE_U32 */, AMDGPU::V_CMP_LE_U32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26200 /* V_CMP_LE_U32 */, AMDGPU::V_CMP_LE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26200 /* V_CMP_LE_U32 */, AMDGPU::V_CMP_LE_U32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26200 /* V_CMP_LE_U32 */, AMDGPU::V_CMP_LE_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26200 /* V_CMP_LE_U32 */, AMDGPU::V_CMP_LE_U32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26200 /* V_CMP_LE_U32 */, AMDGPU::V_CMP_LE_U32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26200 /* V_CMP_LE_U32 */, AMDGPU::V_CMP_LE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26200 /* V_CMP_LE_U32 */, AMDGPU::V_CMP_LE_U32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26200 /* V_CMP_LE_U32 */, AMDGPU::V_CMP_LE_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26213 /* v_cmp_le_u32_e32 */, AMDGPU::V_CMP_LE_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26213 /* v_cmp_le_u32_e32 */, AMDGPU::V_CMP_LE_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26213 /* v_cmp_le_u32_e32 */, AMDGPU::V_CMP_LE_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26213 /* v_cmp_le_u32_e32 */, AMDGPU::V_CMP_LE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26213 /* v_cmp_le_u32_e32 */, AMDGPU::V_CMP_LE_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26230 /* V_CMP_LE_U64 */, AMDGPU::V_CMP_LE_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26230 /* V_CMP_LE_U64 */, AMDGPU::V_CMP_LE_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26230 /* V_CMP_LE_U64 */, AMDGPU::V_CMP_LE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26230 /* V_CMP_LE_U64 */, AMDGPU::V_CMP_LE_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26230 /* V_CMP_LE_U64 */, AMDGPU::V_CMP_LE_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26230 /* V_CMP_LE_U64 */, AMDGPU::V_CMP_LE_U64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26230 /* V_CMP_LE_U64 */, AMDGPU::V_CMP_LE_U64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26230 /* V_CMP_LE_U64 */, AMDGPU::V_CMP_LE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26230 /* V_CMP_LE_U64 */, AMDGPU::V_CMP_LE_U64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26230 /* V_CMP_LE_U64 */, AMDGPU::V_CMP_LE_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26230 /* V_CMP_LE_U64 */, AMDGPU::V_CMP_LE_U64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26230 /* V_CMP_LE_U64 */, AMDGPU::V_CMP_LE_U64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26230 /* V_CMP_LE_U64 */, AMDGPU::V_CMP_LE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26230 /* V_CMP_LE_U64 */, AMDGPU::V_CMP_LE_U64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26230 /* V_CMP_LE_U64 */, AMDGPU::V_CMP_LE_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26243 /* v_cmp_le_u64_e32 */, AMDGPU::V_CMP_LE_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26243 /* v_cmp_le_u64_e32 */, AMDGPU::V_CMP_LE_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26243 /* v_cmp_le_u64_e32 */, AMDGPU::V_CMP_LE_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26243 /* v_cmp_le_u64_e32 */, AMDGPU::V_CMP_LE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26243 /* v_cmp_le_u64_e32 */, AMDGPU::V_CMP_LE_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26260 /* V_CMP_LG_F16 */, AMDGPU::V_CMP_LG_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26260 /* V_CMP_LG_F16 */, AMDGPU::V_CMP_LG_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26260 /* V_CMP_LG_F16 */, AMDGPU::V_CMP_LG_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26260 /* V_CMP_LG_F16 */, AMDGPU::V_CMP_LG_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26260 /* V_CMP_LG_F16 */, AMDGPU::V_CMP_LG_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26260 /* V_CMP_LG_F16 */, AMDGPU::V_CMP_LG_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26273 /* v_cmp_lg_f16_e32 */, AMDGPU::V_CMP_LG_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26273 /* v_cmp_lg_f16_e32 */, AMDGPU::V_CMP_LG_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26273 /* v_cmp_lg_f16_e32 */, AMDGPU::V_CMP_LG_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26273 /* v_cmp_lg_f16_e32 */, AMDGPU::V_CMP_LG_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26273 /* v_cmp_lg_f16_e32 */, AMDGPU::V_CMP_LG_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26273 /* v_cmp_lg_f16_e32 */, AMDGPU::V_CMP_LG_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26290 /* V_CMP_LG_F32 */, AMDGPU::V_CMP_LG_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26290 /* V_CMP_LG_F32 */, AMDGPU::V_CMP_LG_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26290 /* V_CMP_LG_F32 */, AMDGPU::V_CMP_LG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26290 /* V_CMP_LG_F32 */, AMDGPU::V_CMP_LG_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26290 /* V_CMP_LG_F32 */, AMDGPU::V_CMP_LG_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26290 /* V_CMP_LG_F32 */, AMDGPU::V_CMP_LG_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26290 /* V_CMP_LG_F32 */, AMDGPU::V_CMP_LG_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26290 /* V_CMP_LG_F32 */, AMDGPU::V_CMP_LG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26290 /* V_CMP_LG_F32 */, AMDGPU::V_CMP_LG_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26290 /* V_CMP_LG_F32 */, AMDGPU::V_CMP_LG_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26290 /* V_CMP_LG_F32 */, AMDGPU::V_CMP_LG_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26290 /* V_CMP_LG_F32 */, AMDGPU::V_CMP_LG_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26290 /* V_CMP_LG_F32 */, AMDGPU::V_CMP_LG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26290 /* V_CMP_LG_F32 */, AMDGPU::V_CMP_LG_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26290 /* V_CMP_LG_F32 */, AMDGPU::V_CMP_LG_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26303 /* v_cmp_lg_f32_e32 */, AMDGPU::V_CMP_LG_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26303 /* v_cmp_lg_f32_e32 */, AMDGPU::V_CMP_LG_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26303 /* v_cmp_lg_f32_e32 */, AMDGPU::V_CMP_LG_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26303 /* v_cmp_lg_f32_e32 */, AMDGPU::V_CMP_LG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26303 /* v_cmp_lg_f32_e32 */, AMDGPU::V_CMP_LG_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26320 /* V_CMP_LG_F64 */, AMDGPU::V_CMP_LG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26320 /* V_CMP_LG_F64 */, AMDGPU::V_CMP_LG_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26320 /* V_CMP_LG_F64 */, AMDGPU::V_CMP_LG_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26320 /* V_CMP_LG_F64 */, AMDGPU::V_CMP_LG_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26320 /* V_CMP_LG_F64 */, AMDGPU::V_CMP_LG_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26320 /* V_CMP_LG_F64 */, AMDGPU::V_CMP_LG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26320 /* V_CMP_LG_F64 */, AMDGPU::V_CMP_LG_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26320 /* V_CMP_LG_F64 */, AMDGPU::V_CMP_LG_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26320 /* V_CMP_LG_F64 */, AMDGPU::V_CMP_LG_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26320 /* V_CMP_LG_F64 */, AMDGPU::V_CMP_LG_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26320 /* V_CMP_LG_F64 */, AMDGPU::V_CMP_LG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26320 /* V_CMP_LG_F64 */, AMDGPU::V_CMP_LG_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26320 /* V_CMP_LG_F64 */, AMDGPU::V_CMP_LG_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26320 /* V_CMP_LG_F64 */, AMDGPU::V_CMP_LG_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26320 /* V_CMP_LG_F64 */, AMDGPU::V_CMP_LG_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26333 /* v_cmp_lg_f64_e32 */, AMDGPU::V_CMP_LG_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26333 /* v_cmp_lg_f64_e32 */, AMDGPU::V_CMP_LG_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26333 /* v_cmp_lg_f64_e32 */, AMDGPU::V_CMP_LG_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26333 /* v_cmp_lg_f64_e32 */, AMDGPU::V_CMP_LG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26333 /* v_cmp_lg_f64_e32 */, AMDGPU::V_CMP_LG_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26350 /* V_CMP_LT_F16 */, AMDGPU::V_CMP_LT_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26350 /* V_CMP_LT_F16 */, AMDGPU::V_CMP_LT_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26350 /* V_CMP_LT_F16 */, AMDGPU::V_CMP_LT_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26350 /* V_CMP_LT_F16 */, AMDGPU::V_CMP_LT_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26350 /* V_CMP_LT_F16 */, AMDGPU::V_CMP_LT_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26350 /* V_CMP_LT_F16 */, AMDGPU::V_CMP_LT_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26363 /* v_cmp_lt_f16_e32 */, AMDGPU::V_CMP_LT_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26363 /* v_cmp_lt_f16_e32 */, AMDGPU::V_CMP_LT_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26363 /* v_cmp_lt_f16_e32 */, AMDGPU::V_CMP_LT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26363 /* v_cmp_lt_f16_e32 */, AMDGPU::V_CMP_LT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26363 /* v_cmp_lt_f16_e32 */, AMDGPU::V_CMP_LT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26363 /* v_cmp_lt_f16_e32 */, AMDGPU::V_CMP_LT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26380 /* V_CMP_LT_F32 */, AMDGPU::V_CMP_LT_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26380 /* V_CMP_LT_F32 */, AMDGPU::V_CMP_LT_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26380 /* V_CMP_LT_F32 */, AMDGPU::V_CMP_LT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26380 /* V_CMP_LT_F32 */, AMDGPU::V_CMP_LT_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26380 /* V_CMP_LT_F32 */, AMDGPU::V_CMP_LT_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26380 /* V_CMP_LT_F32 */, AMDGPU::V_CMP_LT_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26380 /* V_CMP_LT_F32 */, AMDGPU::V_CMP_LT_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26380 /* V_CMP_LT_F32 */, AMDGPU::V_CMP_LT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26380 /* V_CMP_LT_F32 */, AMDGPU::V_CMP_LT_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26380 /* V_CMP_LT_F32 */, AMDGPU::V_CMP_LT_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26380 /* V_CMP_LT_F32 */, AMDGPU::V_CMP_LT_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26380 /* V_CMP_LT_F32 */, AMDGPU::V_CMP_LT_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26380 /* V_CMP_LT_F32 */, AMDGPU::V_CMP_LT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26380 /* V_CMP_LT_F32 */, AMDGPU::V_CMP_LT_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26380 /* V_CMP_LT_F32 */, AMDGPU::V_CMP_LT_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26393 /* v_cmp_lt_f32_e32 */, AMDGPU::V_CMP_LT_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26393 /* v_cmp_lt_f32_e32 */, AMDGPU::V_CMP_LT_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26393 /* v_cmp_lt_f32_e32 */, AMDGPU::V_CMP_LT_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26393 /* v_cmp_lt_f32_e32 */, AMDGPU::V_CMP_LT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26393 /* v_cmp_lt_f32_e32 */, AMDGPU::V_CMP_LT_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26410 /* V_CMP_LT_F64 */, AMDGPU::V_CMP_LT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26410 /* V_CMP_LT_F64 */, AMDGPU::V_CMP_LT_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26410 /* V_CMP_LT_F64 */, AMDGPU::V_CMP_LT_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26410 /* V_CMP_LT_F64 */, AMDGPU::V_CMP_LT_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26410 /* V_CMP_LT_F64 */, AMDGPU::V_CMP_LT_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26410 /* V_CMP_LT_F64 */, AMDGPU::V_CMP_LT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26410 /* V_CMP_LT_F64 */, AMDGPU::V_CMP_LT_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26410 /* V_CMP_LT_F64 */, AMDGPU::V_CMP_LT_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26410 /* V_CMP_LT_F64 */, AMDGPU::V_CMP_LT_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26410 /* V_CMP_LT_F64 */, AMDGPU::V_CMP_LT_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26410 /* V_CMP_LT_F64 */, AMDGPU::V_CMP_LT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26410 /* V_CMP_LT_F64 */, AMDGPU::V_CMP_LT_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26410 /* V_CMP_LT_F64 */, AMDGPU::V_CMP_LT_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26410 /* V_CMP_LT_F64 */, AMDGPU::V_CMP_LT_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26410 /* V_CMP_LT_F64 */, AMDGPU::V_CMP_LT_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26423 /* v_cmp_lt_f64_e32 */, AMDGPU::V_CMP_LT_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26423 /* v_cmp_lt_f64_e32 */, AMDGPU::V_CMP_LT_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26423 /* v_cmp_lt_f64_e32 */, AMDGPU::V_CMP_LT_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26423 /* v_cmp_lt_f64_e32 */, AMDGPU::V_CMP_LT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26423 /* v_cmp_lt_f64_e32 */, AMDGPU::V_CMP_LT_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26440 /* V_CMP_LT_I16 */, AMDGPU::V_CMP_LT_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26440 /* V_CMP_LT_I16 */, AMDGPU::V_CMP_LT_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26440 /* V_CMP_LT_I16 */, AMDGPU::V_CMP_LT_I16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26440 /* V_CMP_LT_I16 */, AMDGPU::V_CMP_LT_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26440 /* V_CMP_LT_I16 */, AMDGPU::V_CMP_LT_I16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26440 /* V_CMP_LT_I16 */, AMDGPU::V_CMP_LT_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26453 /* v_cmp_lt_i16_e32 */, AMDGPU::V_CMP_LT_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26453 /* v_cmp_lt_i16_e32 */, AMDGPU::V_CMP_LT_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26453 /* v_cmp_lt_i16_e32 */, AMDGPU::V_CMP_LT_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26453 /* v_cmp_lt_i16_e32 */, AMDGPU::V_CMP_LT_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26453 /* v_cmp_lt_i16_e32 */, AMDGPU::V_CMP_LT_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26453 /* v_cmp_lt_i16_e32 */, AMDGPU::V_CMP_LT_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26470 /* V_CMP_LT_I32 */, AMDGPU::V_CMP_LT_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26470 /* V_CMP_LT_I32 */, AMDGPU::V_CMP_LT_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26470 /* V_CMP_LT_I32 */, AMDGPU::V_CMP_LT_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26470 /* V_CMP_LT_I32 */, AMDGPU::V_CMP_LT_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26470 /* V_CMP_LT_I32 */, AMDGPU::V_CMP_LT_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26470 /* V_CMP_LT_I32 */, AMDGPU::V_CMP_LT_I32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26470 /* V_CMP_LT_I32 */, AMDGPU::V_CMP_LT_I32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26470 /* V_CMP_LT_I32 */, AMDGPU::V_CMP_LT_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26470 /* V_CMP_LT_I32 */, AMDGPU::V_CMP_LT_I32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26470 /* V_CMP_LT_I32 */, AMDGPU::V_CMP_LT_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26470 /* V_CMP_LT_I32 */, AMDGPU::V_CMP_LT_I32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26470 /* V_CMP_LT_I32 */, AMDGPU::V_CMP_LT_I32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26470 /* V_CMP_LT_I32 */, AMDGPU::V_CMP_LT_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26470 /* V_CMP_LT_I32 */, AMDGPU::V_CMP_LT_I32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26470 /* V_CMP_LT_I32 */, AMDGPU::V_CMP_LT_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26483 /* v_cmp_lt_i32_e32 */, AMDGPU::V_CMP_LT_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26483 /* v_cmp_lt_i32_e32 */, AMDGPU::V_CMP_LT_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26483 /* v_cmp_lt_i32_e32 */, AMDGPU::V_CMP_LT_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26483 /* v_cmp_lt_i32_e32 */, AMDGPU::V_CMP_LT_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26483 /* v_cmp_lt_i32_e32 */, AMDGPU::V_CMP_LT_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26500 /* V_CMP_LT_I64 */, AMDGPU::V_CMP_LT_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26500 /* V_CMP_LT_I64 */, AMDGPU::V_CMP_LT_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26500 /* V_CMP_LT_I64 */, AMDGPU::V_CMP_LT_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26500 /* V_CMP_LT_I64 */, AMDGPU::V_CMP_LT_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26500 /* V_CMP_LT_I64 */, AMDGPU::V_CMP_LT_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26500 /* V_CMP_LT_I64 */, AMDGPU::V_CMP_LT_I64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26500 /* V_CMP_LT_I64 */, AMDGPU::V_CMP_LT_I64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26500 /* V_CMP_LT_I64 */, AMDGPU::V_CMP_LT_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26500 /* V_CMP_LT_I64 */, AMDGPU::V_CMP_LT_I64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26500 /* V_CMP_LT_I64 */, AMDGPU::V_CMP_LT_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26500 /* V_CMP_LT_I64 */, AMDGPU::V_CMP_LT_I64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26500 /* V_CMP_LT_I64 */, AMDGPU::V_CMP_LT_I64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26500 /* V_CMP_LT_I64 */, AMDGPU::V_CMP_LT_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26500 /* V_CMP_LT_I64 */, AMDGPU::V_CMP_LT_I64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26500 /* V_CMP_LT_I64 */, AMDGPU::V_CMP_LT_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26513 /* v_cmp_lt_i64_e32 */, AMDGPU::V_CMP_LT_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26513 /* v_cmp_lt_i64_e32 */, AMDGPU::V_CMP_LT_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26513 /* v_cmp_lt_i64_e32 */, AMDGPU::V_CMP_LT_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26513 /* v_cmp_lt_i64_e32 */, AMDGPU::V_CMP_LT_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26513 /* v_cmp_lt_i64_e32 */, AMDGPU::V_CMP_LT_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26530 /* V_CMP_LT_U16 */, AMDGPU::V_CMP_LT_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26530 /* V_CMP_LT_U16 */, AMDGPU::V_CMP_LT_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26530 /* V_CMP_LT_U16 */, AMDGPU::V_CMP_LT_U16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26530 /* V_CMP_LT_U16 */, AMDGPU::V_CMP_LT_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26530 /* V_CMP_LT_U16 */, AMDGPU::V_CMP_LT_U16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26530 /* V_CMP_LT_U16 */, AMDGPU::V_CMP_LT_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26543 /* v_cmp_lt_u16_e32 */, AMDGPU::V_CMP_LT_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26543 /* v_cmp_lt_u16_e32 */, AMDGPU::V_CMP_LT_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26543 /* v_cmp_lt_u16_e32 */, AMDGPU::V_CMP_LT_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26543 /* v_cmp_lt_u16_e32 */, AMDGPU::V_CMP_LT_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26543 /* v_cmp_lt_u16_e32 */, AMDGPU::V_CMP_LT_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26543 /* v_cmp_lt_u16_e32 */, AMDGPU::V_CMP_LT_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26560 /* V_CMP_LT_U32 */, AMDGPU::V_CMP_LT_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26560 /* V_CMP_LT_U32 */, AMDGPU::V_CMP_LT_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26560 /* V_CMP_LT_U32 */, AMDGPU::V_CMP_LT_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26560 /* V_CMP_LT_U32 */, AMDGPU::V_CMP_LT_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26560 /* V_CMP_LT_U32 */, AMDGPU::V_CMP_LT_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26560 /* V_CMP_LT_U32 */, AMDGPU::V_CMP_LT_U32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26560 /* V_CMP_LT_U32 */, AMDGPU::V_CMP_LT_U32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26560 /* V_CMP_LT_U32 */, AMDGPU::V_CMP_LT_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26560 /* V_CMP_LT_U32 */, AMDGPU::V_CMP_LT_U32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26560 /* V_CMP_LT_U32 */, AMDGPU::V_CMP_LT_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26560 /* V_CMP_LT_U32 */, AMDGPU::V_CMP_LT_U32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26560 /* V_CMP_LT_U32 */, AMDGPU::V_CMP_LT_U32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26560 /* V_CMP_LT_U32 */, AMDGPU::V_CMP_LT_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26560 /* V_CMP_LT_U32 */, AMDGPU::V_CMP_LT_U32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26560 /* V_CMP_LT_U32 */, AMDGPU::V_CMP_LT_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26573 /* v_cmp_lt_u32_e32 */, AMDGPU::V_CMP_LT_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26573 /* v_cmp_lt_u32_e32 */, AMDGPU::V_CMP_LT_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26573 /* v_cmp_lt_u32_e32 */, AMDGPU::V_CMP_LT_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26573 /* v_cmp_lt_u32_e32 */, AMDGPU::V_CMP_LT_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26573 /* v_cmp_lt_u32_e32 */, AMDGPU::V_CMP_LT_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26590 /* V_CMP_LT_U64 */, AMDGPU::V_CMP_LT_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26590 /* V_CMP_LT_U64 */, AMDGPU::V_CMP_LT_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26590 /* V_CMP_LT_U64 */, AMDGPU::V_CMP_LT_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26590 /* V_CMP_LT_U64 */, AMDGPU::V_CMP_LT_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26590 /* V_CMP_LT_U64 */, AMDGPU::V_CMP_LT_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26590 /* V_CMP_LT_U64 */, AMDGPU::V_CMP_LT_U64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26590 /* V_CMP_LT_U64 */, AMDGPU::V_CMP_LT_U64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26590 /* V_CMP_LT_U64 */, AMDGPU::V_CMP_LT_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26590 /* V_CMP_LT_U64 */, AMDGPU::V_CMP_LT_U64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26590 /* V_CMP_LT_U64 */, AMDGPU::V_CMP_LT_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26590 /* V_CMP_LT_U64 */, AMDGPU::V_CMP_LT_U64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26590 /* V_CMP_LT_U64 */, AMDGPU::V_CMP_LT_U64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26590 /* V_CMP_LT_U64 */, AMDGPU::V_CMP_LT_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26590 /* V_CMP_LT_U64 */, AMDGPU::V_CMP_LT_U64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26590 /* V_CMP_LT_U64 */, AMDGPU::V_CMP_LT_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26603 /* v_cmp_lt_u64_e32 */, AMDGPU::V_CMP_LT_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26603 /* v_cmp_lt_u64_e32 */, AMDGPU::V_CMP_LT_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26603 /* v_cmp_lt_u64_e32 */, AMDGPU::V_CMP_LT_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26603 /* v_cmp_lt_u64_e32 */, AMDGPU::V_CMP_LT_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26603 /* v_cmp_lt_u64_e32 */, AMDGPU::V_CMP_LT_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26620 /* V_CMP_NE_I16 */, AMDGPU::V_CMP_NE_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26620 /* V_CMP_NE_I16 */, AMDGPU::V_CMP_NE_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26620 /* V_CMP_NE_I16 */, AMDGPU::V_CMP_NE_I16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26620 /* V_CMP_NE_I16 */, AMDGPU::V_CMP_NE_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26620 /* V_CMP_NE_I16 */, AMDGPU::V_CMP_NE_I16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26620 /* V_CMP_NE_I16 */, AMDGPU::V_CMP_NE_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26633 /* v_cmp_ne_i16_e32 */, AMDGPU::V_CMP_NE_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26633 /* v_cmp_ne_i16_e32 */, AMDGPU::V_CMP_NE_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26633 /* v_cmp_ne_i16_e32 */, AMDGPU::V_CMP_NE_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26633 /* v_cmp_ne_i16_e32 */, AMDGPU::V_CMP_NE_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26633 /* v_cmp_ne_i16_e32 */, AMDGPU::V_CMP_NE_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26633 /* v_cmp_ne_i16_e32 */, AMDGPU::V_CMP_NE_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26650 /* V_CMP_NE_I32 */, AMDGPU::V_CMP_NE_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26650 /* V_CMP_NE_I32 */, AMDGPU::V_CMP_NE_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26650 /* V_CMP_NE_I32 */, AMDGPU::V_CMP_NE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26650 /* V_CMP_NE_I32 */, AMDGPU::V_CMP_NE_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26650 /* V_CMP_NE_I32 */, AMDGPU::V_CMP_NE_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26650 /* V_CMP_NE_I32 */, AMDGPU::V_CMP_NE_I32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26650 /* V_CMP_NE_I32 */, AMDGPU::V_CMP_NE_I32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26650 /* V_CMP_NE_I32 */, AMDGPU::V_CMP_NE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26650 /* V_CMP_NE_I32 */, AMDGPU::V_CMP_NE_I32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26650 /* V_CMP_NE_I32 */, AMDGPU::V_CMP_NE_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26650 /* V_CMP_NE_I32 */, AMDGPU::V_CMP_NE_I32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26650 /* V_CMP_NE_I32 */, AMDGPU::V_CMP_NE_I32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26650 /* V_CMP_NE_I32 */, AMDGPU::V_CMP_NE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26650 /* V_CMP_NE_I32 */, AMDGPU::V_CMP_NE_I32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26650 /* V_CMP_NE_I32 */, AMDGPU::V_CMP_NE_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26663 /* v_cmp_ne_i32_e32 */, AMDGPU::V_CMP_NE_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26663 /* v_cmp_ne_i32_e32 */, AMDGPU::V_CMP_NE_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26663 /* v_cmp_ne_i32_e32 */, AMDGPU::V_CMP_NE_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26663 /* v_cmp_ne_i32_e32 */, AMDGPU::V_CMP_NE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26663 /* v_cmp_ne_i32_e32 */, AMDGPU::V_CMP_NE_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26680 /* V_CMP_NE_I64 */, AMDGPU::V_CMP_NE_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26680 /* V_CMP_NE_I64 */, AMDGPU::V_CMP_NE_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26680 /* V_CMP_NE_I64 */, AMDGPU::V_CMP_NE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26680 /* V_CMP_NE_I64 */, AMDGPU::V_CMP_NE_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26680 /* V_CMP_NE_I64 */, AMDGPU::V_CMP_NE_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26680 /* V_CMP_NE_I64 */, AMDGPU::V_CMP_NE_I64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26680 /* V_CMP_NE_I64 */, AMDGPU::V_CMP_NE_I64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26680 /* V_CMP_NE_I64 */, AMDGPU::V_CMP_NE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26680 /* V_CMP_NE_I64 */, AMDGPU::V_CMP_NE_I64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26680 /* V_CMP_NE_I64 */, AMDGPU::V_CMP_NE_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26680 /* V_CMP_NE_I64 */, AMDGPU::V_CMP_NE_I64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26680 /* V_CMP_NE_I64 */, AMDGPU::V_CMP_NE_I64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26680 /* V_CMP_NE_I64 */, AMDGPU::V_CMP_NE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26680 /* V_CMP_NE_I64 */, AMDGPU::V_CMP_NE_I64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26680 /* V_CMP_NE_I64 */, AMDGPU::V_CMP_NE_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26693 /* v_cmp_ne_i64_e32 */, AMDGPU::V_CMP_NE_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26693 /* v_cmp_ne_i64_e32 */, AMDGPU::V_CMP_NE_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26693 /* v_cmp_ne_i64_e32 */, AMDGPU::V_CMP_NE_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26693 /* v_cmp_ne_i64_e32 */, AMDGPU::V_CMP_NE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26693 /* v_cmp_ne_i64_e32 */, AMDGPU::V_CMP_NE_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26710 /* V_CMP_NE_U16 */, AMDGPU::V_CMP_NE_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26710 /* V_CMP_NE_U16 */, AMDGPU::V_CMP_NE_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26710 /* V_CMP_NE_U16 */, AMDGPU::V_CMP_NE_U16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26710 /* V_CMP_NE_U16 */, AMDGPU::V_CMP_NE_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26710 /* V_CMP_NE_U16 */, AMDGPU::V_CMP_NE_U16_e32_gfx10, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26710 /* V_CMP_NE_U16 */, AMDGPU::V_CMP_NE_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26723 /* v_cmp_ne_u16_e32 */, AMDGPU::V_CMP_NE_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26723 /* v_cmp_ne_u16_e32 */, AMDGPU::V_CMP_NE_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 26723 /* v_cmp_ne_u16_e32 */, AMDGPU::V_CMP_NE_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26723 /* v_cmp_ne_u16_e32 */, AMDGPU::V_CMP_NE_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26723 /* v_cmp_ne_u16_e32 */, AMDGPU::V_CMP_NE_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26723 /* v_cmp_ne_u16_e32 */, AMDGPU::V_CMP_NE_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26740 /* V_CMP_NE_U32 */, AMDGPU::V_CMP_NE_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26740 /* V_CMP_NE_U32 */, AMDGPU::V_CMP_NE_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26740 /* V_CMP_NE_U32 */, AMDGPU::V_CMP_NE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26740 /* V_CMP_NE_U32 */, AMDGPU::V_CMP_NE_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26740 /* V_CMP_NE_U32 */, AMDGPU::V_CMP_NE_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26740 /* V_CMP_NE_U32 */, AMDGPU::V_CMP_NE_U32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26740 /* V_CMP_NE_U32 */, AMDGPU::V_CMP_NE_U32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26740 /* V_CMP_NE_U32 */, AMDGPU::V_CMP_NE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26740 /* V_CMP_NE_U32 */, AMDGPU::V_CMP_NE_U32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26740 /* V_CMP_NE_U32 */, AMDGPU::V_CMP_NE_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26740 /* V_CMP_NE_U32 */, AMDGPU::V_CMP_NE_U32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26740 /* V_CMP_NE_U32 */, AMDGPU::V_CMP_NE_U32_e32_gfx12, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26740 /* V_CMP_NE_U32 */, AMDGPU::V_CMP_NE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26740 /* V_CMP_NE_U32 */, AMDGPU::V_CMP_NE_U32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26740 /* V_CMP_NE_U32 */, AMDGPU::V_CMP_NE_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26753 /* v_cmp_ne_u32_e32 */, AMDGPU::V_CMP_NE_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26753 /* v_cmp_ne_u32_e32 */, AMDGPU::V_CMP_NE_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26753 /* v_cmp_ne_u32_e32 */, AMDGPU::V_CMP_NE_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26753 /* v_cmp_ne_u32_e32 */, AMDGPU::V_CMP_NE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26753 /* v_cmp_ne_u32_e32 */, AMDGPU::V_CMP_NE_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 26770 /* V_CMP_NE_U64 */, AMDGPU::V_CMP_NE_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26770 /* V_CMP_NE_U64 */, AMDGPU::V_CMP_NE_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26770 /* V_CMP_NE_U64 */, AMDGPU::V_CMP_NE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26770 /* V_CMP_NE_U64 */, AMDGPU::V_CMP_NE_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26770 /* V_CMP_NE_U64 */, AMDGPU::V_CMP_NE_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26770 /* V_CMP_NE_U64 */, AMDGPU::V_CMP_NE_U64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26770 /* V_CMP_NE_U64 */, AMDGPU::V_CMP_NE_U64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26770 /* V_CMP_NE_U64 */, AMDGPU::V_CMP_NE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26770 /* V_CMP_NE_U64 */, AMDGPU::V_CMP_NE_U64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26770 /* V_CMP_NE_U64 */, AMDGPU::V_CMP_NE_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26770 /* V_CMP_NE_U64 */, AMDGPU::V_CMP_NE_U64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26770 /* V_CMP_NE_U64 */, AMDGPU::V_CMP_NE_U64_e32_gfx12, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26770 /* V_CMP_NE_U64 */, AMDGPU::V_CMP_NE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26770 /* V_CMP_NE_U64 */, AMDGPU::V_CMP_NE_U64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26770 /* V_CMP_NE_U64 */, AMDGPU::V_CMP_NE_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26783 /* v_cmp_ne_u64_e32 */, AMDGPU::V_CMP_NE_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26783 /* v_cmp_ne_u64_e32 */, AMDGPU::V_CMP_NE_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26783 /* v_cmp_ne_u64_e32 */, AMDGPU::V_CMP_NE_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26783 /* v_cmp_ne_u64_e32 */, AMDGPU::V_CMP_NE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26783 /* v_cmp_ne_u64_e32 */, AMDGPU::V_CMP_NE_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26800 /* V_CMP_NEQ_F16 */, AMDGPU::V_CMP_NEQ_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26800 /* V_CMP_NEQ_F16 */, AMDGPU::V_CMP_NEQ_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26800 /* V_CMP_NEQ_F16 */, AMDGPU::V_CMP_NEQ_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26800 /* V_CMP_NEQ_F16 */, AMDGPU::V_CMP_NEQ_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26800 /* V_CMP_NEQ_F16 */, AMDGPU::V_CMP_NEQ_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26800 /* V_CMP_NEQ_F16 */, AMDGPU::V_CMP_NEQ_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26814 /* v_cmp_neq_f16_e32 */, AMDGPU::V_CMP_NEQ_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26814 /* v_cmp_neq_f16_e32 */, AMDGPU::V_CMP_NEQ_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26814 /* v_cmp_neq_f16_e32 */, AMDGPU::V_CMP_NEQ_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26814 /* v_cmp_neq_f16_e32 */, AMDGPU::V_CMP_NEQ_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26814 /* v_cmp_neq_f16_e32 */, AMDGPU::V_CMP_NEQ_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26814 /* v_cmp_neq_f16_e32 */, AMDGPU::V_CMP_NEQ_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26832 /* V_CMP_NEQ_F32 */, AMDGPU::V_CMP_NEQ_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26832 /* V_CMP_NEQ_F32 */, AMDGPU::V_CMP_NEQ_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26832 /* V_CMP_NEQ_F32 */, AMDGPU::V_CMP_NEQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26832 /* V_CMP_NEQ_F32 */, AMDGPU::V_CMP_NEQ_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26832 /* V_CMP_NEQ_F32 */, AMDGPU::V_CMP_NEQ_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26832 /* V_CMP_NEQ_F32 */, AMDGPU::V_CMP_NEQ_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26832 /* V_CMP_NEQ_F32 */, AMDGPU::V_CMP_NEQ_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26832 /* V_CMP_NEQ_F32 */, AMDGPU::V_CMP_NEQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26832 /* V_CMP_NEQ_F32 */, AMDGPU::V_CMP_NEQ_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26832 /* V_CMP_NEQ_F32 */, AMDGPU::V_CMP_NEQ_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26832 /* V_CMP_NEQ_F32 */, AMDGPU::V_CMP_NEQ_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26832 /* V_CMP_NEQ_F32 */, AMDGPU::V_CMP_NEQ_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26832 /* V_CMP_NEQ_F32 */, AMDGPU::V_CMP_NEQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26832 /* V_CMP_NEQ_F32 */, AMDGPU::V_CMP_NEQ_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26832 /* V_CMP_NEQ_F32 */, AMDGPU::V_CMP_NEQ_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26846 /* v_cmp_neq_f32_e32 */, AMDGPU::V_CMP_NEQ_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26846 /* v_cmp_neq_f32_e32 */, AMDGPU::V_CMP_NEQ_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26846 /* v_cmp_neq_f32_e32 */, AMDGPU::V_CMP_NEQ_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26846 /* v_cmp_neq_f32_e32 */, AMDGPU::V_CMP_NEQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26846 /* v_cmp_neq_f32_e32 */, AMDGPU::V_CMP_NEQ_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26864 /* V_CMP_NEQ_F64 */, AMDGPU::V_CMP_NEQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26864 /* V_CMP_NEQ_F64 */, AMDGPU::V_CMP_NEQ_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26864 /* V_CMP_NEQ_F64 */, AMDGPU::V_CMP_NEQ_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26864 /* V_CMP_NEQ_F64 */, AMDGPU::V_CMP_NEQ_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26864 /* V_CMP_NEQ_F64 */, AMDGPU::V_CMP_NEQ_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26864 /* V_CMP_NEQ_F64 */, AMDGPU::V_CMP_NEQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26864 /* V_CMP_NEQ_F64 */, AMDGPU::V_CMP_NEQ_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26864 /* V_CMP_NEQ_F64 */, AMDGPU::V_CMP_NEQ_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26864 /* V_CMP_NEQ_F64 */, AMDGPU::V_CMP_NEQ_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26864 /* V_CMP_NEQ_F64 */, AMDGPU::V_CMP_NEQ_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26864 /* V_CMP_NEQ_F64 */, AMDGPU::V_CMP_NEQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26864 /* V_CMP_NEQ_F64 */, AMDGPU::V_CMP_NEQ_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26864 /* V_CMP_NEQ_F64 */, AMDGPU::V_CMP_NEQ_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26864 /* V_CMP_NEQ_F64 */, AMDGPU::V_CMP_NEQ_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26864 /* V_CMP_NEQ_F64 */, AMDGPU::V_CMP_NEQ_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26878 /* v_cmp_neq_f64_e32 */, AMDGPU::V_CMP_NEQ_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26878 /* v_cmp_neq_f64_e32 */, AMDGPU::V_CMP_NEQ_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26878 /* v_cmp_neq_f64_e32 */, AMDGPU::V_CMP_NEQ_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26878 /* v_cmp_neq_f64_e32 */, AMDGPU::V_CMP_NEQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26878 /* v_cmp_neq_f64_e32 */, AMDGPU::V_CMP_NEQ_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26896 /* V_CMP_NGE_F16 */, AMDGPU::V_CMP_NGE_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26896 /* V_CMP_NGE_F16 */, AMDGPU::V_CMP_NGE_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26896 /* V_CMP_NGE_F16 */, AMDGPU::V_CMP_NGE_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26896 /* V_CMP_NGE_F16 */, AMDGPU::V_CMP_NGE_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26896 /* V_CMP_NGE_F16 */, AMDGPU::V_CMP_NGE_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26896 /* V_CMP_NGE_F16 */, AMDGPU::V_CMP_NGE_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26910 /* v_cmp_nge_f16_e32 */, AMDGPU::V_CMP_NGE_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26910 /* v_cmp_nge_f16_e32 */, AMDGPU::V_CMP_NGE_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26910 /* v_cmp_nge_f16_e32 */, AMDGPU::V_CMP_NGE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26910 /* v_cmp_nge_f16_e32 */, AMDGPU::V_CMP_NGE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26910 /* v_cmp_nge_f16_e32 */, AMDGPU::V_CMP_NGE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26910 /* v_cmp_nge_f16_e32 */, AMDGPU::V_CMP_NGE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26928 /* V_CMP_NGE_F32 */, AMDGPU::V_CMP_NGE_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26928 /* V_CMP_NGE_F32 */, AMDGPU::V_CMP_NGE_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26928 /* V_CMP_NGE_F32 */, AMDGPU::V_CMP_NGE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26928 /* V_CMP_NGE_F32 */, AMDGPU::V_CMP_NGE_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26928 /* V_CMP_NGE_F32 */, AMDGPU::V_CMP_NGE_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26928 /* V_CMP_NGE_F32 */, AMDGPU::V_CMP_NGE_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26928 /* V_CMP_NGE_F32 */, AMDGPU::V_CMP_NGE_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26928 /* V_CMP_NGE_F32 */, AMDGPU::V_CMP_NGE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26928 /* V_CMP_NGE_F32 */, AMDGPU::V_CMP_NGE_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26928 /* V_CMP_NGE_F32 */, AMDGPU::V_CMP_NGE_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26928 /* V_CMP_NGE_F32 */, AMDGPU::V_CMP_NGE_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26928 /* V_CMP_NGE_F32 */, AMDGPU::V_CMP_NGE_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26928 /* V_CMP_NGE_F32 */, AMDGPU::V_CMP_NGE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26928 /* V_CMP_NGE_F32 */, AMDGPU::V_CMP_NGE_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26928 /* V_CMP_NGE_F32 */, AMDGPU::V_CMP_NGE_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26942 /* v_cmp_nge_f32_e32 */, AMDGPU::V_CMP_NGE_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26942 /* v_cmp_nge_f32_e32 */, AMDGPU::V_CMP_NGE_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26942 /* v_cmp_nge_f32_e32 */, AMDGPU::V_CMP_NGE_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26942 /* v_cmp_nge_f32_e32 */, AMDGPU::V_CMP_NGE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26942 /* v_cmp_nge_f32_e32 */, AMDGPU::V_CMP_NGE_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 26960 /* V_CMP_NGE_F64 */, AMDGPU::V_CMP_NGE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26960 /* V_CMP_NGE_F64 */, AMDGPU::V_CMP_NGE_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26960 /* V_CMP_NGE_F64 */, AMDGPU::V_CMP_NGE_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26960 /* V_CMP_NGE_F64 */, AMDGPU::V_CMP_NGE_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26960 /* V_CMP_NGE_F64 */, AMDGPU::V_CMP_NGE_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26960 /* V_CMP_NGE_F64 */, AMDGPU::V_CMP_NGE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26960 /* V_CMP_NGE_F64 */, AMDGPU::V_CMP_NGE_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26960 /* V_CMP_NGE_F64 */, AMDGPU::V_CMP_NGE_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26960 /* V_CMP_NGE_F64 */, AMDGPU::V_CMP_NGE_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26960 /* V_CMP_NGE_F64 */, AMDGPU::V_CMP_NGE_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26960 /* V_CMP_NGE_F64 */, AMDGPU::V_CMP_NGE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26960 /* V_CMP_NGE_F64 */, AMDGPU::V_CMP_NGE_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26960 /* V_CMP_NGE_F64 */, AMDGPU::V_CMP_NGE_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26960 /* V_CMP_NGE_F64 */, AMDGPU::V_CMP_NGE_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26960 /* V_CMP_NGE_F64 */, AMDGPU::V_CMP_NGE_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26974 /* v_cmp_nge_f64_e32 */, AMDGPU::V_CMP_NGE_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26974 /* v_cmp_nge_f64_e32 */, AMDGPU::V_CMP_NGE_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26974 /* v_cmp_nge_f64_e32 */, AMDGPU::V_CMP_NGE_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26974 /* v_cmp_nge_f64_e32 */, AMDGPU::V_CMP_NGE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26974 /* v_cmp_nge_f64_e32 */, AMDGPU::V_CMP_NGE_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 26992 /* V_CMP_NGT_F16 */, AMDGPU::V_CMP_NGT_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26992 /* V_CMP_NGT_F16 */, AMDGPU::V_CMP_NGT_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26992 /* V_CMP_NGT_F16 */, AMDGPU::V_CMP_NGT_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26992 /* V_CMP_NGT_F16 */, AMDGPU::V_CMP_NGT_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26992 /* V_CMP_NGT_F16 */, AMDGPU::V_CMP_NGT_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26992 /* V_CMP_NGT_F16 */, AMDGPU::V_CMP_NGT_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27006 /* v_cmp_ngt_f16_e32 */, AMDGPU::V_CMP_NGT_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27006 /* v_cmp_ngt_f16_e32 */, AMDGPU::V_CMP_NGT_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27006 /* v_cmp_ngt_f16_e32 */, AMDGPU::V_CMP_NGT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27006 /* v_cmp_ngt_f16_e32 */, AMDGPU::V_CMP_NGT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27006 /* v_cmp_ngt_f16_e32 */, AMDGPU::V_CMP_NGT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27006 /* v_cmp_ngt_f16_e32 */, AMDGPU::V_CMP_NGT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27024 /* V_CMP_NGT_F32 */, AMDGPU::V_CMP_NGT_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27024 /* V_CMP_NGT_F32 */, AMDGPU::V_CMP_NGT_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27024 /* V_CMP_NGT_F32 */, AMDGPU::V_CMP_NGT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27024 /* V_CMP_NGT_F32 */, AMDGPU::V_CMP_NGT_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27024 /* V_CMP_NGT_F32 */, AMDGPU::V_CMP_NGT_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27024 /* V_CMP_NGT_F32 */, AMDGPU::V_CMP_NGT_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27024 /* V_CMP_NGT_F32 */, AMDGPU::V_CMP_NGT_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27024 /* V_CMP_NGT_F32 */, AMDGPU::V_CMP_NGT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27024 /* V_CMP_NGT_F32 */, AMDGPU::V_CMP_NGT_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27024 /* V_CMP_NGT_F32 */, AMDGPU::V_CMP_NGT_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27024 /* V_CMP_NGT_F32 */, AMDGPU::V_CMP_NGT_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27024 /* V_CMP_NGT_F32 */, AMDGPU::V_CMP_NGT_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27024 /* V_CMP_NGT_F32 */, AMDGPU::V_CMP_NGT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27024 /* V_CMP_NGT_F32 */, AMDGPU::V_CMP_NGT_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27024 /* V_CMP_NGT_F32 */, AMDGPU::V_CMP_NGT_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27038 /* v_cmp_ngt_f32_e32 */, AMDGPU::V_CMP_NGT_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27038 /* v_cmp_ngt_f32_e32 */, AMDGPU::V_CMP_NGT_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27038 /* v_cmp_ngt_f32_e32 */, AMDGPU::V_CMP_NGT_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27038 /* v_cmp_ngt_f32_e32 */, AMDGPU::V_CMP_NGT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27038 /* v_cmp_ngt_f32_e32 */, AMDGPU::V_CMP_NGT_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27056 /* V_CMP_NGT_F64 */, AMDGPU::V_CMP_NGT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27056 /* V_CMP_NGT_F64 */, AMDGPU::V_CMP_NGT_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27056 /* V_CMP_NGT_F64 */, AMDGPU::V_CMP_NGT_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27056 /* V_CMP_NGT_F64 */, AMDGPU::V_CMP_NGT_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27056 /* V_CMP_NGT_F64 */, AMDGPU::V_CMP_NGT_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27056 /* V_CMP_NGT_F64 */, AMDGPU::V_CMP_NGT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27056 /* V_CMP_NGT_F64 */, AMDGPU::V_CMP_NGT_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27056 /* V_CMP_NGT_F64 */, AMDGPU::V_CMP_NGT_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27056 /* V_CMP_NGT_F64 */, AMDGPU::V_CMP_NGT_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27056 /* V_CMP_NGT_F64 */, AMDGPU::V_CMP_NGT_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27056 /* V_CMP_NGT_F64 */, AMDGPU::V_CMP_NGT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27056 /* V_CMP_NGT_F64 */, AMDGPU::V_CMP_NGT_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27056 /* V_CMP_NGT_F64 */, AMDGPU::V_CMP_NGT_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27056 /* V_CMP_NGT_F64 */, AMDGPU::V_CMP_NGT_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27056 /* V_CMP_NGT_F64 */, AMDGPU::V_CMP_NGT_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27070 /* v_cmp_ngt_f64_e32 */, AMDGPU::V_CMP_NGT_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27070 /* v_cmp_ngt_f64_e32 */, AMDGPU::V_CMP_NGT_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27070 /* v_cmp_ngt_f64_e32 */, AMDGPU::V_CMP_NGT_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27070 /* v_cmp_ngt_f64_e32 */, AMDGPU::V_CMP_NGT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27070 /* v_cmp_ngt_f64_e32 */, AMDGPU::V_CMP_NGT_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27088 /* V_CMP_NLE_F16 */, AMDGPU::V_CMP_NLE_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27088 /* V_CMP_NLE_F16 */, AMDGPU::V_CMP_NLE_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27088 /* V_CMP_NLE_F16 */, AMDGPU::V_CMP_NLE_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27088 /* V_CMP_NLE_F16 */, AMDGPU::V_CMP_NLE_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27088 /* V_CMP_NLE_F16 */, AMDGPU::V_CMP_NLE_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27088 /* V_CMP_NLE_F16 */, AMDGPU::V_CMP_NLE_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27102 /* v_cmp_nle_f16_e32 */, AMDGPU::V_CMP_NLE_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27102 /* v_cmp_nle_f16_e32 */, AMDGPU::V_CMP_NLE_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27102 /* v_cmp_nle_f16_e32 */, AMDGPU::V_CMP_NLE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27102 /* v_cmp_nle_f16_e32 */, AMDGPU::V_CMP_NLE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27102 /* v_cmp_nle_f16_e32 */, AMDGPU::V_CMP_NLE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27102 /* v_cmp_nle_f16_e32 */, AMDGPU::V_CMP_NLE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27120 /* V_CMP_NLE_F32 */, AMDGPU::V_CMP_NLE_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27120 /* V_CMP_NLE_F32 */, AMDGPU::V_CMP_NLE_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27120 /* V_CMP_NLE_F32 */, AMDGPU::V_CMP_NLE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27120 /* V_CMP_NLE_F32 */, AMDGPU::V_CMP_NLE_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27120 /* V_CMP_NLE_F32 */, AMDGPU::V_CMP_NLE_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27120 /* V_CMP_NLE_F32 */, AMDGPU::V_CMP_NLE_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27120 /* V_CMP_NLE_F32 */, AMDGPU::V_CMP_NLE_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27120 /* V_CMP_NLE_F32 */, AMDGPU::V_CMP_NLE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27120 /* V_CMP_NLE_F32 */, AMDGPU::V_CMP_NLE_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27120 /* V_CMP_NLE_F32 */, AMDGPU::V_CMP_NLE_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27120 /* V_CMP_NLE_F32 */, AMDGPU::V_CMP_NLE_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27120 /* V_CMP_NLE_F32 */, AMDGPU::V_CMP_NLE_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27120 /* V_CMP_NLE_F32 */, AMDGPU::V_CMP_NLE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27120 /* V_CMP_NLE_F32 */, AMDGPU::V_CMP_NLE_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27120 /* V_CMP_NLE_F32 */, AMDGPU::V_CMP_NLE_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27134 /* v_cmp_nle_f32_e32 */, AMDGPU::V_CMP_NLE_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27134 /* v_cmp_nle_f32_e32 */, AMDGPU::V_CMP_NLE_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27134 /* v_cmp_nle_f32_e32 */, AMDGPU::V_CMP_NLE_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27134 /* v_cmp_nle_f32_e32 */, AMDGPU::V_CMP_NLE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27134 /* v_cmp_nle_f32_e32 */, AMDGPU::V_CMP_NLE_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27152 /* V_CMP_NLE_F64 */, AMDGPU::V_CMP_NLE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27152 /* V_CMP_NLE_F64 */, AMDGPU::V_CMP_NLE_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27152 /* V_CMP_NLE_F64 */, AMDGPU::V_CMP_NLE_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27152 /* V_CMP_NLE_F64 */, AMDGPU::V_CMP_NLE_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27152 /* V_CMP_NLE_F64 */, AMDGPU::V_CMP_NLE_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27152 /* V_CMP_NLE_F64 */, AMDGPU::V_CMP_NLE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27152 /* V_CMP_NLE_F64 */, AMDGPU::V_CMP_NLE_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27152 /* V_CMP_NLE_F64 */, AMDGPU::V_CMP_NLE_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27152 /* V_CMP_NLE_F64 */, AMDGPU::V_CMP_NLE_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27152 /* V_CMP_NLE_F64 */, AMDGPU::V_CMP_NLE_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27152 /* V_CMP_NLE_F64 */, AMDGPU::V_CMP_NLE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27152 /* V_CMP_NLE_F64 */, AMDGPU::V_CMP_NLE_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27152 /* V_CMP_NLE_F64 */, AMDGPU::V_CMP_NLE_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27152 /* V_CMP_NLE_F64 */, AMDGPU::V_CMP_NLE_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27152 /* V_CMP_NLE_F64 */, AMDGPU::V_CMP_NLE_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27166 /* v_cmp_nle_f64_e32 */, AMDGPU::V_CMP_NLE_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27166 /* v_cmp_nle_f64_e32 */, AMDGPU::V_CMP_NLE_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27166 /* v_cmp_nle_f64_e32 */, AMDGPU::V_CMP_NLE_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27166 /* v_cmp_nle_f64_e32 */, AMDGPU::V_CMP_NLE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27166 /* v_cmp_nle_f64_e32 */, AMDGPU::V_CMP_NLE_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27184 /* V_CMP_NLG_F16 */, AMDGPU::V_CMP_NLG_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27184 /* V_CMP_NLG_F16 */, AMDGPU::V_CMP_NLG_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27184 /* V_CMP_NLG_F16 */, AMDGPU::V_CMP_NLG_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27184 /* V_CMP_NLG_F16 */, AMDGPU::V_CMP_NLG_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27184 /* V_CMP_NLG_F16 */, AMDGPU::V_CMP_NLG_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27184 /* V_CMP_NLG_F16 */, AMDGPU::V_CMP_NLG_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27198 /* v_cmp_nlg_f16_e32 */, AMDGPU::V_CMP_NLG_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27198 /* v_cmp_nlg_f16_e32 */, AMDGPU::V_CMP_NLG_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27198 /* v_cmp_nlg_f16_e32 */, AMDGPU::V_CMP_NLG_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27198 /* v_cmp_nlg_f16_e32 */, AMDGPU::V_CMP_NLG_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27198 /* v_cmp_nlg_f16_e32 */, AMDGPU::V_CMP_NLG_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27198 /* v_cmp_nlg_f16_e32 */, AMDGPU::V_CMP_NLG_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27216 /* V_CMP_NLG_F32 */, AMDGPU::V_CMP_NLG_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27216 /* V_CMP_NLG_F32 */, AMDGPU::V_CMP_NLG_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27216 /* V_CMP_NLG_F32 */, AMDGPU::V_CMP_NLG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27216 /* V_CMP_NLG_F32 */, AMDGPU::V_CMP_NLG_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27216 /* V_CMP_NLG_F32 */, AMDGPU::V_CMP_NLG_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27216 /* V_CMP_NLG_F32 */, AMDGPU::V_CMP_NLG_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27216 /* V_CMP_NLG_F32 */, AMDGPU::V_CMP_NLG_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27216 /* V_CMP_NLG_F32 */, AMDGPU::V_CMP_NLG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27216 /* V_CMP_NLG_F32 */, AMDGPU::V_CMP_NLG_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27216 /* V_CMP_NLG_F32 */, AMDGPU::V_CMP_NLG_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27216 /* V_CMP_NLG_F32 */, AMDGPU::V_CMP_NLG_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27216 /* V_CMP_NLG_F32 */, AMDGPU::V_CMP_NLG_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27216 /* V_CMP_NLG_F32 */, AMDGPU::V_CMP_NLG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27216 /* V_CMP_NLG_F32 */, AMDGPU::V_CMP_NLG_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27216 /* V_CMP_NLG_F32 */, AMDGPU::V_CMP_NLG_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27230 /* v_cmp_nlg_f32_e32 */, AMDGPU::V_CMP_NLG_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27230 /* v_cmp_nlg_f32_e32 */, AMDGPU::V_CMP_NLG_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27230 /* v_cmp_nlg_f32_e32 */, AMDGPU::V_CMP_NLG_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27230 /* v_cmp_nlg_f32_e32 */, AMDGPU::V_CMP_NLG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27230 /* v_cmp_nlg_f32_e32 */, AMDGPU::V_CMP_NLG_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27248 /* V_CMP_NLG_F64 */, AMDGPU::V_CMP_NLG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27248 /* V_CMP_NLG_F64 */, AMDGPU::V_CMP_NLG_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27248 /* V_CMP_NLG_F64 */, AMDGPU::V_CMP_NLG_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27248 /* V_CMP_NLG_F64 */, AMDGPU::V_CMP_NLG_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27248 /* V_CMP_NLG_F64 */, AMDGPU::V_CMP_NLG_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27248 /* V_CMP_NLG_F64 */, AMDGPU::V_CMP_NLG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27248 /* V_CMP_NLG_F64 */, AMDGPU::V_CMP_NLG_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27248 /* V_CMP_NLG_F64 */, AMDGPU::V_CMP_NLG_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27248 /* V_CMP_NLG_F64 */, AMDGPU::V_CMP_NLG_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27248 /* V_CMP_NLG_F64 */, AMDGPU::V_CMP_NLG_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27248 /* V_CMP_NLG_F64 */, AMDGPU::V_CMP_NLG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27248 /* V_CMP_NLG_F64 */, AMDGPU::V_CMP_NLG_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27248 /* V_CMP_NLG_F64 */, AMDGPU::V_CMP_NLG_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27248 /* V_CMP_NLG_F64 */, AMDGPU::V_CMP_NLG_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27248 /* V_CMP_NLG_F64 */, AMDGPU::V_CMP_NLG_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27262 /* v_cmp_nlg_f64_e32 */, AMDGPU::V_CMP_NLG_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27262 /* v_cmp_nlg_f64_e32 */, AMDGPU::V_CMP_NLG_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27262 /* v_cmp_nlg_f64_e32 */, AMDGPU::V_CMP_NLG_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27262 /* v_cmp_nlg_f64_e32 */, AMDGPU::V_CMP_NLG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27262 /* v_cmp_nlg_f64_e32 */, AMDGPU::V_CMP_NLG_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27280 /* V_CMP_NLT_F16 */, AMDGPU::V_CMP_NLT_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27280 /* V_CMP_NLT_F16 */, AMDGPU::V_CMP_NLT_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27280 /* V_CMP_NLT_F16 */, AMDGPU::V_CMP_NLT_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27280 /* V_CMP_NLT_F16 */, AMDGPU::V_CMP_NLT_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27280 /* V_CMP_NLT_F16 */, AMDGPU::V_CMP_NLT_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27280 /* V_CMP_NLT_F16 */, AMDGPU::V_CMP_NLT_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27294 /* v_cmp_nlt_f16_e32 */, AMDGPU::V_CMP_NLT_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27294 /* v_cmp_nlt_f16_e32 */, AMDGPU::V_CMP_NLT_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27294 /* v_cmp_nlt_f16_e32 */, AMDGPU::V_CMP_NLT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27294 /* v_cmp_nlt_f16_e32 */, AMDGPU::V_CMP_NLT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27294 /* v_cmp_nlt_f16_e32 */, AMDGPU::V_CMP_NLT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27294 /* v_cmp_nlt_f16_e32 */, AMDGPU::V_CMP_NLT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27312 /* V_CMP_NLT_F32 */, AMDGPU::V_CMP_NLT_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27312 /* V_CMP_NLT_F32 */, AMDGPU::V_CMP_NLT_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27312 /* V_CMP_NLT_F32 */, AMDGPU::V_CMP_NLT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27312 /* V_CMP_NLT_F32 */, AMDGPU::V_CMP_NLT_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27312 /* V_CMP_NLT_F32 */, AMDGPU::V_CMP_NLT_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27312 /* V_CMP_NLT_F32 */, AMDGPU::V_CMP_NLT_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27312 /* V_CMP_NLT_F32 */, AMDGPU::V_CMP_NLT_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27312 /* V_CMP_NLT_F32 */, AMDGPU::V_CMP_NLT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27312 /* V_CMP_NLT_F32 */, AMDGPU::V_CMP_NLT_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27312 /* V_CMP_NLT_F32 */, AMDGPU::V_CMP_NLT_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27312 /* V_CMP_NLT_F32 */, AMDGPU::V_CMP_NLT_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27312 /* V_CMP_NLT_F32 */, AMDGPU::V_CMP_NLT_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27312 /* V_CMP_NLT_F32 */, AMDGPU::V_CMP_NLT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27312 /* V_CMP_NLT_F32 */, AMDGPU::V_CMP_NLT_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27312 /* V_CMP_NLT_F32 */, AMDGPU::V_CMP_NLT_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27326 /* v_cmp_nlt_f32_e32 */, AMDGPU::V_CMP_NLT_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27326 /* v_cmp_nlt_f32_e32 */, AMDGPU::V_CMP_NLT_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27326 /* v_cmp_nlt_f32_e32 */, AMDGPU::V_CMP_NLT_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27326 /* v_cmp_nlt_f32_e32 */, AMDGPU::V_CMP_NLT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27326 /* v_cmp_nlt_f32_e32 */, AMDGPU::V_CMP_NLT_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27344 /* V_CMP_NLT_F64 */, AMDGPU::V_CMP_NLT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27344 /* V_CMP_NLT_F64 */, AMDGPU::V_CMP_NLT_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27344 /* V_CMP_NLT_F64 */, AMDGPU::V_CMP_NLT_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27344 /* V_CMP_NLT_F64 */, AMDGPU::V_CMP_NLT_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27344 /* V_CMP_NLT_F64 */, AMDGPU::V_CMP_NLT_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27344 /* V_CMP_NLT_F64 */, AMDGPU::V_CMP_NLT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27344 /* V_CMP_NLT_F64 */, AMDGPU::V_CMP_NLT_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27344 /* V_CMP_NLT_F64 */, AMDGPU::V_CMP_NLT_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27344 /* V_CMP_NLT_F64 */, AMDGPU::V_CMP_NLT_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27344 /* V_CMP_NLT_F64 */, AMDGPU::V_CMP_NLT_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27344 /* V_CMP_NLT_F64 */, AMDGPU::V_CMP_NLT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27344 /* V_CMP_NLT_F64 */, AMDGPU::V_CMP_NLT_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27344 /* V_CMP_NLT_F64 */, AMDGPU::V_CMP_NLT_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27344 /* V_CMP_NLT_F64 */, AMDGPU::V_CMP_NLT_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27344 /* V_CMP_NLT_F64 */, AMDGPU::V_CMP_NLT_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27358 /* v_cmp_nlt_f64_e32 */, AMDGPU::V_CMP_NLT_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27358 /* v_cmp_nlt_f64_e32 */, AMDGPU::V_CMP_NLT_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27358 /* v_cmp_nlt_f64_e32 */, AMDGPU::V_CMP_NLT_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27358 /* v_cmp_nlt_f64_e32 */, AMDGPU::V_CMP_NLT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27358 /* v_cmp_nlt_f64_e32 */, AMDGPU::V_CMP_NLT_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27376 /* V_CMP_O_F16 */, AMDGPU::V_CMP_O_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27376 /* V_CMP_O_F16 */, AMDGPU::V_CMP_O_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27376 /* V_CMP_O_F16 */, AMDGPU::V_CMP_O_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27376 /* V_CMP_O_F16 */, AMDGPU::V_CMP_O_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27376 /* V_CMP_O_F16 */, AMDGPU::V_CMP_O_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27376 /* V_CMP_O_F16 */, AMDGPU::V_CMP_O_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27388 /* v_cmp_o_f16_e32 */, AMDGPU::V_CMP_O_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27388 /* v_cmp_o_f16_e32 */, AMDGPU::V_CMP_O_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27388 /* v_cmp_o_f16_e32 */, AMDGPU::V_CMP_O_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27388 /* v_cmp_o_f16_e32 */, AMDGPU::V_CMP_O_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27388 /* v_cmp_o_f16_e32 */, AMDGPU::V_CMP_O_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27388 /* v_cmp_o_f16_e32 */, AMDGPU::V_CMP_O_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27404 /* V_CMP_O_F32 */, AMDGPU::V_CMP_O_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27404 /* V_CMP_O_F32 */, AMDGPU::V_CMP_O_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27404 /* V_CMP_O_F32 */, AMDGPU::V_CMP_O_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27404 /* V_CMP_O_F32 */, AMDGPU::V_CMP_O_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27404 /* V_CMP_O_F32 */, AMDGPU::V_CMP_O_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27404 /* V_CMP_O_F32 */, AMDGPU::V_CMP_O_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27404 /* V_CMP_O_F32 */, AMDGPU::V_CMP_O_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27404 /* V_CMP_O_F32 */, AMDGPU::V_CMP_O_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27404 /* V_CMP_O_F32 */, AMDGPU::V_CMP_O_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27404 /* V_CMP_O_F32 */, AMDGPU::V_CMP_O_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27404 /* V_CMP_O_F32 */, AMDGPU::V_CMP_O_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27404 /* V_CMP_O_F32 */, AMDGPU::V_CMP_O_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27404 /* V_CMP_O_F32 */, AMDGPU::V_CMP_O_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27404 /* V_CMP_O_F32 */, AMDGPU::V_CMP_O_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27404 /* V_CMP_O_F32 */, AMDGPU::V_CMP_O_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27416 /* v_cmp_o_f32_e32 */, AMDGPU::V_CMP_O_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27416 /* v_cmp_o_f32_e32 */, AMDGPU::V_CMP_O_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27416 /* v_cmp_o_f32_e32 */, AMDGPU::V_CMP_O_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27416 /* v_cmp_o_f32_e32 */, AMDGPU::V_CMP_O_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27416 /* v_cmp_o_f32_e32 */, AMDGPU::V_CMP_O_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27432 /* V_CMP_O_F64 */, AMDGPU::V_CMP_O_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27432 /* V_CMP_O_F64 */, AMDGPU::V_CMP_O_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27432 /* V_CMP_O_F64 */, AMDGPU::V_CMP_O_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27432 /* V_CMP_O_F64 */, AMDGPU::V_CMP_O_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27432 /* V_CMP_O_F64 */, AMDGPU::V_CMP_O_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27432 /* V_CMP_O_F64 */, AMDGPU::V_CMP_O_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27432 /* V_CMP_O_F64 */, AMDGPU::V_CMP_O_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27432 /* V_CMP_O_F64 */, AMDGPU::V_CMP_O_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27432 /* V_CMP_O_F64 */, AMDGPU::V_CMP_O_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27432 /* V_CMP_O_F64 */, AMDGPU::V_CMP_O_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27432 /* V_CMP_O_F64 */, AMDGPU::V_CMP_O_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27432 /* V_CMP_O_F64 */, AMDGPU::V_CMP_O_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27432 /* V_CMP_O_F64 */, AMDGPU::V_CMP_O_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27432 /* V_CMP_O_F64 */, AMDGPU::V_CMP_O_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27432 /* V_CMP_O_F64 */, AMDGPU::V_CMP_O_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27444 /* v_cmp_o_f64_e32 */, AMDGPU::V_CMP_O_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27444 /* v_cmp_o_f64_e32 */, AMDGPU::V_CMP_O_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27444 /* v_cmp_o_f64_e32 */, AMDGPU::V_CMP_O_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27444 /* v_cmp_o_f64_e32 */, AMDGPU::V_CMP_O_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27444 /* v_cmp_o_f64_e32 */, AMDGPU::V_CMP_O_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27472 /* v_cmp_t_f16_e32 */, AMDGPU::V_CMP_T_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27472 /* v_cmp_t_f16_e32 */, AMDGPU::V_CMP_T_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27488 /* v_cmp_t_f32 */, AMDGPU::V_CMP_T_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27488 /* v_cmp_t_f32 */, AMDGPU::V_CMP_T_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27488 /* v_cmp_t_f32 */, AMDGPU::V_CMP_T_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27500 /* v_cmp_t_f32_e32 */, AMDGPU::V_CMP_T_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27516 /* v_cmp_t_f64 */, AMDGPU::V_CMP_T_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27516 /* v_cmp_t_f64 */, AMDGPU::V_CMP_T_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27516 /* v_cmp_t_f64 */, AMDGPU::V_CMP_T_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27528 /* v_cmp_t_f64_e32 */, AMDGPU::V_CMP_T_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27544 /* V_CMP_T_I16 */, AMDGPU::V_CMP_T_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 27544 /* V_CMP_T_I16 */, AMDGPU::V_CMP_T_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 27544 /* V_CMP_T_I16 */, AMDGPU::V_CMP_T_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 27556 /* v_cmp_t_i16_e32 */, AMDGPU::V_CMP_T_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 27572 /* V_CMP_T_I32 */, AMDGPU::V_CMP_T_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27572 /* V_CMP_T_I32 */, AMDGPU::V_CMP_T_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27572 /* V_CMP_T_I32 */, AMDGPU::V_CMP_T_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27572 /* V_CMP_T_I32 */, AMDGPU::V_CMP_T_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27572 /* V_CMP_T_I32 */, AMDGPU::V_CMP_T_I32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27572 /* V_CMP_T_I32 */, AMDGPU::V_CMP_T_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27572 /* V_CMP_T_I32 */, AMDGPU::V_CMP_T_I32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27572 /* V_CMP_T_I32 */, AMDGPU::V_CMP_T_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27572 /* V_CMP_T_I32 */, AMDGPU::V_CMP_T_I32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27572 /* V_CMP_T_I32 */, AMDGPU::V_CMP_T_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27572 /* V_CMP_T_I32 */, AMDGPU::V_CMP_T_I32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27572 /* V_CMP_T_I32 */, AMDGPU::V_CMP_T_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27584 /* v_cmp_t_i32_e32 */, AMDGPU::V_CMP_T_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27584 /* v_cmp_t_i32_e32 */, AMDGPU::V_CMP_T_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27584 /* v_cmp_t_i32_e32 */, AMDGPU::V_CMP_T_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27584 /* v_cmp_t_i32_e32 */, AMDGPU::V_CMP_T_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27600 /* V_CMP_T_I64 */, AMDGPU::V_CMP_T_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27600 /* V_CMP_T_I64 */, AMDGPU::V_CMP_T_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27600 /* V_CMP_T_I64 */, AMDGPU::V_CMP_T_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27600 /* V_CMP_T_I64 */, AMDGPU::V_CMP_T_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27600 /* V_CMP_T_I64 */, AMDGPU::V_CMP_T_I64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27600 /* V_CMP_T_I64 */, AMDGPU::V_CMP_T_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27600 /* V_CMP_T_I64 */, AMDGPU::V_CMP_T_I64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27600 /* V_CMP_T_I64 */, AMDGPU::V_CMP_T_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27600 /* V_CMP_T_I64 */, AMDGPU::V_CMP_T_I64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27600 /* V_CMP_T_I64 */, AMDGPU::V_CMP_T_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27600 /* V_CMP_T_I64 */, AMDGPU::V_CMP_T_I64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27600 /* V_CMP_T_I64 */, AMDGPU::V_CMP_T_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27612 /* v_cmp_t_i64_e32 */, AMDGPU::V_CMP_T_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27612 /* v_cmp_t_i64_e32 */, AMDGPU::V_CMP_T_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27612 /* v_cmp_t_i64_e32 */, AMDGPU::V_CMP_T_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27612 /* v_cmp_t_i64_e32 */, AMDGPU::V_CMP_T_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27628 /* V_CMP_T_U16 */, AMDGPU::V_CMP_T_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 27628 /* V_CMP_T_U16 */, AMDGPU::V_CMP_T_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 27628 /* V_CMP_T_U16 */, AMDGPU::V_CMP_T_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 27640 /* v_cmp_t_u16_e32 */, AMDGPU::V_CMP_T_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 27656 /* V_CMP_T_U32 */, AMDGPU::V_CMP_T_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27656 /* V_CMP_T_U32 */, AMDGPU::V_CMP_T_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27656 /* V_CMP_T_U32 */, AMDGPU::V_CMP_T_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27656 /* V_CMP_T_U32 */, AMDGPU::V_CMP_T_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27656 /* V_CMP_T_U32 */, AMDGPU::V_CMP_T_U32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27656 /* V_CMP_T_U32 */, AMDGPU::V_CMP_T_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27656 /* V_CMP_T_U32 */, AMDGPU::V_CMP_T_U32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27656 /* V_CMP_T_U32 */, AMDGPU::V_CMP_T_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27656 /* V_CMP_T_U32 */, AMDGPU::V_CMP_T_U32_e32_gfx11, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27656 /* V_CMP_T_U32 */, AMDGPU::V_CMP_T_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27656 /* V_CMP_T_U32 */, AMDGPU::V_CMP_T_U32_e32_gfx10, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27656 /* V_CMP_T_U32 */, AMDGPU::V_CMP_T_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27668 /* v_cmp_t_u32_e32 */, AMDGPU::V_CMP_T_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27668 /* v_cmp_t_u32_e32 */, AMDGPU::V_CMP_T_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27668 /* v_cmp_t_u32_e32 */, AMDGPU::V_CMP_T_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27668 /* v_cmp_t_u32_e32 */, AMDGPU::V_CMP_T_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 27684 /* V_CMP_T_U64 */, AMDGPU::V_CMP_T_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27684 /* V_CMP_T_U64 */, AMDGPU::V_CMP_T_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27684 /* V_CMP_T_U64 */, AMDGPU::V_CMP_T_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27684 /* V_CMP_T_U64 */, AMDGPU::V_CMP_T_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27684 /* V_CMP_T_U64 */, AMDGPU::V_CMP_T_U64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27684 /* V_CMP_T_U64 */, AMDGPU::V_CMP_T_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27684 /* V_CMP_T_U64 */, AMDGPU::V_CMP_T_U64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27684 /* V_CMP_T_U64 */, AMDGPU::V_CMP_T_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27684 /* V_CMP_T_U64 */, AMDGPU::V_CMP_T_U64_e32_gfx11, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27684 /* V_CMP_T_U64 */, AMDGPU::V_CMP_T_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27684 /* V_CMP_T_U64 */, AMDGPU::V_CMP_T_U64_e32_gfx10, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27684 /* V_CMP_T_U64 */, AMDGPU::V_CMP_T_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27696 /* v_cmp_t_u64_e32 */, AMDGPU::V_CMP_T_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27696 /* v_cmp_t_u64_e32 */, AMDGPU::V_CMP_T_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27696 /* v_cmp_t_u64_e32 */, AMDGPU::V_CMP_T_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27696 /* v_cmp_t_u64_e32 */, AMDGPU::V_CMP_T_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27712 /* V_CMP_TRU_F16 */, AMDGPU::V_CMP_TRU_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27712 /* V_CMP_TRU_F16 */, AMDGPU::V_CMP_TRU_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27712 /* V_CMP_TRU_F16 */, AMDGPU::V_CMP_TRU_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27712 /* V_CMP_TRU_F16 */, AMDGPU::V_CMP_TRU_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27712 /* V_CMP_TRU_F16 */, AMDGPU::V_CMP_TRU_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27712 /* V_CMP_TRU_F16 */, AMDGPU::V_CMP_TRU_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27726 /* v_cmp_tru_f16_e32 */, AMDGPU::V_CMP_TRU_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27726 /* v_cmp_tru_f16_e32 */, AMDGPU::V_CMP_TRU_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27744 /* V_CMP_TRU_F32 */, AMDGPU::V_CMP_TRU_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27744 /* V_CMP_TRU_F32 */, AMDGPU::V_CMP_TRU_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27744 /* V_CMP_TRU_F32 */, AMDGPU::V_CMP_TRU_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27744 /* V_CMP_TRU_F32 */, AMDGPU::V_CMP_TRU_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27744 /* V_CMP_TRU_F32 */, AMDGPU::V_CMP_TRU_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27744 /* V_CMP_TRU_F32 */, AMDGPU::V_CMP_TRU_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27744 /* V_CMP_TRU_F32 */, AMDGPU::V_CMP_TRU_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27744 /* V_CMP_TRU_F32 */, AMDGPU::V_CMP_TRU_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27744 /* V_CMP_TRU_F32 */, AMDGPU::V_CMP_TRU_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27758 /* v_cmp_tru_f32_e32 */, AMDGPU::V_CMP_TRU_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27758 /* v_cmp_tru_f32_e32 */, AMDGPU::V_CMP_TRU_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27758 /* v_cmp_tru_f32_e32 */, AMDGPU::V_CMP_TRU_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27776 /* V_CMP_TRU_F64 */, AMDGPU::V_CMP_TRU_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27776 /* V_CMP_TRU_F64 */, AMDGPU::V_CMP_TRU_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27776 /* V_CMP_TRU_F64 */, AMDGPU::V_CMP_TRU_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27776 /* V_CMP_TRU_F64 */, AMDGPU::V_CMP_TRU_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27776 /* V_CMP_TRU_F64 */, AMDGPU::V_CMP_TRU_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27776 /* V_CMP_TRU_F64 */, AMDGPU::V_CMP_TRU_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27776 /* V_CMP_TRU_F64 */, AMDGPU::V_CMP_TRU_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27776 /* V_CMP_TRU_F64 */, AMDGPU::V_CMP_TRU_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27776 /* V_CMP_TRU_F64 */, AMDGPU::V_CMP_TRU_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27790 /* v_cmp_tru_f64_e32 */, AMDGPU::V_CMP_TRU_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27790 /* v_cmp_tru_f64_e32 */, AMDGPU::V_CMP_TRU_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27790 /* v_cmp_tru_f64_e32 */, AMDGPU::V_CMP_TRU_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27808 /* V_CMP_U_F16 */, AMDGPU::V_CMP_U_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27808 /* V_CMP_U_F16 */, AMDGPU::V_CMP_U_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27808 /* V_CMP_U_F16 */, AMDGPU::V_CMP_U_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27808 /* V_CMP_U_F16 */, AMDGPU::V_CMP_U_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27808 /* V_CMP_U_F16 */, AMDGPU::V_CMP_U_F16_e32_gfx10, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27808 /* V_CMP_U_F16 */, AMDGPU::V_CMP_U_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27820 /* v_cmp_u_f16_e32 */, AMDGPU::V_CMP_U_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27820 /* v_cmp_u_f16_e32 */, AMDGPU::V_CMP_U_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 27820 /* v_cmp_u_f16_e32 */, AMDGPU::V_CMP_U_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27820 /* v_cmp_u_f16_e32 */, AMDGPU::V_CMP_U_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 27820 /* v_cmp_u_f16_e32 */, AMDGPU::V_CMP_U_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27820 /* v_cmp_u_f16_e32 */, AMDGPU::V_CMP_U_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 27836 /* V_CMP_U_F32 */, AMDGPU::V_CMP_U_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27836 /* V_CMP_U_F32 */, AMDGPU::V_CMP_U_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27836 /* V_CMP_U_F32 */, AMDGPU::V_CMP_U_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27836 /* V_CMP_U_F32 */, AMDGPU::V_CMP_U_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27836 /* V_CMP_U_F32 */, AMDGPU::V_CMP_U_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27836 /* V_CMP_U_F32 */, AMDGPU::V_CMP_U_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27836 /* V_CMP_U_F32 */, AMDGPU::V_CMP_U_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27836 /* V_CMP_U_F32 */, AMDGPU::V_CMP_U_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27836 /* V_CMP_U_F32 */, AMDGPU::V_CMP_U_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27836 /* V_CMP_U_F32 */, AMDGPU::V_CMP_U_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27836 /* V_CMP_U_F32 */, AMDGPU::V_CMP_U_F32_e32_gfx11, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27836 /* V_CMP_U_F32 */, AMDGPU::V_CMP_U_F32_e32_gfx12, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27836 /* V_CMP_U_F32 */, AMDGPU::V_CMP_U_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27836 /* V_CMP_U_F32 */, AMDGPU::V_CMP_U_F32_e32_gfx10, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27836 /* V_CMP_U_F32 */, AMDGPU::V_CMP_U_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27848 /* v_cmp_u_f32_e32 */, AMDGPU::V_CMP_U_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27848 /* v_cmp_u_f32_e32 */, AMDGPU::V_CMP_U_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27848 /* v_cmp_u_f32_e32 */, AMDGPU::V_CMP_U_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27848 /* v_cmp_u_f32_e32 */, AMDGPU::V_CMP_U_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27848 /* v_cmp_u_f32_e32 */, AMDGPU::V_CMP_U_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27864 /* V_CMP_U_F64 */, AMDGPU::V_CMP_U_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27864 /* V_CMP_U_F64 */, AMDGPU::V_CMP_U_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27864 /* V_CMP_U_F64 */, AMDGPU::V_CMP_U_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27864 /* V_CMP_U_F64 */, AMDGPU::V_CMP_U_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27864 /* V_CMP_U_F64 */, AMDGPU::V_CMP_U_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27864 /* V_CMP_U_F64 */, AMDGPU::V_CMP_U_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27864 /* V_CMP_U_F64 */, AMDGPU::V_CMP_U_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27864 /* V_CMP_U_F64 */, AMDGPU::V_CMP_U_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27864 /* V_CMP_U_F64 */, AMDGPU::V_CMP_U_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27864 /* V_CMP_U_F64 */, AMDGPU::V_CMP_U_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27864 /* V_CMP_U_F64 */, AMDGPU::V_CMP_U_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27864 /* V_CMP_U_F64 */, AMDGPU::V_CMP_U_F64_e32_gfx10, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX10Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27864 /* V_CMP_U_F64 */, AMDGPU::V_CMP_U_F64_e32_gfx11, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27864 /* V_CMP_U_F64 */, AMDGPU::V_CMP_U_F64_e32_gfx12, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27864 /* V_CMP_U_F64 */, AMDGPU::V_CMP_U_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27876 /* v_cmp_u_f64_e32 */, AMDGPU::V_CMP_U_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27876 /* v_cmp_u_f64_e32 */, AMDGPU::V_CMP_U_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27876 /* v_cmp_u_f64_e32 */, AMDGPU::V_CMP_U_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27876 /* v_cmp_u_f64_e32 */, AMDGPU::V_CMP_U_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27876 /* v_cmp_u_f64_e32 */, AMDGPU::V_CMP_U_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27892 /* V_CMPS_EQ_F32 */, AMDGPU::V_CMPS_EQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27892 /* V_CMPS_EQ_F32 */, AMDGPU::V_CMPS_EQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27892 /* V_CMPS_EQ_F32 */, AMDGPU::V_CMPS_EQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27906 /* v_cmps_eq_f32_e32 */, AMDGPU::V_CMPS_EQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27924 /* V_CMPS_EQ_F64 */, AMDGPU::V_CMPS_EQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27924 /* V_CMPS_EQ_F64 */, AMDGPU::V_CMPS_EQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27924 /* V_CMPS_EQ_F64 */, AMDGPU::V_CMPS_EQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27938 /* v_cmps_eq_f64_e32 */, AMDGPU::V_CMPS_EQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27956 /* V_CMPS_F_F32 */, AMDGPU::V_CMPS_F_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27956 /* V_CMPS_F_F32 */, AMDGPU::V_CMPS_F_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27956 /* V_CMPS_F_F32 */, AMDGPU::V_CMPS_F_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27969 /* v_cmps_f_f32_e32 */, AMDGPU::V_CMPS_F_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 27986 /* V_CMPS_F_F64 */, AMDGPU::V_CMPS_F_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27986 /* V_CMPS_F_F64 */, AMDGPU::V_CMPS_F_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27986 /* V_CMPS_F_F64 */, AMDGPU::V_CMPS_F_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 27999 /* v_cmps_f_f64_e32 */, AMDGPU::V_CMPS_F_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28016 /* V_CMPS_GE_F32 */, AMDGPU::V_CMPS_GE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28016 /* V_CMPS_GE_F32 */, AMDGPU::V_CMPS_GE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28016 /* V_CMPS_GE_F32 */, AMDGPU::V_CMPS_GE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28030 /* v_cmps_ge_f32_e32 */, AMDGPU::V_CMPS_GE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28048 /* V_CMPS_GE_F64 */, AMDGPU::V_CMPS_GE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28048 /* V_CMPS_GE_F64 */, AMDGPU::V_CMPS_GE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28048 /* V_CMPS_GE_F64 */, AMDGPU::V_CMPS_GE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28062 /* v_cmps_ge_f64_e32 */, AMDGPU::V_CMPS_GE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28080 /* V_CMPS_GT_F32 */, AMDGPU::V_CMPS_GT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28080 /* V_CMPS_GT_F32 */, AMDGPU::V_CMPS_GT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28080 /* V_CMPS_GT_F32 */, AMDGPU::V_CMPS_GT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28094 /* v_cmps_gt_f32_e32 */, AMDGPU::V_CMPS_GT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28112 /* V_CMPS_GT_F64 */, AMDGPU::V_CMPS_GT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28112 /* V_CMPS_GT_F64 */, AMDGPU::V_CMPS_GT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28112 /* V_CMPS_GT_F64 */, AMDGPU::V_CMPS_GT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28126 /* v_cmps_gt_f64_e32 */, AMDGPU::V_CMPS_GT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28144 /* V_CMPS_LE_F32 */, AMDGPU::V_CMPS_LE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28144 /* V_CMPS_LE_F32 */, AMDGPU::V_CMPS_LE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28144 /* V_CMPS_LE_F32 */, AMDGPU::V_CMPS_LE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28158 /* v_cmps_le_f32_e32 */, AMDGPU::V_CMPS_LE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28176 /* V_CMPS_LE_F64 */, AMDGPU::V_CMPS_LE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28176 /* V_CMPS_LE_F64 */, AMDGPU::V_CMPS_LE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28176 /* V_CMPS_LE_F64 */, AMDGPU::V_CMPS_LE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28190 /* v_cmps_le_f64_e32 */, AMDGPU::V_CMPS_LE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28208 /* V_CMPS_LG_F32 */, AMDGPU::V_CMPS_LG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28208 /* V_CMPS_LG_F32 */, AMDGPU::V_CMPS_LG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28208 /* V_CMPS_LG_F32 */, AMDGPU::V_CMPS_LG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28222 /* v_cmps_lg_f32_e32 */, AMDGPU::V_CMPS_LG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28240 /* V_CMPS_LG_F64 */, AMDGPU::V_CMPS_LG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28240 /* V_CMPS_LG_F64 */, AMDGPU::V_CMPS_LG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28240 /* V_CMPS_LG_F64 */, AMDGPU::V_CMPS_LG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28254 /* v_cmps_lg_f64_e32 */, AMDGPU::V_CMPS_LG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28272 /* V_CMPS_LT_F32 */, AMDGPU::V_CMPS_LT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28272 /* V_CMPS_LT_F32 */, AMDGPU::V_CMPS_LT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28272 /* V_CMPS_LT_F32 */, AMDGPU::V_CMPS_LT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28286 /* v_cmps_lt_f32_e32 */, AMDGPU::V_CMPS_LT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28304 /* V_CMPS_LT_F64 */, AMDGPU::V_CMPS_LT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28304 /* V_CMPS_LT_F64 */, AMDGPU::V_CMPS_LT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28304 /* V_CMPS_LT_F64 */, AMDGPU::V_CMPS_LT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28318 /* v_cmps_lt_f64_e32 */, AMDGPU::V_CMPS_LT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28336 /* V_CMPS_NEQ_F32 */, AMDGPU::V_CMPS_NEQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28336 /* V_CMPS_NEQ_F32 */, AMDGPU::V_CMPS_NEQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28336 /* V_CMPS_NEQ_F32 */, AMDGPU::V_CMPS_NEQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28351 /* v_cmps_neq_f32_e32 */, AMDGPU::V_CMPS_NEQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28370 /* V_CMPS_NEQ_F64 */, AMDGPU::V_CMPS_NEQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28370 /* V_CMPS_NEQ_F64 */, AMDGPU::V_CMPS_NEQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28370 /* V_CMPS_NEQ_F64 */, AMDGPU::V_CMPS_NEQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28385 /* v_cmps_neq_f64_e32 */, AMDGPU::V_CMPS_NEQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28404 /* V_CMPS_NGE_F32 */, AMDGPU::V_CMPS_NGE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28404 /* V_CMPS_NGE_F32 */, AMDGPU::V_CMPS_NGE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28404 /* V_CMPS_NGE_F32 */, AMDGPU::V_CMPS_NGE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28419 /* v_cmps_nge_f32_e32 */, AMDGPU::V_CMPS_NGE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28438 /* V_CMPS_NGE_F64 */, AMDGPU::V_CMPS_NGE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28438 /* V_CMPS_NGE_F64 */, AMDGPU::V_CMPS_NGE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28438 /* V_CMPS_NGE_F64 */, AMDGPU::V_CMPS_NGE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28453 /* v_cmps_nge_f64_e32 */, AMDGPU::V_CMPS_NGE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28472 /* V_CMPS_NGT_F32 */, AMDGPU::V_CMPS_NGT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28472 /* V_CMPS_NGT_F32 */, AMDGPU::V_CMPS_NGT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28472 /* V_CMPS_NGT_F32 */, AMDGPU::V_CMPS_NGT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28487 /* v_cmps_ngt_f32_e32 */, AMDGPU::V_CMPS_NGT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28506 /* V_CMPS_NGT_F64 */, AMDGPU::V_CMPS_NGT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28506 /* V_CMPS_NGT_F64 */, AMDGPU::V_CMPS_NGT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28506 /* V_CMPS_NGT_F64 */, AMDGPU::V_CMPS_NGT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28521 /* v_cmps_ngt_f64_e32 */, AMDGPU::V_CMPS_NGT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28540 /* V_CMPS_NLE_F32 */, AMDGPU::V_CMPS_NLE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28540 /* V_CMPS_NLE_F32 */, AMDGPU::V_CMPS_NLE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28540 /* V_CMPS_NLE_F32 */, AMDGPU::V_CMPS_NLE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28555 /* v_cmps_nle_f32_e32 */, AMDGPU::V_CMPS_NLE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28574 /* V_CMPS_NLE_F64 */, AMDGPU::V_CMPS_NLE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28574 /* V_CMPS_NLE_F64 */, AMDGPU::V_CMPS_NLE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28574 /* V_CMPS_NLE_F64 */, AMDGPU::V_CMPS_NLE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28589 /* v_cmps_nle_f64_e32 */, AMDGPU::V_CMPS_NLE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28608 /* V_CMPS_NLG_F32 */, AMDGPU::V_CMPS_NLG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28608 /* V_CMPS_NLG_F32 */, AMDGPU::V_CMPS_NLG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28608 /* V_CMPS_NLG_F32 */, AMDGPU::V_CMPS_NLG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28623 /* v_cmps_nlg_f32_e32 */, AMDGPU::V_CMPS_NLG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28642 /* V_CMPS_NLG_F64 */, AMDGPU::V_CMPS_NLG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28642 /* V_CMPS_NLG_F64 */, AMDGPU::V_CMPS_NLG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28642 /* V_CMPS_NLG_F64 */, AMDGPU::V_CMPS_NLG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28657 /* v_cmps_nlg_f64_e32 */, AMDGPU::V_CMPS_NLG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28676 /* V_CMPS_NLT_F32 */, AMDGPU::V_CMPS_NLT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28676 /* V_CMPS_NLT_F32 */, AMDGPU::V_CMPS_NLT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28676 /* V_CMPS_NLT_F32 */, AMDGPU::V_CMPS_NLT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28691 /* v_cmps_nlt_f32_e32 */, AMDGPU::V_CMPS_NLT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28710 /* V_CMPS_NLT_F64 */, AMDGPU::V_CMPS_NLT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28710 /* V_CMPS_NLT_F64 */, AMDGPU::V_CMPS_NLT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28710 /* V_CMPS_NLT_F64 */, AMDGPU::V_CMPS_NLT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28725 /* v_cmps_nlt_f64_e32 */, AMDGPU::V_CMPS_NLT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28744 /* V_CMPS_O_F32 */, AMDGPU::V_CMPS_O_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28744 /* V_CMPS_O_F32 */, AMDGPU::V_CMPS_O_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28744 /* V_CMPS_O_F32 */, AMDGPU::V_CMPS_O_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28757 /* v_cmps_o_f32_e32 */, AMDGPU::V_CMPS_O_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28774 /* V_CMPS_O_F64 */, AMDGPU::V_CMPS_O_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28774 /* V_CMPS_O_F64 */, AMDGPU::V_CMPS_O_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28774 /* V_CMPS_O_F64 */, AMDGPU::V_CMPS_O_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28787 /* v_cmps_o_f64_e32 */, AMDGPU::V_CMPS_O_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28804 /* V_CMPS_TRU_F32 */, AMDGPU::V_CMPS_TRU_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28804 /* V_CMPS_TRU_F32 */, AMDGPU::V_CMPS_TRU_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28804 /* V_CMPS_TRU_F32 */, AMDGPU::V_CMPS_TRU_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28819 /* v_cmps_tru_f32_e32 */, AMDGPU::V_CMPS_TRU_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28838 /* V_CMPS_TRU_F64 */, AMDGPU::V_CMPS_TRU_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28838 /* V_CMPS_TRU_F64 */, AMDGPU::V_CMPS_TRU_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28838 /* V_CMPS_TRU_F64 */, AMDGPU::V_CMPS_TRU_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28853 /* v_cmps_tru_f64_e32 */, AMDGPU::V_CMPS_TRU_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28872 /* V_CMPS_U_F32 */, AMDGPU::V_CMPS_U_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28872 /* V_CMPS_U_F32 */, AMDGPU::V_CMPS_U_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28872 /* V_CMPS_U_F32 */, AMDGPU::V_CMPS_U_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28885 /* v_cmps_u_f32_e32 */, AMDGPU::V_CMPS_U_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28902 /* V_CMPS_U_F64 */, AMDGPU::V_CMPS_U_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28902 /* V_CMPS_U_F64 */, AMDGPU::V_CMPS_U_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28902 /* V_CMPS_U_F64 */, AMDGPU::V_CMPS_U_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28915 /* v_cmps_u_f64_e32 */, AMDGPU::V_CMPS_U_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28932 /* V_CMPSX_EQ_F32 */, AMDGPU::V_CMPSX_EQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28932 /* V_CMPSX_EQ_F32 */, AMDGPU::V_CMPSX_EQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28932 /* V_CMPSX_EQ_F32 */, AMDGPU::V_CMPSX_EQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28947 /* v_cmpsx_eq_f32_e32 */, AMDGPU::V_CMPSX_EQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 28966 /* V_CMPSX_EQ_F64 */, AMDGPU::V_CMPSX_EQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28966 /* V_CMPSX_EQ_F64 */, AMDGPU::V_CMPSX_EQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28966 /* V_CMPSX_EQ_F64 */, AMDGPU::V_CMPSX_EQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 28981 /* v_cmpsx_eq_f64_e32 */, AMDGPU::V_CMPSX_EQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29000 /* V_CMPSX_F_F32 */, AMDGPU::V_CMPSX_F_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29000 /* V_CMPSX_F_F32 */, AMDGPU::V_CMPSX_F_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29000 /* V_CMPSX_F_F32 */, AMDGPU::V_CMPSX_F_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29014 /* v_cmpsx_f_f32_e32 */, AMDGPU::V_CMPSX_F_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29032 /* V_CMPSX_F_F64 */, AMDGPU::V_CMPSX_F_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29032 /* V_CMPSX_F_F64 */, AMDGPU::V_CMPSX_F_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29032 /* V_CMPSX_F_F64 */, AMDGPU::V_CMPSX_F_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29046 /* v_cmpsx_f_f64_e32 */, AMDGPU::V_CMPSX_F_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29064 /* V_CMPSX_GE_F32 */, AMDGPU::V_CMPSX_GE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29064 /* V_CMPSX_GE_F32 */, AMDGPU::V_CMPSX_GE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29064 /* V_CMPSX_GE_F32 */, AMDGPU::V_CMPSX_GE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29079 /* v_cmpsx_ge_f32_e32 */, AMDGPU::V_CMPSX_GE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29098 /* V_CMPSX_GE_F64 */, AMDGPU::V_CMPSX_GE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29098 /* V_CMPSX_GE_F64 */, AMDGPU::V_CMPSX_GE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29098 /* V_CMPSX_GE_F64 */, AMDGPU::V_CMPSX_GE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29113 /* v_cmpsx_ge_f64_e32 */, AMDGPU::V_CMPSX_GE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29132 /* V_CMPSX_GT_F32 */, AMDGPU::V_CMPSX_GT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29132 /* V_CMPSX_GT_F32 */, AMDGPU::V_CMPSX_GT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29132 /* V_CMPSX_GT_F32 */, AMDGPU::V_CMPSX_GT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29147 /* v_cmpsx_gt_f32_e32 */, AMDGPU::V_CMPSX_GT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29166 /* V_CMPSX_GT_F64 */, AMDGPU::V_CMPSX_GT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29166 /* V_CMPSX_GT_F64 */, AMDGPU::V_CMPSX_GT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29166 /* V_CMPSX_GT_F64 */, AMDGPU::V_CMPSX_GT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29181 /* v_cmpsx_gt_f64_e32 */, AMDGPU::V_CMPSX_GT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29200 /* V_CMPSX_LE_F32 */, AMDGPU::V_CMPSX_LE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29200 /* V_CMPSX_LE_F32 */, AMDGPU::V_CMPSX_LE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29200 /* V_CMPSX_LE_F32 */, AMDGPU::V_CMPSX_LE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29215 /* v_cmpsx_le_f32_e32 */, AMDGPU::V_CMPSX_LE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29234 /* V_CMPSX_LE_F64 */, AMDGPU::V_CMPSX_LE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29234 /* V_CMPSX_LE_F64 */, AMDGPU::V_CMPSX_LE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29234 /* V_CMPSX_LE_F64 */, AMDGPU::V_CMPSX_LE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29249 /* v_cmpsx_le_f64_e32 */, AMDGPU::V_CMPSX_LE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29268 /* V_CMPSX_LG_F32 */, AMDGPU::V_CMPSX_LG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29268 /* V_CMPSX_LG_F32 */, AMDGPU::V_CMPSX_LG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29268 /* V_CMPSX_LG_F32 */, AMDGPU::V_CMPSX_LG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29283 /* v_cmpsx_lg_f32_e32 */, AMDGPU::V_CMPSX_LG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29302 /* V_CMPSX_LG_F64 */, AMDGPU::V_CMPSX_LG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29302 /* V_CMPSX_LG_F64 */, AMDGPU::V_CMPSX_LG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29302 /* V_CMPSX_LG_F64 */, AMDGPU::V_CMPSX_LG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29317 /* v_cmpsx_lg_f64_e32 */, AMDGPU::V_CMPSX_LG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29336 /* V_CMPSX_LT_F32 */, AMDGPU::V_CMPSX_LT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29336 /* V_CMPSX_LT_F32 */, AMDGPU::V_CMPSX_LT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29336 /* V_CMPSX_LT_F32 */, AMDGPU::V_CMPSX_LT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29351 /* v_cmpsx_lt_f32_e32 */, AMDGPU::V_CMPSX_LT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29370 /* V_CMPSX_LT_F64 */, AMDGPU::V_CMPSX_LT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29370 /* V_CMPSX_LT_F64 */, AMDGPU::V_CMPSX_LT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29370 /* V_CMPSX_LT_F64 */, AMDGPU::V_CMPSX_LT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29385 /* v_cmpsx_lt_f64_e32 */, AMDGPU::V_CMPSX_LT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29404 /* V_CMPSX_NEQ_F32 */, AMDGPU::V_CMPSX_NEQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29404 /* V_CMPSX_NEQ_F32 */, AMDGPU::V_CMPSX_NEQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29404 /* V_CMPSX_NEQ_F32 */, AMDGPU::V_CMPSX_NEQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29420 /* v_cmpsx_neq_f32_e32 */, AMDGPU::V_CMPSX_NEQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29440 /* V_CMPSX_NEQ_F64 */, AMDGPU::V_CMPSX_NEQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29440 /* V_CMPSX_NEQ_F64 */, AMDGPU::V_CMPSX_NEQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29440 /* V_CMPSX_NEQ_F64 */, AMDGPU::V_CMPSX_NEQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29456 /* v_cmpsx_neq_f64_e32 */, AMDGPU::V_CMPSX_NEQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29476 /* V_CMPSX_NGE_F32 */, AMDGPU::V_CMPSX_NGE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29476 /* V_CMPSX_NGE_F32 */, AMDGPU::V_CMPSX_NGE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29476 /* V_CMPSX_NGE_F32 */, AMDGPU::V_CMPSX_NGE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29492 /* v_cmpsx_nge_f32_e32 */, AMDGPU::V_CMPSX_NGE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29512 /* V_CMPSX_NGE_F64 */, AMDGPU::V_CMPSX_NGE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29512 /* V_CMPSX_NGE_F64 */, AMDGPU::V_CMPSX_NGE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29512 /* V_CMPSX_NGE_F64 */, AMDGPU::V_CMPSX_NGE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29528 /* v_cmpsx_nge_f64_e32 */, AMDGPU::V_CMPSX_NGE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29548 /* V_CMPSX_NGT_F32 */, AMDGPU::V_CMPSX_NGT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29548 /* V_CMPSX_NGT_F32 */, AMDGPU::V_CMPSX_NGT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29548 /* V_CMPSX_NGT_F32 */, AMDGPU::V_CMPSX_NGT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29564 /* v_cmpsx_ngt_f32_e32 */, AMDGPU::V_CMPSX_NGT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29584 /* V_CMPSX_NGT_F64 */, AMDGPU::V_CMPSX_NGT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29584 /* V_CMPSX_NGT_F64 */, AMDGPU::V_CMPSX_NGT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29584 /* V_CMPSX_NGT_F64 */, AMDGPU::V_CMPSX_NGT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29600 /* v_cmpsx_ngt_f64_e32 */, AMDGPU::V_CMPSX_NGT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29620 /* V_CMPSX_NLE_F32 */, AMDGPU::V_CMPSX_NLE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29620 /* V_CMPSX_NLE_F32 */, AMDGPU::V_CMPSX_NLE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29620 /* V_CMPSX_NLE_F32 */, AMDGPU::V_CMPSX_NLE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29636 /* v_cmpsx_nle_f32_e32 */, AMDGPU::V_CMPSX_NLE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29656 /* V_CMPSX_NLE_F64 */, AMDGPU::V_CMPSX_NLE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29656 /* V_CMPSX_NLE_F64 */, AMDGPU::V_CMPSX_NLE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29656 /* V_CMPSX_NLE_F64 */, AMDGPU::V_CMPSX_NLE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29672 /* v_cmpsx_nle_f64_e32 */, AMDGPU::V_CMPSX_NLE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29692 /* V_CMPSX_NLG_F32 */, AMDGPU::V_CMPSX_NLG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29692 /* V_CMPSX_NLG_F32 */, AMDGPU::V_CMPSX_NLG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29692 /* V_CMPSX_NLG_F32 */, AMDGPU::V_CMPSX_NLG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29708 /* v_cmpsx_nlg_f32_e32 */, AMDGPU::V_CMPSX_NLG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29728 /* V_CMPSX_NLG_F64 */, AMDGPU::V_CMPSX_NLG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29728 /* V_CMPSX_NLG_F64 */, AMDGPU::V_CMPSX_NLG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29728 /* V_CMPSX_NLG_F64 */, AMDGPU::V_CMPSX_NLG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29744 /* v_cmpsx_nlg_f64_e32 */, AMDGPU::V_CMPSX_NLG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29764 /* V_CMPSX_NLT_F32 */, AMDGPU::V_CMPSX_NLT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29764 /* V_CMPSX_NLT_F32 */, AMDGPU::V_CMPSX_NLT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29764 /* V_CMPSX_NLT_F32 */, AMDGPU::V_CMPSX_NLT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29780 /* v_cmpsx_nlt_f32_e32 */, AMDGPU::V_CMPSX_NLT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29800 /* V_CMPSX_NLT_F64 */, AMDGPU::V_CMPSX_NLT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29800 /* V_CMPSX_NLT_F64 */, AMDGPU::V_CMPSX_NLT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29800 /* V_CMPSX_NLT_F64 */, AMDGPU::V_CMPSX_NLT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29816 /* v_cmpsx_nlt_f64_e32 */, AMDGPU::V_CMPSX_NLT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29836 /* V_CMPSX_O_F32 */, AMDGPU::V_CMPSX_O_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29836 /* V_CMPSX_O_F32 */, AMDGPU::V_CMPSX_O_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29836 /* V_CMPSX_O_F32 */, AMDGPU::V_CMPSX_O_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29850 /* v_cmpsx_o_f32_e32 */, AMDGPU::V_CMPSX_O_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29868 /* V_CMPSX_O_F64 */, AMDGPU::V_CMPSX_O_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29868 /* V_CMPSX_O_F64 */, AMDGPU::V_CMPSX_O_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29868 /* V_CMPSX_O_F64 */, AMDGPU::V_CMPSX_O_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29882 /* v_cmpsx_o_f64_e32 */, AMDGPU::V_CMPSX_O_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29900 /* V_CMPSX_TRU_F32 */, AMDGPU::V_CMPSX_TRU_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29900 /* V_CMPSX_TRU_F32 */, AMDGPU::V_CMPSX_TRU_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29900 /* V_CMPSX_TRU_F32 */, AMDGPU::V_CMPSX_TRU_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29916 /* v_cmpsx_tru_f32_e32 */, AMDGPU::V_CMPSX_TRU_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29936 /* V_CMPSX_TRU_F64 */, AMDGPU::V_CMPSX_TRU_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29936 /* V_CMPSX_TRU_F64 */, AMDGPU::V_CMPSX_TRU_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29936 /* V_CMPSX_TRU_F64 */, AMDGPU::V_CMPSX_TRU_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29952 /* v_cmpsx_tru_f64_e32 */, AMDGPU::V_CMPSX_TRU_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 29972 /* V_CMPSX_U_F32 */, AMDGPU::V_CMPSX_U_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29972 /* V_CMPSX_U_F32 */, AMDGPU::V_CMPSX_U_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29972 /* V_CMPSX_U_F32 */, AMDGPU::V_CMPSX_U_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 29986 /* v_cmpsx_u_f32_e32 */, AMDGPU::V_CMPSX_U_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30004 /* V_CMPSX_U_F64 */, AMDGPU::V_CMPSX_U_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30004 /* V_CMPSX_U_F64 */, AMDGPU::V_CMPSX_U_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30004 /* V_CMPSX_U_F64 */, AMDGPU::V_CMPSX_U_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30018 /* v_cmpsx_u_f64_e32 */, AMDGPU::V_CMPSX_U_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30036 /* V_CMPX_CLASS_F16 */, AMDGPU::V_CMPX_CLASS_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30036 /* V_CMPX_CLASS_F16 */, AMDGPU::V_CMPX_CLASS_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30036 /* V_CMPX_CLASS_F16 */, AMDGPU::V_CMPX_CLASS_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30036 /* V_CMPX_CLASS_F16 */, AMDGPU::V_CMPX_CLASS_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30053 /* v_cmpx_class_f16_e32 */, AMDGPU::V_CMPX_CLASS_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_HasNoSdstCMPX_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30053 /* v_cmpx_class_f16_e32 */, AMDGPU::V_CMPX_CLASS_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30053 /* v_cmpx_class_f16_e32 */, AMDGPU::V_CMPX_CLASS_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30053 /* v_cmpx_class_f16_e32 */, AMDGPU::V_CMPX_CLASS_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30053 /* v_cmpx_class_f16_e32 */, AMDGPU::V_CMPX_CLASS_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30053 /* v_cmpx_class_f16_e32 */, AMDGPU::V_CMPX_CLASS_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30074 /* V_CMPX_CLASS_F32 */, AMDGPU::V_CMPX_CLASS_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30074 /* V_CMPX_CLASS_F32 */, AMDGPU::V_CMPX_CLASS_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30074 /* V_CMPX_CLASS_F32 */, AMDGPU::V_CMPX_CLASS_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30074 /* V_CMPX_CLASS_F32 */, AMDGPU::V_CMPX_CLASS_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30074 /* V_CMPX_CLASS_F32 */, AMDGPU::V_CMPX_CLASS_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30074 /* V_CMPX_CLASS_F32 */, AMDGPU::V_CMPX_CLASS_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30074 /* V_CMPX_CLASS_F32 */, AMDGPU::V_CMPX_CLASS_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30074 /* V_CMPX_CLASS_F32 */, AMDGPU::V_CMPX_CLASS_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30074 /* V_CMPX_CLASS_F32 */, AMDGPU::V_CMPX_CLASS_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30091 /* v_cmpx_class_f32_e32 */, AMDGPU::V_CMPX_CLASS_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30091 /* v_cmpx_class_f32_e32 */, AMDGPU::V_CMPX_CLASS_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30091 /* v_cmpx_class_f32_e32 */, AMDGPU::V_CMPX_CLASS_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30091 /* v_cmpx_class_f32_e32 */, AMDGPU::V_CMPX_CLASS_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30091 /* v_cmpx_class_f32_e32 */, AMDGPU::V_CMPX_CLASS_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30112 /* V_CMPX_CLASS_F64 */, AMDGPU::V_CMPX_CLASS_F64_e32_gfx11, Convert__VSrc_f641_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 30112 /* V_CMPX_CLASS_F64 */, AMDGPU::V_CMPX_CLASS_F64_e32_gfx12, Convert__VSrc_f641_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 30112 /* V_CMPX_CLASS_F64 */, AMDGPU::V_CMPX_CLASS_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 30112 /* V_CMPX_CLASS_F64 */, AMDGPU::V_CMPX_CLASS_F64_e32_gfx10, Convert__VSrc_f641_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 30112 /* V_CMPX_CLASS_F64 */, AMDGPU::V_CMPX_CLASS_F64_e32_vi, Convert__VSrc_f641_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 30112 /* V_CMPX_CLASS_F64 */, AMDGPU::V_CMPX_CLASS_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 30112 /* V_CMPX_CLASS_F64 */, AMDGPU::V_CMPX_CLASS_F64_e32_vi, Convert__VSrc_f641_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 30112 /* V_CMPX_CLASS_F64 */, AMDGPU::V_CMPX_CLASS_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 30112 /* V_CMPX_CLASS_F64 */, AMDGPU::V_CMPX_CLASS_F64_e32_vi, Convert__VSrc_f641_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 30129 /* v_cmpx_class_f64_e32 */, AMDGPU::V_CMPX_CLASS_F64_e32_gfx10, Convert__VSrc_f641_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 30129 /* v_cmpx_class_f64_e32 */, AMDGPU::V_CMPX_CLASS_F64_e32_gfx11, Convert__VSrc_f641_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 30129 /* v_cmpx_class_f64_e32 */, AMDGPU::V_CMPX_CLASS_F64_e32_gfx12, Convert__VSrc_f641_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 30129 /* v_cmpx_class_f64_e32 */, AMDGPU::V_CMPX_CLASS_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 30129 /* v_cmpx_class_f64_e32 */, AMDGPU::V_CMPX_CLASS_F64_e32_vi, Convert__VSrc_f641_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_VGPR_32 }, },
  { 30150 /* V_CMPX_EQ_F16 */, AMDGPU::V_CMPX_EQ_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30150 /* V_CMPX_EQ_F16 */, AMDGPU::V_CMPX_EQ_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30150 /* V_CMPX_EQ_F16 */, AMDGPU::V_CMPX_EQ_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30150 /* V_CMPX_EQ_F16 */, AMDGPU::V_CMPX_EQ_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30164 /* v_cmpx_eq_f16_e32 */, AMDGPU::V_CMPX_EQ_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30164 /* v_cmpx_eq_f16_e32 */, AMDGPU::V_CMPX_EQ_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30164 /* v_cmpx_eq_f16_e32 */, AMDGPU::V_CMPX_EQ_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30164 /* v_cmpx_eq_f16_e32 */, AMDGPU::V_CMPX_EQ_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30164 /* v_cmpx_eq_f16_e32 */, AMDGPU::V_CMPX_EQ_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30164 /* v_cmpx_eq_f16_e32 */, AMDGPU::V_CMPX_EQ_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30182 /* V_CMPX_EQ_F32 */, AMDGPU::V_CMPX_EQ_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30182 /* V_CMPX_EQ_F32 */, AMDGPU::V_CMPX_EQ_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30182 /* V_CMPX_EQ_F32 */, AMDGPU::V_CMPX_EQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30182 /* V_CMPX_EQ_F32 */, AMDGPU::V_CMPX_EQ_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30182 /* V_CMPX_EQ_F32 */, AMDGPU::V_CMPX_EQ_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30182 /* V_CMPX_EQ_F32 */, AMDGPU::V_CMPX_EQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30182 /* V_CMPX_EQ_F32 */, AMDGPU::V_CMPX_EQ_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30182 /* V_CMPX_EQ_F32 */, AMDGPU::V_CMPX_EQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30182 /* V_CMPX_EQ_F32 */, AMDGPU::V_CMPX_EQ_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30196 /* v_cmpx_eq_f32_e32 */, AMDGPU::V_CMPX_EQ_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30196 /* v_cmpx_eq_f32_e32 */, AMDGPU::V_CMPX_EQ_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30196 /* v_cmpx_eq_f32_e32 */, AMDGPU::V_CMPX_EQ_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30196 /* v_cmpx_eq_f32_e32 */, AMDGPU::V_CMPX_EQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30196 /* v_cmpx_eq_f32_e32 */, AMDGPU::V_CMPX_EQ_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30214 /* V_CMPX_EQ_F64 */, AMDGPU::V_CMPX_EQ_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30214 /* V_CMPX_EQ_F64 */, AMDGPU::V_CMPX_EQ_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30214 /* V_CMPX_EQ_F64 */, AMDGPU::V_CMPX_EQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30214 /* V_CMPX_EQ_F64 */, AMDGPU::V_CMPX_EQ_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30214 /* V_CMPX_EQ_F64 */, AMDGPU::V_CMPX_EQ_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30214 /* V_CMPX_EQ_F64 */, AMDGPU::V_CMPX_EQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30214 /* V_CMPX_EQ_F64 */, AMDGPU::V_CMPX_EQ_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30214 /* V_CMPX_EQ_F64 */, AMDGPU::V_CMPX_EQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30214 /* V_CMPX_EQ_F64 */, AMDGPU::V_CMPX_EQ_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30228 /* v_cmpx_eq_f64_e32 */, AMDGPU::V_CMPX_EQ_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30228 /* v_cmpx_eq_f64_e32 */, AMDGPU::V_CMPX_EQ_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30228 /* v_cmpx_eq_f64_e32 */, AMDGPU::V_CMPX_EQ_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30228 /* v_cmpx_eq_f64_e32 */, AMDGPU::V_CMPX_EQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30228 /* v_cmpx_eq_f64_e32 */, AMDGPU::V_CMPX_EQ_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30246 /* V_CMPX_EQ_I16 */, AMDGPU::V_CMPX_EQ_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30246 /* V_CMPX_EQ_I16 */, AMDGPU::V_CMPX_EQ_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30246 /* V_CMPX_EQ_I16 */, AMDGPU::V_CMPX_EQ_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30246 /* V_CMPX_EQ_I16 */, AMDGPU::V_CMPX_EQ_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30260 /* v_cmpx_eq_i16_e32 */, AMDGPU::V_CMPX_EQ_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30260 /* v_cmpx_eq_i16_e32 */, AMDGPU::V_CMPX_EQ_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30260 /* v_cmpx_eq_i16_e32 */, AMDGPU::V_CMPX_EQ_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30260 /* v_cmpx_eq_i16_e32 */, AMDGPU::V_CMPX_EQ_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30260 /* v_cmpx_eq_i16_e32 */, AMDGPU::V_CMPX_EQ_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30260 /* v_cmpx_eq_i16_e32 */, AMDGPU::V_CMPX_EQ_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30278 /* V_CMPX_EQ_I32 */, AMDGPU::V_CMPX_EQ_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30278 /* V_CMPX_EQ_I32 */, AMDGPU::V_CMPX_EQ_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30278 /* V_CMPX_EQ_I32 */, AMDGPU::V_CMPX_EQ_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30278 /* V_CMPX_EQ_I32 */, AMDGPU::V_CMPX_EQ_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30278 /* V_CMPX_EQ_I32 */, AMDGPU::V_CMPX_EQ_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30278 /* V_CMPX_EQ_I32 */, AMDGPU::V_CMPX_EQ_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30278 /* V_CMPX_EQ_I32 */, AMDGPU::V_CMPX_EQ_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30278 /* V_CMPX_EQ_I32 */, AMDGPU::V_CMPX_EQ_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30278 /* V_CMPX_EQ_I32 */, AMDGPU::V_CMPX_EQ_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30292 /* v_cmpx_eq_i32_e32 */, AMDGPU::V_CMPX_EQ_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30292 /* v_cmpx_eq_i32_e32 */, AMDGPU::V_CMPX_EQ_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30292 /* v_cmpx_eq_i32_e32 */, AMDGPU::V_CMPX_EQ_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30292 /* v_cmpx_eq_i32_e32 */, AMDGPU::V_CMPX_EQ_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30292 /* v_cmpx_eq_i32_e32 */, AMDGPU::V_CMPX_EQ_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30310 /* V_CMPX_EQ_I64 */, AMDGPU::V_CMPX_EQ_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30310 /* V_CMPX_EQ_I64 */, AMDGPU::V_CMPX_EQ_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30310 /* V_CMPX_EQ_I64 */, AMDGPU::V_CMPX_EQ_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30310 /* V_CMPX_EQ_I64 */, AMDGPU::V_CMPX_EQ_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30310 /* V_CMPX_EQ_I64 */, AMDGPU::V_CMPX_EQ_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30310 /* V_CMPX_EQ_I64 */, AMDGPU::V_CMPX_EQ_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30310 /* V_CMPX_EQ_I64 */, AMDGPU::V_CMPX_EQ_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30310 /* V_CMPX_EQ_I64 */, AMDGPU::V_CMPX_EQ_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30310 /* V_CMPX_EQ_I64 */, AMDGPU::V_CMPX_EQ_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30324 /* v_cmpx_eq_i64_e32 */, AMDGPU::V_CMPX_EQ_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30324 /* v_cmpx_eq_i64_e32 */, AMDGPU::V_CMPX_EQ_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30324 /* v_cmpx_eq_i64_e32 */, AMDGPU::V_CMPX_EQ_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30324 /* v_cmpx_eq_i64_e32 */, AMDGPU::V_CMPX_EQ_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30324 /* v_cmpx_eq_i64_e32 */, AMDGPU::V_CMPX_EQ_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30342 /* V_CMPX_EQ_U16 */, AMDGPU::V_CMPX_EQ_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30342 /* V_CMPX_EQ_U16 */, AMDGPU::V_CMPX_EQ_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30342 /* V_CMPX_EQ_U16 */, AMDGPU::V_CMPX_EQ_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30342 /* V_CMPX_EQ_U16 */, AMDGPU::V_CMPX_EQ_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30356 /* v_cmpx_eq_u16_e32 */, AMDGPU::V_CMPX_EQ_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30356 /* v_cmpx_eq_u16_e32 */, AMDGPU::V_CMPX_EQ_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30356 /* v_cmpx_eq_u16_e32 */, AMDGPU::V_CMPX_EQ_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30356 /* v_cmpx_eq_u16_e32 */, AMDGPU::V_CMPX_EQ_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30356 /* v_cmpx_eq_u16_e32 */, AMDGPU::V_CMPX_EQ_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30356 /* v_cmpx_eq_u16_e32 */, AMDGPU::V_CMPX_EQ_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30374 /* V_CMPX_EQ_U32 */, AMDGPU::V_CMPX_EQ_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30374 /* V_CMPX_EQ_U32 */, AMDGPU::V_CMPX_EQ_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30374 /* V_CMPX_EQ_U32 */, AMDGPU::V_CMPX_EQ_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30374 /* V_CMPX_EQ_U32 */, AMDGPU::V_CMPX_EQ_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30374 /* V_CMPX_EQ_U32 */, AMDGPU::V_CMPX_EQ_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30374 /* V_CMPX_EQ_U32 */, AMDGPU::V_CMPX_EQ_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30374 /* V_CMPX_EQ_U32 */, AMDGPU::V_CMPX_EQ_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30374 /* V_CMPX_EQ_U32 */, AMDGPU::V_CMPX_EQ_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30374 /* V_CMPX_EQ_U32 */, AMDGPU::V_CMPX_EQ_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30388 /* v_cmpx_eq_u32_e32 */, AMDGPU::V_CMPX_EQ_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30388 /* v_cmpx_eq_u32_e32 */, AMDGPU::V_CMPX_EQ_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30388 /* v_cmpx_eq_u32_e32 */, AMDGPU::V_CMPX_EQ_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30388 /* v_cmpx_eq_u32_e32 */, AMDGPU::V_CMPX_EQ_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30388 /* v_cmpx_eq_u32_e32 */, AMDGPU::V_CMPX_EQ_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30406 /* V_CMPX_EQ_U64 */, AMDGPU::V_CMPX_EQ_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30406 /* V_CMPX_EQ_U64 */, AMDGPU::V_CMPX_EQ_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30406 /* V_CMPX_EQ_U64 */, AMDGPU::V_CMPX_EQ_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30406 /* V_CMPX_EQ_U64 */, AMDGPU::V_CMPX_EQ_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30406 /* V_CMPX_EQ_U64 */, AMDGPU::V_CMPX_EQ_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30406 /* V_CMPX_EQ_U64 */, AMDGPU::V_CMPX_EQ_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30406 /* V_CMPX_EQ_U64 */, AMDGPU::V_CMPX_EQ_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30406 /* V_CMPX_EQ_U64 */, AMDGPU::V_CMPX_EQ_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30406 /* V_CMPX_EQ_U64 */, AMDGPU::V_CMPX_EQ_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30420 /* v_cmpx_eq_u64_e32 */, AMDGPU::V_CMPX_EQ_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30420 /* v_cmpx_eq_u64_e32 */, AMDGPU::V_CMPX_EQ_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30420 /* v_cmpx_eq_u64_e32 */, AMDGPU::V_CMPX_EQ_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30420 /* v_cmpx_eq_u64_e32 */, AMDGPU::V_CMPX_EQ_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30420 /* v_cmpx_eq_u64_e32 */, AMDGPU::V_CMPX_EQ_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30438 /* V_CMPX_F_F16 */, AMDGPU::V_CMPX_F_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30438 /* V_CMPX_F_F16 */, AMDGPU::V_CMPX_F_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30438 /* v_cmpx_f_f16 */, AMDGPU::V_CMPX_F_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30438 /* v_cmpx_f_f16 */, AMDGPU::V_CMPX_F_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30438 /* V_CMPX_F_F16 */, AMDGPU::V_CMPX_F_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30438 /* V_CMPX_F_F16 */, AMDGPU::V_CMPX_F_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30451 /* v_cmpx_f_f16_e32 */, AMDGPU::V_CMPX_F_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30451 /* v_cmpx_f_f16_e32 */, AMDGPU::V_CMPX_F_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30451 /* v_cmpx_f_f16_e32 */, AMDGPU::V_CMPX_F_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30451 /* v_cmpx_f_f16_e32 */, AMDGPU::V_CMPX_F_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30468 /* V_CMPX_F_F32 */, AMDGPU::V_CMPX_F_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30468 /* V_CMPX_F_F32 */, AMDGPU::V_CMPX_F_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30468 /* V_CMPX_F_F32 */, AMDGPU::V_CMPX_F_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30468 /* V_CMPX_F_F32 */, AMDGPU::V_CMPX_F_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30468 /* V_CMPX_F_F32 */, AMDGPU::V_CMPX_F_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30468 /* V_CMPX_F_F32 */, AMDGPU::V_CMPX_F_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30468 /* V_CMPX_F_F32 */, AMDGPU::V_CMPX_F_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30468 /* V_CMPX_F_F32 */, AMDGPU::V_CMPX_F_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30481 /* v_cmpx_f_f32_e32 */, AMDGPU::V_CMPX_F_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30481 /* v_cmpx_f_f32_e32 */, AMDGPU::V_CMPX_F_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30481 /* v_cmpx_f_f32_e32 */, AMDGPU::V_CMPX_F_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30481 /* v_cmpx_f_f32_e32 */, AMDGPU::V_CMPX_F_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30498 /* V_CMPX_F_F64 */, AMDGPU::V_CMPX_F_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30498 /* V_CMPX_F_F64 */, AMDGPU::V_CMPX_F_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30498 /* V_CMPX_F_F64 */, AMDGPU::V_CMPX_F_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30498 /* V_CMPX_F_F64 */, AMDGPU::V_CMPX_F_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30498 /* V_CMPX_F_F64 */, AMDGPU::V_CMPX_F_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30498 /* V_CMPX_F_F64 */, AMDGPU::V_CMPX_F_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30498 /* V_CMPX_F_F64 */, AMDGPU::V_CMPX_F_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30498 /* V_CMPX_F_F64 */, AMDGPU::V_CMPX_F_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30511 /* v_cmpx_f_f64_e32 */, AMDGPU::V_CMPX_F_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30511 /* v_cmpx_f_f64_e32 */, AMDGPU::V_CMPX_F_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30511 /* v_cmpx_f_f64_e32 */, AMDGPU::V_CMPX_F_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30511 /* v_cmpx_f_f64_e32 */, AMDGPU::V_CMPX_F_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30528 /* V_CMPX_F_I16 */, AMDGPU::V_CMPX_F_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30528 /* V_CMPX_F_I16 */, AMDGPU::V_CMPX_F_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30528 /* V_CMPX_F_I16 */, AMDGPU::V_CMPX_F_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30541 /* v_cmpx_f_i16_e32 */, AMDGPU::V_CMPX_F_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30558 /* V_CMPX_F_I32 */, AMDGPU::V_CMPX_F_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30558 /* V_CMPX_F_I32 */, AMDGPU::V_CMPX_F_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30558 /* V_CMPX_F_I32 */, AMDGPU::V_CMPX_F_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30558 /* V_CMPX_F_I32 */, AMDGPU::V_CMPX_F_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30558 /* V_CMPX_F_I32 */, AMDGPU::V_CMPX_F_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30558 /* V_CMPX_F_I32 */, AMDGPU::V_CMPX_F_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30558 /* V_CMPX_F_I32 */, AMDGPU::V_CMPX_F_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30558 /* V_CMPX_F_I32 */, AMDGPU::V_CMPX_F_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30571 /* v_cmpx_f_i32_e32 */, AMDGPU::V_CMPX_F_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30571 /* v_cmpx_f_i32_e32 */, AMDGPU::V_CMPX_F_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30571 /* v_cmpx_f_i32_e32 */, AMDGPU::V_CMPX_F_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30571 /* v_cmpx_f_i32_e32 */, AMDGPU::V_CMPX_F_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30588 /* V_CMPX_F_I64 */, AMDGPU::V_CMPX_F_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30588 /* V_CMPX_F_I64 */, AMDGPU::V_CMPX_F_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30588 /* V_CMPX_F_I64 */, AMDGPU::V_CMPX_F_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30588 /* V_CMPX_F_I64 */, AMDGPU::V_CMPX_F_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30588 /* V_CMPX_F_I64 */, AMDGPU::V_CMPX_F_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30588 /* V_CMPX_F_I64 */, AMDGPU::V_CMPX_F_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30588 /* V_CMPX_F_I64 */, AMDGPU::V_CMPX_F_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30588 /* V_CMPX_F_I64 */, AMDGPU::V_CMPX_F_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30601 /* v_cmpx_f_i64_e32 */, AMDGPU::V_CMPX_F_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30601 /* v_cmpx_f_i64_e32 */, AMDGPU::V_CMPX_F_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30601 /* v_cmpx_f_i64_e32 */, AMDGPU::V_CMPX_F_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30601 /* v_cmpx_f_i64_e32 */, AMDGPU::V_CMPX_F_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30618 /* V_CMPX_F_U16 */, AMDGPU::V_CMPX_F_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30618 /* V_CMPX_F_U16 */, AMDGPU::V_CMPX_F_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30618 /* V_CMPX_F_U16 */, AMDGPU::V_CMPX_F_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30631 /* v_cmpx_f_u16_e32 */, AMDGPU::V_CMPX_F_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30648 /* V_CMPX_F_U32 */, AMDGPU::V_CMPX_F_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30648 /* V_CMPX_F_U32 */, AMDGPU::V_CMPX_F_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30648 /* V_CMPX_F_U32 */, AMDGPU::V_CMPX_F_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30648 /* V_CMPX_F_U32 */, AMDGPU::V_CMPX_F_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30648 /* V_CMPX_F_U32 */, AMDGPU::V_CMPX_F_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30648 /* V_CMPX_F_U32 */, AMDGPU::V_CMPX_F_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30648 /* V_CMPX_F_U32 */, AMDGPU::V_CMPX_F_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30648 /* V_CMPX_F_U32 */, AMDGPU::V_CMPX_F_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30661 /* v_cmpx_f_u32_e32 */, AMDGPU::V_CMPX_F_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30661 /* v_cmpx_f_u32_e32 */, AMDGPU::V_CMPX_F_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30661 /* v_cmpx_f_u32_e32 */, AMDGPU::V_CMPX_F_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30661 /* v_cmpx_f_u32_e32 */, AMDGPU::V_CMPX_F_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30678 /* V_CMPX_F_U64 */, AMDGPU::V_CMPX_F_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30678 /* V_CMPX_F_U64 */, AMDGPU::V_CMPX_F_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30678 /* V_CMPX_F_U64 */, AMDGPU::V_CMPX_F_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30678 /* V_CMPX_F_U64 */, AMDGPU::V_CMPX_F_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30678 /* V_CMPX_F_U64 */, AMDGPU::V_CMPX_F_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30678 /* V_CMPX_F_U64 */, AMDGPU::V_CMPX_F_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30678 /* V_CMPX_F_U64 */, AMDGPU::V_CMPX_F_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30678 /* V_CMPX_F_U64 */, AMDGPU::V_CMPX_F_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30691 /* v_cmpx_f_u64_e32 */, AMDGPU::V_CMPX_F_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30691 /* v_cmpx_f_u64_e32 */, AMDGPU::V_CMPX_F_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30691 /* v_cmpx_f_u64_e32 */, AMDGPU::V_CMPX_F_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30691 /* v_cmpx_f_u64_e32 */, AMDGPU::V_CMPX_F_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30708 /* V_CMPX_GE_F16 */, AMDGPU::V_CMPX_GE_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30708 /* V_CMPX_GE_F16 */, AMDGPU::V_CMPX_GE_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30708 /* V_CMPX_GE_F16 */, AMDGPU::V_CMPX_GE_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30708 /* V_CMPX_GE_F16 */, AMDGPU::V_CMPX_GE_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30722 /* v_cmpx_ge_f16_e32 */, AMDGPU::V_CMPX_GE_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30722 /* v_cmpx_ge_f16_e32 */, AMDGPU::V_CMPX_GE_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30722 /* v_cmpx_ge_f16_e32 */, AMDGPU::V_CMPX_GE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30722 /* v_cmpx_ge_f16_e32 */, AMDGPU::V_CMPX_GE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30722 /* v_cmpx_ge_f16_e32 */, AMDGPU::V_CMPX_GE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30722 /* v_cmpx_ge_f16_e32 */, AMDGPU::V_CMPX_GE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30740 /* V_CMPX_GE_F32 */, AMDGPU::V_CMPX_GE_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30740 /* V_CMPX_GE_F32 */, AMDGPU::V_CMPX_GE_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30740 /* V_CMPX_GE_F32 */, AMDGPU::V_CMPX_GE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30740 /* V_CMPX_GE_F32 */, AMDGPU::V_CMPX_GE_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30740 /* V_CMPX_GE_F32 */, AMDGPU::V_CMPX_GE_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30740 /* V_CMPX_GE_F32 */, AMDGPU::V_CMPX_GE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30740 /* V_CMPX_GE_F32 */, AMDGPU::V_CMPX_GE_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30740 /* V_CMPX_GE_F32 */, AMDGPU::V_CMPX_GE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30740 /* V_CMPX_GE_F32 */, AMDGPU::V_CMPX_GE_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30754 /* v_cmpx_ge_f32_e32 */, AMDGPU::V_CMPX_GE_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30754 /* v_cmpx_ge_f32_e32 */, AMDGPU::V_CMPX_GE_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30754 /* v_cmpx_ge_f32_e32 */, AMDGPU::V_CMPX_GE_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30754 /* v_cmpx_ge_f32_e32 */, AMDGPU::V_CMPX_GE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30754 /* v_cmpx_ge_f32_e32 */, AMDGPU::V_CMPX_GE_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 30772 /* V_CMPX_GE_F64 */, AMDGPU::V_CMPX_GE_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30772 /* V_CMPX_GE_F64 */, AMDGPU::V_CMPX_GE_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30772 /* V_CMPX_GE_F64 */, AMDGPU::V_CMPX_GE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30772 /* V_CMPX_GE_F64 */, AMDGPU::V_CMPX_GE_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30772 /* V_CMPX_GE_F64 */, AMDGPU::V_CMPX_GE_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30772 /* V_CMPX_GE_F64 */, AMDGPU::V_CMPX_GE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30772 /* V_CMPX_GE_F64 */, AMDGPU::V_CMPX_GE_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30772 /* V_CMPX_GE_F64 */, AMDGPU::V_CMPX_GE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30772 /* V_CMPX_GE_F64 */, AMDGPU::V_CMPX_GE_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30786 /* v_cmpx_ge_f64_e32 */, AMDGPU::V_CMPX_GE_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30786 /* v_cmpx_ge_f64_e32 */, AMDGPU::V_CMPX_GE_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30786 /* v_cmpx_ge_f64_e32 */, AMDGPU::V_CMPX_GE_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30786 /* v_cmpx_ge_f64_e32 */, AMDGPU::V_CMPX_GE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30786 /* v_cmpx_ge_f64_e32 */, AMDGPU::V_CMPX_GE_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30804 /* V_CMPX_GE_I16 */, AMDGPU::V_CMPX_GE_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30804 /* V_CMPX_GE_I16 */, AMDGPU::V_CMPX_GE_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30804 /* V_CMPX_GE_I16 */, AMDGPU::V_CMPX_GE_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30804 /* V_CMPX_GE_I16 */, AMDGPU::V_CMPX_GE_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30818 /* v_cmpx_ge_i16_e32 */, AMDGPU::V_CMPX_GE_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30818 /* v_cmpx_ge_i16_e32 */, AMDGPU::V_CMPX_GE_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30818 /* v_cmpx_ge_i16_e32 */, AMDGPU::V_CMPX_GE_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30818 /* v_cmpx_ge_i16_e32 */, AMDGPU::V_CMPX_GE_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30818 /* v_cmpx_ge_i16_e32 */, AMDGPU::V_CMPX_GE_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30818 /* v_cmpx_ge_i16_e32 */, AMDGPU::V_CMPX_GE_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30836 /* V_CMPX_GE_I32 */, AMDGPU::V_CMPX_GE_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30836 /* V_CMPX_GE_I32 */, AMDGPU::V_CMPX_GE_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30836 /* V_CMPX_GE_I32 */, AMDGPU::V_CMPX_GE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30836 /* V_CMPX_GE_I32 */, AMDGPU::V_CMPX_GE_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30836 /* V_CMPX_GE_I32 */, AMDGPU::V_CMPX_GE_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30836 /* V_CMPX_GE_I32 */, AMDGPU::V_CMPX_GE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30836 /* V_CMPX_GE_I32 */, AMDGPU::V_CMPX_GE_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30836 /* V_CMPX_GE_I32 */, AMDGPU::V_CMPX_GE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30836 /* V_CMPX_GE_I32 */, AMDGPU::V_CMPX_GE_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30850 /* v_cmpx_ge_i32_e32 */, AMDGPU::V_CMPX_GE_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30850 /* v_cmpx_ge_i32_e32 */, AMDGPU::V_CMPX_GE_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30850 /* v_cmpx_ge_i32_e32 */, AMDGPU::V_CMPX_GE_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30850 /* v_cmpx_ge_i32_e32 */, AMDGPU::V_CMPX_GE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30850 /* v_cmpx_ge_i32_e32 */, AMDGPU::V_CMPX_GE_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30868 /* V_CMPX_GE_I64 */, AMDGPU::V_CMPX_GE_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30868 /* V_CMPX_GE_I64 */, AMDGPU::V_CMPX_GE_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30868 /* V_CMPX_GE_I64 */, AMDGPU::V_CMPX_GE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30868 /* V_CMPX_GE_I64 */, AMDGPU::V_CMPX_GE_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30868 /* V_CMPX_GE_I64 */, AMDGPU::V_CMPX_GE_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30868 /* V_CMPX_GE_I64 */, AMDGPU::V_CMPX_GE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30868 /* V_CMPX_GE_I64 */, AMDGPU::V_CMPX_GE_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30868 /* V_CMPX_GE_I64 */, AMDGPU::V_CMPX_GE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30868 /* V_CMPX_GE_I64 */, AMDGPU::V_CMPX_GE_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30882 /* v_cmpx_ge_i64_e32 */, AMDGPU::V_CMPX_GE_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30882 /* v_cmpx_ge_i64_e32 */, AMDGPU::V_CMPX_GE_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30882 /* v_cmpx_ge_i64_e32 */, AMDGPU::V_CMPX_GE_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30882 /* v_cmpx_ge_i64_e32 */, AMDGPU::V_CMPX_GE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30882 /* v_cmpx_ge_i64_e32 */, AMDGPU::V_CMPX_GE_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30900 /* V_CMPX_GE_U16 */, AMDGPU::V_CMPX_GE_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30900 /* V_CMPX_GE_U16 */, AMDGPU::V_CMPX_GE_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30900 /* V_CMPX_GE_U16 */, AMDGPU::V_CMPX_GE_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30900 /* V_CMPX_GE_U16 */, AMDGPU::V_CMPX_GE_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30914 /* v_cmpx_ge_u16_e32 */, AMDGPU::V_CMPX_GE_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30914 /* v_cmpx_ge_u16_e32 */, AMDGPU::V_CMPX_GE_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 30914 /* v_cmpx_ge_u16_e32 */, AMDGPU::V_CMPX_GE_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30914 /* v_cmpx_ge_u16_e32 */, AMDGPU::V_CMPX_GE_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30914 /* v_cmpx_ge_u16_e32 */, AMDGPU::V_CMPX_GE_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30914 /* v_cmpx_ge_u16_e32 */, AMDGPU::V_CMPX_GE_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30932 /* V_CMPX_GE_U32 */, AMDGPU::V_CMPX_GE_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30932 /* V_CMPX_GE_U32 */, AMDGPU::V_CMPX_GE_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30932 /* V_CMPX_GE_U32 */, AMDGPU::V_CMPX_GE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30932 /* V_CMPX_GE_U32 */, AMDGPU::V_CMPX_GE_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30932 /* V_CMPX_GE_U32 */, AMDGPU::V_CMPX_GE_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30932 /* V_CMPX_GE_U32 */, AMDGPU::V_CMPX_GE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30932 /* V_CMPX_GE_U32 */, AMDGPU::V_CMPX_GE_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30932 /* V_CMPX_GE_U32 */, AMDGPU::V_CMPX_GE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30932 /* V_CMPX_GE_U32 */, AMDGPU::V_CMPX_GE_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30946 /* v_cmpx_ge_u32_e32 */, AMDGPU::V_CMPX_GE_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30946 /* v_cmpx_ge_u32_e32 */, AMDGPU::V_CMPX_GE_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30946 /* v_cmpx_ge_u32_e32 */, AMDGPU::V_CMPX_GE_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30946 /* v_cmpx_ge_u32_e32 */, AMDGPU::V_CMPX_GE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30946 /* v_cmpx_ge_u32_e32 */, AMDGPU::V_CMPX_GE_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 30964 /* V_CMPX_GE_U64 */, AMDGPU::V_CMPX_GE_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30964 /* V_CMPX_GE_U64 */, AMDGPU::V_CMPX_GE_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30964 /* V_CMPX_GE_U64 */, AMDGPU::V_CMPX_GE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30964 /* V_CMPX_GE_U64 */, AMDGPU::V_CMPX_GE_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30964 /* V_CMPX_GE_U64 */, AMDGPU::V_CMPX_GE_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30964 /* V_CMPX_GE_U64 */, AMDGPU::V_CMPX_GE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30964 /* V_CMPX_GE_U64 */, AMDGPU::V_CMPX_GE_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30964 /* V_CMPX_GE_U64 */, AMDGPU::V_CMPX_GE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30964 /* V_CMPX_GE_U64 */, AMDGPU::V_CMPX_GE_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30978 /* v_cmpx_ge_u64_e32 */, AMDGPU::V_CMPX_GE_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30978 /* v_cmpx_ge_u64_e32 */, AMDGPU::V_CMPX_GE_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30978 /* v_cmpx_ge_u64_e32 */, AMDGPU::V_CMPX_GE_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30978 /* v_cmpx_ge_u64_e32 */, AMDGPU::V_CMPX_GE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30978 /* v_cmpx_ge_u64_e32 */, AMDGPU::V_CMPX_GE_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 30996 /* V_CMPX_GT_F16 */, AMDGPU::V_CMPX_GT_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30996 /* V_CMPX_GT_F16 */, AMDGPU::V_CMPX_GT_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 30996 /* V_CMPX_GT_F16 */, AMDGPU::V_CMPX_GT_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 30996 /* V_CMPX_GT_F16 */, AMDGPU::V_CMPX_GT_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 31010 /* v_cmpx_gt_f16_e32 */, AMDGPU::V_CMPX_GT_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 31010 /* v_cmpx_gt_f16_e32 */, AMDGPU::V_CMPX_GT_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 31010 /* v_cmpx_gt_f16_e32 */, AMDGPU::V_CMPX_GT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31010 /* v_cmpx_gt_f16_e32 */, AMDGPU::V_CMPX_GT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31010 /* v_cmpx_gt_f16_e32 */, AMDGPU::V_CMPX_GT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31010 /* v_cmpx_gt_f16_e32 */, AMDGPU::V_CMPX_GT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31028 /* V_CMPX_GT_F32 */, AMDGPU::V_CMPX_GT_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31028 /* V_CMPX_GT_F32 */, AMDGPU::V_CMPX_GT_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31028 /* V_CMPX_GT_F32 */, AMDGPU::V_CMPX_GT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31028 /* V_CMPX_GT_F32 */, AMDGPU::V_CMPX_GT_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31028 /* V_CMPX_GT_F32 */, AMDGPU::V_CMPX_GT_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31028 /* V_CMPX_GT_F32 */, AMDGPU::V_CMPX_GT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31028 /* V_CMPX_GT_F32 */, AMDGPU::V_CMPX_GT_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31028 /* V_CMPX_GT_F32 */, AMDGPU::V_CMPX_GT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31028 /* V_CMPX_GT_F32 */, AMDGPU::V_CMPX_GT_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31042 /* v_cmpx_gt_f32_e32 */, AMDGPU::V_CMPX_GT_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31042 /* v_cmpx_gt_f32_e32 */, AMDGPU::V_CMPX_GT_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31042 /* v_cmpx_gt_f32_e32 */, AMDGPU::V_CMPX_GT_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31042 /* v_cmpx_gt_f32_e32 */, AMDGPU::V_CMPX_GT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31042 /* v_cmpx_gt_f32_e32 */, AMDGPU::V_CMPX_GT_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31060 /* V_CMPX_GT_F64 */, AMDGPU::V_CMPX_GT_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31060 /* V_CMPX_GT_F64 */, AMDGPU::V_CMPX_GT_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31060 /* V_CMPX_GT_F64 */, AMDGPU::V_CMPX_GT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31060 /* V_CMPX_GT_F64 */, AMDGPU::V_CMPX_GT_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31060 /* V_CMPX_GT_F64 */, AMDGPU::V_CMPX_GT_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31060 /* V_CMPX_GT_F64 */, AMDGPU::V_CMPX_GT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31060 /* V_CMPX_GT_F64 */, AMDGPU::V_CMPX_GT_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31060 /* V_CMPX_GT_F64 */, AMDGPU::V_CMPX_GT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31060 /* V_CMPX_GT_F64 */, AMDGPU::V_CMPX_GT_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31074 /* v_cmpx_gt_f64_e32 */, AMDGPU::V_CMPX_GT_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31074 /* v_cmpx_gt_f64_e32 */, AMDGPU::V_CMPX_GT_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31074 /* v_cmpx_gt_f64_e32 */, AMDGPU::V_CMPX_GT_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31074 /* v_cmpx_gt_f64_e32 */, AMDGPU::V_CMPX_GT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31074 /* v_cmpx_gt_f64_e32 */, AMDGPU::V_CMPX_GT_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31092 /* V_CMPX_GT_I16 */, AMDGPU::V_CMPX_GT_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31092 /* V_CMPX_GT_I16 */, AMDGPU::V_CMPX_GT_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31092 /* V_CMPX_GT_I16 */, AMDGPU::V_CMPX_GT_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31092 /* V_CMPX_GT_I16 */, AMDGPU::V_CMPX_GT_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31106 /* v_cmpx_gt_i16_e32 */, AMDGPU::V_CMPX_GT_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31106 /* v_cmpx_gt_i16_e32 */, AMDGPU::V_CMPX_GT_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31106 /* v_cmpx_gt_i16_e32 */, AMDGPU::V_CMPX_GT_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31106 /* v_cmpx_gt_i16_e32 */, AMDGPU::V_CMPX_GT_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31106 /* v_cmpx_gt_i16_e32 */, AMDGPU::V_CMPX_GT_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31106 /* v_cmpx_gt_i16_e32 */, AMDGPU::V_CMPX_GT_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31124 /* V_CMPX_GT_I32 */, AMDGPU::V_CMPX_GT_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31124 /* V_CMPX_GT_I32 */, AMDGPU::V_CMPX_GT_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31124 /* V_CMPX_GT_I32 */, AMDGPU::V_CMPX_GT_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31124 /* V_CMPX_GT_I32 */, AMDGPU::V_CMPX_GT_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31124 /* V_CMPX_GT_I32 */, AMDGPU::V_CMPX_GT_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31124 /* V_CMPX_GT_I32 */, AMDGPU::V_CMPX_GT_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31124 /* V_CMPX_GT_I32 */, AMDGPU::V_CMPX_GT_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31124 /* V_CMPX_GT_I32 */, AMDGPU::V_CMPX_GT_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31124 /* V_CMPX_GT_I32 */, AMDGPU::V_CMPX_GT_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31138 /* v_cmpx_gt_i32_e32 */, AMDGPU::V_CMPX_GT_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31138 /* v_cmpx_gt_i32_e32 */, AMDGPU::V_CMPX_GT_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31138 /* v_cmpx_gt_i32_e32 */, AMDGPU::V_CMPX_GT_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31138 /* v_cmpx_gt_i32_e32 */, AMDGPU::V_CMPX_GT_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31138 /* v_cmpx_gt_i32_e32 */, AMDGPU::V_CMPX_GT_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31156 /* V_CMPX_GT_I64 */, AMDGPU::V_CMPX_GT_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31156 /* V_CMPX_GT_I64 */, AMDGPU::V_CMPX_GT_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31156 /* V_CMPX_GT_I64 */, AMDGPU::V_CMPX_GT_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31156 /* V_CMPX_GT_I64 */, AMDGPU::V_CMPX_GT_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31156 /* V_CMPX_GT_I64 */, AMDGPU::V_CMPX_GT_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31156 /* V_CMPX_GT_I64 */, AMDGPU::V_CMPX_GT_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31156 /* V_CMPX_GT_I64 */, AMDGPU::V_CMPX_GT_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31156 /* V_CMPX_GT_I64 */, AMDGPU::V_CMPX_GT_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31156 /* V_CMPX_GT_I64 */, AMDGPU::V_CMPX_GT_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31170 /* v_cmpx_gt_i64_e32 */, AMDGPU::V_CMPX_GT_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31170 /* v_cmpx_gt_i64_e32 */, AMDGPU::V_CMPX_GT_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31170 /* v_cmpx_gt_i64_e32 */, AMDGPU::V_CMPX_GT_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31170 /* v_cmpx_gt_i64_e32 */, AMDGPU::V_CMPX_GT_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31170 /* v_cmpx_gt_i64_e32 */, AMDGPU::V_CMPX_GT_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31188 /* V_CMPX_GT_U16 */, AMDGPU::V_CMPX_GT_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31188 /* V_CMPX_GT_U16 */, AMDGPU::V_CMPX_GT_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31188 /* V_CMPX_GT_U16 */, AMDGPU::V_CMPX_GT_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31188 /* V_CMPX_GT_U16 */, AMDGPU::V_CMPX_GT_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31202 /* v_cmpx_gt_u16_e32 */, AMDGPU::V_CMPX_GT_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31202 /* v_cmpx_gt_u16_e32 */, AMDGPU::V_CMPX_GT_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31202 /* v_cmpx_gt_u16_e32 */, AMDGPU::V_CMPX_GT_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31202 /* v_cmpx_gt_u16_e32 */, AMDGPU::V_CMPX_GT_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31202 /* v_cmpx_gt_u16_e32 */, AMDGPU::V_CMPX_GT_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31202 /* v_cmpx_gt_u16_e32 */, AMDGPU::V_CMPX_GT_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31220 /* V_CMPX_GT_U32 */, AMDGPU::V_CMPX_GT_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31220 /* V_CMPX_GT_U32 */, AMDGPU::V_CMPX_GT_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31220 /* V_CMPX_GT_U32 */, AMDGPU::V_CMPX_GT_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31220 /* V_CMPX_GT_U32 */, AMDGPU::V_CMPX_GT_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31220 /* V_CMPX_GT_U32 */, AMDGPU::V_CMPX_GT_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31220 /* V_CMPX_GT_U32 */, AMDGPU::V_CMPX_GT_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31220 /* V_CMPX_GT_U32 */, AMDGPU::V_CMPX_GT_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31220 /* V_CMPX_GT_U32 */, AMDGPU::V_CMPX_GT_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31220 /* V_CMPX_GT_U32 */, AMDGPU::V_CMPX_GT_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31234 /* v_cmpx_gt_u32_e32 */, AMDGPU::V_CMPX_GT_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31234 /* v_cmpx_gt_u32_e32 */, AMDGPU::V_CMPX_GT_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31234 /* v_cmpx_gt_u32_e32 */, AMDGPU::V_CMPX_GT_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31234 /* v_cmpx_gt_u32_e32 */, AMDGPU::V_CMPX_GT_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31234 /* v_cmpx_gt_u32_e32 */, AMDGPU::V_CMPX_GT_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31252 /* V_CMPX_GT_U64 */, AMDGPU::V_CMPX_GT_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31252 /* V_CMPX_GT_U64 */, AMDGPU::V_CMPX_GT_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31252 /* V_CMPX_GT_U64 */, AMDGPU::V_CMPX_GT_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31252 /* V_CMPX_GT_U64 */, AMDGPU::V_CMPX_GT_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31252 /* V_CMPX_GT_U64 */, AMDGPU::V_CMPX_GT_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31252 /* V_CMPX_GT_U64 */, AMDGPU::V_CMPX_GT_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31252 /* V_CMPX_GT_U64 */, AMDGPU::V_CMPX_GT_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31252 /* V_CMPX_GT_U64 */, AMDGPU::V_CMPX_GT_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31252 /* V_CMPX_GT_U64 */, AMDGPU::V_CMPX_GT_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31266 /* v_cmpx_gt_u64_e32 */, AMDGPU::V_CMPX_GT_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31266 /* v_cmpx_gt_u64_e32 */, AMDGPU::V_CMPX_GT_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31266 /* v_cmpx_gt_u64_e32 */, AMDGPU::V_CMPX_GT_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31266 /* v_cmpx_gt_u64_e32 */, AMDGPU::V_CMPX_GT_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31266 /* v_cmpx_gt_u64_e32 */, AMDGPU::V_CMPX_GT_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31284 /* V_CMPX_LE_F16 */, AMDGPU::V_CMPX_LE_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 31284 /* V_CMPX_LE_F16 */, AMDGPU::V_CMPX_LE_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31284 /* V_CMPX_LE_F16 */, AMDGPU::V_CMPX_LE_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 31284 /* V_CMPX_LE_F16 */, AMDGPU::V_CMPX_LE_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 31298 /* v_cmpx_le_f16_e32 */, AMDGPU::V_CMPX_LE_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 31298 /* v_cmpx_le_f16_e32 */, AMDGPU::V_CMPX_LE_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 31298 /* v_cmpx_le_f16_e32 */, AMDGPU::V_CMPX_LE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31298 /* v_cmpx_le_f16_e32 */, AMDGPU::V_CMPX_LE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31298 /* v_cmpx_le_f16_e32 */, AMDGPU::V_CMPX_LE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31298 /* v_cmpx_le_f16_e32 */, AMDGPU::V_CMPX_LE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31316 /* V_CMPX_LE_F32 */, AMDGPU::V_CMPX_LE_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31316 /* V_CMPX_LE_F32 */, AMDGPU::V_CMPX_LE_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31316 /* V_CMPX_LE_F32 */, AMDGPU::V_CMPX_LE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31316 /* V_CMPX_LE_F32 */, AMDGPU::V_CMPX_LE_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31316 /* V_CMPX_LE_F32 */, AMDGPU::V_CMPX_LE_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31316 /* V_CMPX_LE_F32 */, AMDGPU::V_CMPX_LE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31316 /* V_CMPX_LE_F32 */, AMDGPU::V_CMPX_LE_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31316 /* V_CMPX_LE_F32 */, AMDGPU::V_CMPX_LE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31316 /* V_CMPX_LE_F32 */, AMDGPU::V_CMPX_LE_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31330 /* v_cmpx_le_f32_e32 */, AMDGPU::V_CMPX_LE_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31330 /* v_cmpx_le_f32_e32 */, AMDGPU::V_CMPX_LE_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31330 /* v_cmpx_le_f32_e32 */, AMDGPU::V_CMPX_LE_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31330 /* v_cmpx_le_f32_e32 */, AMDGPU::V_CMPX_LE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31330 /* v_cmpx_le_f32_e32 */, AMDGPU::V_CMPX_LE_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31348 /* V_CMPX_LE_F64 */, AMDGPU::V_CMPX_LE_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31348 /* V_CMPX_LE_F64 */, AMDGPU::V_CMPX_LE_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31348 /* V_CMPX_LE_F64 */, AMDGPU::V_CMPX_LE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31348 /* V_CMPX_LE_F64 */, AMDGPU::V_CMPX_LE_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31348 /* V_CMPX_LE_F64 */, AMDGPU::V_CMPX_LE_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31348 /* V_CMPX_LE_F64 */, AMDGPU::V_CMPX_LE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31348 /* V_CMPX_LE_F64 */, AMDGPU::V_CMPX_LE_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31348 /* V_CMPX_LE_F64 */, AMDGPU::V_CMPX_LE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31348 /* V_CMPX_LE_F64 */, AMDGPU::V_CMPX_LE_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31362 /* v_cmpx_le_f64_e32 */, AMDGPU::V_CMPX_LE_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31362 /* v_cmpx_le_f64_e32 */, AMDGPU::V_CMPX_LE_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31362 /* v_cmpx_le_f64_e32 */, AMDGPU::V_CMPX_LE_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31362 /* v_cmpx_le_f64_e32 */, AMDGPU::V_CMPX_LE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31362 /* v_cmpx_le_f64_e32 */, AMDGPU::V_CMPX_LE_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31380 /* V_CMPX_LE_I16 */, AMDGPU::V_CMPX_LE_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31380 /* V_CMPX_LE_I16 */, AMDGPU::V_CMPX_LE_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31380 /* V_CMPX_LE_I16 */, AMDGPU::V_CMPX_LE_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31380 /* V_CMPX_LE_I16 */, AMDGPU::V_CMPX_LE_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31394 /* v_cmpx_le_i16_e32 */, AMDGPU::V_CMPX_LE_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31394 /* v_cmpx_le_i16_e32 */, AMDGPU::V_CMPX_LE_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31394 /* v_cmpx_le_i16_e32 */, AMDGPU::V_CMPX_LE_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31394 /* v_cmpx_le_i16_e32 */, AMDGPU::V_CMPX_LE_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31394 /* v_cmpx_le_i16_e32 */, AMDGPU::V_CMPX_LE_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31394 /* v_cmpx_le_i16_e32 */, AMDGPU::V_CMPX_LE_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31412 /* V_CMPX_LE_I32 */, AMDGPU::V_CMPX_LE_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31412 /* V_CMPX_LE_I32 */, AMDGPU::V_CMPX_LE_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31412 /* V_CMPX_LE_I32 */, AMDGPU::V_CMPX_LE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31412 /* V_CMPX_LE_I32 */, AMDGPU::V_CMPX_LE_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31412 /* V_CMPX_LE_I32 */, AMDGPU::V_CMPX_LE_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31412 /* V_CMPX_LE_I32 */, AMDGPU::V_CMPX_LE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31412 /* V_CMPX_LE_I32 */, AMDGPU::V_CMPX_LE_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31412 /* V_CMPX_LE_I32 */, AMDGPU::V_CMPX_LE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31412 /* V_CMPX_LE_I32 */, AMDGPU::V_CMPX_LE_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31426 /* v_cmpx_le_i32_e32 */, AMDGPU::V_CMPX_LE_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31426 /* v_cmpx_le_i32_e32 */, AMDGPU::V_CMPX_LE_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31426 /* v_cmpx_le_i32_e32 */, AMDGPU::V_CMPX_LE_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31426 /* v_cmpx_le_i32_e32 */, AMDGPU::V_CMPX_LE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31426 /* v_cmpx_le_i32_e32 */, AMDGPU::V_CMPX_LE_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31444 /* V_CMPX_LE_I64 */, AMDGPU::V_CMPX_LE_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31444 /* V_CMPX_LE_I64 */, AMDGPU::V_CMPX_LE_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31444 /* V_CMPX_LE_I64 */, AMDGPU::V_CMPX_LE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31444 /* V_CMPX_LE_I64 */, AMDGPU::V_CMPX_LE_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31444 /* V_CMPX_LE_I64 */, AMDGPU::V_CMPX_LE_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31444 /* V_CMPX_LE_I64 */, AMDGPU::V_CMPX_LE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31444 /* V_CMPX_LE_I64 */, AMDGPU::V_CMPX_LE_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31444 /* V_CMPX_LE_I64 */, AMDGPU::V_CMPX_LE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31444 /* V_CMPX_LE_I64 */, AMDGPU::V_CMPX_LE_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31458 /* v_cmpx_le_i64_e32 */, AMDGPU::V_CMPX_LE_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31458 /* v_cmpx_le_i64_e32 */, AMDGPU::V_CMPX_LE_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31458 /* v_cmpx_le_i64_e32 */, AMDGPU::V_CMPX_LE_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31458 /* v_cmpx_le_i64_e32 */, AMDGPU::V_CMPX_LE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31458 /* v_cmpx_le_i64_e32 */, AMDGPU::V_CMPX_LE_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31476 /* V_CMPX_LE_U16 */, AMDGPU::V_CMPX_LE_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31476 /* V_CMPX_LE_U16 */, AMDGPU::V_CMPX_LE_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31476 /* V_CMPX_LE_U16 */, AMDGPU::V_CMPX_LE_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31476 /* V_CMPX_LE_U16 */, AMDGPU::V_CMPX_LE_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31490 /* v_cmpx_le_u16_e32 */, AMDGPU::V_CMPX_LE_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31490 /* v_cmpx_le_u16_e32 */, AMDGPU::V_CMPX_LE_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31490 /* v_cmpx_le_u16_e32 */, AMDGPU::V_CMPX_LE_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31490 /* v_cmpx_le_u16_e32 */, AMDGPU::V_CMPX_LE_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31490 /* v_cmpx_le_u16_e32 */, AMDGPU::V_CMPX_LE_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31490 /* v_cmpx_le_u16_e32 */, AMDGPU::V_CMPX_LE_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31508 /* V_CMPX_LE_U32 */, AMDGPU::V_CMPX_LE_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31508 /* V_CMPX_LE_U32 */, AMDGPU::V_CMPX_LE_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31508 /* V_CMPX_LE_U32 */, AMDGPU::V_CMPX_LE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31508 /* V_CMPX_LE_U32 */, AMDGPU::V_CMPX_LE_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31508 /* V_CMPX_LE_U32 */, AMDGPU::V_CMPX_LE_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31508 /* V_CMPX_LE_U32 */, AMDGPU::V_CMPX_LE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31508 /* V_CMPX_LE_U32 */, AMDGPU::V_CMPX_LE_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31508 /* V_CMPX_LE_U32 */, AMDGPU::V_CMPX_LE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31508 /* V_CMPX_LE_U32 */, AMDGPU::V_CMPX_LE_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31522 /* v_cmpx_le_u32_e32 */, AMDGPU::V_CMPX_LE_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31522 /* v_cmpx_le_u32_e32 */, AMDGPU::V_CMPX_LE_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31522 /* v_cmpx_le_u32_e32 */, AMDGPU::V_CMPX_LE_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31522 /* v_cmpx_le_u32_e32 */, AMDGPU::V_CMPX_LE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31522 /* v_cmpx_le_u32_e32 */, AMDGPU::V_CMPX_LE_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31540 /* V_CMPX_LE_U64 */, AMDGPU::V_CMPX_LE_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31540 /* V_CMPX_LE_U64 */, AMDGPU::V_CMPX_LE_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31540 /* V_CMPX_LE_U64 */, AMDGPU::V_CMPX_LE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31540 /* V_CMPX_LE_U64 */, AMDGPU::V_CMPX_LE_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31540 /* V_CMPX_LE_U64 */, AMDGPU::V_CMPX_LE_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31540 /* V_CMPX_LE_U64 */, AMDGPU::V_CMPX_LE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31540 /* V_CMPX_LE_U64 */, AMDGPU::V_CMPX_LE_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31540 /* V_CMPX_LE_U64 */, AMDGPU::V_CMPX_LE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31540 /* V_CMPX_LE_U64 */, AMDGPU::V_CMPX_LE_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31554 /* v_cmpx_le_u64_e32 */, AMDGPU::V_CMPX_LE_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31554 /* v_cmpx_le_u64_e32 */, AMDGPU::V_CMPX_LE_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31554 /* v_cmpx_le_u64_e32 */, AMDGPU::V_CMPX_LE_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31554 /* v_cmpx_le_u64_e32 */, AMDGPU::V_CMPX_LE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31554 /* v_cmpx_le_u64_e32 */, AMDGPU::V_CMPX_LE_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31572 /* V_CMPX_LG_F16 */, AMDGPU::V_CMPX_LG_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 31572 /* V_CMPX_LG_F16 */, AMDGPU::V_CMPX_LG_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31572 /* V_CMPX_LG_F16 */, AMDGPU::V_CMPX_LG_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 31572 /* V_CMPX_LG_F16 */, AMDGPU::V_CMPX_LG_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 31586 /* v_cmpx_lg_f16_e32 */, AMDGPU::V_CMPX_LG_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 31586 /* v_cmpx_lg_f16_e32 */, AMDGPU::V_CMPX_LG_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 31586 /* v_cmpx_lg_f16_e32 */, AMDGPU::V_CMPX_LG_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31586 /* v_cmpx_lg_f16_e32 */, AMDGPU::V_CMPX_LG_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31586 /* v_cmpx_lg_f16_e32 */, AMDGPU::V_CMPX_LG_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31586 /* v_cmpx_lg_f16_e32 */, AMDGPU::V_CMPX_LG_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31604 /* V_CMPX_LG_F32 */, AMDGPU::V_CMPX_LG_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31604 /* V_CMPX_LG_F32 */, AMDGPU::V_CMPX_LG_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31604 /* V_CMPX_LG_F32 */, AMDGPU::V_CMPX_LG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31604 /* V_CMPX_LG_F32 */, AMDGPU::V_CMPX_LG_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31604 /* V_CMPX_LG_F32 */, AMDGPU::V_CMPX_LG_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31604 /* V_CMPX_LG_F32 */, AMDGPU::V_CMPX_LG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31604 /* V_CMPX_LG_F32 */, AMDGPU::V_CMPX_LG_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31604 /* V_CMPX_LG_F32 */, AMDGPU::V_CMPX_LG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31604 /* V_CMPX_LG_F32 */, AMDGPU::V_CMPX_LG_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31618 /* v_cmpx_lg_f32_e32 */, AMDGPU::V_CMPX_LG_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31618 /* v_cmpx_lg_f32_e32 */, AMDGPU::V_CMPX_LG_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31618 /* v_cmpx_lg_f32_e32 */, AMDGPU::V_CMPX_LG_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31618 /* v_cmpx_lg_f32_e32 */, AMDGPU::V_CMPX_LG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31618 /* v_cmpx_lg_f32_e32 */, AMDGPU::V_CMPX_LG_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31636 /* V_CMPX_LG_F64 */, AMDGPU::V_CMPX_LG_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31636 /* V_CMPX_LG_F64 */, AMDGPU::V_CMPX_LG_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31636 /* V_CMPX_LG_F64 */, AMDGPU::V_CMPX_LG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31636 /* V_CMPX_LG_F64 */, AMDGPU::V_CMPX_LG_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31636 /* V_CMPX_LG_F64 */, AMDGPU::V_CMPX_LG_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31636 /* V_CMPX_LG_F64 */, AMDGPU::V_CMPX_LG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31636 /* V_CMPX_LG_F64 */, AMDGPU::V_CMPX_LG_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31636 /* V_CMPX_LG_F64 */, AMDGPU::V_CMPX_LG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31636 /* V_CMPX_LG_F64 */, AMDGPU::V_CMPX_LG_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31650 /* v_cmpx_lg_f64_e32 */, AMDGPU::V_CMPX_LG_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31650 /* v_cmpx_lg_f64_e32 */, AMDGPU::V_CMPX_LG_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31650 /* v_cmpx_lg_f64_e32 */, AMDGPU::V_CMPX_LG_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31650 /* v_cmpx_lg_f64_e32 */, AMDGPU::V_CMPX_LG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31650 /* v_cmpx_lg_f64_e32 */, AMDGPU::V_CMPX_LG_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31668 /* V_CMPX_LT_F16 */, AMDGPU::V_CMPX_LT_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 31668 /* V_CMPX_LT_F16 */, AMDGPU::V_CMPX_LT_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31668 /* V_CMPX_LT_F16 */, AMDGPU::V_CMPX_LT_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 31668 /* V_CMPX_LT_F16 */, AMDGPU::V_CMPX_LT_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 31682 /* v_cmpx_lt_f16_e32 */, AMDGPU::V_CMPX_LT_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 31682 /* v_cmpx_lt_f16_e32 */, AMDGPU::V_CMPX_LT_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 31682 /* v_cmpx_lt_f16_e32 */, AMDGPU::V_CMPX_LT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31682 /* v_cmpx_lt_f16_e32 */, AMDGPU::V_CMPX_LT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31682 /* v_cmpx_lt_f16_e32 */, AMDGPU::V_CMPX_LT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31682 /* v_cmpx_lt_f16_e32 */, AMDGPU::V_CMPX_LT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31700 /* V_CMPX_LT_F32 */, AMDGPU::V_CMPX_LT_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31700 /* V_CMPX_LT_F32 */, AMDGPU::V_CMPX_LT_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31700 /* V_CMPX_LT_F32 */, AMDGPU::V_CMPX_LT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31700 /* V_CMPX_LT_F32 */, AMDGPU::V_CMPX_LT_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31700 /* V_CMPX_LT_F32 */, AMDGPU::V_CMPX_LT_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31700 /* V_CMPX_LT_F32 */, AMDGPU::V_CMPX_LT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31700 /* V_CMPX_LT_F32 */, AMDGPU::V_CMPX_LT_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31700 /* V_CMPX_LT_F32 */, AMDGPU::V_CMPX_LT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31700 /* V_CMPX_LT_F32 */, AMDGPU::V_CMPX_LT_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31714 /* v_cmpx_lt_f32_e32 */, AMDGPU::V_CMPX_LT_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31714 /* v_cmpx_lt_f32_e32 */, AMDGPU::V_CMPX_LT_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31714 /* v_cmpx_lt_f32_e32 */, AMDGPU::V_CMPX_LT_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31714 /* v_cmpx_lt_f32_e32 */, AMDGPU::V_CMPX_LT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31714 /* v_cmpx_lt_f32_e32 */, AMDGPU::V_CMPX_LT_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 31732 /* V_CMPX_LT_F64 */, AMDGPU::V_CMPX_LT_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31732 /* V_CMPX_LT_F64 */, AMDGPU::V_CMPX_LT_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31732 /* V_CMPX_LT_F64 */, AMDGPU::V_CMPX_LT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31732 /* V_CMPX_LT_F64 */, AMDGPU::V_CMPX_LT_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31732 /* V_CMPX_LT_F64 */, AMDGPU::V_CMPX_LT_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31732 /* V_CMPX_LT_F64 */, AMDGPU::V_CMPX_LT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31732 /* V_CMPX_LT_F64 */, AMDGPU::V_CMPX_LT_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31732 /* V_CMPX_LT_F64 */, AMDGPU::V_CMPX_LT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31732 /* V_CMPX_LT_F64 */, AMDGPU::V_CMPX_LT_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31746 /* v_cmpx_lt_f64_e32 */, AMDGPU::V_CMPX_LT_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31746 /* v_cmpx_lt_f64_e32 */, AMDGPU::V_CMPX_LT_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31746 /* v_cmpx_lt_f64_e32 */, AMDGPU::V_CMPX_LT_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31746 /* v_cmpx_lt_f64_e32 */, AMDGPU::V_CMPX_LT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31746 /* v_cmpx_lt_f64_e32 */, AMDGPU::V_CMPX_LT_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31764 /* V_CMPX_LT_I16 */, AMDGPU::V_CMPX_LT_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31764 /* V_CMPX_LT_I16 */, AMDGPU::V_CMPX_LT_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31764 /* V_CMPX_LT_I16 */, AMDGPU::V_CMPX_LT_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31764 /* V_CMPX_LT_I16 */, AMDGPU::V_CMPX_LT_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31778 /* v_cmpx_lt_i16_e32 */, AMDGPU::V_CMPX_LT_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31778 /* v_cmpx_lt_i16_e32 */, AMDGPU::V_CMPX_LT_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31778 /* v_cmpx_lt_i16_e32 */, AMDGPU::V_CMPX_LT_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31778 /* v_cmpx_lt_i16_e32 */, AMDGPU::V_CMPX_LT_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31778 /* v_cmpx_lt_i16_e32 */, AMDGPU::V_CMPX_LT_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31778 /* v_cmpx_lt_i16_e32 */, AMDGPU::V_CMPX_LT_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31796 /* V_CMPX_LT_I32 */, AMDGPU::V_CMPX_LT_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31796 /* V_CMPX_LT_I32 */, AMDGPU::V_CMPX_LT_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31796 /* V_CMPX_LT_I32 */, AMDGPU::V_CMPX_LT_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31796 /* V_CMPX_LT_I32 */, AMDGPU::V_CMPX_LT_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31796 /* V_CMPX_LT_I32 */, AMDGPU::V_CMPX_LT_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31796 /* V_CMPX_LT_I32 */, AMDGPU::V_CMPX_LT_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31796 /* V_CMPX_LT_I32 */, AMDGPU::V_CMPX_LT_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31796 /* V_CMPX_LT_I32 */, AMDGPU::V_CMPX_LT_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31796 /* V_CMPX_LT_I32 */, AMDGPU::V_CMPX_LT_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31810 /* v_cmpx_lt_i32_e32 */, AMDGPU::V_CMPX_LT_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31810 /* v_cmpx_lt_i32_e32 */, AMDGPU::V_CMPX_LT_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31810 /* v_cmpx_lt_i32_e32 */, AMDGPU::V_CMPX_LT_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31810 /* v_cmpx_lt_i32_e32 */, AMDGPU::V_CMPX_LT_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31810 /* v_cmpx_lt_i32_e32 */, AMDGPU::V_CMPX_LT_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31828 /* V_CMPX_LT_I64 */, AMDGPU::V_CMPX_LT_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31828 /* V_CMPX_LT_I64 */, AMDGPU::V_CMPX_LT_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31828 /* V_CMPX_LT_I64 */, AMDGPU::V_CMPX_LT_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31828 /* V_CMPX_LT_I64 */, AMDGPU::V_CMPX_LT_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31828 /* V_CMPX_LT_I64 */, AMDGPU::V_CMPX_LT_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31828 /* V_CMPX_LT_I64 */, AMDGPU::V_CMPX_LT_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31828 /* V_CMPX_LT_I64 */, AMDGPU::V_CMPX_LT_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31828 /* V_CMPX_LT_I64 */, AMDGPU::V_CMPX_LT_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31828 /* V_CMPX_LT_I64 */, AMDGPU::V_CMPX_LT_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31842 /* v_cmpx_lt_i64_e32 */, AMDGPU::V_CMPX_LT_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31842 /* v_cmpx_lt_i64_e32 */, AMDGPU::V_CMPX_LT_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31842 /* v_cmpx_lt_i64_e32 */, AMDGPU::V_CMPX_LT_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31842 /* v_cmpx_lt_i64_e32 */, AMDGPU::V_CMPX_LT_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31842 /* v_cmpx_lt_i64_e32 */, AMDGPU::V_CMPX_LT_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31860 /* V_CMPX_LT_U16 */, AMDGPU::V_CMPX_LT_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31860 /* V_CMPX_LT_U16 */, AMDGPU::V_CMPX_LT_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31860 /* V_CMPX_LT_U16 */, AMDGPU::V_CMPX_LT_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31860 /* V_CMPX_LT_U16 */, AMDGPU::V_CMPX_LT_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31874 /* v_cmpx_lt_u16_e32 */, AMDGPU::V_CMPX_LT_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31874 /* v_cmpx_lt_u16_e32 */, AMDGPU::V_CMPX_LT_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31874 /* v_cmpx_lt_u16_e32 */, AMDGPU::V_CMPX_LT_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31874 /* v_cmpx_lt_u16_e32 */, AMDGPU::V_CMPX_LT_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31874 /* v_cmpx_lt_u16_e32 */, AMDGPU::V_CMPX_LT_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31874 /* v_cmpx_lt_u16_e32 */, AMDGPU::V_CMPX_LT_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31892 /* V_CMPX_LT_U32 */, AMDGPU::V_CMPX_LT_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31892 /* V_CMPX_LT_U32 */, AMDGPU::V_CMPX_LT_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31892 /* V_CMPX_LT_U32 */, AMDGPU::V_CMPX_LT_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31892 /* V_CMPX_LT_U32 */, AMDGPU::V_CMPX_LT_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31892 /* V_CMPX_LT_U32 */, AMDGPU::V_CMPX_LT_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31892 /* V_CMPX_LT_U32 */, AMDGPU::V_CMPX_LT_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31892 /* V_CMPX_LT_U32 */, AMDGPU::V_CMPX_LT_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31892 /* V_CMPX_LT_U32 */, AMDGPU::V_CMPX_LT_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31892 /* V_CMPX_LT_U32 */, AMDGPU::V_CMPX_LT_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31906 /* v_cmpx_lt_u32_e32 */, AMDGPU::V_CMPX_LT_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31906 /* v_cmpx_lt_u32_e32 */, AMDGPU::V_CMPX_LT_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31906 /* v_cmpx_lt_u32_e32 */, AMDGPU::V_CMPX_LT_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31906 /* v_cmpx_lt_u32_e32 */, AMDGPU::V_CMPX_LT_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31906 /* v_cmpx_lt_u32_e32 */, AMDGPU::V_CMPX_LT_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31924 /* V_CMPX_LT_U64 */, AMDGPU::V_CMPX_LT_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31924 /* V_CMPX_LT_U64 */, AMDGPU::V_CMPX_LT_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31924 /* V_CMPX_LT_U64 */, AMDGPU::V_CMPX_LT_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31924 /* V_CMPX_LT_U64 */, AMDGPU::V_CMPX_LT_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31924 /* V_CMPX_LT_U64 */, AMDGPU::V_CMPX_LT_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31924 /* V_CMPX_LT_U64 */, AMDGPU::V_CMPX_LT_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31924 /* V_CMPX_LT_U64 */, AMDGPU::V_CMPX_LT_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31924 /* V_CMPX_LT_U64 */, AMDGPU::V_CMPX_LT_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31924 /* V_CMPX_LT_U64 */, AMDGPU::V_CMPX_LT_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31938 /* v_cmpx_lt_u64_e32 */, AMDGPU::V_CMPX_LT_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31938 /* v_cmpx_lt_u64_e32 */, AMDGPU::V_CMPX_LT_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31938 /* v_cmpx_lt_u64_e32 */, AMDGPU::V_CMPX_LT_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31938 /* v_cmpx_lt_u64_e32 */, AMDGPU::V_CMPX_LT_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31938 /* v_cmpx_lt_u64_e32 */, AMDGPU::V_CMPX_LT_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 31956 /* V_CMPX_NE_I16 */, AMDGPU::V_CMPX_NE_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31956 /* V_CMPX_NE_I16 */, AMDGPU::V_CMPX_NE_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31956 /* V_CMPX_NE_I16 */, AMDGPU::V_CMPX_NE_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31956 /* V_CMPX_NE_I16 */, AMDGPU::V_CMPX_NE_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31970 /* v_cmpx_ne_i16_e32 */, AMDGPU::V_CMPX_NE_I16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31970 /* v_cmpx_ne_i16_e32 */, AMDGPU::V_CMPX_NE_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 31970 /* v_cmpx_ne_i16_e32 */, AMDGPU::V_CMPX_NE_I16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31970 /* v_cmpx_ne_i16_e32 */, AMDGPU::V_CMPX_NE_I16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 31970 /* v_cmpx_ne_i16_e32 */, AMDGPU::V_CMPX_NE_I16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31970 /* v_cmpx_ne_i16_e32 */, AMDGPU::V_CMPX_NE_I16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 31988 /* V_CMPX_NE_I32 */, AMDGPU::V_CMPX_NE_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31988 /* V_CMPX_NE_I32 */, AMDGPU::V_CMPX_NE_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31988 /* V_CMPX_NE_I32 */, AMDGPU::V_CMPX_NE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31988 /* V_CMPX_NE_I32 */, AMDGPU::V_CMPX_NE_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31988 /* V_CMPX_NE_I32 */, AMDGPU::V_CMPX_NE_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31988 /* V_CMPX_NE_I32 */, AMDGPU::V_CMPX_NE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31988 /* V_CMPX_NE_I32 */, AMDGPU::V_CMPX_NE_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31988 /* V_CMPX_NE_I32 */, AMDGPU::V_CMPX_NE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 31988 /* V_CMPX_NE_I32 */, AMDGPU::V_CMPX_NE_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32002 /* v_cmpx_ne_i32_e32 */, AMDGPU::V_CMPX_NE_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32002 /* v_cmpx_ne_i32_e32 */, AMDGPU::V_CMPX_NE_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32002 /* v_cmpx_ne_i32_e32 */, AMDGPU::V_CMPX_NE_I32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32002 /* v_cmpx_ne_i32_e32 */, AMDGPU::V_CMPX_NE_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32002 /* v_cmpx_ne_i32_e32 */, AMDGPU::V_CMPX_NE_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32020 /* V_CMPX_NE_I64 */, AMDGPU::V_CMPX_NE_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32020 /* V_CMPX_NE_I64 */, AMDGPU::V_CMPX_NE_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32020 /* V_CMPX_NE_I64 */, AMDGPU::V_CMPX_NE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32020 /* V_CMPX_NE_I64 */, AMDGPU::V_CMPX_NE_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32020 /* V_CMPX_NE_I64 */, AMDGPU::V_CMPX_NE_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32020 /* V_CMPX_NE_I64 */, AMDGPU::V_CMPX_NE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32020 /* V_CMPX_NE_I64 */, AMDGPU::V_CMPX_NE_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32020 /* V_CMPX_NE_I64 */, AMDGPU::V_CMPX_NE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32020 /* V_CMPX_NE_I64 */, AMDGPU::V_CMPX_NE_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32034 /* v_cmpx_ne_i64_e32 */, AMDGPU::V_CMPX_NE_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32034 /* v_cmpx_ne_i64_e32 */, AMDGPU::V_CMPX_NE_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32034 /* v_cmpx_ne_i64_e32 */, AMDGPU::V_CMPX_NE_I64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32034 /* v_cmpx_ne_i64_e32 */, AMDGPU::V_CMPX_NE_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32034 /* v_cmpx_ne_i64_e32 */, AMDGPU::V_CMPX_NE_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32052 /* V_CMPX_NE_U16 */, AMDGPU::V_CMPX_NE_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 32052 /* V_CMPX_NE_U16 */, AMDGPU::V_CMPX_NE_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32052 /* V_CMPX_NE_U16 */, AMDGPU::V_CMPX_NE_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 32052 /* V_CMPX_NE_U16 */, AMDGPU::V_CMPX_NE_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 32066 /* v_cmpx_ne_u16_e32 */, AMDGPU::V_CMPX_NE_U16_e32_gfx10, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 32066 /* v_cmpx_ne_u16_e32 */, AMDGPU::V_CMPX_NE_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 32066 /* v_cmpx_ne_u16_e32 */, AMDGPU::V_CMPX_NE_U16_t16_e32_gfx11, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32066 /* v_cmpx_ne_u16_e32 */, AMDGPU::V_CMPX_NE_U16_t16_e32_gfx12, Convert__VSrcT_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32066 /* v_cmpx_ne_u16_e32 */, AMDGPU::V_CMPX_NE_U16_fake16_e32_gfx11, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32066 /* v_cmpx_ne_u16_e32 */, AMDGPU::V_CMPX_NE_U16_fake16_e32_gfx12, Convert__VSrcFake16_b16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_b16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32084 /* V_CMPX_NE_U32 */, AMDGPU::V_CMPX_NE_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32084 /* V_CMPX_NE_U32 */, AMDGPU::V_CMPX_NE_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32084 /* V_CMPX_NE_U32 */, AMDGPU::V_CMPX_NE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32084 /* V_CMPX_NE_U32 */, AMDGPU::V_CMPX_NE_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32084 /* V_CMPX_NE_U32 */, AMDGPU::V_CMPX_NE_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32084 /* V_CMPX_NE_U32 */, AMDGPU::V_CMPX_NE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32084 /* V_CMPX_NE_U32 */, AMDGPU::V_CMPX_NE_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32084 /* V_CMPX_NE_U32 */, AMDGPU::V_CMPX_NE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32084 /* V_CMPX_NE_U32 */, AMDGPU::V_CMPX_NE_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32098 /* v_cmpx_ne_u32_e32 */, AMDGPU::V_CMPX_NE_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32098 /* v_cmpx_ne_u32_e32 */, AMDGPU::V_CMPX_NE_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32098 /* v_cmpx_ne_u32_e32 */, AMDGPU::V_CMPX_NE_U32_e32_gfx12, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32098 /* v_cmpx_ne_u32_e32 */, AMDGPU::V_CMPX_NE_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32098 /* v_cmpx_ne_u32_e32 */, AMDGPU::V_CMPX_NE_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32116 /* V_CMPX_NE_U64 */, AMDGPU::V_CMPX_NE_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32116 /* V_CMPX_NE_U64 */, AMDGPU::V_CMPX_NE_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32116 /* V_CMPX_NE_U64 */, AMDGPU::V_CMPX_NE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32116 /* V_CMPX_NE_U64 */, AMDGPU::V_CMPX_NE_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32116 /* V_CMPX_NE_U64 */, AMDGPU::V_CMPX_NE_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32116 /* V_CMPX_NE_U64 */, AMDGPU::V_CMPX_NE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32116 /* V_CMPX_NE_U64 */, AMDGPU::V_CMPX_NE_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32116 /* V_CMPX_NE_U64 */, AMDGPU::V_CMPX_NE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32116 /* V_CMPX_NE_U64 */, AMDGPU::V_CMPX_NE_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32130 /* v_cmpx_ne_u64_e32 */, AMDGPU::V_CMPX_NE_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32130 /* v_cmpx_ne_u64_e32 */, AMDGPU::V_CMPX_NE_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32130 /* v_cmpx_ne_u64_e32 */, AMDGPU::V_CMPX_NE_U64_e32_gfx12, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32130 /* v_cmpx_ne_u64_e32 */, AMDGPU::V_CMPX_NE_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32130 /* v_cmpx_ne_u64_e32 */, AMDGPU::V_CMPX_NE_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32148 /* V_CMPX_NEQ_F16 */, AMDGPU::V_CMPX_NEQ_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32148 /* V_CMPX_NEQ_F16 */, AMDGPU::V_CMPX_NEQ_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32148 /* V_CMPX_NEQ_F16 */, AMDGPU::V_CMPX_NEQ_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32148 /* V_CMPX_NEQ_F16 */, AMDGPU::V_CMPX_NEQ_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32163 /* v_cmpx_neq_f16_e32 */, AMDGPU::V_CMPX_NEQ_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32163 /* v_cmpx_neq_f16_e32 */, AMDGPU::V_CMPX_NEQ_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32163 /* v_cmpx_neq_f16_e32 */, AMDGPU::V_CMPX_NEQ_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32163 /* v_cmpx_neq_f16_e32 */, AMDGPU::V_CMPX_NEQ_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32163 /* v_cmpx_neq_f16_e32 */, AMDGPU::V_CMPX_NEQ_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32163 /* v_cmpx_neq_f16_e32 */, AMDGPU::V_CMPX_NEQ_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32182 /* V_CMPX_NEQ_F32 */, AMDGPU::V_CMPX_NEQ_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32182 /* V_CMPX_NEQ_F32 */, AMDGPU::V_CMPX_NEQ_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32182 /* V_CMPX_NEQ_F32 */, AMDGPU::V_CMPX_NEQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32182 /* V_CMPX_NEQ_F32 */, AMDGPU::V_CMPX_NEQ_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32182 /* V_CMPX_NEQ_F32 */, AMDGPU::V_CMPX_NEQ_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32182 /* V_CMPX_NEQ_F32 */, AMDGPU::V_CMPX_NEQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32182 /* V_CMPX_NEQ_F32 */, AMDGPU::V_CMPX_NEQ_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32182 /* V_CMPX_NEQ_F32 */, AMDGPU::V_CMPX_NEQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32182 /* V_CMPX_NEQ_F32 */, AMDGPU::V_CMPX_NEQ_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32197 /* v_cmpx_neq_f32_e32 */, AMDGPU::V_CMPX_NEQ_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32197 /* v_cmpx_neq_f32_e32 */, AMDGPU::V_CMPX_NEQ_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32197 /* v_cmpx_neq_f32_e32 */, AMDGPU::V_CMPX_NEQ_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32197 /* v_cmpx_neq_f32_e32 */, AMDGPU::V_CMPX_NEQ_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32197 /* v_cmpx_neq_f32_e32 */, AMDGPU::V_CMPX_NEQ_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32216 /* V_CMPX_NEQ_F64 */, AMDGPU::V_CMPX_NEQ_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32216 /* V_CMPX_NEQ_F64 */, AMDGPU::V_CMPX_NEQ_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32216 /* V_CMPX_NEQ_F64 */, AMDGPU::V_CMPX_NEQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32216 /* V_CMPX_NEQ_F64 */, AMDGPU::V_CMPX_NEQ_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32216 /* V_CMPX_NEQ_F64 */, AMDGPU::V_CMPX_NEQ_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32216 /* V_CMPX_NEQ_F64 */, AMDGPU::V_CMPX_NEQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32216 /* V_CMPX_NEQ_F64 */, AMDGPU::V_CMPX_NEQ_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32216 /* V_CMPX_NEQ_F64 */, AMDGPU::V_CMPX_NEQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32216 /* V_CMPX_NEQ_F64 */, AMDGPU::V_CMPX_NEQ_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32231 /* v_cmpx_neq_f64_e32 */, AMDGPU::V_CMPX_NEQ_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32231 /* v_cmpx_neq_f64_e32 */, AMDGPU::V_CMPX_NEQ_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32231 /* v_cmpx_neq_f64_e32 */, AMDGPU::V_CMPX_NEQ_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32231 /* v_cmpx_neq_f64_e32 */, AMDGPU::V_CMPX_NEQ_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32231 /* v_cmpx_neq_f64_e32 */, AMDGPU::V_CMPX_NEQ_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32250 /* V_CMPX_NGE_F16 */, AMDGPU::V_CMPX_NGE_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32250 /* V_CMPX_NGE_F16 */, AMDGPU::V_CMPX_NGE_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32250 /* V_CMPX_NGE_F16 */, AMDGPU::V_CMPX_NGE_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32250 /* V_CMPX_NGE_F16 */, AMDGPU::V_CMPX_NGE_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32265 /* v_cmpx_nge_f16_e32 */, AMDGPU::V_CMPX_NGE_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32265 /* v_cmpx_nge_f16_e32 */, AMDGPU::V_CMPX_NGE_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32265 /* v_cmpx_nge_f16_e32 */, AMDGPU::V_CMPX_NGE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32265 /* v_cmpx_nge_f16_e32 */, AMDGPU::V_CMPX_NGE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32265 /* v_cmpx_nge_f16_e32 */, AMDGPU::V_CMPX_NGE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32265 /* v_cmpx_nge_f16_e32 */, AMDGPU::V_CMPX_NGE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32284 /* V_CMPX_NGE_F32 */, AMDGPU::V_CMPX_NGE_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32284 /* V_CMPX_NGE_F32 */, AMDGPU::V_CMPX_NGE_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32284 /* V_CMPX_NGE_F32 */, AMDGPU::V_CMPX_NGE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32284 /* V_CMPX_NGE_F32 */, AMDGPU::V_CMPX_NGE_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32284 /* V_CMPX_NGE_F32 */, AMDGPU::V_CMPX_NGE_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32284 /* V_CMPX_NGE_F32 */, AMDGPU::V_CMPX_NGE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32284 /* V_CMPX_NGE_F32 */, AMDGPU::V_CMPX_NGE_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32284 /* V_CMPX_NGE_F32 */, AMDGPU::V_CMPX_NGE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32284 /* V_CMPX_NGE_F32 */, AMDGPU::V_CMPX_NGE_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32299 /* v_cmpx_nge_f32_e32 */, AMDGPU::V_CMPX_NGE_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32299 /* v_cmpx_nge_f32_e32 */, AMDGPU::V_CMPX_NGE_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32299 /* v_cmpx_nge_f32_e32 */, AMDGPU::V_CMPX_NGE_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32299 /* v_cmpx_nge_f32_e32 */, AMDGPU::V_CMPX_NGE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32299 /* v_cmpx_nge_f32_e32 */, AMDGPU::V_CMPX_NGE_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32318 /* V_CMPX_NGE_F64 */, AMDGPU::V_CMPX_NGE_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32318 /* V_CMPX_NGE_F64 */, AMDGPU::V_CMPX_NGE_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32318 /* V_CMPX_NGE_F64 */, AMDGPU::V_CMPX_NGE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32318 /* V_CMPX_NGE_F64 */, AMDGPU::V_CMPX_NGE_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32318 /* V_CMPX_NGE_F64 */, AMDGPU::V_CMPX_NGE_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32318 /* V_CMPX_NGE_F64 */, AMDGPU::V_CMPX_NGE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32318 /* V_CMPX_NGE_F64 */, AMDGPU::V_CMPX_NGE_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32318 /* V_CMPX_NGE_F64 */, AMDGPU::V_CMPX_NGE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32318 /* V_CMPX_NGE_F64 */, AMDGPU::V_CMPX_NGE_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32333 /* v_cmpx_nge_f64_e32 */, AMDGPU::V_CMPX_NGE_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32333 /* v_cmpx_nge_f64_e32 */, AMDGPU::V_CMPX_NGE_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32333 /* v_cmpx_nge_f64_e32 */, AMDGPU::V_CMPX_NGE_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32333 /* v_cmpx_nge_f64_e32 */, AMDGPU::V_CMPX_NGE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32333 /* v_cmpx_nge_f64_e32 */, AMDGPU::V_CMPX_NGE_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32352 /* V_CMPX_NGT_F16 */, AMDGPU::V_CMPX_NGT_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32352 /* V_CMPX_NGT_F16 */, AMDGPU::V_CMPX_NGT_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32352 /* V_CMPX_NGT_F16 */, AMDGPU::V_CMPX_NGT_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32352 /* V_CMPX_NGT_F16 */, AMDGPU::V_CMPX_NGT_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32367 /* v_cmpx_ngt_f16_e32 */, AMDGPU::V_CMPX_NGT_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32367 /* v_cmpx_ngt_f16_e32 */, AMDGPU::V_CMPX_NGT_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32367 /* v_cmpx_ngt_f16_e32 */, AMDGPU::V_CMPX_NGT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32367 /* v_cmpx_ngt_f16_e32 */, AMDGPU::V_CMPX_NGT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32367 /* v_cmpx_ngt_f16_e32 */, AMDGPU::V_CMPX_NGT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32367 /* v_cmpx_ngt_f16_e32 */, AMDGPU::V_CMPX_NGT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32386 /* V_CMPX_NGT_F32 */, AMDGPU::V_CMPX_NGT_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32386 /* V_CMPX_NGT_F32 */, AMDGPU::V_CMPX_NGT_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32386 /* V_CMPX_NGT_F32 */, AMDGPU::V_CMPX_NGT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32386 /* V_CMPX_NGT_F32 */, AMDGPU::V_CMPX_NGT_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32386 /* V_CMPX_NGT_F32 */, AMDGPU::V_CMPX_NGT_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32386 /* V_CMPX_NGT_F32 */, AMDGPU::V_CMPX_NGT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32386 /* V_CMPX_NGT_F32 */, AMDGPU::V_CMPX_NGT_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32386 /* V_CMPX_NGT_F32 */, AMDGPU::V_CMPX_NGT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32386 /* V_CMPX_NGT_F32 */, AMDGPU::V_CMPX_NGT_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32401 /* v_cmpx_ngt_f32_e32 */, AMDGPU::V_CMPX_NGT_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32401 /* v_cmpx_ngt_f32_e32 */, AMDGPU::V_CMPX_NGT_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32401 /* v_cmpx_ngt_f32_e32 */, AMDGPU::V_CMPX_NGT_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32401 /* v_cmpx_ngt_f32_e32 */, AMDGPU::V_CMPX_NGT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32401 /* v_cmpx_ngt_f32_e32 */, AMDGPU::V_CMPX_NGT_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32420 /* V_CMPX_NGT_F64 */, AMDGPU::V_CMPX_NGT_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32420 /* V_CMPX_NGT_F64 */, AMDGPU::V_CMPX_NGT_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32420 /* V_CMPX_NGT_F64 */, AMDGPU::V_CMPX_NGT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32420 /* V_CMPX_NGT_F64 */, AMDGPU::V_CMPX_NGT_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32420 /* V_CMPX_NGT_F64 */, AMDGPU::V_CMPX_NGT_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32420 /* V_CMPX_NGT_F64 */, AMDGPU::V_CMPX_NGT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32420 /* V_CMPX_NGT_F64 */, AMDGPU::V_CMPX_NGT_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32420 /* V_CMPX_NGT_F64 */, AMDGPU::V_CMPX_NGT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32420 /* V_CMPX_NGT_F64 */, AMDGPU::V_CMPX_NGT_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32435 /* v_cmpx_ngt_f64_e32 */, AMDGPU::V_CMPX_NGT_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32435 /* v_cmpx_ngt_f64_e32 */, AMDGPU::V_CMPX_NGT_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32435 /* v_cmpx_ngt_f64_e32 */, AMDGPU::V_CMPX_NGT_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32435 /* v_cmpx_ngt_f64_e32 */, AMDGPU::V_CMPX_NGT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32435 /* v_cmpx_ngt_f64_e32 */, AMDGPU::V_CMPX_NGT_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32454 /* V_CMPX_NLE_F16 */, AMDGPU::V_CMPX_NLE_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32454 /* V_CMPX_NLE_F16 */, AMDGPU::V_CMPX_NLE_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32454 /* V_CMPX_NLE_F16 */, AMDGPU::V_CMPX_NLE_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32454 /* V_CMPX_NLE_F16 */, AMDGPU::V_CMPX_NLE_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32469 /* v_cmpx_nle_f16_e32 */, AMDGPU::V_CMPX_NLE_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32469 /* v_cmpx_nle_f16_e32 */, AMDGPU::V_CMPX_NLE_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32469 /* v_cmpx_nle_f16_e32 */, AMDGPU::V_CMPX_NLE_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32469 /* v_cmpx_nle_f16_e32 */, AMDGPU::V_CMPX_NLE_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32469 /* v_cmpx_nle_f16_e32 */, AMDGPU::V_CMPX_NLE_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32469 /* v_cmpx_nle_f16_e32 */, AMDGPU::V_CMPX_NLE_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32488 /* V_CMPX_NLE_F32 */, AMDGPU::V_CMPX_NLE_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32488 /* V_CMPX_NLE_F32 */, AMDGPU::V_CMPX_NLE_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32488 /* V_CMPX_NLE_F32 */, AMDGPU::V_CMPX_NLE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32488 /* V_CMPX_NLE_F32 */, AMDGPU::V_CMPX_NLE_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32488 /* V_CMPX_NLE_F32 */, AMDGPU::V_CMPX_NLE_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32488 /* V_CMPX_NLE_F32 */, AMDGPU::V_CMPX_NLE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32488 /* V_CMPX_NLE_F32 */, AMDGPU::V_CMPX_NLE_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32488 /* V_CMPX_NLE_F32 */, AMDGPU::V_CMPX_NLE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32488 /* V_CMPX_NLE_F32 */, AMDGPU::V_CMPX_NLE_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32503 /* v_cmpx_nle_f32_e32 */, AMDGPU::V_CMPX_NLE_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32503 /* v_cmpx_nle_f32_e32 */, AMDGPU::V_CMPX_NLE_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32503 /* v_cmpx_nle_f32_e32 */, AMDGPU::V_CMPX_NLE_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32503 /* v_cmpx_nle_f32_e32 */, AMDGPU::V_CMPX_NLE_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32503 /* v_cmpx_nle_f32_e32 */, AMDGPU::V_CMPX_NLE_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32522 /* V_CMPX_NLE_F64 */, AMDGPU::V_CMPX_NLE_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32522 /* V_CMPX_NLE_F64 */, AMDGPU::V_CMPX_NLE_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32522 /* V_CMPX_NLE_F64 */, AMDGPU::V_CMPX_NLE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32522 /* V_CMPX_NLE_F64 */, AMDGPU::V_CMPX_NLE_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32522 /* V_CMPX_NLE_F64 */, AMDGPU::V_CMPX_NLE_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32522 /* V_CMPX_NLE_F64 */, AMDGPU::V_CMPX_NLE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32522 /* V_CMPX_NLE_F64 */, AMDGPU::V_CMPX_NLE_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32522 /* V_CMPX_NLE_F64 */, AMDGPU::V_CMPX_NLE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32522 /* V_CMPX_NLE_F64 */, AMDGPU::V_CMPX_NLE_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32537 /* v_cmpx_nle_f64_e32 */, AMDGPU::V_CMPX_NLE_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32537 /* v_cmpx_nle_f64_e32 */, AMDGPU::V_CMPX_NLE_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32537 /* v_cmpx_nle_f64_e32 */, AMDGPU::V_CMPX_NLE_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32537 /* v_cmpx_nle_f64_e32 */, AMDGPU::V_CMPX_NLE_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32537 /* v_cmpx_nle_f64_e32 */, AMDGPU::V_CMPX_NLE_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32556 /* V_CMPX_NLG_F16 */, AMDGPU::V_CMPX_NLG_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32556 /* V_CMPX_NLG_F16 */, AMDGPU::V_CMPX_NLG_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32556 /* V_CMPX_NLG_F16 */, AMDGPU::V_CMPX_NLG_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32556 /* V_CMPX_NLG_F16 */, AMDGPU::V_CMPX_NLG_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32571 /* v_cmpx_nlg_f16_e32 */, AMDGPU::V_CMPX_NLG_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32571 /* v_cmpx_nlg_f16_e32 */, AMDGPU::V_CMPX_NLG_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32571 /* v_cmpx_nlg_f16_e32 */, AMDGPU::V_CMPX_NLG_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32571 /* v_cmpx_nlg_f16_e32 */, AMDGPU::V_CMPX_NLG_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32571 /* v_cmpx_nlg_f16_e32 */, AMDGPU::V_CMPX_NLG_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32571 /* v_cmpx_nlg_f16_e32 */, AMDGPU::V_CMPX_NLG_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32590 /* V_CMPX_NLG_F32 */, AMDGPU::V_CMPX_NLG_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32590 /* V_CMPX_NLG_F32 */, AMDGPU::V_CMPX_NLG_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32590 /* V_CMPX_NLG_F32 */, AMDGPU::V_CMPX_NLG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32590 /* V_CMPX_NLG_F32 */, AMDGPU::V_CMPX_NLG_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32590 /* V_CMPX_NLG_F32 */, AMDGPU::V_CMPX_NLG_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32590 /* V_CMPX_NLG_F32 */, AMDGPU::V_CMPX_NLG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32590 /* V_CMPX_NLG_F32 */, AMDGPU::V_CMPX_NLG_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32590 /* V_CMPX_NLG_F32 */, AMDGPU::V_CMPX_NLG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32590 /* V_CMPX_NLG_F32 */, AMDGPU::V_CMPX_NLG_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32605 /* v_cmpx_nlg_f32_e32 */, AMDGPU::V_CMPX_NLG_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32605 /* v_cmpx_nlg_f32_e32 */, AMDGPU::V_CMPX_NLG_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32605 /* v_cmpx_nlg_f32_e32 */, AMDGPU::V_CMPX_NLG_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32605 /* v_cmpx_nlg_f32_e32 */, AMDGPU::V_CMPX_NLG_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32605 /* v_cmpx_nlg_f32_e32 */, AMDGPU::V_CMPX_NLG_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32624 /* V_CMPX_NLG_F64 */, AMDGPU::V_CMPX_NLG_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32624 /* V_CMPX_NLG_F64 */, AMDGPU::V_CMPX_NLG_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32624 /* V_CMPX_NLG_F64 */, AMDGPU::V_CMPX_NLG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32624 /* V_CMPX_NLG_F64 */, AMDGPU::V_CMPX_NLG_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32624 /* V_CMPX_NLG_F64 */, AMDGPU::V_CMPX_NLG_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32624 /* V_CMPX_NLG_F64 */, AMDGPU::V_CMPX_NLG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32624 /* V_CMPX_NLG_F64 */, AMDGPU::V_CMPX_NLG_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32624 /* V_CMPX_NLG_F64 */, AMDGPU::V_CMPX_NLG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32624 /* V_CMPX_NLG_F64 */, AMDGPU::V_CMPX_NLG_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32639 /* v_cmpx_nlg_f64_e32 */, AMDGPU::V_CMPX_NLG_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32639 /* v_cmpx_nlg_f64_e32 */, AMDGPU::V_CMPX_NLG_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32639 /* v_cmpx_nlg_f64_e32 */, AMDGPU::V_CMPX_NLG_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32639 /* v_cmpx_nlg_f64_e32 */, AMDGPU::V_CMPX_NLG_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32639 /* v_cmpx_nlg_f64_e32 */, AMDGPU::V_CMPX_NLG_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32658 /* V_CMPX_NLT_F16 */, AMDGPU::V_CMPX_NLT_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32658 /* V_CMPX_NLT_F16 */, AMDGPU::V_CMPX_NLT_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32658 /* V_CMPX_NLT_F16 */, AMDGPU::V_CMPX_NLT_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32658 /* V_CMPX_NLT_F16 */, AMDGPU::V_CMPX_NLT_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32673 /* v_cmpx_nlt_f16_e32 */, AMDGPU::V_CMPX_NLT_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32673 /* v_cmpx_nlt_f16_e32 */, AMDGPU::V_CMPX_NLT_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32673 /* v_cmpx_nlt_f16_e32 */, AMDGPU::V_CMPX_NLT_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32673 /* v_cmpx_nlt_f16_e32 */, AMDGPU::V_CMPX_NLT_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32673 /* v_cmpx_nlt_f16_e32 */, AMDGPU::V_CMPX_NLT_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32673 /* v_cmpx_nlt_f16_e32 */, AMDGPU::V_CMPX_NLT_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32692 /* V_CMPX_NLT_F32 */, AMDGPU::V_CMPX_NLT_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32692 /* V_CMPX_NLT_F32 */, AMDGPU::V_CMPX_NLT_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32692 /* V_CMPX_NLT_F32 */, AMDGPU::V_CMPX_NLT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32692 /* V_CMPX_NLT_F32 */, AMDGPU::V_CMPX_NLT_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32692 /* V_CMPX_NLT_F32 */, AMDGPU::V_CMPX_NLT_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32692 /* V_CMPX_NLT_F32 */, AMDGPU::V_CMPX_NLT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32692 /* V_CMPX_NLT_F32 */, AMDGPU::V_CMPX_NLT_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32692 /* V_CMPX_NLT_F32 */, AMDGPU::V_CMPX_NLT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32692 /* V_CMPX_NLT_F32 */, AMDGPU::V_CMPX_NLT_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32707 /* v_cmpx_nlt_f32_e32 */, AMDGPU::V_CMPX_NLT_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32707 /* v_cmpx_nlt_f32_e32 */, AMDGPU::V_CMPX_NLT_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32707 /* v_cmpx_nlt_f32_e32 */, AMDGPU::V_CMPX_NLT_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32707 /* v_cmpx_nlt_f32_e32 */, AMDGPU::V_CMPX_NLT_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32707 /* v_cmpx_nlt_f32_e32 */, AMDGPU::V_CMPX_NLT_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32726 /* V_CMPX_NLT_F64 */, AMDGPU::V_CMPX_NLT_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32726 /* V_CMPX_NLT_F64 */, AMDGPU::V_CMPX_NLT_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32726 /* V_CMPX_NLT_F64 */, AMDGPU::V_CMPX_NLT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32726 /* V_CMPX_NLT_F64 */, AMDGPU::V_CMPX_NLT_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32726 /* V_CMPX_NLT_F64 */, AMDGPU::V_CMPX_NLT_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32726 /* V_CMPX_NLT_F64 */, AMDGPU::V_CMPX_NLT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32726 /* V_CMPX_NLT_F64 */, AMDGPU::V_CMPX_NLT_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32726 /* V_CMPX_NLT_F64 */, AMDGPU::V_CMPX_NLT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32726 /* V_CMPX_NLT_F64 */, AMDGPU::V_CMPX_NLT_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32741 /* v_cmpx_nlt_f64_e32 */, AMDGPU::V_CMPX_NLT_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32741 /* v_cmpx_nlt_f64_e32 */, AMDGPU::V_CMPX_NLT_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32741 /* v_cmpx_nlt_f64_e32 */, AMDGPU::V_CMPX_NLT_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32741 /* v_cmpx_nlt_f64_e32 */, AMDGPU::V_CMPX_NLT_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32741 /* v_cmpx_nlt_f64_e32 */, AMDGPU::V_CMPX_NLT_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32760 /* V_CMPX_O_F16 */, AMDGPU::V_CMPX_O_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32760 /* V_CMPX_O_F16 */, AMDGPU::V_CMPX_O_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32760 /* V_CMPX_O_F16 */, AMDGPU::V_CMPX_O_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32760 /* V_CMPX_O_F16 */, AMDGPU::V_CMPX_O_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32773 /* v_cmpx_o_f16_e32 */, AMDGPU::V_CMPX_O_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32773 /* v_cmpx_o_f16_e32 */, AMDGPU::V_CMPX_O_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 32773 /* v_cmpx_o_f16_e32 */, AMDGPU::V_CMPX_O_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32773 /* v_cmpx_o_f16_e32 */, AMDGPU::V_CMPX_O_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32773 /* v_cmpx_o_f16_e32 */, AMDGPU::V_CMPX_O_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32773 /* v_cmpx_o_f16_e32 */, AMDGPU::V_CMPX_O_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32790 /* V_CMPX_O_F32 */, AMDGPU::V_CMPX_O_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32790 /* V_CMPX_O_F32 */, AMDGPU::V_CMPX_O_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32790 /* V_CMPX_O_F32 */, AMDGPU::V_CMPX_O_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32790 /* V_CMPX_O_F32 */, AMDGPU::V_CMPX_O_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32790 /* V_CMPX_O_F32 */, AMDGPU::V_CMPX_O_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32790 /* V_CMPX_O_F32 */, AMDGPU::V_CMPX_O_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32790 /* V_CMPX_O_F32 */, AMDGPU::V_CMPX_O_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32790 /* V_CMPX_O_F32 */, AMDGPU::V_CMPX_O_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32790 /* V_CMPX_O_F32 */, AMDGPU::V_CMPX_O_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32803 /* v_cmpx_o_f32_e32 */, AMDGPU::V_CMPX_O_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32803 /* v_cmpx_o_f32_e32 */, AMDGPU::V_CMPX_O_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32803 /* v_cmpx_o_f32_e32 */, AMDGPU::V_CMPX_O_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32803 /* v_cmpx_o_f32_e32 */, AMDGPU::V_CMPX_O_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32803 /* v_cmpx_o_f32_e32 */, AMDGPU::V_CMPX_O_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32820 /* V_CMPX_O_F64 */, AMDGPU::V_CMPX_O_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32820 /* V_CMPX_O_F64 */, AMDGPU::V_CMPX_O_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32820 /* V_CMPX_O_F64 */, AMDGPU::V_CMPX_O_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32820 /* V_CMPX_O_F64 */, AMDGPU::V_CMPX_O_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32820 /* V_CMPX_O_F64 */, AMDGPU::V_CMPX_O_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32820 /* V_CMPX_O_F64 */, AMDGPU::V_CMPX_O_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32820 /* V_CMPX_O_F64 */, AMDGPU::V_CMPX_O_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32820 /* V_CMPX_O_F64 */, AMDGPU::V_CMPX_O_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32820 /* V_CMPX_O_F64 */, AMDGPU::V_CMPX_O_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32833 /* v_cmpx_o_f64_e32 */, AMDGPU::V_CMPX_O_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32833 /* v_cmpx_o_f64_e32 */, AMDGPU::V_CMPX_O_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32833 /* v_cmpx_o_f64_e32 */, AMDGPU::V_CMPX_O_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32833 /* v_cmpx_o_f64_e32 */, AMDGPU::V_CMPX_O_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32833 /* v_cmpx_o_f64_e32 */, AMDGPU::V_CMPX_O_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32850 /* v_cmpx_t_f16 */, AMDGPU::V_CMPX_T_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32850 /* v_cmpx_t_f16 */, AMDGPU::V_CMPX_T_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32863 /* v_cmpx_t_f16_e32 */, AMDGPU::V_CMPX_T_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 32863 /* v_cmpx_t_f16_e32 */, AMDGPU::V_CMPX_T_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 32880 /* v_cmpx_t_f32 */, AMDGPU::V_CMPX_T_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32893 /* v_cmpx_t_f32_e32 */, AMDGPU::V_CMPX_T_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 32910 /* v_cmpx_t_f64 */, AMDGPU::V_CMPX_T_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32923 /* v_cmpx_t_f64_e32 */, AMDGPU::V_CMPX_T_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 32940 /* V_CMPX_T_I16 */, AMDGPU::V_CMPX_T_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 32940 /* V_CMPX_T_I16 */, AMDGPU::V_CMPX_T_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 32940 /* V_CMPX_T_I16 */, AMDGPU::V_CMPX_T_I16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 32953 /* v_cmpx_t_i16_e32 */, AMDGPU::V_CMPX_T_I16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 32970 /* V_CMPX_T_I32 */, AMDGPU::V_CMPX_T_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32970 /* V_CMPX_T_I32 */, AMDGPU::V_CMPX_T_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32970 /* V_CMPX_T_I32 */, AMDGPU::V_CMPX_T_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32970 /* V_CMPX_T_I32 */, AMDGPU::V_CMPX_T_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32970 /* V_CMPX_T_I32 */, AMDGPU::V_CMPX_T_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32970 /* V_CMPX_T_I32 */, AMDGPU::V_CMPX_T_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32970 /* V_CMPX_T_I32 */, AMDGPU::V_CMPX_T_I32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32970 /* V_CMPX_T_I32 */, AMDGPU::V_CMPX_T_I32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32983 /* v_cmpx_t_i32_e32 */, AMDGPU::V_CMPX_T_I32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32983 /* v_cmpx_t_i32_e32 */, AMDGPU::V_CMPX_T_I32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32983 /* v_cmpx_t_i32_e32 */, AMDGPU::V_CMPX_T_I32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 32983 /* v_cmpx_t_i32_e32 */, AMDGPU::V_CMPX_T_I32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 33000 /* V_CMPX_T_I64 */, AMDGPU::V_CMPX_T_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33000 /* V_CMPX_T_I64 */, AMDGPU::V_CMPX_T_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33000 /* V_CMPX_T_I64 */, AMDGPU::V_CMPX_T_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33000 /* V_CMPX_T_I64 */, AMDGPU::V_CMPX_T_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33000 /* V_CMPX_T_I64 */, AMDGPU::V_CMPX_T_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33000 /* V_CMPX_T_I64 */, AMDGPU::V_CMPX_T_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33000 /* V_CMPX_T_I64 */, AMDGPU::V_CMPX_T_I64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33000 /* V_CMPX_T_I64 */, AMDGPU::V_CMPX_T_I64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33013 /* v_cmpx_t_i64_e32 */, AMDGPU::V_CMPX_T_I64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33013 /* v_cmpx_t_i64_e32 */, AMDGPU::V_CMPX_T_I64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33013 /* v_cmpx_t_i64_e32 */, AMDGPU::V_CMPX_T_I64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33013 /* v_cmpx_t_i64_e32 */, AMDGPU::V_CMPX_T_I64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33030 /* V_CMPX_T_U16 */, AMDGPU::V_CMPX_T_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 33030 /* V_CMPX_T_U16 */, AMDGPU::V_CMPX_T_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 33030 /* V_CMPX_T_U16 */, AMDGPU::V_CMPX_T_U16_e32_vi, Convert__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 33043 /* v_cmpx_t_u16_e32 */, AMDGPU::V_CMPX_T_U16_e32_vi, Convert__VSrc_b161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 33060 /* V_CMPX_T_U32 */, AMDGPU::V_CMPX_T_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 33060 /* V_CMPX_T_U32 */, AMDGPU::V_CMPX_T_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 33060 /* V_CMPX_T_U32 */, AMDGPU::V_CMPX_T_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 33060 /* V_CMPX_T_U32 */, AMDGPU::V_CMPX_T_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 33060 /* V_CMPX_T_U32 */, AMDGPU::V_CMPX_T_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 33060 /* V_CMPX_T_U32 */, AMDGPU::V_CMPX_T_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 33060 /* V_CMPX_T_U32 */, AMDGPU::V_CMPX_T_U32_e32_gfx6_gfx7, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 33060 /* V_CMPX_T_U32 */, AMDGPU::V_CMPX_T_U32_e32_vi, Convert__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 33073 /* v_cmpx_t_u32_e32 */, AMDGPU::V_CMPX_T_U32_e32_gfx10, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 33073 /* v_cmpx_t_u32_e32 */, AMDGPU::V_CMPX_T_U32_e32_gfx11, Convert__VSrc_b321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 33073 /* v_cmpx_t_u32_e32 */, AMDGPU::V_CMPX_T_U32_e32_gfx6_gfx7, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 33073 /* v_cmpx_t_u32_e32 */, AMDGPU::V_CMPX_T_U32_e32_vi, Convert__VSrc_b321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 33090 /* V_CMPX_T_U64 */, AMDGPU::V_CMPX_T_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33090 /* V_CMPX_T_U64 */, AMDGPU::V_CMPX_T_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33090 /* V_CMPX_T_U64 */, AMDGPU::V_CMPX_T_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33090 /* V_CMPX_T_U64 */, AMDGPU::V_CMPX_T_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33090 /* V_CMPX_T_U64 */, AMDGPU::V_CMPX_T_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33090 /* V_CMPX_T_U64 */, AMDGPU::V_CMPX_T_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33090 /* V_CMPX_T_U64 */, AMDGPU::V_CMPX_T_U64_e32_gfx6_gfx7, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33090 /* V_CMPX_T_U64 */, AMDGPU::V_CMPX_T_U64_e32_vi, Convert__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33103 /* v_cmpx_t_u64_e32 */, AMDGPU::V_CMPX_T_U64_e32_gfx10, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33103 /* v_cmpx_t_u64_e32 */, AMDGPU::V_CMPX_T_U64_e32_gfx11, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33103 /* v_cmpx_t_u64_e32 */, AMDGPU::V_CMPX_T_U64_e32_gfx6_gfx7, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33103 /* v_cmpx_t_u64_e32 */, AMDGPU::V_CMPX_T_U64_e32_vi, Convert__VSrc_b641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33120 /* V_CMPX_TRU_F16 */, AMDGPU::V_CMPX_TRU_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 33120 /* V_CMPX_TRU_F16 */, AMDGPU::V_CMPX_TRU_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 33120 /* V_CMPX_TRU_F16 */, AMDGPU::V_CMPX_TRU_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 33120 /* V_CMPX_TRU_F16 */, AMDGPU::V_CMPX_TRU_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 33135 /* v_cmpx_tru_f16_e32 */, AMDGPU::V_CMPX_TRU_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 33135 /* v_cmpx_tru_f16_e32 */, AMDGPU::V_CMPX_TRU_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 33154 /* V_CMPX_TRU_F32 */, AMDGPU::V_CMPX_TRU_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33154 /* V_CMPX_TRU_F32 */, AMDGPU::V_CMPX_TRU_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33154 /* V_CMPX_TRU_F32 */, AMDGPU::V_CMPX_TRU_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33154 /* V_CMPX_TRU_F32 */, AMDGPU::V_CMPX_TRU_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33154 /* V_CMPX_TRU_F32 */, AMDGPU::V_CMPX_TRU_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33154 /* V_CMPX_TRU_F32 */, AMDGPU::V_CMPX_TRU_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33154 /* V_CMPX_TRU_F32 */, AMDGPU::V_CMPX_TRU_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33169 /* v_cmpx_tru_f32_e32 */, AMDGPU::V_CMPX_TRU_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33169 /* v_cmpx_tru_f32_e32 */, AMDGPU::V_CMPX_TRU_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33169 /* v_cmpx_tru_f32_e32 */, AMDGPU::V_CMPX_TRU_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33188 /* V_CMPX_TRU_F64 */, AMDGPU::V_CMPX_TRU_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33188 /* V_CMPX_TRU_F64 */, AMDGPU::V_CMPX_TRU_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33188 /* V_CMPX_TRU_F64 */, AMDGPU::V_CMPX_TRU_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33188 /* V_CMPX_TRU_F64 */, AMDGPU::V_CMPX_TRU_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33188 /* V_CMPX_TRU_F64 */, AMDGPU::V_CMPX_TRU_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33188 /* V_CMPX_TRU_F64 */, AMDGPU::V_CMPX_TRU_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33188 /* V_CMPX_TRU_F64 */, AMDGPU::V_CMPX_TRU_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33203 /* v_cmpx_tru_f64_e32 */, AMDGPU::V_CMPX_TRU_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33203 /* v_cmpx_tru_f64_e32 */, AMDGPU::V_CMPX_TRU_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33203 /* v_cmpx_tru_f64_e32 */, AMDGPU::V_CMPX_TRU_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33222 /* V_CMPX_U_F16 */, AMDGPU::V_CMPX_U_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 33222 /* V_CMPX_U_F16 */, AMDGPU::V_CMPX_U_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 33222 /* V_CMPX_U_F16 */, AMDGPU::V_CMPX_U_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 33222 /* V_CMPX_U_F16 */, AMDGPU::V_CMPX_U_F16_e32_vi, Convert__VSrc_f161_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 33235 /* v_cmpx_u_f16_e32 */, AMDGPU::V_CMPX_U_F16_e32_gfx10, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 33235 /* v_cmpx_u_f16_e32 */, AMDGPU::V_CMPX_U_F16_e32_vi, Convert__VSrc_f161_0__Reg1_1, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 33235 /* v_cmpx_u_f16_e32 */, AMDGPU::V_CMPX_U_F16_t16_e32_gfx11, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 33235 /* v_cmpx_u_f16_e32 */, AMDGPU::V_CMPX_U_F16_t16_e32_gfx12, Convert__VSrcT_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 33235 /* v_cmpx_u_f16_e32 */, AMDGPU::V_CMPX_U_F16_fake16_e32_gfx11, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX11Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 33235 /* v_cmpx_u_f16_e32 */, AMDGPU::V_CMPX_U_F16_fake16_e32_gfx12, Convert__VSrcFake16_f16_Lo1281_0__Reg1_1, AMFBS_Has16BitInsts_isGFX12Only_UseFakeTrue16Insts, { MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 33252 /* V_CMPX_U_F32 */, AMDGPU::V_CMPX_U_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33252 /* V_CMPX_U_F32 */, AMDGPU::V_CMPX_U_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33252 /* V_CMPX_U_F32 */, AMDGPU::V_CMPX_U_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33252 /* V_CMPX_U_F32 */, AMDGPU::V_CMPX_U_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33252 /* V_CMPX_U_F32 */, AMDGPU::V_CMPX_U_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33252 /* V_CMPX_U_F32 */, AMDGPU::V_CMPX_U_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33252 /* V_CMPX_U_F32 */, AMDGPU::V_CMPX_U_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33252 /* V_CMPX_U_F32 */, AMDGPU::V_CMPX_U_F32_e32_gfx6_gfx7, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33252 /* V_CMPX_U_F32 */, AMDGPU::V_CMPX_U_F32_e32_vi, Convert__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33265 /* v_cmpx_u_f32_e32 */, AMDGPU::V_CMPX_U_F32_e32_gfx10, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33265 /* v_cmpx_u_f32_e32 */, AMDGPU::V_CMPX_U_F32_e32_gfx11, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33265 /* v_cmpx_u_f32_e32 */, AMDGPU::V_CMPX_U_F32_e32_gfx12, Convert__VSrc_f321_0__Reg1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33265 /* v_cmpx_u_f32_e32 */, AMDGPU::V_CMPX_U_F32_e32_gfx6_gfx7, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33265 /* v_cmpx_u_f32_e32 */, AMDGPU::V_CMPX_U_F32_e32_vi, Convert__VSrc_f321_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33282 /* V_CMPX_U_F64 */, AMDGPU::V_CMPX_U_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33282 /* V_CMPX_U_F64 */, AMDGPU::V_CMPX_U_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33282 /* V_CMPX_U_F64 */, AMDGPU::V_CMPX_U_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33282 /* V_CMPX_U_F64 */, AMDGPU::V_CMPX_U_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33282 /* V_CMPX_U_F64 */, AMDGPU::V_CMPX_U_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33282 /* V_CMPX_U_F64 */, AMDGPU::V_CMPX_U_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33282 /* V_CMPX_U_F64 */, AMDGPU::V_CMPX_U_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VCC, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33282 /* V_CMPX_U_F64 */, AMDGPU::V_CMPX_U_F64_e32_gfx6_gfx7, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33282 /* V_CMPX_U_F64 */, AMDGPU::V_CMPX_U_F64_e32_vi, Convert__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VCC_LO, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33295 /* v_cmpx_u_f64_e32 */, AMDGPU::V_CMPX_U_F64_e32_gfx10, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33295 /* v_cmpx_u_f64_e32 */, AMDGPU::V_CMPX_U_F64_e32_gfx11, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33295 /* v_cmpx_u_f64_e32 */, AMDGPU::V_CMPX_U_F64_e32_gfx12, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33295 /* v_cmpx_u_f64_e32 */, AMDGPU::V_CMPX_U_F64_e32_gfx6_gfx7, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX6GFX7, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33295 /* v_cmpx_u_f64_e32 */, AMDGPU::V_CMPX_U_F64_e32_vi, Convert__VSrc_f641_0__RegByHwMode_VReg_64_AlignTarget1_1, AMFBS_isGFX8GFX9, { MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e32_vi, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Plus_isWave64, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave64, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave64, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave64, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e32_vi, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave64, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Plus_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC_LO }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC_LO }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC_LO }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC_LO }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e32_vi, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC_LO }, },
  { 33340 /* v_cos_bf16 */, AMDGPU::V_COS_BF16V_COS_BF16_fake16_e32_gfx1250, Convert__Reg1_0__VSrcFake16_bf16_Lo1281_1, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_bf16_Lo128 }, },
  { 33340 /* v_cos_bf16 */, AMDGPU::V_COS_BF16V_COS_BF16_t16_e32_gfx1250, Convert__Reg1_0__VSrcT_bf16_Lo1281_1, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VSrcT_bf16_Lo128 }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 33371 /* v_ctz_i32_b32 */, AMDGPU::V_CTZ_I32_B32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33371 /* v_ctz_i32_b32 */, AMDGPU::V_CTZ_I32_B32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33437 /* v_cvt_f16_bf8 */, AMDGPU::V_CVT_F16_BF8V_CVT_F16_BF8_fake16_e32_gfx1250, Convert__Reg1_0__VSrc_b321_1, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VSrc_b32 }, },
  { 33437 /* v_cvt_f16_bf8 */, AMDGPU::V_CVT_F16_BF8V_CVT_F16_BF8_t16_e32_gfx1250, Convert__Reg1_0__VSrc_b321_1, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VSrc_b32 }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_fake16_e32_gfx11, Convert__Reg1_0__VSrc_f321_1, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrc_f32 }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_fake16_e32_gfx12, Convert__Reg1_0__VSrc_f321_1, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrc_f32 }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_t16_e32_gfx11, Convert__Reg1_0__VSrc_f321_1, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrc_f32 }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_t16_e32_gfx12, Convert__Reg1_0__VSrc_f321_1, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrc_f32 }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1, AMFBS_NotHasTrue16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_NotHasTrue16BitInsts_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1, AMFBS_NotHasTrue16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 33465 /* v_cvt_f16_fp8 */, AMDGPU::V_CVT_F16_FP8V_CVT_F16_FP8_fake16_e32_gfx1250, Convert__Reg1_0__VSrc_b321_1, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VSrc_b32 }, },
  { 33465 /* v_cvt_f16_fp8 */, AMDGPU::V_CVT_F16_FP8V_CVT_F16_FP8_t16_e32_gfx1250, Convert__Reg1_0__VSrc_b321_1, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VSrc_b32 }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_b16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_b16_Lo128 }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_b16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_b16_Lo128 }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_b16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_b16_Lo128 }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_b16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_b16_Lo128 }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16_e32_gfx10, Convert__Reg1_0__VSrc_b161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b16 }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16_e32_vi, Convert__Reg1_0__VSrc_b161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b16 }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_b16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_b16_Lo128 }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_b16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_b16_Lo128 }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_b16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_b16_Lo128 }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_b16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_b16_Lo128 }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16_e32_gfx10, Convert__Reg1_0__VSrc_b161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b16 }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16_e32_vi, Convert__Reg1_0__VSrc_b161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b16 }, },
  { 33507 /* v_cvt_f32_bf16 */, AMDGPU::V_CVT_F32_BF16_e32_vi, Convert__Reg1_0__VSrc_bf161_1, AMFBS_HasBF16ConversionInsts_HasGFX950Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_bf16 }, },
  { 33507 /* v_cvt_f32_bf16 */, AMDGPU::V_CVT_F32_BF16_gfx1250V_CVT_F32_BF16_gfx1250_t16_e32_gfx1250, Convert__Reg1_0__VSrcT_bf16_Lo1281_1, AMFBS_HasBF16ConversionInsts_isGFX1250Plus_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VSrcT_bf16_Lo128 }, },
  { 33507 /* v_cvt_f32_bf16 */, AMDGPU::V_CVT_F32_BF16_gfx1250V_CVT_F32_BF16_gfx1250_fake16_e32_gfx1250, Convert__Reg1_0__VSrcFake16_bf16_Lo1281_1, AMFBS_HasBF16ConversionInsts_isGFX1250Plus_isGFX125xOnly_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VSrcFake16_bf16_Lo128 }, },
  { 33522 /* v_cvt_f32_bf8 */, AMDGPU::V_CVT_F32_BF8_e32_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33522 /* v_cvt_f32_bf8 */, AMDGPU::V_CVT_F32_BF8_e32_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_HasFP8ConversionInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VSrcT_f16_Lo128 }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrcT_f16_Lo128 }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VSrcFake16_f16_Lo128 }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrcFake16_f16_Lo128 }, },
  { 33550 /* v_cvt_f32_f64 */, AMDGPU::V_CVT_F32_F64_e32_gfx10, Convert__Reg1_0__VSrc_f641_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f64 }, },
  { 33550 /* v_cvt_f32_f64 */, AMDGPU::V_CVT_F32_F64_e32_gfx11, Convert__Reg1_0__VSrc_f641_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f64 }, },
  { 33550 /* v_cvt_f32_f64 */, AMDGPU::V_CVT_F32_F64_e32_gfx12, Convert__Reg1_0__VSrc_f641_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f64 }, },
  { 33550 /* v_cvt_f32_f64 */, AMDGPU::V_CVT_F32_F64_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f641_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f64 }, },
  { 33550 /* v_cvt_f32_f64 */, AMDGPU::V_CVT_F32_F64_e32_vi, Convert__Reg1_0__VSrc_f641_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f64 }, },
  { 33564 /* v_cvt_f32_fp8 */, AMDGPU::V_CVT_F32_FP8_e32_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_HasFP8ConversionInsts_isGFX12PlusNot12_50_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33564 /* v_cvt_f32_fp8 */, AMDGPU::V_CVT_F32_FP8_e32_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_HasFP8ConversionInsts_isGFX12PlusNot12_50_isGFX12Not12_50, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33564 /* v_cvt_f32_fp8 */, AMDGPU::V_CVT_F32_FP8_e32_gfx1250, Convert__Reg1_0__VSrc_b321_1, AMFBS_HasFP8ConversionInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33564 /* v_cvt_f32_fp8 */, AMDGPU::V_CVT_F32_FP8_e32_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_HasFP8ConversionInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_e32_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_e32_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_e32_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_e32_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_e32_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_e32_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_e32_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_e32_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_e32_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_e32_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_e32_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_e32_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_e32_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_e32_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_e32_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_e32_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_e32_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_e32_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33674 /* v_cvt_f64_f32 */, AMDGPU::V_CVT_F64_F32_e32_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f321_1, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f32 }, },
  { 33674 /* v_cvt_f64_f32 */, AMDGPU::V_CVT_F64_F32_e32_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f321_1, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f32 }, },
  { 33674 /* v_cvt_f64_f32 */, AMDGPU::V_CVT_F64_F32_e32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f321_1, AMFBS_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f32 }, },
  { 33674 /* v_cvt_f64_f32 */, AMDGPU::V_CVT_F64_F32_e32_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f32 }, },
  { 33674 /* v_cvt_f64_f32 */, AMDGPU::V_CVT_F64_F32_e32_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f321_1, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f32 }, },
  { 33688 /* v_cvt_f64_i32 */, AMDGPU::V_CVT_F64_I32_e32_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32 }, },
  { 33688 /* v_cvt_f64_i32 */, AMDGPU::V_CVT_F64_I32_e32_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32 }, },
  { 33688 /* v_cvt_f64_i32 */, AMDGPU::V_CVT_F64_I32_e32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1, AMFBS_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32 }, },
  { 33688 /* v_cvt_f64_i32 */, AMDGPU::V_CVT_F64_I32_e32_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32 }, },
  { 33688 /* v_cvt_f64_i32 */, AMDGPU::V_CVT_F64_I32_e32_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32 }, },
  { 33702 /* v_cvt_f64_u32 */, AMDGPU::V_CVT_F64_U32_e32_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32 }, },
  { 33702 /* v_cvt_f64_u32 */, AMDGPU::V_CVT_F64_U32_e32_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32 }, },
  { 33702 /* v_cvt_f64_u32 */, AMDGPU::V_CVT_F64_U32_e32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1, AMFBS_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32 }, },
  { 33702 /* v_cvt_f64_u32 */, AMDGPU::V_CVT_F64_U32_e32_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32 }, },
  { 33702 /* v_cvt_f64_u32 */, AMDGPU::V_CVT_F64_U32_e32_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32 }, },
  { 33716 /* v_cvt_floor_i32_f32 */, AMDGPU::V_CVT_FLOOR_I32_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 33716 /* v_cvt_floor_i32_f32 */, AMDGPU::V_CVT_FLOOR_I32_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 33736 /* v_cvt_flr_i32_f32 */, AMDGPU::V_CVT_FLR_I32_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 33736 /* v_cvt_flr_i32_f32 */, AMDGPU::V_CVT_FLR_I32_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 33736 /* v_cvt_flr_i32_f32 */, AMDGPU::V_CVT_FLR_I32_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 33782 /* v_cvt_i32_f64 */, AMDGPU::V_CVT_I32_F64_e32_gfx10, Convert__Reg1_0__VSrc_f641_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f64 }, },
  { 33782 /* v_cvt_i32_f64 */, AMDGPU::V_CVT_I32_F64_e32_gfx11, Convert__Reg1_0__VSrc_f641_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f64 }, },
  { 33782 /* v_cvt_i32_f64 */, AMDGPU::V_CVT_I32_F64_e32_gfx12, Convert__Reg1_0__VSrc_f641_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f64 }, },
  { 33782 /* v_cvt_i32_f64 */, AMDGPU::V_CVT_I32_F64_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f641_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f64 }, },
  { 33782 /* v_cvt_i32_f64 */, AMDGPU::V_CVT_I32_F64_e32_vi, Convert__Reg1_0__VSrc_f641_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f64 }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_b16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrcT_b16_Lo128 }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_b16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrcT_b16_Lo128 }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_b16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrcFake16_b16_Lo128 }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_b16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrcFake16_b16_Lo128 }, },
  { 33810 /* v_cvt_nearest_i32_f32 */, AMDGPU::V_CVT_NEAREST_I32_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 33810 /* v_cvt_nearest_i32_f32 */, AMDGPU::V_CVT_NEAREST_I32_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasCvtNormInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasCvtNormInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasCvtNormInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasCvtNormInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_e32_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_e32_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_e32_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_e32_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33939 /* v_cvt_pk_f16_bf8 */, AMDGPU::V_CVT_PK_F16_BF8V_CVT_PK_F16_BF8_t16_e32_gfx1250, Convert__Reg1_0__VSrcT_b16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrcT_b16_Lo128 }, },
  { 33939 /* v_cvt_pk_f16_bf8 */, AMDGPU::V_CVT_PK_F16_BF8V_CVT_PK_F16_BF8_fake16_e32_gfx1250, Convert__Reg1_0__VSrcFake16_b16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrcFake16_b16_Lo128 }, },
  { 33973 /* v_cvt_pk_f16_fp8 */, AMDGPU::V_CVT_PK_F16_FP8V_CVT_PK_F16_FP8_t16_e32_gfx1250, Convert__Reg1_0__VSrcT_b16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrcT_b16_Lo128 }, },
  { 33973 /* v_cvt_pk_f16_fp8 */, AMDGPU::V_CVT_PK_F16_FP8V_CVT_PK_F16_FP8_fake16_e32_gfx1250, Convert__Reg1_0__VSrcFake16_b16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrcFake16_b16_Lo128 }, },
  { 33990 /* v_cvt_pk_f32_bf8 */, AMDGPU::V_CVT_PK_F32_BF8_t16_e32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrcT_f16_Lo1281_1, AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX12Only_UseRealTrue16Insts, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrcT_f16_Lo128 }, },
  { 33990 /* v_cvt_pk_f32_bf8 */, AMDGPU::V_CVT_PK_F32_BF8_fake16_e32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrcFake16_f16_Lo1281_1, AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX12Only_UseFakeTrue16Insts, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrcFake16_f16_Lo128 }, },
  { 33990 /* v_cvt_pk_f32_bf8 */, AMDGPU::V_CVT_PK_F32_BF8_e32_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1, AMFBS_HasFP8ConversionInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32 }, },
  { 34007 /* v_cvt_pk_f32_fp8 */, AMDGPU::V_CVT_PK_F32_FP8_t16_e32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrcT_f16_Lo1281_1, AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX12Only_UseRealTrue16Insts, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrcT_f16_Lo128 }, },
  { 34007 /* v_cvt_pk_f32_fp8 */, AMDGPU::V_CVT_PK_F32_FP8_fake16_e32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrcFake16_f16_Lo1281_1, AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX12Only_UseFakeTrue16Insts, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrcFake16_f16_Lo128 }, },
  { 34007 /* v_cvt_pk_f32_fp8 */, AMDGPU::V_CVT_PK_F32_FP8_e32_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1, AMFBS_HasFP8ConversionInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32 }, },
  { 34075 /* v_cvt_pk_i16_i32 */, AMDGPU::V_CVT_PK_I16_I32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 34180 /* v_cvt_pk_rtz_f16_f32 */, AMDGPU::V_CVT_PK_RTZ_F16_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 34180 /* v_cvt_pk_rtz_f16_f32 */, AMDGPU::V_CVT_PK_RTZ_F16_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 34218 /* v_cvt_pk_u16_u32 */, AMDGPU::V_CVT_PK_U16_U32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 34251 /* v_cvt_pkaccum_u8_f32 */, AMDGPU::V_CVT_PKACCUM_U8_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 34293 /* v_cvt_pknorm_i16_f32 */, AMDGPU::V_CVT_PKNORM_I16_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_HasCvtPkNormVOP2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 34335 /* v_cvt_pknorm_u16_f32 */, AMDGPU::V_CVT_PKNORM_U16_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_HasCvtPkNormVOP2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 34356 /* v_cvt_pkrtz_f16_f32 */, AMDGPU::V_CVT_PKRTZ_F16_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 34356 /* v_cvt_pkrtz_f16_f32 */, AMDGPU::V_CVT_PKRTZ_F16_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 34376 /* v_cvt_rpi_i32_f32 */, AMDGPU::V_CVT_RPI_I32_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 34376 /* v_cvt_rpi_i32_f32 */, AMDGPU::V_CVT_RPI_I32_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 34376 /* v_cvt_rpi_i32_f32 */, AMDGPU::V_CVT_RPI_I32_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 37158 /* v_cvt_u32_f64 */, AMDGPU::V_CVT_U32_F64_e32_gfx10, Convert__Reg1_0__VSrc_f641_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f64 }, },
  { 37158 /* v_cvt_u32_f64 */, AMDGPU::V_CVT_U32_F64_e32_gfx11, Convert__Reg1_0__VSrc_f641_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f64 }, },
  { 37158 /* v_cvt_u32_f64 */, AMDGPU::V_CVT_U32_F64_e32_gfx12, Convert__Reg1_0__VSrc_f641_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f64 }, },
  { 37158 /* v_cvt_u32_f64 */, AMDGPU::V_CVT_U32_F64_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f641_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f64 }, },
  { 37158 /* v_cvt_u32_f64 */, AMDGPU::V_CVT_U32_F64_e32_vi, Convert__Reg1_0__VSrc_f641_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f64 }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_b16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrcT_b16_Lo128 }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_b16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrcT_b16_Lo128 }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_b16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrcFake16_b16_Lo128 }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_b16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrcFake16_b16_Lo128 }, },
  { 37412 /* v_dot2acc_f32_f16 */, AMDGPU::V_DOT2ACC_F32_F16_e32_gfx11, Convert__Reg1_0__VSrc_v2f161_1__Reg1_2__Tie0_1_1, AMFBS_HasDot5Insts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37430 /* v_dot2c_f32_bf16 */, AMDGPU::V_DOT2C_F32_BF16_e32_vi, Convert__Reg1_0__VSrc_v2bf161_1__Reg1_2__Tie0_1_1, AMFBS_HasDot13Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37447 /* v_dot2c_f32_f16 */, AMDGPU::V_DOT2C_F32_F16_e32_gfx10, Convert__Reg1_0__VSrc_v2f161_1__Reg1_2__Tie0_1_1, AMFBS_HasDot5Insts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37447 /* v_dot2c_f32_f16 */, AMDGPU::V_DOT2C_F32_F16_e32_vi, Convert__Reg1_0__VSrc_v2f161_1__Reg1_2__Tie0_1_1, AMFBS_HasDot5Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37463 /* v_dot2c_i32_i16 */, AMDGPU::V_DOT2C_I32_I16_e32_vi, Convert__Reg1_0__VSrc_b321_1__Reg1_2__Tie0_1_1, AMFBS_HasDot4Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37598 /* v_dot4c_i32_i8 */, AMDGPU::V_DOT4C_I32_I8_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2__Tie0_1_1, AMFBS_HasDot6Insts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37598 /* v_dot4c_i32_i8 */, AMDGPU::V_DOT4C_I32_I8_e32_vi, Convert__Reg1_0__VSrc_b321_1__Reg1_2__Tie0_1_1, AMFBS_HasDot6Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37656 /* v_dot8c_i32_i4 */, AMDGPU::V_DOT8C_I32_I4_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2__Tie0_1_1, AMFBS_HasDot3Insts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37656 /* v_dot8c_i32_i4 */, AMDGPU::V_DOT8C_I32_I4_e32_vi, Convert__Reg1_0__VSrc_b321_1__Reg1_2__Tie0_1_1, AMFBS_HasDot3Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MOV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MOV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MOV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_ADD_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_ADD_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_ADD_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_ADD_U32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_ADD_U32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_ADD_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_AND_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_AND_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_ASHRREV_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_CNDMASK_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_CNDMASK_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_CNDMASK_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_DOT2C_F32_BF16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_DOT2C_F32_BF16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_DOT2C_F32_BF16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_DOT2C_F32_F16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_DOT2C_F32_F16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_DOT2C_F32_F16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_FMAC_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_FMAC_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_FMAC_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_LSHLREV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_LSHLREV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_LSHLREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_LSHRREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MAX_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MAX_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MAX_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MAX_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MIN_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MIN_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MIN_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MIN_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MUL_LEGACY_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MUL_LEGACY_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MUL_LEGACY_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MUL_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MUL_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_MUL_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_SUB_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_SUB_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_SUB_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_SUB_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_SUBREV_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_SUBREV_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_SUBREV_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_FMAAK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_FMAAK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_FMAAK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_FMAMK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_FMAMK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37671 /* v_dual_add_f32 */, AMDGPU::V_DUAL_ADD_F32_e32_X_FMAMK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37686 /* v_dual_add_f64 */, AMDGPU::V_DUAL_ADD_F64_pseudo_e32_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 37686 /* v_dual_add_f64 */, AMDGPU::V_DUAL_ADD_F64_pseudo_e32_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37686 /* v_dual_add_f64 */, AMDGPU::V_DUAL_ADD_F64_pseudo_e32_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37686 /* v_dual_add_f64 */, AMDGPU::V_DUAL_ADD_F64_pseudo_e32_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37686 /* v_dual_add_f64 */, AMDGPU::V_DUAL_ADD_F64_pseudo_e32_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37686 /* v_dual_add_f64 */, AMDGPU::V_DUAL_ADD_F64_pseudo_e32_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37686 /* v_dual_add_f64 */, AMDGPU::V_DUAL_ADD_F64_pseudo_e32_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37686 /* v_dual_add_f64 */, AMDGPU::V_DUAL_ADD_F64_pseudo_e32_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37686 /* v_dual_add_f64 */, AMDGPU::V_DUAL_ADD_F64_pseudo_e32_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37686 /* v_dual_add_f64 */, AMDGPU::V_DUAL_ADD_F64_pseudo_e32_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37686 /* v_dual_add_f64 */, AMDGPU::V_DUAL_ADD_F64_pseudo_e32_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37686 /* v_dual_add_f64 */, AMDGPU::V_DUAL_ADD_F64_pseudo_e32_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37686 /* v_dual_add_f64 */, AMDGPU::V_DUAL_ADD_F64_pseudo_e32_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37686 /* v_dual_add_f64 */, AMDGPU::V_DUAL_ADD_F64_pseudo_e32_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37686 /* v_dual_add_f64 */, AMDGPU::V_DUAL_ADD_F64_pseudo_e32_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37686 /* v_dual_add_f64 */, AMDGPU::V_DUAL_ADD_F64_pseudo_e32_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37686 /* v_dual_add_f64 */, AMDGPU::V_DUAL_ADD_F64_pseudo_e32_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37686 /* v_dual_add_f64 */, AMDGPU::V_DUAL_ADD_F64_pseudo_e32_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37686 /* v_dual_add_f64 */, AMDGPU::V_DUAL_ADD_F64_pseudo_e32_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 37686 /* v_dual_add_f64 */, AMDGPU::V_DUAL_ADD_F64_pseudo_e32_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 37686 /* v_dual_add_f64 */, AMDGPU::V_DUAL_ADD_F64_pseudo_e32_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37701 /* v_dual_add_nc_u32 */, AMDGPU::V_DUAL_ADD_U32_e32_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 37701 /* v_dual_add_nc_u32 */, AMDGPU::V_DUAL_ADD_U32_e32_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37701 /* v_dual_add_nc_u32 */, AMDGPU::V_DUAL_ADD_U32_e32_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37701 /* v_dual_add_nc_u32 */, AMDGPU::V_DUAL_ADD_U32_e32_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37701 /* v_dual_add_nc_u32 */, AMDGPU::V_DUAL_ADD_U32_e32_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37701 /* v_dual_add_nc_u32 */, AMDGPU::V_DUAL_ADD_U32_e32_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37701 /* v_dual_add_nc_u32 */, AMDGPU::V_DUAL_ADD_U32_e32_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37701 /* v_dual_add_nc_u32 */, AMDGPU::V_DUAL_ADD_U32_e32_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37701 /* v_dual_add_nc_u32 */, AMDGPU::V_DUAL_ADD_U32_e32_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37701 /* v_dual_add_nc_u32 */, AMDGPU::V_DUAL_ADD_U32_e32_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37701 /* v_dual_add_nc_u32 */, AMDGPU::V_DUAL_ADD_U32_e32_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37701 /* v_dual_add_nc_u32 */, AMDGPU::V_DUAL_ADD_U32_e32_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37701 /* v_dual_add_nc_u32 */, AMDGPU::V_DUAL_ADD_U32_e32_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37701 /* v_dual_add_nc_u32 */, AMDGPU::V_DUAL_ADD_U32_e32_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37701 /* v_dual_add_nc_u32 */, AMDGPU::V_DUAL_ADD_U32_e32_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37701 /* v_dual_add_nc_u32 */, AMDGPU::V_DUAL_ADD_U32_e32_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37701 /* v_dual_add_nc_u32 */, AMDGPU::V_DUAL_ADD_U32_e32_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37701 /* v_dual_add_nc_u32 */, AMDGPU::V_DUAL_ADD_U32_e32_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37701 /* v_dual_add_nc_u32 */, AMDGPU::V_DUAL_ADD_U32_e32_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 37701 /* v_dual_add_nc_u32 */, AMDGPU::V_DUAL_ADD_U32_e32_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 37701 /* v_dual_add_nc_u32 */, AMDGPU::V_DUAL_ADD_U32_e32_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37719 /* v_dual_ashrrev_i32 */, AMDGPU::V_DUAL_ASHRREV_I32_e32_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 37719 /* v_dual_ashrrev_i32 */, AMDGPU::V_DUAL_ASHRREV_I32_e32_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37719 /* v_dual_ashrrev_i32 */, AMDGPU::V_DUAL_ASHRREV_I32_e32_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37719 /* v_dual_ashrrev_i32 */, AMDGPU::V_DUAL_ASHRREV_I32_e32_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37719 /* v_dual_ashrrev_i32 */, AMDGPU::V_DUAL_ASHRREV_I32_e32_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37719 /* v_dual_ashrrev_i32 */, AMDGPU::V_DUAL_ASHRREV_I32_e32_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37719 /* v_dual_ashrrev_i32 */, AMDGPU::V_DUAL_ASHRREV_I32_e32_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37719 /* v_dual_ashrrev_i32 */, AMDGPU::V_DUAL_ASHRREV_I32_e32_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37719 /* v_dual_ashrrev_i32 */, AMDGPU::V_DUAL_ASHRREV_I32_e32_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37719 /* v_dual_ashrrev_i32 */, AMDGPU::V_DUAL_ASHRREV_I32_e32_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37719 /* v_dual_ashrrev_i32 */, AMDGPU::V_DUAL_ASHRREV_I32_e32_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37719 /* v_dual_ashrrev_i32 */, AMDGPU::V_DUAL_ASHRREV_I32_e32_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37719 /* v_dual_ashrrev_i32 */, AMDGPU::V_DUAL_ASHRREV_I32_e32_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37719 /* v_dual_ashrrev_i32 */, AMDGPU::V_DUAL_ASHRREV_I32_e32_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37719 /* v_dual_ashrrev_i32 */, AMDGPU::V_DUAL_ASHRREV_I32_e32_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37719 /* v_dual_ashrrev_i32 */, AMDGPU::V_DUAL_ASHRREV_I32_e32_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37719 /* v_dual_ashrrev_i32 */, AMDGPU::V_DUAL_ASHRREV_I32_e32_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37719 /* v_dual_ashrrev_i32 */, AMDGPU::V_DUAL_ASHRREV_I32_e32_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37719 /* v_dual_ashrrev_i32 */, AMDGPU::V_DUAL_ASHRREV_I32_e32_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 37719 /* v_dual_ashrrev_i32 */, AMDGPU::V_DUAL_ASHRREV_I32_e32_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 37719 /* v_dual_ashrrev_i32 */, AMDGPU::V_DUAL_ASHRREV_I32_e32_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MOV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MOV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MOV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_ADD_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_ADD_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_ADD_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_ADD_U32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_ADD_U32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_ADD_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_AND_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_AND_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_ASHRREV_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_CNDMASK_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_CNDMASK_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_CNDMASK_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_DOT2C_F32_BF16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_DOT2C_F32_BF16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_DOT2C_F32_BF16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_DOT2C_F32_F16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_DOT2C_F32_F16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_DOT2C_F32_F16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_FMAC_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_FMAC_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_FMAC_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_LSHLREV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_LSHLREV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_LSHLREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_LSHRREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MAX_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MAX_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MAX_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MAX_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MIN_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MIN_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MIN_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MIN_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MUL_LEGACY_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MUL_LEGACY_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MUL_LEGACY_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MUL_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MUL_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MUL_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_SUB_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_SUB_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_SUB_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_SUB_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_SUBREV_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_SUBREV_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_SUBREV_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_FMAAK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_FMAAK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_FMAAK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_FMAMK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_FMAMK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_FMAMK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 37738 /* v_dual_cndmask_b32 */, AMDGPU::V_DUAL_CNDMASK_B32_e32_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MOV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MOV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MOV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_ADD_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_ADD_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_ADD_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_ADD_U32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_ADD_U32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_ADD_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_AND_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_AND_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_ASHRREV_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_CNDMASK_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_CNDMASK_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_CNDMASK_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_DOT2C_F32_BF16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_DOT2C_F32_BF16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_DOT2C_F32_BF16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_DOT2C_F32_F16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_DOT2C_F32_F16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_DOT2C_F32_F16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_FMAC_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_FMAC_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_FMAC_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_LSHLREV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_LSHLREV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_LSHLREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_LSHRREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MAX_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MAX_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MAX_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MAX_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MIN_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MIN_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MIN_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MIN_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MUL_LEGACY_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MUL_LEGACY_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MUL_LEGACY_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MUL_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MUL_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_MUL_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_SUB_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_SUB_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_SUB_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_SUB_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_SUBREV_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_SUBREV_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_SUBREV_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_FMAAK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_FMAAK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_FMAAK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_FMAMK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_FMAMK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37757 /* v_dual_dot2acc_f32_bf16 */, AMDGPU::V_DUAL_DOT2C_F32_BF16_e32_X_FMAMK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MOV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MOV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MOV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_ADD_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_ADD_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_ADD_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_ADD_U32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_ADD_U32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_ADD_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_AND_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_AND_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_ASHRREV_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_CNDMASK_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_CNDMASK_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_CNDMASK_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_DOT2C_F32_BF16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_DOT2C_F32_BF16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_DOT2C_F32_BF16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_DOT2C_F32_F16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_DOT2C_F32_F16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_DOT2C_F32_F16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_FMAC_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_FMAC_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_FMAC_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_LSHLREV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_LSHLREV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_LSHLREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_LSHRREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MAX_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MAX_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MAX_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MAX_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MIN_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MIN_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MIN_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MIN_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MUL_LEGACY_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MUL_LEGACY_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MUL_LEGACY_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MUL_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MUL_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_MUL_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_SUB_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_SUB_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_SUB_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_SUB_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_SUBREV_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_SUBREV_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_SUBREV_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_FMAAK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_FMAAK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_FMAAK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_FMAMK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_FMAMK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37781 /* v_dual_dot2acc_f32_f16 */, AMDGPU::V_DUAL_DOT2C_F32_F16_e32_X_FMAMK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37804 /* v_dual_fma_f32 */, AMDGPU::V_DUAL_FMA_F32_e64_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 37804 /* v_dual_fma_f32 */, AMDGPU::V_DUAL_FMA_F32_e64_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37804 /* v_dual_fma_f32 */, AMDGPU::V_DUAL_FMA_F32_e64_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37804 /* v_dual_fma_f32 */, AMDGPU::V_DUAL_FMA_F32_e64_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37804 /* v_dual_fma_f32 */, AMDGPU::V_DUAL_FMA_F32_e64_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37804 /* v_dual_fma_f32 */, AMDGPU::V_DUAL_FMA_F32_e64_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37804 /* v_dual_fma_f32 */, AMDGPU::V_DUAL_FMA_F32_e64_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37804 /* v_dual_fma_f32 */, AMDGPU::V_DUAL_FMA_F32_e64_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37804 /* v_dual_fma_f32 */, AMDGPU::V_DUAL_FMA_F32_e64_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37804 /* v_dual_fma_f32 */, AMDGPU::V_DUAL_FMA_F32_e64_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37804 /* v_dual_fma_f32 */, AMDGPU::V_DUAL_FMA_F32_e64_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37804 /* v_dual_fma_f32 */, AMDGPU::V_DUAL_FMA_F32_e64_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37804 /* v_dual_fma_f32 */, AMDGPU::V_DUAL_FMA_F32_e64_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37804 /* v_dual_fma_f32 */, AMDGPU::V_DUAL_FMA_F32_e64_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37804 /* v_dual_fma_f32 */, AMDGPU::V_DUAL_FMA_F32_e64_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37804 /* v_dual_fma_f32 */, AMDGPU::V_DUAL_FMA_F32_e64_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37804 /* v_dual_fma_f32 */, AMDGPU::V_DUAL_FMA_F32_e64_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37804 /* v_dual_fma_f32 */, AMDGPU::V_DUAL_FMA_F32_e64_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37804 /* v_dual_fma_f32 */, AMDGPU::V_DUAL_FMA_F32_e64_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 37804 /* v_dual_fma_f32 */, AMDGPU::V_DUAL_FMA_F32_e64_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 37804 /* v_dual_fma_f32 */, AMDGPU::V_DUAL_FMA_F32_e64_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37819 /* v_dual_fma_f64 */, AMDGPU::V_DUAL_FMA_F64_e64_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 37819 /* v_dual_fma_f64 */, AMDGPU::V_DUAL_FMA_F64_e64_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37819 /* v_dual_fma_f64 */, AMDGPU::V_DUAL_FMA_F64_e64_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37819 /* v_dual_fma_f64 */, AMDGPU::V_DUAL_FMA_F64_e64_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37819 /* v_dual_fma_f64 */, AMDGPU::V_DUAL_FMA_F64_e64_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37819 /* v_dual_fma_f64 */, AMDGPU::V_DUAL_FMA_F64_e64_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37819 /* v_dual_fma_f64 */, AMDGPU::V_DUAL_FMA_F64_e64_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37819 /* v_dual_fma_f64 */, AMDGPU::V_DUAL_FMA_F64_e64_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37819 /* v_dual_fma_f64 */, AMDGPU::V_DUAL_FMA_F64_e64_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37819 /* v_dual_fma_f64 */, AMDGPU::V_DUAL_FMA_F64_e64_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37819 /* v_dual_fma_f64 */, AMDGPU::V_DUAL_FMA_F64_e64_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37819 /* v_dual_fma_f64 */, AMDGPU::V_DUAL_FMA_F64_e64_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37819 /* v_dual_fma_f64 */, AMDGPU::V_DUAL_FMA_F64_e64_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37819 /* v_dual_fma_f64 */, AMDGPU::V_DUAL_FMA_F64_e64_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37819 /* v_dual_fma_f64 */, AMDGPU::V_DUAL_FMA_F64_e64_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37819 /* v_dual_fma_f64 */, AMDGPU::V_DUAL_FMA_F64_e64_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37819 /* v_dual_fma_f64 */, AMDGPU::V_DUAL_FMA_F64_e64_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37819 /* v_dual_fma_f64 */, AMDGPU::V_DUAL_FMA_F64_e64_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37819 /* v_dual_fma_f64 */, AMDGPU::V_DUAL_FMA_F64_e64_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 37819 /* v_dual_fma_f64 */, AMDGPU::V_DUAL_FMA_F64_e64_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 37819 /* v_dual_fma_f64 */, AMDGPU::V_DUAL_FMA_F64_e64_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_MOV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_MOV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_MOV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_ADD_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_ADD_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_ADD_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_ADD_U32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_ADD_U32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_ADD_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_AND_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_AND_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_ASHRREV_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_CNDMASK_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_CNDMASK_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_CNDMASK_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_DOT2C_F32_BF16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_DOT2C_F32_BF16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_DOT2C_F32_BF16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_DOT2C_F32_F16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_DOT2C_F32_F16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_DOT2C_F32_F16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_FMAC_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_FMAC_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_FMAC_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_LSHLREV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_LSHLREV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_LSHLREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_LSHRREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_MAX_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_MAX_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_MAX_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_MAX_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_MIN_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_MIN_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_MIN_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_MIN_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_MUL_LEGACY_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_MUL_LEGACY_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_MUL_LEGACY_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_MUL_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_MUL_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_MUL_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_SUB_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_SUB_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_SUB_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_SUB_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_SUBREV_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_SUBREV_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_SUBREV_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_FMAAK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_FMAAK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_FMAAK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_FMAMK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_FMAMK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37834 /* v_dual_fmaak_f32 */, AMDGPU::V_DUAL_FMAAK_F32_X_FMAMK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MOV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MOV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MOV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_ADD_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_ADD_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_ADD_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_ADD_U32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_ADD_U32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_ADD_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_AND_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_AND_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_ASHRREV_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_CNDMASK_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_CNDMASK_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_CNDMASK_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_DOT2C_F32_BF16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_DOT2C_F32_BF16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_DOT2C_F32_BF16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_DOT2C_F32_F16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_DOT2C_F32_F16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_DOT2C_F32_F16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_FMAC_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_FMAC_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_FMAC_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_LSHLREV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_LSHLREV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_LSHLREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_LSHRREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MAX_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MAX_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MAX_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MAX_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MIN_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MIN_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MIN_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MIN_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MUL_LEGACY_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MUL_LEGACY_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MUL_LEGACY_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MUL_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MUL_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_MUL_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_SUB_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_SUB_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_SUB_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_SUB_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_SUBREV_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_SUBREV_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_SUBREV_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_FMAAK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_FMAAK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_FMAAK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_FMAMK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_FMAMK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37851 /* v_dual_fmac_f32 */, AMDGPU::V_DUAL_FMAC_F32_e32_X_FMAMK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_MOV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_MOV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_MOV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_ADD_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_ADD_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_ADD_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_ADD_U32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_ADD_U32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_ADD_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_AND_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_AND_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_ASHRREV_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_CNDMASK_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_CNDMASK_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_CNDMASK_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_DOT2C_F32_BF16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_DOT2C_F32_BF16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_DOT2C_F32_BF16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_DOT2C_F32_F16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_DOT2C_F32_F16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_DOT2C_F32_F16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_FMAC_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_FMAC_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_FMAC_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_LSHLREV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_LSHLREV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_LSHLREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_LSHRREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_MAX_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_MAX_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_MAX_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_MAX_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_MIN_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_MIN_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_MIN_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_MIN_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_MUL_LEGACY_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_MUL_LEGACY_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_MUL_LEGACY_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_MUL_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_MUL_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_MUL_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_SUB_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_SUB_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_SUB_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_SUB_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_SUBREV_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_SUBREV_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_SUBREV_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_FMAAK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_FMAAK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_FMAAK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_FMAMK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_FMAMK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37867 /* v_dual_fmamk_f32 */, AMDGPU::V_DUAL_FMAMK_F32_X_FMAMK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37884 /* v_dual_lshlrev_b32 */, AMDGPU::V_DUAL_LSHLREV_B32_e32_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 37884 /* v_dual_lshlrev_b32 */, AMDGPU::V_DUAL_LSHLREV_B32_e32_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37884 /* v_dual_lshlrev_b32 */, AMDGPU::V_DUAL_LSHLREV_B32_e32_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37884 /* v_dual_lshlrev_b32 */, AMDGPU::V_DUAL_LSHLREV_B32_e32_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37884 /* v_dual_lshlrev_b32 */, AMDGPU::V_DUAL_LSHLREV_B32_e32_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37884 /* v_dual_lshlrev_b32 */, AMDGPU::V_DUAL_LSHLREV_B32_e32_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37884 /* v_dual_lshlrev_b32 */, AMDGPU::V_DUAL_LSHLREV_B32_e32_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37884 /* v_dual_lshlrev_b32 */, AMDGPU::V_DUAL_LSHLREV_B32_e32_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37884 /* v_dual_lshlrev_b32 */, AMDGPU::V_DUAL_LSHLREV_B32_e32_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37884 /* v_dual_lshlrev_b32 */, AMDGPU::V_DUAL_LSHLREV_B32_e32_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37884 /* v_dual_lshlrev_b32 */, AMDGPU::V_DUAL_LSHLREV_B32_e32_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37884 /* v_dual_lshlrev_b32 */, AMDGPU::V_DUAL_LSHLREV_B32_e32_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37884 /* v_dual_lshlrev_b32 */, AMDGPU::V_DUAL_LSHLREV_B32_e32_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37884 /* v_dual_lshlrev_b32 */, AMDGPU::V_DUAL_LSHLREV_B32_e32_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37884 /* v_dual_lshlrev_b32 */, AMDGPU::V_DUAL_LSHLREV_B32_e32_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37884 /* v_dual_lshlrev_b32 */, AMDGPU::V_DUAL_LSHLREV_B32_e32_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37884 /* v_dual_lshlrev_b32 */, AMDGPU::V_DUAL_LSHLREV_B32_e32_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37884 /* v_dual_lshlrev_b32 */, AMDGPU::V_DUAL_LSHLREV_B32_e32_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37884 /* v_dual_lshlrev_b32 */, AMDGPU::V_DUAL_LSHLREV_B32_e32_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 37884 /* v_dual_lshlrev_b32 */, AMDGPU::V_DUAL_LSHLREV_B32_e32_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 37884 /* v_dual_lshlrev_b32 */, AMDGPU::V_DUAL_LSHLREV_B32_e32_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37903 /* v_dual_lshrrev_b32 */, AMDGPU::V_DUAL_LSHRREV_B32_e32_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 37903 /* v_dual_lshrrev_b32 */, AMDGPU::V_DUAL_LSHRREV_B32_e32_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37903 /* v_dual_lshrrev_b32 */, AMDGPU::V_DUAL_LSHRREV_B32_e32_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37903 /* v_dual_lshrrev_b32 */, AMDGPU::V_DUAL_LSHRREV_B32_e32_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37903 /* v_dual_lshrrev_b32 */, AMDGPU::V_DUAL_LSHRREV_B32_e32_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37903 /* v_dual_lshrrev_b32 */, AMDGPU::V_DUAL_LSHRREV_B32_e32_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37903 /* v_dual_lshrrev_b32 */, AMDGPU::V_DUAL_LSHRREV_B32_e32_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37903 /* v_dual_lshrrev_b32 */, AMDGPU::V_DUAL_LSHRREV_B32_e32_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37903 /* v_dual_lshrrev_b32 */, AMDGPU::V_DUAL_LSHRREV_B32_e32_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37903 /* v_dual_lshrrev_b32 */, AMDGPU::V_DUAL_LSHRREV_B32_e32_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37903 /* v_dual_lshrrev_b32 */, AMDGPU::V_DUAL_LSHRREV_B32_e32_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37903 /* v_dual_lshrrev_b32 */, AMDGPU::V_DUAL_LSHRREV_B32_e32_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37903 /* v_dual_lshrrev_b32 */, AMDGPU::V_DUAL_LSHRREV_B32_e32_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37903 /* v_dual_lshrrev_b32 */, AMDGPU::V_DUAL_LSHRREV_B32_e32_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37903 /* v_dual_lshrrev_b32 */, AMDGPU::V_DUAL_LSHRREV_B32_e32_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37903 /* v_dual_lshrrev_b32 */, AMDGPU::V_DUAL_LSHRREV_B32_e32_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37903 /* v_dual_lshrrev_b32 */, AMDGPU::V_DUAL_LSHRREV_B32_e32_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37903 /* v_dual_lshrrev_b32 */, AMDGPU::V_DUAL_LSHRREV_B32_e32_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37903 /* v_dual_lshrrev_b32 */, AMDGPU::V_DUAL_LSHRREV_B32_e32_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 37903 /* v_dual_lshrrev_b32 */, AMDGPU::V_DUAL_LSHRREV_B32_e32_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 37903 /* v_dual_lshrrev_b32 */, AMDGPU::V_DUAL_LSHRREV_B32_e32_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37922 /* v_dual_max_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MOV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37922 /* v_dual_max_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_ADD_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37922 /* v_dual_max_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_ADD_U32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37922 /* v_dual_max_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_AND_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37922 /* v_dual_max_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_CNDMASK_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37922 /* v_dual_max_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_DOT2C_F32_BF16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37922 /* v_dual_max_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_DOT2C_F32_F16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37922 /* v_dual_max_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_FMAC_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37922 /* v_dual_max_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_LSHLREV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37922 /* v_dual_max_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MAX_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37922 /* v_dual_max_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MIN_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37922 /* v_dual_max_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MUL_LEGACY_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37922 /* v_dual_max_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MUL_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37922 /* v_dual_max_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_SUB_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37922 /* v_dual_max_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_SUBREV_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37922 /* v_dual_max_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_FMAAK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37922 /* v_dual_max_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_FMAMK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MOV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MOV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_ADD_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_ADD_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_ADD_U32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_ADD_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_AND_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_ASHRREV_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_CNDMASK_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_CNDMASK_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_DOT2C_F32_BF16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_DOT2C_F32_BF16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_DOT2C_F32_F16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_DOT2C_F32_F16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_FMAC_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_FMAC_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_LSHLREV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_LSHLREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_LSHRREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MAX_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MAX_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MAX_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MIN_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MIN_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MIN_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MUL_LEGACY_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MUL_LEGACY_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MUL_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_MUL_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_SUB_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_SUB_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_SUB_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_SUBREV_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_SUBREV_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_FMAAK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_FMAAK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_FMAMK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37937 /* v_dual_max_num_f32 */, AMDGPU::V_DUAL_MAX_F32_e32_X_FMAMK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37956 /* v_dual_max_num_f64 */, AMDGPU::V_DUAL_MAX_NUM_F64_e32_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 37956 /* v_dual_max_num_f64 */, AMDGPU::V_DUAL_MAX_NUM_F64_e32_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37956 /* v_dual_max_num_f64 */, AMDGPU::V_DUAL_MAX_NUM_F64_e32_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37956 /* v_dual_max_num_f64 */, AMDGPU::V_DUAL_MAX_NUM_F64_e32_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37956 /* v_dual_max_num_f64 */, AMDGPU::V_DUAL_MAX_NUM_F64_e32_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37956 /* v_dual_max_num_f64 */, AMDGPU::V_DUAL_MAX_NUM_F64_e32_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37956 /* v_dual_max_num_f64 */, AMDGPU::V_DUAL_MAX_NUM_F64_e32_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37956 /* v_dual_max_num_f64 */, AMDGPU::V_DUAL_MAX_NUM_F64_e32_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37956 /* v_dual_max_num_f64 */, AMDGPU::V_DUAL_MAX_NUM_F64_e32_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37956 /* v_dual_max_num_f64 */, AMDGPU::V_DUAL_MAX_NUM_F64_e32_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37956 /* v_dual_max_num_f64 */, AMDGPU::V_DUAL_MAX_NUM_F64_e32_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37956 /* v_dual_max_num_f64 */, AMDGPU::V_DUAL_MAX_NUM_F64_e32_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37956 /* v_dual_max_num_f64 */, AMDGPU::V_DUAL_MAX_NUM_F64_e32_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37956 /* v_dual_max_num_f64 */, AMDGPU::V_DUAL_MAX_NUM_F64_e32_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37956 /* v_dual_max_num_f64 */, AMDGPU::V_DUAL_MAX_NUM_F64_e32_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37956 /* v_dual_max_num_f64 */, AMDGPU::V_DUAL_MAX_NUM_F64_e32_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37956 /* v_dual_max_num_f64 */, AMDGPU::V_DUAL_MAX_NUM_F64_e32_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37956 /* v_dual_max_num_f64 */, AMDGPU::V_DUAL_MAX_NUM_F64_e32_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37956 /* v_dual_max_num_f64 */, AMDGPU::V_DUAL_MAX_NUM_F64_e32_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 37956 /* v_dual_max_num_f64 */, AMDGPU::V_DUAL_MAX_NUM_F64_e32_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 37956 /* v_dual_max_num_f64 */, AMDGPU::V_DUAL_MAX_NUM_F64_e32_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37975 /* v_dual_min_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MOV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37975 /* v_dual_min_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_ADD_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37975 /* v_dual_min_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_ADD_U32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37975 /* v_dual_min_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_AND_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37975 /* v_dual_min_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_CNDMASK_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37975 /* v_dual_min_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_DOT2C_F32_BF16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37975 /* v_dual_min_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_DOT2C_F32_F16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37975 /* v_dual_min_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_FMAC_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37975 /* v_dual_min_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_LSHLREV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37975 /* v_dual_min_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MAX_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37975 /* v_dual_min_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MIN_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37975 /* v_dual_min_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MUL_LEGACY_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37975 /* v_dual_min_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MUL_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37975 /* v_dual_min_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_SUB_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37975 /* v_dual_min_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_SUBREV_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37975 /* v_dual_min_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_FMAAK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37975 /* v_dual_min_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_FMAMK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MOV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MOV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_ADD_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_ADD_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_ADD_U32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_ADD_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_AND_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_ASHRREV_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_CNDMASK_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_CNDMASK_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_DOT2C_F32_BF16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_DOT2C_F32_BF16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_DOT2C_F32_F16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_DOT2C_F32_F16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_FMAC_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_FMAC_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_LSHLREV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_LSHLREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_LSHRREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MAX_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MAX_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MAX_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MIN_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MIN_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MIN_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MUL_LEGACY_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MUL_LEGACY_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MUL_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_MUL_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_SUB_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_SUB_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_SUB_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_SUBREV_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_SUBREV_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_FMAAK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_FMAAK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_FMAMK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 37990 /* v_dual_min_num_f32 */, AMDGPU::V_DUAL_MIN_F32_e32_X_FMAMK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 38009 /* v_dual_min_num_f64 */, AMDGPU::V_DUAL_MIN_NUM_F64_e32_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 38009 /* v_dual_min_num_f64 */, AMDGPU::V_DUAL_MIN_NUM_F64_e32_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38009 /* v_dual_min_num_f64 */, AMDGPU::V_DUAL_MIN_NUM_F64_e32_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38009 /* v_dual_min_num_f64 */, AMDGPU::V_DUAL_MIN_NUM_F64_e32_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38009 /* v_dual_min_num_f64 */, AMDGPU::V_DUAL_MIN_NUM_F64_e32_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38009 /* v_dual_min_num_f64 */, AMDGPU::V_DUAL_MIN_NUM_F64_e32_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38009 /* v_dual_min_num_f64 */, AMDGPU::V_DUAL_MIN_NUM_F64_e32_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38009 /* v_dual_min_num_f64 */, AMDGPU::V_DUAL_MIN_NUM_F64_e32_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38009 /* v_dual_min_num_f64 */, AMDGPU::V_DUAL_MIN_NUM_F64_e32_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38009 /* v_dual_min_num_f64 */, AMDGPU::V_DUAL_MIN_NUM_F64_e32_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38009 /* v_dual_min_num_f64 */, AMDGPU::V_DUAL_MIN_NUM_F64_e32_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38009 /* v_dual_min_num_f64 */, AMDGPU::V_DUAL_MIN_NUM_F64_e32_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38009 /* v_dual_min_num_f64 */, AMDGPU::V_DUAL_MIN_NUM_F64_e32_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38009 /* v_dual_min_num_f64 */, AMDGPU::V_DUAL_MIN_NUM_F64_e32_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38009 /* v_dual_min_num_f64 */, AMDGPU::V_DUAL_MIN_NUM_F64_e32_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38009 /* v_dual_min_num_f64 */, AMDGPU::V_DUAL_MIN_NUM_F64_e32_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38009 /* v_dual_min_num_f64 */, AMDGPU::V_DUAL_MIN_NUM_F64_e32_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38009 /* v_dual_min_num_f64 */, AMDGPU::V_DUAL_MIN_NUM_F64_e32_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38009 /* v_dual_min_num_f64 */, AMDGPU::V_DUAL_MIN_NUM_F64_e32_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 38009 /* v_dual_min_num_f64 */, AMDGPU::V_DUAL_MIN_NUM_F64_e32_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 38009 /* v_dual_min_num_f64 */, AMDGPU::V_DUAL_MIN_NUM_F64_e32_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MOV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MOV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MOV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_ADD_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_ADD_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_ADD_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_ADD_U32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_ADD_U32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_ADD_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_AND_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_AND_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_ASHRREV_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_CNDMASK_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_CNDMASK_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_CNDMASK_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_DOT2C_F32_BF16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_DOT2C_F32_BF16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_DOT2C_F32_BF16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_DOT2C_F32_F16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_DOT2C_F32_F16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_DOT2C_F32_F16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_FMAC_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_FMAC_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_FMAC_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_LSHLREV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_LSHLREV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_LSHLREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_LSHRREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MAX_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MAX_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MAX_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MAX_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MIN_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MIN_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MIN_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MIN_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MUL_LEGACY_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MUL_LEGACY_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MUL_LEGACY_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MUL_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MUL_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MUL_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_SUB_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_SUB_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_SUB_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_SUB_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_SUBREV_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_SUBREV_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_SUBREV_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_FMAAK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_FMAAK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_FMAAK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_FMAMK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_FMAMK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_FMAMK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 38028 /* v_dual_mov_b32 */, AMDGPU::V_DUAL_MOV_B32_e32_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MOV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MOV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MOV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_ADD_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_ADD_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_ADD_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_ADD_U32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_ADD_U32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_ADD_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_AND_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_AND_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_ASHRREV_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_CNDMASK_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_CNDMASK_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_CNDMASK_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_DOT2C_F32_BF16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_DOT2C_F32_BF16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_DOT2C_F32_BF16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_DOT2C_F32_F16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_DOT2C_F32_F16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_DOT2C_F32_F16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_FMAC_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_FMAC_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_FMAC_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_LSHLREV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_LSHLREV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_LSHLREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_LSHRREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MAX_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MAX_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MAX_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MAX_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MIN_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MIN_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MIN_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MIN_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MUL_LEGACY_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MUL_LEGACY_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MUL_LEGACY_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MUL_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MUL_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_MUL_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_SUB_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_SUB_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_SUB_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_SUB_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_SUBREV_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_SUBREV_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_SUBREV_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_FMAAK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_FMAAK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_FMAAK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_FMAMK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_FMAMK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 38043 /* v_dual_mul_dx9_zero_f32 */, AMDGPU::V_DUAL_MUL_LEGACY_F32_e32_X_FMAMK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MOV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MOV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MOV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_ADD_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_ADD_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_ADD_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_ADD_U32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_ADD_U32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_ADD_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_AND_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_AND_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_ASHRREV_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_CNDMASK_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_CNDMASK_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_CNDMASK_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_DOT2C_F32_BF16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_DOT2C_F32_BF16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_DOT2C_F32_BF16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_DOT2C_F32_F16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_DOT2C_F32_F16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_DOT2C_F32_F16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_FMAC_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_FMAC_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_FMAC_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_LSHLREV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_LSHLREV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_LSHLREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_LSHRREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MAX_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MAX_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MAX_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MAX_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MIN_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MIN_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MIN_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MIN_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MUL_LEGACY_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MUL_LEGACY_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MUL_LEGACY_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MUL_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MUL_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_MUL_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_SUB_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_SUB_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_SUB_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_SUB_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_SUBREV_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_SUBREV_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_SUBREV_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_FMAAK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_FMAAK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_FMAAK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_FMAMK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_FMAMK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 38067 /* v_dual_mul_f32 */, AMDGPU::V_DUAL_MUL_F32_e32_X_FMAMK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 38082 /* v_dual_mul_f64 */, AMDGPU::V_DUAL_MUL_F64_pseudo_e32_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 38082 /* v_dual_mul_f64 */, AMDGPU::V_DUAL_MUL_F64_pseudo_e32_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38082 /* v_dual_mul_f64 */, AMDGPU::V_DUAL_MUL_F64_pseudo_e32_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38082 /* v_dual_mul_f64 */, AMDGPU::V_DUAL_MUL_F64_pseudo_e32_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38082 /* v_dual_mul_f64 */, AMDGPU::V_DUAL_MUL_F64_pseudo_e32_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38082 /* v_dual_mul_f64 */, AMDGPU::V_DUAL_MUL_F64_pseudo_e32_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38082 /* v_dual_mul_f64 */, AMDGPU::V_DUAL_MUL_F64_pseudo_e32_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38082 /* v_dual_mul_f64 */, AMDGPU::V_DUAL_MUL_F64_pseudo_e32_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38082 /* v_dual_mul_f64 */, AMDGPU::V_DUAL_MUL_F64_pseudo_e32_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38082 /* v_dual_mul_f64 */, AMDGPU::V_DUAL_MUL_F64_pseudo_e32_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38082 /* v_dual_mul_f64 */, AMDGPU::V_DUAL_MUL_F64_pseudo_e32_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38082 /* v_dual_mul_f64 */, AMDGPU::V_DUAL_MUL_F64_pseudo_e32_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38082 /* v_dual_mul_f64 */, AMDGPU::V_DUAL_MUL_F64_pseudo_e32_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38082 /* v_dual_mul_f64 */, AMDGPU::V_DUAL_MUL_F64_pseudo_e32_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38082 /* v_dual_mul_f64 */, AMDGPU::V_DUAL_MUL_F64_pseudo_e32_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38082 /* v_dual_mul_f64 */, AMDGPU::V_DUAL_MUL_F64_pseudo_e32_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38082 /* v_dual_mul_f64 */, AMDGPU::V_DUAL_MUL_F64_pseudo_e32_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38082 /* v_dual_mul_f64 */, AMDGPU::V_DUAL_MUL_F64_pseudo_e32_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38082 /* v_dual_mul_f64 */, AMDGPU::V_DUAL_MUL_F64_pseudo_e32_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 38082 /* v_dual_mul_f64 */, AMDGPU::V_DUAL_MUL_F64_pseudo_e32_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 38082 /* v_dual_mul_f64 */, AMDGPU::V_DUAL_MUL_F64_pseudo_e32_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrInlineImmWithFP64InputMods, MCK_VRegWithFP64InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MOV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MOV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MOV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_ADD_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_ADD_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_ADD_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_ADD_U32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_ADD_U32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_ADD_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_AND_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_AND_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_ASHRREV_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_CNDMASK_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_CNDMASK_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_CNDMASK_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_DOT2C_F32_BF16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_DOT2C_F32_BF16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_DOT2C_F32_BF16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_DOT2C_F32_F16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_DOT2C_F32_F16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_DOT2C_F32_F16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_FMAC_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_FMAC_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_FMAC_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_LSHLREV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_LSHLREV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_LSHLREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_LSHRREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MAX_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MAX_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MAX_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MAX_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MIN_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MIN_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MIN_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MIN_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MUL_LEGACY_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MUL_LEGACY_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MUL_LEGACY_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MUL_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MUL_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_MUL_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_SUB_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_SUB_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_SUB_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_SUB_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_SUBREV_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_SUBREV_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_SUBREV_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_FMAAK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_FMAAK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_FMAAK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_FMAMK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_FMAMK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 38097 /* v_dual_sub_f32 */, AMDGPU::V_DUAL_SUB_F32_e32_X_FMAMK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 38112 /* v_dual_sub_nc_u32 */, AMDGPU::V_DUAL_SUB_U32_e32_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 38112 /* v_dual_sub_nc_u32 */, AMDGPU::V_DUAL_SUB_U32_e32_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38112 /* v_dual_sub_nc_u32 */, AMDGPU::V_DUAL_SUB_U32_e32_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38112 /* v_dual_sub_nc_u32 */, AMDGPU::V_DUAL_SUB_U32_e32_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38112 /* v_dual_sub_nc_u32 */, AMDGPU::V_DUAL_SUB_U32_e32_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38112 /* v_dual_sub_nc_u32 */, AMDGPU::V_DUAL_SUB_U32_e32_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38112 /* v_dual_sub_nc_u32 */, AMDGPU::V_DUAL_SUB_U32_e32_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38112 /* v_dual_sub_nc_u32 */, AMDGPU::V_DUAL_SUB_U32_e32_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38112 /* v_dual_sub_nc_u32 */, AMDGPU::V_DUAL_SUB_U32_e32_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38112 /* v_dual_sub_nc_u32 */, AMDGPU::V_DUAL_SUB_U32_e32_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38112 /* v_dual_sub_nc_u32 */, AMDGPU::V_DUAL_SUB_U32_e32_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38112 /* v_dual_sub_nc_u32 */, AMDGPU::V_DUAL_SUB_U32_e32_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38112 /* v_dual_sub_nc_u32 */, AMDGPU::V_DUAL_SUB_U32_e32_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38112 /* v_dual_sub_nc_u32 */, AMDGPU::V_DUAL_SUB_U32_e32_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38112 /* v_dual_sub_nc_u32 */, AMDGPU::V_DUAL_SUB_U32_e32_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38112 /* v_dual_sub_nc_u32 */, AMDGPU::V_DUAL_SUB_U32_e32_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38112 /* v_dual_sub_nc_u32 */, AMDGPU::V_DUAL_SUB_U32_e32_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38112 /* v_dual_sub_nc_u32 */, AMDGPU::V_DUAL_SUB_U32_e32_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38112 /* v_dual_sub_nc_u32 */, AMDGPU::V_DUAL_SUB_U32_e32_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 38112 /* v_dual_sub_nc_u32 */, AMDGPU::V_DUAL_SUB_U32_e32_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 38112 /* v_dual_sub_nc_u32 */, AMDGPU::V_DUAL_SUB_U32_e32_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MOV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VCSrc_b32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MOV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MOV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MOV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mov_95_b32, MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_ADD_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_ADD_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_ASHRREV_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_DOT2C_F32_BF16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_DOT2C_F32_F16_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_FMAC_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_LSHLREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_LSHRREV_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MAX_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MAX_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MIN_I32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MIN_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MUL_LEGACY_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MUL_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_SUB_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_SUB_U32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_SUBREV_F32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_ADD_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_ADD_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_ADD_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_ADD_U32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_ADD_U32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_ADD_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_add_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_AND_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_AND_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_and_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_ASHRREV_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_ashrrev_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_CNDMASK_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_CNDMASK_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_CNDMASK_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_DOT2C_F32_BF16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_DOT2C_F32_BF16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_DOT2C_F32_BF16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_bf16, MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_DOT2C_F32_F16_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_DOT2C_F32_F16_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_DOT2C_F32_F16_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_dot2acc_95_f32_95_f16, MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_FMAC_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_FMAC_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_FMAC_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmac_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_LSHLREV_B32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_LSHLREV_B32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_LSHLREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshlrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_LSHRREV_B32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_lshrrev_95_b32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MAX_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MAX_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MAX_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MAX_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_max_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MIN_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MIN_I32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_i32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MIN_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MIN_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_min_95_num_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MUL_LEGACY_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MUL_LEGACY_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MUL_LEGACY_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_dx9_95_zero_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MUL_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MUL_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_MUL_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_mul_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_SUB_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_SUB_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_SUB_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_SUB_U32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_sub_95_nc_95_u32, MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_SUBREV_F32_e32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_SUBREV_F32_e32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_SUBREV_F32_e32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_subrev_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_BITOP2_B32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_bitop2_95_b32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VGPR_32, MCK_BitOp3 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_CNDMASK_B32_e32_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_cndmask_95_b32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_BoolReg }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_FMA_F32_e64_e96_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK__COLON__COLON_, MCK_v_95_dual_95_fma_95_f32, MCK_VGPR_32, MCK_RegOrInlineImmWithFP32InputMods, MCK_VRegWithFP32InputMods, MCK_VRegWithFP32InputMods }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_FMAAK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_FMAAK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_FMAAK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmaak_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_FMAMK_F32_gfx11, ConvertCustom_cvtVOPD, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_FMAMK_F32_gfx12, ConvertCustom_cvtVOPD, AMFBS_isGFX12Not12_50_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 38130 /* v_dual_subrev_f32 */, AMDGPU::V_DUAL_SUBREV_F32_e32_X_FMAMK_F32_gfx1250, ConvertCustom_cvtVOPD, AMFBS_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK__COLON__COLON_, MCK_v_95_dual_95_fmamk_95_f32, MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 38148 /* v_exp_bf16 */, AMDGPU::V_EXP_BF16V_EXP_BF16_fake16_e32_gfx1250, Convert__Reg1_0__VSrcFake16_bf16_Lo1281_1, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_bf16_Lo128 }, },
  { 38148 /* v_exp_bf16 */, AMDGPU::V_EXP_BF16V_EXP_BF16_t16_e32_gfx1250, Convert__Reg1_0__VSrcT_bf16_Lo1281_1, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VSrcT_bf16_Lo128 }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38179 /* v_exp_legacy_f32 */, AMDGPU::V_EXP_LEGACY_F32_e32_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX7GFX8GFX9_isGFX7Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38179 /* v_exp_legacy_f32 */, AMDGPU::V_EXP_LEGACY_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX7GFX8GFX9_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38196 /* v_ffbh_i32 */, AMDGPU::V_FFBH_I32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38196 /* v_ffbh_i32 */, AMDGPU::V_FFBH_I32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38196 /* v_ffbh_i32 */, AMDGPU::V_FFBH_I32_e32_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38207 /* v_ffbh_u32 */, AMDGPU::V_FFBH_U32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38207 /* v_ffbh_u32 */, AMDGPU::V_FFBH_U32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38207 /* v_ffbh_u32 */, AMDGPU::V_FFBH_U32_e32_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38218 /* v_ffbl_b32 */, AMDGPU::V_FFBL_B32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38218 /* v_ffbl_b32 */, AMDGPU::V_FFBL_B32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38218 /* v_ffbl_b32 */, AMDGPU::V_FFBL_B32_e32_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38253 /* v_floor_f64 */, AMDGPU::V_FLOOR_F64_e32_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX7Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 38253 /* v_floor_f64 */, AMDGPU::V_FLOOR_F64_e32_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX7Plus_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 38253 /* v_floor_f64 */, AMDGPU::V_FLOOR_F64_e32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX7Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 38253 /* v_floor_f64 */, AMDGPU::V_FLOOR_F64_e32_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX7Plus_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 38253 /* v_floor_f64 */, AMDGPU::V_FLOOR_F64_e32_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 38447 /* v_fmaak_f16 */, AMDGPU::V_FMAAK_F16_fake16_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2__KImmFP161_3, AMFBS_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128, MCK_KImmFP16 }, },
  { 38447 /* v_fmaak_f16 */, AMDGPU::V_FMAAK_F16_fake16_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2__KImmFP161_3, AMFBS_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128, MCK_KImmFP16 }, },
  { 38447 /* v_fmaak_f16 */, AMDGPU::V_FMAAK_F16_t16_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2__KImmFP161_3, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128, MCK_KImmFP16 }, },
  { 38447 /* v_fmaak_f16 */, AMDGPU::V_FMAAK_F16_t16_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2__KImmFP161_3, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128, MCK_KImmFP16 }, },
  { 38447 /* v_fmaak_f16 */, AMDGPU::V_FMAAK_F16_gfx10, Convert__Reg1_0__VSrc_f161_1__Reg1_2__KImmFP161_3, AMFBS_isGFX10Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_f16, MCK_VGPR_32, MCK_KImmFP16 }, },
  { 38459 /* v_fmaak_f32 */, AMDGPU::V_FMAAK_F32_gfx10, Convert__Reg1_0__VSrc_f321_1__Reg1_2__KImmFP321_3, AMFBS_HasFmaakFmamkF32Insts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 38459 /* v_fmaak_f32 */, AMDGPU::V_FMAAK_F32_gfx11, Convert__Reg1_0__VSrc_f321_1__Reg1_2__KImmFP321_3, AMFBS_HasFmaakFmamkF32Insts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 38459 /* v_fmaak_f32 */, AMDGPU::V_FMAAK_F32_gfx12, Convert__Reg1_0__VSrc_f321_1__Reg1_2__KImmFP321_3, AMFBS_HasFmaakFmamkF32Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 38459 /* v_fmaak_f32 */, AMDGPU::V_FMAAK_F32_gfx940, Convert__Reg1_0__VSrc_f321_1__Reg1_2__KImmFP321_3, AMFBS_HasFmaakFmamkF32Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 38471 /* v_fmaak_f64 */, AMDGPU::V_FMAAK_F64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2__KImmFP641_3, AMFBS_HasFmaakFmamkF64Insts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_KImmFP64 }, },
  { 38483 /* v_fmac_dx9_zero_f32 */, AMDGPU::V_FMAC_DX9_ZERO_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1__Reg1_2__Tie0_1_1, AMFBS_HasFmacLegacy32_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2__Tie0_1_1, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2__Tie0_1_1, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2__Tie0_1_1, AMFBS_isGFX10Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2__Tie0_1_1, AMFBS_isGFX10Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1__Reg1_2__Tie0_1_1, AMFBS_isGFX10Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 38514 /* v_fmac_f32 */, AMDGPU::V_FMAC_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1__Reg1_2__Tie0_1_1, AMFBS_HasDLInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38514 /* v_fmac_f32 */, AMDGPU::V_FMAC_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1__Reg1_2__Tie0_1_1, AMFBS_HasDLInsts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38514 /* v_fmac_f32 */, AMDGPU::V_FMAC_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1__Reg1_2__Tie0_1_1, AMFBS_HasDLInsts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38514 /* v_fmac_f32 */, AMDGPU::V_FMAC_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1__Reg1_2__Tie0_1_1, AMFBS_HasDLInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38525 /* v_fmac_f64 */, AMDGPU::V_FMAC_F64_e32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2__Tie0_1_1, AMFBS_HasFmacF64Inst_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 38525 /* v_fmac_f64 */, AMDGPU::V_FMAC_F64_e32_gfx90a, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2__Tie0_1_1, AMFBS_isGFX9Only_HasFmacF64Inst, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 38536 /* v_fmac_legacy_f32 */, AMDGPU::V_FMAC_LEGACY_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1__Reg1_2__Tie0_1_1, AMFBS_HasFmacLegacy32_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 38554 /* v_fmamk_f16 */, AMDGPU::V_FMAMK_F16_fake16_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__KImmFP161_2__Reg1_3, AMFBS_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128, MCK_KImmFP16, MCK_VGPR_32_Lo128 }, },
  { 38554 /* v_fmamk_f16 */, AMDGPU::V_FMAMK_F16_fake16_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__KImmFP161_2__Reg1_3, AMFBS_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128, MCK_KImmFP16, MCK_VGPR_32_Lo128 }, },
  { 38554 /* v_fmamk_f16 */, AMDGPU::V_FMAMK_F16_t16_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1__KImmFP161_2__Reg1_3, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128, MCK_KImmFP16, MCK_VGPR_16_Lo128 }, },
  { 38554 /* v_fmamk_f16 */, AMDGPU::V_FMAMK_F16_t16_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1__KImmFP161_2__Reg1_3, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128, MCK_KImmFP16, MCK_VGPR_16_Lo128 }, },
  { 38554 /* v_fmamk_f16 */, AMDGPU::V_FMAMK_F16_gfx10, Convert__Reg1_0__VSrc_f161_1__KImmFP161_2__Reg1_3, AMFBS_isGFX10Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_f16, MCK_KImmFP16, MCK_VGPR_32 }, },
  { 38566 /* v_fmamk_f32 */, AMDGPU::V_FMAMK_F32_gfx10, Convert__Reg1_0__VSrc_f321_1__KImmFP321_2__Reg1_3, AMFBS_HasFmaakFmamkF32Insts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 38566 /* v_fmamk_f32 */, AMDGPU::V_FMAMK_F32_gfx11, Convert__Reg1_0__VSrc_f321_1__KImmFP321_2__Reg1_3, AMFBS_HasFmaakFmamkF32Insts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 38566 /* v_fmamk_f32 */, AMDGPU::V_FMAMK_F32_gfx12, Convert__Reg1_0__VSrc_f321_1__KImmFP321_2__Reg1_3, AMFBS_HasFmaakFmamkF32Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 38566 /* v_fmamk_f32 */, AMDGPU::V_FMAMK_F32_gfx940, Convert__Reg1_0__VSrc_f321_1__KImmFP321_2__Reg1_3, AMFBS_HasFmaakFmamkF32Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 38578 /* v_fmamk_f64 */, AMDGPU::V_FMAMK_F64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1__KImmFP641_2__Reg1_3, AMFBS_HasFmaakFmamkF64Insts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64, MCK_KImmFP64, MCK_VReg_64 }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38614 /* v_fract_f64 */, AMDGPU::V_FRACT_F64_e32_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 38614 /* v_fract_f64 */, AMDGPU::V_FRACT_F64_e32_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 38614 /* v_fract_f64 */, AMDGPU::V_FRACT_F64_e32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 38614 /* v_fract_f64 */, AMDGPU::V_FRACT_F64_e32_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 38614 /* v_fract_f64 */, AMDGPU::V_FRACT_F64_e32_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38666 /* v_frexp_exp_i32_f64 */, AMDGPU::V_FREXP_EXP_I32_F64_e32_gfx10, Convert__Reg1_0__VSrc_f641_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f64 }, },
  { 38666 /* v_frexp_exp_i32_f64 */, AMDGPU::V_FREXP_EXP_I32_F64_e32_gfx11, Convert__Reg1_0__VSrc_f641_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f64 }, },
  { 38666 /* v_frexp_exp_i32_f64 */, AMDGPU::V_FREXP_EXP_I32_F64_e32_gfx12, Convert__Reg1_0__VSrc_f641_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f64 }, },
  { 38666 /* v_frexp_exp_i32_f64 */, AMDGPU::V_FREXP_EXP_I32_F64_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f641_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f64 }, },
  { 38666 /* v_frexp_exp_i32_f64 */, AMDGPU::V_FREXP_EXP_I32_F64_e32_vi, Convert__Reg1_0__VSrc_f641_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f64 }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 38720 /* v_frexp_mant_f64 */, AMDGPU::V_FREXP_MANT_F64_e32_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 38720 /* v_frexp_mant_f64 */, AMDGPU::V_FREXP_MANT_F64_e32_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 38720 /* v_frexp_mant_f64 */, AMDGPU::V_FREXP_MANT_F64_e32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 38720 /* v_frexp_mant_f64 */, AMDGPU::V_FREXP_MANT_F64_e32_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 38720 /* v_frexp_mant_f64 */, AMDGPU::V_FREXP_MANT_F64_e32_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 38737 /* v_illegal */, AMDGPU::V_ILLEGAL, Convert_NoOperands, AMFBS_isGFX10Plus, {  }, },
  { 38747 /* v_interp_mov_f32 */, AMDGPU::V_INTERP_MOV_F32_gfx10, Convert__Reg1_0__InterpSlot1_1__InterpAttr1_2__InterpAttrChan1_3, AMFBS_isNotGFX90APlus_isGFX10Only, { MCK_VGPR_32, MCK_InterpSlot, MCK_InterpAttr, MCK_InterpAttrChan }, },
  { 38747 /* v_interp_mov_f32 */, AMDGPU::V_INTERP_MOV_F32_si, Convert__Reg1_0__InterpSlot1_1__InterpAttr1_2__InterpAttrChan1_3, AMFBS_isNotGFX90APlus_isGFX6GFX7, { MCK_VGPR_32, MCK_InterpSlot, MCK_InterpAttr, MCK_InterpAttrChan }, },
  { 38747 /* v_interp_mov_f32 */, AMDGPU::V_INTERP_MOV_F32_vi, Convert__Reg1_0__InterpSlot1_1__InterpAttr1_2__InterpAttrChan1_3, AMFBS_isNotGFX90APlus_isGFX8GFX9, { MCK_VGPR_32, MCK_InterpSlot, MCK_InterpAttr, MCK_InterpAttrChan }, },
  { 38827 /* v_interp_p1_f32 */, AMDGPU::V_INTERP_P1_F32_16bank_gfx10, Convert__Reg1_0__Reg1_1__InterpAttr1_2__InterpAttrChan1_3, AMFBS_isNotGFX90APlus_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_InterpAttr, MCK_InterpAttrChan }, },
  { 38827 /* v_interp_p1_f32 */, AMDGPU::V_INTERP_P1_F32_16bank_si, Convert__Reg1_0__Reg1_1__InterpAttr1_2__InterpAttrChan1_3, AMFBS_isNotGFX90APlus_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_InterpAttr, MCK_InterpAttrChan }, },
  { 38827 /* v_interp_p1_f32 */, AMDGPU::V_INTERP_P1_F32_16bank_vi, Convert__Reg1_0__Reg1_1__InterpAttr1_2__InterpAttrChan1_3, AMFBS_isNotGFX90APlus_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_InterpAttr, MCK_InterpAttrChan }, },
  { 38827 /* v_interp_p1_f32 */, AMDGPU::V_INTERP_P1_F32_gfx10, Convert__Reg1_0__Reg1_1__InterpAttr1_2__InterpAttrChan1_3, AMFBS_isNotGFX90APlus_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_InterpAttr, MCK_InterpAttrChan }, },
  { 38827 /* v_interp_p1_f32 */, AMDGPU::V_INTERP_P1_F32_si, Convert__Reg1_0__Reg1_1__InterpAttr1_2__InterpAttrChan1_3, AMFBS_isNotGFX90APlus_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_InterpAttr, MCK_InterpAttrChan }, },
  { 38827 /* v_interp_p1_f32 */, AMDGPU::V_INTERP_P1_F32_vi, Convert__Reg1_0__Reg1_1__InterpAttr1_2__InterpAttrChan1_3, AMFBS_isNotGFX90APlus_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_InterpAttr, MCK_InterpAttrChan }, },
  { 38915 /* v_interp_p2_f32 */, AMDGPU::V_INTERP_P2_F32_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__InterpAttr1_2__InterpAttrChan1_3, AMFBS_isNotGFX90APlus_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_InterpAttr, MCK_InterpAttrChan }, },
  { 38915 /* v_interp_p2_f32 */, AMDGPU::V_INTERP_P2_F32_si, Convert__Reg1_0__Tie0_1_1__Reg1_1__InterpAttr1_2__InterpAttrChan1_3, AMFBS_isNotGFX90APlus_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32, MCK_InterpAttr, MCK_InterpAttrChan }, },
  { 38915 /* v_interp_p2_f32 */, AMDGPU::V_INTERP_P2_F32_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__InterpAttr1_2__InterpAttrChan1_3, AMFBS_isNotGFX90APlus_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_InterpAttr, MCK_InterpAttrChan }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1__Reg1_2, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1__Reg1_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 38990 /* v_ldexp_f32 */, AMDGPU::V_LDEXP_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 39024 /* v_log_bf16 */, AMDGPU::V_LOG_BF16V_LOG_BF16_fake16_e32_gfx1250, Convert__Reg1_0__VSrcFake16_bf16_Lo1281_1, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_bf16_Lo128 }, },
  { 39024 /* v_log_bf16 */, AMDGPU::V_LOG_BF16V_LOG_BF16_t16_e32_gfx1250, Convert__Reg1_0__VSrcT_bf16_Lo1281_1, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VSrcT_bf16_Lo128 }, },
  { 39035 /* v_log_clamp_f32 */, AMDGPU::V_LOG_CLAMP_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 39071 /* v_log_legacy_f32 */, AMDGPU::V_LOG_LEGACY_F32_e32_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX7GFX8GFX9_isGFX7Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 39071 /* v_log_legacy_f32 */, AMDGPU::V_LOG_LEGACY_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX7GFX8GFX9_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 39118 /* v_lshl_b32 */, AMDGPU::V_LSHL_B32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 39154 /* v_lshlrev_b16 */, AMDGPU::V_LSHLREV_B16_e32_vi, Convert__Reg1_0__VSrc_b161_1__Reg1_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_e32_vi, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 39182 /* v_lshlrev_b64 */, AMDGPU::V_LSHLREV_B64_e32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 39196 /* v_lshr_b32 */, AMDGPU::V_LSHR_B32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 39218 /* v_lshrrev_b16 */, AMDGPU::V_LSHRREV_B16_e32_vi, Convert__Reg1_0__VSrc_b161_1__Reg1_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_e32_vi, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 39260 /* v_mac_f16 */, AMDGPU::V_MAC_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1__Reg1_2__Tie0_1_1, AMFBS_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 39270 /* v_mac_f32 */, AMDGPU::V_MAC_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1__Reg1_2__Tie0_1_1, AMFBS_HasMadMacF32Insts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 39270 /* v_mac_f32 */, AMDGPU::V_MAC_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1__Reg1_2__Tie0_1_1, AMFBS_HasMadMacF32Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 39270 /* v_mac_f32 */, AMDGPU::V_MAC_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1__Reg1_2__Tie0_1_1, AMFBS_HasMadMacF32Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 39280 /* v_mac_legacy_f32 */, AMDGPU::V_MAC_LEGACY_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1__Reg1_2__Tie0_1_1, AMFBS_HasMadMacF32Insts_isGFX6GFX7GFX10_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 39280 /* v_mac_legacy_f32 */, AMDGPU::V_MAC_LEGACY_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1__Reg1_2__Tie0_1_1, AMFBS_HasMadMacF32Insts_isGFX6GFX7GFX10_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 39613 /* v_madak_f16 */, AMDGPU::V_MADAK_F16_vi, Convert__Reg1_0__VSrc_f161_1__Reg1_2__KImmFP161_3, AMFBS_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f16, MCK_VGPR_32, MCK_KImmFP16 }, },
  { 39625 /* v_madak_f32 */, AMDGPU::V_MADAK_F32_gfx10, Convert__Reg1_0__VSrc_f321_1__Reg1_2__KImmFP321_3, AMFBS_HasMadMacF32Insts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 39625 /* v_madak_f32 */, AMDGPU::V_MADAK_F32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1__Reg1_2__KImmFP321_3, AMFBS_HasMadMacF32Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 39625 /* v_madak_f32 */, AMDGPU::V_MADAK_F32_vi, Convert__Reg1_0__VSrc_f321_1__Reg1_2__KImmFP321_3, AMFBS_HasMadMacF32Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32, MCK_KImmFP32 }, },
  { 39637 /* v_madmk_f16 */, AMDGPU::V_MADMK_F16_vi, Convert__Reg1_0__VSrc_f161_1__KImmFP161_2__Reg1_3, AMFBS_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f16, MCK_KImmFP16, MCK_VGPR_32 }, },
  { 39649 /* v_madmk_f32 */, AMDGPU::V_MADMK_F32_gfx10, Convert__Reg1_0__VSrc_f321_1__KImmFP321_2__Reg1_3, AMFBS_HasMadMacF32Insts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 39649 /* v_madmk_f32 */, AMDGPU::V_MADMK_F32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1__KImmFP321_2__Reg1_3, AMFBS_HasMadMacF32Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 39649 /* v_madmk_f32 */, AMDGPU::V_MADMK_F32_vi, Convert__Reg1_0__VSrc_f321_1__KImmFP321_2__Reg1_3, AMFBS_HasMadMacF32Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32, MCK_KImmFP32, MCK_VGPR_32 }, },
  { 39757 /* v_max_f16 */, AMDGPU::V_MAX_F16V_MAX_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 39757 /* v_max_f16 */, AMDGPU::V_MAX_F16V_MAX_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 39757 /* v_max_f16 */, AMDGPU::V_MAX_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1__Reg1_2, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 39757 /* v_max_f16 */, AMDGPU::V_MAX_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1__Reg1_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 39767 /* v_max_f32 */, AMDGPU::V_MAX_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 39767 /* v_max_f32 */, AMDGPU::V_MAX_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 39767 /* v_max_f32 */, AMDGPU::V_MAX_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 39767 /* v_max_f32 */, AMDGPU::V_MAX_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 39787 /* v_max_i16 */, AMDGPU::V_MAX_I16_e32_vi, Convert__Reg1_0__VSrc_b161_1__Reg1_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_e32_vi, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 39817 /* v_max_legacy_f32 */, AMDGPU::V_MAX_LEGACY_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 39834 /* v_max_num_f16 */, AMDGPU::V_MAX_NUM_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 39834 /* v_max_num_f16 */, AMDGPU::V_MAX_NUM_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 39848 /* v_max_num_f32 */, AMDGPU::V_MAX_NUM_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 39862 /* v_max_num_f64 */, AMDGPU::V_MAX_NUM_F64_e32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 39876 /* v_max_u16 */, AMDGPU::V_MAX_U16_e32_vi, Convert__Reg1_0__VSrc_b161_1__Reg1_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_e32_vi, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 40106 /* v_mbcnt_hi_u32_b32 */, AMDGPU::V_MBCNT_HI_U32_B32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 40125 /* v_mbcnt_lo_u32_b32 */, AMDGPU::V_MBCNT_LO_U32_B32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 40317 /* v_mfma_f32_16x16x16bf16 */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40317 /* v_mfma_f32_16x16x16bf16 */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40341 /* v_mfma_f32_16x16x16bf16_1k */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40341 /* v_mfma_f32_16x16x16bf16_1k */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40368 /* v_mfma_f32_16x16x16f16 */, AMDGPU::V_MFMA_F32_16X16X16F16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40368 /* v_mfma_f32_16x16x16f16 */, AMDGPU::V_MFMA_F32_16X16X16F16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40417 /* v_mfma_f32_16x16x1f32 */, AMDGPU::V_MFMA_F32_16X16X1F32_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40417 /* v_mfma_f32_16x16x1f32 */, AMDGPU::V_MFMA_F32_16X16X1F32_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40623 /* v_mfma_f32_16x16x32bf16 */, AMDGPU::V_MFMA_F32_16X16X32_BF16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40623 /* v_mfma_f32_16x16x32bf16 */, AMDGPU::V_MFMA_F32_16X16X32_BF16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40647 /* v_mfma_f32_16x16x32f16 */, AMDGPU::V_MFMA_F32_16X16X32_F16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40647 /* v_mfma_f32_16x16x32f16 */, AMDGPU::V_MFMA_F32_16X16X32_F16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40746 /* v_mfma_f32_16x16x4bf16 */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40746 /* v_mfma_f32_16x16x4bf16 */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40769 /* v_mfma_f32_16x16x4bf16_1k */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40769 /* v_mfma_f32_16x16x4bf16_1k */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40795 /* v_mfma_f32_16x16x4f16 */, AMDGPU::V_MFMA_F32_16X16X4F16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40795 /* v_mfma_f32_16x16x4f16 */, AMDGPU::V_MFMA_F32_16X16X4F16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40817 /* v_mfma_f32_16x16x4f32 */, AMDGPU::V_MFMA_F32_16X16X4F32_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40817 /* v_mfma_f32_16x16x4f32 */, AMDGPU::V_MFMA_F32_16X16X4F32_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40886 /* v_mfma_f32_16x16x8xf32 */, AMDGPU::V_MFMA_F32_16X16X8XF32_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40886 /* v_mfma_f32_16x16x8xf32 */, AMDGPU::V_MFMA_F32_16X16X8XF32_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41070 /* v_mfma_f32_32x32x16bf16 */, AMDGPU::V_MFMA_F32_32X32X16_BF16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41070 /* v_mfma_f32_32x32x16bf16 */, AMDGPU::V_MFMA_F32_32X32X16_BF16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41094 /* v_mfma_f32_32x32x16f16 */, AMDGPU::V_MFMA_F32_32X32X16_F16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41094 /* v_mfma_f32_32x32x16f16 */, AMDGPU::V_MFMA_F32_32X32X16_F16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41143 /* v_mfma_f32_32x32x1f32 */, AMDGPU::V_MFMA_F32_32X32X1F32_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_1024_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41143 /* v_mfma_f32_32x32x1f32 */, AMDGPU::V_MFMA_F32_32X32X1F32_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_1024_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_1024_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41211 /* v_mfma_f32_32x32x2f32 */, AMDGPU::V_MFMA_F32_32X32X2F32_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41211 /* v_mfma_f32_32x32x2f32 */, AMDGPU::V_MFMA_F32_32X32X2F32_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41310 /* v_mfma_f32_32x32x4bf16 */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41310 /* v_mfma_f32_32x32x4bf16 */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41333 /* v_mfma_f32_32x32x4bf16_1k */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41333 /* v_mfma_f32_32x32x4bf16_1k */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41359 /* v_mfma_f32_32x32x4f16 */, AMDGPU::V_MFMA_F32_32X32X4F16_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41359 /* v_mfma_f32_32x32x4f16 */, AMDGPU::V_MFMA_F32_32X32X4F16_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41381 /* v_mfma_f32_32x32x4xf32 */, AMDGPU::V_MFMA_F32_32X32X4XF32_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41381 /* v_mfma_f32_32x32x4xf32 */, AMDGPU::V_MFMA_F32_32X32X4XF32_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41478 /* v_mfma_f32_32x32x8bf16 */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41478 /* v_mfma_f32_32x32x8bf16 */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41501 /* v_mfma_f32_32x32x8bf16_1k */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41501 /* v_mfma_f32_32x32x8bf16_1k */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41527 /* v_mfma_f32_32x32x8f16 */, AMDGPU::V_MFMA_F32_32X32X8F16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41527 /* v_mfma_f32_32x32x8f16 */, AMDGPU::V_MFMA_F32_32X32X8F16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41574 /* v_mfma_f32_4x4x1f32 */, AMDGPU::V_MFMA_F32_4X4X1F32_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41574 /* v_mfma_f32_4x4x1f32 */, AMDGPU::V_MFMA_F32_4X4X1F32_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41666 /* v_mfma_f32_4x4x4bf16 */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41666 /* v_mfma_f32_4x4x4bf16 */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41687 /* v_mfma_f32_4x4x4bf16_1k */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41687 /* v_mfma_f32_4x4x4bf16_1k */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41711 /* v_mfma_f32_4x4x4f16 */, AMDGPU::V_MFMA_F32_4X4X4F16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41711 /* v_mfma_f32_4x4x4f16 */, AMDGPU::V_MFMA_F32_4X4X4F16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41754 /* v_mfma_f64_16x16x4f64 */, AMDGPU::V_MFMA_F64_16X16X4F64_gfx940_acd, Convert__RegByHwMode_AReg_256_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_256_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_256_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_256_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41754 /* v_mfma_f64_16x16x4f64 */, AMDGPU::V_MFMA_F64_16X16X4F64_gfx940_vcd, Convert__RegByHwMode_VReg_256_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_256_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_256_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41800 /* v_mfma_f64_4x4x4f64 */, AMDGPU::V_MFMA_F64_4X4X4F64_gfx940_acd, Convert__RegByHwMode_AReg_64_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_64_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_64_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41800 /* v_mfma_f64_4x4x4f64 */, AMDGPU::V_MFMA_F64_4X4X4F64_gfx940_vcd, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_64_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_64_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41865 /* v_mfma_i32_16x16x32i8 */, AMDGPU::V_MFMA_I32_16X16X32I8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41865 /* v_mfma_i32_16x16x32i8 */, AMDGPU::V_MFMA_I32_16X16X32I8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41912 /* v_mfma_i32_16x16x4i8 */, AMDGPU::V_MFMA_I32_16X16X4I8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41912 /* v_mfma_i32_16x16x4i8 */, AMDGPU::V_MFMA_I32_16X16X4I8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41956 /* v_mfma_i32_16x16x64i8 */, AMDGPU::V_MFMA_I32_16X16X64_I8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41956 /* v_mfma_i32_16x16x64i8 */, AMDGPU::V_MFMA_I32_16X16X64_I8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42001 /* v_mfma_i32_32x32x16i8 */, AMDGPU::V_MFMA_I32_32X32X16I8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42001 /* v_mfma_i32_32x32x16i8 */, AMDGPU::V_MFMA_I32_32X32X16I8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42046 /* v_mfma_i32_32x32x32i8 */, AMDGPU::V_MFMA_I32_32X32X32_I8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42046 /* v_mfma_i32_32x32x32i8 */, AMDGPU::V_MFMA_I32_32X32X32_I8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42093 /* v_mfma_i32_32x32x4i8 */, AMDGPU::V_MFMA_I32_32X32X4I8_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42093 /* v_mfma_i32_32x32x4i8 */, AMDGPU::V_MFMA_I32_32X32X4I8_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42159 /* v_mfma_i32_4x4x4i8 */, AMDGPU::V_MFMA_I32_4X4X4I8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42159 /* v_mfma_i32_4x4x4i8 */, AMDGPU::V_MFMA_I32_4X4X4I8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42361 /* v_min_f16 */, AMDGPU::V_MIN_F16V_MIN_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 42361 /* v_min_f16 */, AMDGPU::V_MIN_F16V_MIN_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 42361 /* v_min_f16 */, AMDGPU::V_MIN_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1__Reg1_2, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 42361 /* v_min_f16 */, AMDGPU::V_MIN_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1__Reg1_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 42371 /* v_min_f32 */, AMDGPU::V_MIN_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 42371 /* v_min_f32 */, AMDGPU::V_MIN_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 42371 /* v_min_f32 */, AMDGPU::V_MIN_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 42371 /* v_min_f32 */, AMDGPU::V_MIN_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 42391 /* v_min_i16 */, AMDGPU::V_MIN_I16_e32_vi, Convert__Reg1_0__VSrc_b161_1__Reg1_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_e32_vi, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42421 /* v_min_legacy_f32 */, AMDGPU::V_MIN_LEGACY_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 42438 /* v_min_num_f16 */, AMDGPU::V_MIN_NUM_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 42438 /* v_min_num_f16 */, AMDGPU::V_MIN_NUM_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 42452 /* v_min_num_f32 */, AMDGPU::V_MIN_NUM_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 42466 /* v_min_num_f64 */, AMDGPU::V_MIN_NUM_F64_e32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 42480 /* v_min_u16 */, AMDGPU::V_MIN_U16_e32_vi, Convert__Reg1_0__VSrc_b161_1__Reg1_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_e32_vi, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42710 /* v_mov_b16 */, AMDGPU::V_MOV_B16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_b16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_b16_Lo128 }, },
  { 42710 /* v_mov_b16 */, AMDGPU::V_MOV_B16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_b16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_b16_Lo128 }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_e32_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 42730 /* v_mov_b64 */, AMDGPU::V_MOV_B64_e32_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1, AMFBS_isGFX940orGFX1250_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64 }, },
  { 42730 /* v_mov_b64 */, AMDGPU::V_MOV_B64_e32_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1, AMFBS_isGFX940orGFX1250_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64 }, },
  { 42740 /* v_movreld_b32 */, AMDGPU::V_MOVRELD_B32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_HasMovrel_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 42740 /* v_movreld_b32 */, AMDGPU::V_MOVRELD_B32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_HasMovrel_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 42740 /* v_movreld_b32 */, AMDGPU::V_MOVRELD_B32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_HasMovrel_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 42740 /* v_movreld_b32 */, AMDGPU::V_MOVRELD_B32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1, AMFBS_HasMovrel_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 42740 /* v_movreld_b32 */, AMDGPU::V_MOVRELD_B32_e32_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_HasMovrel_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 42754 /* v_movrels_b32 */, AMDGPU::V_MOVRELS_B32_e32_gfx10, Convert__Reg1_0__Reg1_1, AMFBS_HasMovrel_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42754 /* v_movrels_b32 */, AMDGPU::V_MOVRELS_B32_e32_gfx11, Convert__Reg1_0__Reg1_1, AMFBS_HasMovrel_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42754 /* v_movrels_b32 */, AMDGPU::V_MOVRELS_B32_e32_gfx12, Convert__Reg1_0__Reg1_1, AMFBS_HasMovrel_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42754 /* v_movrels_b32 */, AMDGPU::V_MOVRELS_B32_e32_gfx6_gfx7, Convert__Reg1_0__Reg1_1, AMFBS_HasMovrel_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42754 /* v_movrels_b32 */, AMDGPU::V_MOVRELS_B32_e32_vi, Convert__Reg1_0__Reg1_1, AMFBS_HasMovrel_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42768 /* v_movrelsd_2_b32 */, AMDGPU::V_MOVRELSD_2_B32_e32_gfx10, Convert__Reg1_0__Reg1_1, AMFBS_isGFX10Plus_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42768 /* v_movrelsd_2_b32 */, AMDGPU::V_MOVRELSD_2_B32_e32_gfx11, Convert__Reg1_0__Reg1_1, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42768 /* v_movrelsd_2_b32 */, AMDGPU::V_MOVRELSD_2_B32_e32_gfx12, Convert__Reg1_0__Reg1_1, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42785 /* v_movrelsd_b32 */, AMDGPU::V_MOVRELSD_B32_e32_gfx10, Convert__Reg1_0__Reg1_1, AMFBS_HasMovrel_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42785 /* v_movrelsd_b32 */, AMDGPU::V_MOVRELSD_B32_e32_gfx11, Convert__Reg1_0__Reg1_1, AMFBS_HasMovrel_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42785 /* v_movrelsd_b32 */, AMDGPU::V_MOVRELSD_B32_e32_gfx12, Convert__Reg1_0__Reg1_1, AMFBS_HasMovrel_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42785 /* v_movrelsd_b32 */, AMDGPU::V_MOVRELSD_B32_e32_gfx6_gfx7, Convert__Reg1_0__Reg1_1, AMFBS_HasMovrel_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42785 /* v_movrelsd_b32 */, AMDGPU::V_MOVRELSD_B32_e32_vi, Convert__Reg1_0__Reg1_1, AMFBS_HasMovrel_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42843 /* v_mul_dx9_zero_f32 */, AMDGPU::V_MUL_DX9_ZERO_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 42843 /* v_mul_dx9_zero_f32 */, AMDGPU::V_MUL_DX9_ZERO_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1__Reg1_2, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1__Reg1_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 42882 /* v_mul_f64 */, AMDGPU::V_MUL_F64_e32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_e32_vi, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_e32_vi, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_e32_vi, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 42966 /* v_mul_legacy_f32 */, AMDGPU::V_MUL_LEGACY_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGCN3ExcludingGFX90A_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 42966 /* v_mul_legacy_f32 */, AMDGPU::V_MUL_LEGACY_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 42966 /* v_mul_legacy_f32 */, AMDGPU::V_MUL_LEGACY_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 42996 /* v_mul_lo_u16 */, AMDGPU::V_MUL_LO_U16_e32_vi, Convert__Reg1_0__VSrc_b161_1__Reg1_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_e32_vi, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 43036 /* v_mul_u64 */, AMDGPU::V_MUL_U64_e32_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 43059 /* v_nop */, AMDGPU::V_NOP_e32_gfx10, Convert_NoOperands, AMFBS_isGFX10Only, {  }, },
  { 43059 /* v_nop */, AMDGPU::V_NOP_e32_gfx11, Convert_NoOperands, AMFBS_isGFX11Only, {  }, },
  { 43059 /* v_nop */, AMDGPU::V_NOP_e32_gfx12, Convert_NoOperands, AMFBS_isGFX12Only, {  }, },
  { 43059 /* v_nop */, AMDGPU::V_NOP_e32_gfx6_gfx7, Convert_NoOperands, AMFBS_isGFX6GFX7, {  }, },
  { 43059 /* v_nop */, AMDGPU::V_NOP_e32_vi, Convert_NoOperands, AMFBS_isGFX8GFX9, {  }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_b16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_b16_Lo128 }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_b16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_b16_Lo128 }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_b16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_b16_Lo128 }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_b16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_b16_Lo128 }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_e32_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_e32_vi, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 43210 /* v_permlane16_swap_b32 */, AMDGPU::V_PERMLANE16_SWAP_B32_e32_gfx1250, Convert__Reg1_0__Reg1_1__Tie0_1_1__Tie1_2_2, AMFBS_HasPermlane16Swap_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 43210 /* v_permlane16_swap_b32 */, AMDGPU::V_PERMLANE16_SWAP_B32_e32_gfx9, Convert__Reg1_0__Reg1_1__Tie0_1_1__Tie1_2_2, AMFBS_HasPermlane16Swap_isGFX9Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 43253 /* v_permlane32_swap_b32 */, AMDGPU::V_PERMLANE32_SWAP_B32_e32_gfx9, Convert__Reg1_0__Reg1_1__Tie0_1_1__Tie1_2_2, AMFBS_HasPermlane32Swap_isGFX9Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 43275 /* v_permlane64_b32 */, AMDGPU::V_PERMLANE64_B32_gfx11, Convert__Reg1_0__Reg1_1, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 43275 /* v_permlane64_b32 */, AMDGPU::V_PERMLANE64_B32_gfx12, Convert__Reg1_0__Reg1_1, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 43433 /* v_pipeflush */, AMDGPU::V_PIPEFLUSH_e32_gfx10, Convert_NoOperands, AMFBS_isGFX10Plus_isGFX10Only, {  }, },
  { 43433 /* v_pipeflush */, AMDGPU::V_PIPEFLUSH_e32_gfx11, Convert_NoOperands, AMFBS_isGFX10Plus_isGFX11Only, {  }, },
  { 43433 /* v_pipeflush */, AMDGPU::V_PIPEFLUSH_e32_gfx12, Convert_NoOperands, AMFBS_isGFX10Plus_isGFX12Only, {  }, },
  { 43636 /* v_pk_fmac_f16 */, AMDGPU::V_PK_FMAC_F16_e32_gfx10, Convert__Reg1_0__VSrc_v2f16_splat1_1__Reg1_2, AMFBS_HasPkFmacF16Inst_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2f16_splat, MCK_VGPR_32 }, },
  { 43636 /* v_pk_fmac_f16 */, AMDGPU::V_PK_FMAC_F16_e32_gfx11, Convert__Reg1_0__VSrc_v2f16_splat1_1__Reg1_2, AMFBS_HasPkFmacF16Inst_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2f16_splat, MCK_VGPR_32 }, },
  { 43636 /* v_pk_fmac_f16 */, AMDGPU::V_PK_FMAC_F16_e32_gfx12, Convert__Reg1_0__VSrc_v2f16_splat1_1__Reg1_2, AMFBS_HasPkFmacF16Inst_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2f16_splat, MCK_VGPR_32 }, },
  { 43636 /* v_pk_fmac_f16 */, AMDGPU::V_PK_FMAC_F16_e32_gfx9, Convert__Reg1_0__VSrc_v2f16_splat1_1__Reg1_2, AMFBS_HasPkFmacF16Inst_isGFX9Only, { MCK_VGPR_32, MCK_VSrc_v2f16_splat, MCK_VGPR_32 }, },
  { 43636 /* v_pk_fmac_f16 */, AMDGPU::V_PK_FMAC_F16_e32_vi, Convert__Reg1_0__VSrc_v2f16_splat1_1__Reg1_2, AMFBS_HasPkFmacF16Inst_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_v2f16_splat, MCK_VGPR_32 }, },
  { 44115 /* v_prng_b32 */, AMDGPU::V_PRNG_B32_e32_gfx1250, Convert__Reg1_0__VSrc_b321_1, AMFBS_HasPrngInst_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 44115 /* v_prng_b32 */, AMDGPU::V_PRNG_B32_e32_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_HasPrngInst_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 44143 /* v_rcp_bf16 */, AMDGPU::V_RCP_BF16V_RCP_BF16_fake16_e32_gfx1250, Convert__Reg1_0__VSrcFake16_bf16_Lo1281_1, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_bf16_Lo128 }, },
  { 44143 /* v_rcp_bf16 */, AMDGPU::V_RCP_BF16V_RCP_BF16_t16_e32_gfx1250, Convert__Reg1_0__VSrcT_bf16_Lo1281_1, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VSrcT_bf16_Lo128 }, },
  { 44154 /* v_rcp_clamp_f32 */, AMDGPU::V_RCP_CLAMP_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44170 /* v_rcp_clamp_f64 */, AMDGPU::V_RCP_CLAMP_F64_e32_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44206 /* v_rcp_f64 */, AMDGPU::V_RCP_F64_e32_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 44206 /* v_rcp_f64 */, AMDGPU::V_RCP_F64_e32_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 44206 /* v_rcp_f64 */, AMDGPU::V_RCP_F64_e32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 44206 /* v_rcp_f64 */, AMDGPU::V_RCP_F64_e32_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 44206 /* v_rcp_f64 */, AMDGPU::V_RCP_F64_e32_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44232 /* v_rcp_legacy_f32 */, AMDGPU::V_RCP_LEGACY_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44249 /* v_readfirstlane_b32 */, AMDGPU::V_READFIRSTLANE_B32_gfx10, Convert__Reg1_0__Reg1_1, AMFBS_isGFX10Only, { MCK_SReg_32_XM0, MCK_VRegOrLds_32 }, },
  { 44249 /* v_readfirstlane_b32 */, AMDGPU::V_READFIRSTLANE_B32_gfx11, Convert__Reg1_0__Reg1_1, AMFBS_isGFX11Only, { MCK_SReg_32_XM0, MCK_VRegOrLds_32 }, },
  { 44249 /* v_readfirstlane_b32 */, AMDGPU::V_READFIRSTLANE_B32_gfx12, Convert__Reg1_0__Reg1_1, AMFBS_isGFX12Only, { MCK_SReg_32_XM0, MCK_VRegOrLds_32 }, },
  { 44249 /* v_readfirstlane_b32 */, AMDGPU::V_READFIRSTLANE_B32_gfx6_gfx7, Convert__Reg1_0__Reg1_1, AMFBS_isGFX6GFX7, { MCK_SReg_32_XM0, MCK_VRegOrLds_32 }, },
  { 44249 /* v_readfirstlane_b32 */, AMDGPU::V_READFIRSTLANE_B32_vi, Convert__Reg1_0__Reg1_1, AMFBS_isGFX8GFX9, { MCK_SReg_32_XM0, MCK_VRegOrLds_32 }, },
  { 44269 /* v_readlane_b32 */, AMDGPU::V_READLANE_B32_e64_gfx11, Convert__Reg1_0__Reg1_1__SCSrc_b321_2, AMFBS_isGFX11Only, { MCK_SReg_32_XM0, MCK_VRegOrLds_32, MCK_SCSrc_b32 }, },
  { 44269 /* v_readlane_b32 */, AMDGPU::V_READLANE_B32_e64_gfx12, Convert__Reg1_0__Reg1_1__SCSrc_b321_2, AMFBS_isGFX12Only, { MCK_SReg_32_XM0, MCK_VRegOrLds_32, MCK_SCSrc_b32 }, },
  { 44269 /* v_readlane_b32 */, AMDGPU::V_READLANE_B32_gfx10, Convert__Reg1_0__Reg1_1__SCSrc_b321_2, AMFBS_isGFX10Only, { MCK_SReg_32_XM0, MCK_VRegOrLds_32, MCK_SCSrc_b32 }, },
  { 44269 /* v_readlane_b32 */, AMDGPU::V_READLANE_B32_gfx6_gfx7, Convert__Reg1_0__Reg1_1__SCSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_SReg_32_XM0, MCK_VRegOrLds_32, MCK_SCSrc_b32 }, },
  { 44269 /* v_readlane_b32 */, AMDGPU::V_READLANE_B32_vi, Convert__Reg1_0__Reg1_1__SCSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_SReg_32_XM0, MCK_VRegOrLds_32, MCK_SCSrc_b32 }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44308 /* v_rndne_f64 */, AMDGPU::V_RNDNE_F64_e32_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX7Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 44308 /* v_rndne_f64 */, AMDGPU::V_RNDNE_F64_e32_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX7Plus_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 44308 /* v_rndne_f64 */, AMDGPU::V_RNDNE_F64_e32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX7Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 44308 /* v_rndne_f64 */, AMDGPU::V_RNDNE_F64_e32_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX7Plus_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 44308 /* v_rndne_f64 */, AMDGPU::V_RNDNE_F64_e32_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 44320 /* v_rsq_bf16 */, AMDGPU::V_RSQ_BF16V_RSQ_BF16_fake16_e32_gfx1250, Convert__Reg1_0__VSrcFake16_bf16_Lo1281_1, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_bf16_Lo128 }, },
  { 44320 /* v_rsq_bf16 */, AMDGPU::V_RSQ_BF16V_RSQ_BF16_t16_e32_gfx1250, Convert__Reg1_0__VSrcT_bf16_Lo1281_1, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VSrcT_bf16_Lo128 }, },
  { 44331 /* v_rsq_clamp_f32 */, AMDGPU::V_RSQ_CLAMP_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44347 /* v_rsq_clamp_f64 */, AMDGPU::V_RSQ_CLAMP_F64_e32_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44383 /* v_rsq_f64 */, AMDGPU::V_RSQ_F64_e32_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 44383 /* v_rsq_f64 */, AMDGPU::V_RSQ_F64_e32_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 44383 /* v_rsq_f64 */, AMDGPU::V_RSQ_F64_e32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 44383 /* v_rsq_f64 */, AMDGPU::V_RSQ_F64_e32_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 44383 /* v_rsq_f64 */, AMDGPU::V_RSQ_F64_e32_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 44393 /* v_rsq_legacy_f32 */, AMDGPU::V_RSQ_LEGACY_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44573 /* v_sat_pk4_i4_i8 */, AMDGPU::V_SAT_PK4_I4_I8V_SAT_PK4_I4_I8_fake16_e32_gfx1250, Convert__Reg1_0__VSrc_b321_1, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VSrc_b32 }, },
  { 44573 /* v_sat_pk4_i4_i8 */, AMDGPU::V_SAT_PK4_I4_I8V_SAT_PK4_I4_I8_t16_e32_gfx1250, Convert__Reg1_0__VSrc_b321_1, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VSrc_b32 }, },
  { 44589 /* v_sat_pk4_u4_u8 */, AMDGPU::V_SAT_PK4_U4_U8V_SAT_PK4_U4_U8_fake16_e32_gfx1250, Convert__Reg1_0__VSrc_b321_1, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VSrc_b32 }, },
  { 44589 /* v_sat_pk4_u4_u8 */, AMDGPU::V_SAT_PK4_U4_U8V_SAT_PK4_U4_U8_t16_e32_gfx1250, Convert__Reg1_0__VSrc_b321_1, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VSrc_b32 }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_fake16_e32_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_UseFakeTrue16Insts_isGFX9Plus_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrc_b32 }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_fake16_e32_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_UseFakeTrue16Insts_isGFX9Plus_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrc_b32 }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_t16_e32_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_UseRealTrue16Insts_isGFX9Plus_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrc_b32 }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_t16_e32_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_UseRealTrue16Insts_isGFX9Plus_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrc_b32 }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16_e32_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX9Plus_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16_e32_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX9Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 44621 /* v_screen_partition_4se_b32 */, AMDGPU::V_SCREEN_PARTITION_4SE_B32_e32_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX9Only_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 44648 /* v_sin_bf16 */, AMDGPU::V_SIN_BF16V_SIN_BF16_fake16_e32_gfx1250, Convert__Reg1_0__VSrcFake16_bf16_Lo1281_1, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_bf16_Lo128 }, },
  { 44648 /* v_sin_bf16 */, AMDGPU::V_SIN_BF16V_SIN_BF16_t16_e32_gfx1250, Convert__Reg1_0__VSrcT_bf16_Lo1281_1, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VSrcT_bf16_Lo128 }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 45476 /* v_sqrt_bf16 */, AMDGPU::V_SQRT_BF16V_SQRT_BF16_fake16_e32_gfx1250, Convert__Reg1_0__VSrcFake16_bf16_Lo1281_1, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_bf16_Lo128 }, },
  { 45476 /* v_sqrt_bf16 */, AMDGPU::V_SQRT_BF16V_SQRT_BF16_t16_e32_gfx1250, Convert__Reg1_0__VSrcT_bf16_Lo1281_1, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VSrcT_bf16_Lo128 }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 45510 /* v_sqrt_f64 */, AMDGPU::V_SQRT_F64_e32_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 45510 /* v_sqrt_f64 */, AMDGPU::V_SQRT_F64_e32_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 45510 /* v_sqrt_f64 */, AMDGPU::V_SQRT_F64_e32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 45510 /* v_sqrt_f64 */, AMDGPU::V_SQRT_F64_e32_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 45510 /* v_sqrt_f64 */, AMDGPU::V_SQRT_F64_e32_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_e32_gfx12, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX12Plus_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_e32_gfx11, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX11Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_e32_gfx10, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX10Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_e32_gfx12, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX12Plus_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC_LO }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_e32_gfx11, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC_LO }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_e32_gfx10, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX10Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC_LO }, },
  { 45537 /* v_sub_co_u32 */, AMDGPU::V_SUB_CO_U32_e32_gfx9, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX9Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45537 /* v_sub_co_u32 */, AMDGPU::V_SUB_CO_U32_e32_gfx9, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX9Only_isWave64, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45537 /* v_sub_co_u32 */, AMDGPU::V_SUB_CO_U32_e32_gfx9, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45537 /* v_sub_co_u32 */, AMDGPU::V_SUB_I32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX6GFX7_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 45537 /* v_sub_co_u32 */, AMDGPU::V_SUB_I32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX6GFX7_isWave32, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC_LO }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1__Reg1_2, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1__Reg1_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 45580 /* v_sub_i32 */, AMDGPU::V_SUB_I32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45629 /* v_sub_nc_u32 */, AMDGPU::V_SUB_NC_U32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_HasAddNoCarryInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45629 /* v_sub_nc_u32 */, AMDGPU::V_SUB_NC_U32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_HasAddNoCarryInsts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45629 /* v_sub_nc_u32 */, AMDGPU::V_SUB_NC_U32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_HasAddNoCarryInsts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45642 /* v_sub_nc_u64 */, AMDGPU::V_SUB_U64_e32_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1__RegByHwMode_VReg_64_AlignTarget1_2, AMFBS_HasAddSubU64Insts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_RegByHwMode_VReg_64_AlignTarget }, },
  { 45655 /* v_sub_u16 */, AMDGPU::V_SUB_U16_e32_vi, Convert__Reg1_0__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 45665 /* v_sub_u32 */, AMDGPU::V_SUB_U32_e32_gfx9, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_HasAddNoCarryInsts_isGFX9Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45665 /* v_sub_u32 */, AMDGPU::V_SUB_U32_e32_vi, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45675 /* v_subb_co_u32 */, AMDGPU::V_SUBB_CO_U32_e32_gfx9, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX9Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 45675 /* v_subb_co_u32 */, AMDGPU::V_SUBB_CO_U32_e32_gfx9, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 45675 /* v_subb_co_u32 */, AMDGPU::V_SUBB_CO_U32_e32_gfx9, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX9Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC_LO }, },
  { 45689 /* v_subb_u32 */, AMDGPU::V_SUBB_U32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 45689 /* v_subb_u32 */, AMDGPU::V_SUBB_U32_e32_vi, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 45700 /* v_subbrev_co_u32 */, AMDGPU::V_SUBBREV_CO_U32_e32_gfx9, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX9Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 45700 /* v_subbrev_co_u32 */, AMDGPU::V_SUBBREV_CO_U32_e32_gfx9, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 45700 /* v_subbrev_co_u32 */, AMDGPU::V_SUBBREV_CO_U32_e32_gfx9, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX9Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC_LO }, },
  { 45717 /* v_subbrev_u32 */, AMDGPU::V_SUBBREV_U32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 45717 /* v_subbrev_u32 */, AMDGPU::V_SUBBREV_U32_e32_vi, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_e32_gfx12, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX12Plus_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_e32_gfx11, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX11Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_e32_gfx10, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX10Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_e32_gfx12, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX12Plus_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC_LO }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_e32_gfx11, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC_LO }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_e32_gfx10, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX10Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC_LO }, },
  { 45750 /* v_subrev_co_u32 */, AMDGPU::V_SUBREV_CO_U32_e32_gfx9, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX9Only_isWave32, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45750 /* v_subrev_co_u32 */, AMDGPU::V_SUBREV_CO_U32_e32_gfx9, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX9Only_isWave64, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45750 /* v_subrev_co_u32 */, AMDGPU::V_SUBREV_CO_U32_e32_gfx9, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45750 /* v_subrev_co_u32 */, AMDGPU::V_SUBREV_I32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX6GFX7_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC }, },
  { 45750 /* v_subrev_co_u32 */, AMDGPU::V_SUBREV_I32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX6GFX7_isWave32, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32, MCK_VCC_LO }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1__Reg1_2, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128, MCK_VGPR_32_Lo128 }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1__Reg1_2, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1__Reg1_2, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1__Reg1_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_f16, MCK_VGPR_32 }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32, MCK_VGPR_32 }, },
  { 45792 /* v_subrev_i32 */, AMDGPU::V_SUBREV_I32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45805 /* v_subrev_nc_u32 */, AMDGPU::V_SUBREV_NC_U32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_HasAddNoCarryInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45805 /* v_subrev_nc_u32 */, AMDGPU::V_SUBREV_NC_U32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_HasAddNoCarryInsts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45805 /* v_subrev_nc_u32 */, AMDGPU::V_SUBREV_NC_U32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_HasAddNoCarryInsts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45821 /* v_subrev_u16 */, AMDGPU::V_SUBREV_U16_e32_vi, Convert__Reg1_0__VSrc_b161_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VGPR_32 }, },
  { 45834 /* v_subrev_u32 */, AMDGPU::V_SUBREV_U32_e32_gfx9, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_HasAddNoCarryInsts_isGFX9Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45834 /* v_subrev_u32 */, AMDGPU::V_SUBREV_U32_e32_vi, Convert__Reg1_0__VSrc_b321_2__Reg1_3, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_VCC, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 45847 /* v_swap_b16 */, AMDGPU::V_SWAP_B16_gfx11, Convert__Reg1_0__Reg1_1__Tie1_2_2__Tie0_1_1, AMFBS_isGFX11Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 45847 /* v_swap_b16 */, AMDGPU::V_SWAP_B16_gfx12, Convert__Reg1_0__Reg1_1__Tie1_2_2__Tie0_1_1, AMFBS_isGFX11Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128 }, },
  { 45858 /* v_swap_b32 */, AMDGPU::V_SWAP_B32_gfx10, Convert__Reg1_0__Reg1_1__Tie1_2_2__Tie0_1_1, AMFBS_isGFX9Plus_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 45858 /* v_swap_b32 */, AMDGPU::V_SWAP_B32_gfx11, Convert__Reg1_0__Reg1_1__Tie1_2_2__Tie0_1_1, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 45858 /* v_swap_b32 */, AMDGPU::V_SWAP_B32_gfx12, Convert__Reg1_0__Reg1_1__Tie1_2_2__Tie0_1_1, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 45858 /* v_swap_b32 */, AMDGPU::V_SWAP_B32_vi, Convert__Reg1_0__Reg1_1__Tie1_2_2__Tie0_1_1, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 45869 /* v_swaprel_b32 */, AMDGPU::V_SWAPREL_B32_gfx10, Convert__Reg1_0__Reg1_1__Tie1_2_2__Tie0_1_1, AMFBS_isGFX10Plus_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 45869 /* v_swaprel_b32 */, AMDGPU::V_SWAPREL_B32_gfx11, Convert__Reg1_0__Reg1_1__Tie1_2_2__Tie0_1_1, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 45869 /* v_swaprel_b32 */, AMDGPU::V_SWAPREL_B32_gfx12, Convert__Reg1_0__Reg1_1__Tie1_2_2__Tie0_1_1, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 46601 /* v_tanh_bf16 */, AMDGPU::V_TANH_BF16V_TANH_BF16_fake16_e32_gfx1250, Convert__Reg1_0__VSrcFake16_bf16_Lo1281_1, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_bf16_Lo128 }, },
  { 46601 /* v_tanh_bf16 */, AMDGPU::V_TANH_BF16V_TANH_BF16_t16_e32_gfx1250, Convert__Reg1_0__VSrcT_bf16_Lo1281_1, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VSrcT_bf16_Lo128 }, },
  { 46613 /* v_tanh_f16 */, AMDGPU::V_TANH_F16V_TANH_F16_fake16_e32_gfx1250, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_HasTanhInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 46613 /* v_tanh_f16 */, AMDGPU::V_TANH_F16V_TANH_F16_t16_e32_gfx1250, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_HasTanhInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 46624 /* v_tanh_f32 */, AMDGPU::V_TANH_F32_e32_gfx1250, Convert__Reg1_0__VSrc_f321_1, AMFBS_HasTanhInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_fake16_e32_gfx11, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_fake16_e32_gfx12, Convert__Reg1_0__VSrcFake16_f16_Lo1281_1, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VSrcFake16_f16_Lo128 }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_t16_e32_gfx11, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_t16_e32_gfx12, Convert__Reg1_0__VSrcT_f16_Lo1281_1, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VSrcT_f16_Lo128 }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16_e32_gfx10, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16_e32_vi, Convert__Reg1_0__VSrc_f161_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f16 }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_e32_gfx10, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_e32_gfx11, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_e32_gfx12, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_e32_vi, Convert__Reg1_0__VSrc_f321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_f32 }, },
  { 46676 /* v_trunc_f64 */, AMDGPU::V_TRUNC_F64_e32_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX7Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 46676 /* v_trunc_f64 */, AMDGPU::V_TRUNC_F64_e32_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX7Plus_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 46676 /* v_trunc_f64 */, AMDGPU::V_TRUNC_F64_e32_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX7Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 46676 /* v_trunc_f64 */, AMDGPU::V_TRUNC_F64_e32_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX7Plus_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 46676 /* v_trunc_f64 */, AMDGPU::V_TRUNC_F64_e32_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_f641_1, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_f64 }, },
  { 47842 /* v_writelane_b32 */, AMDGPU::V_WRITELANE_B32_e64_gfx11, Convert__Reg1_0__SSrcOrLds_b321_1__SCSrc_b321_2__Tie0_1_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_SSrcOrLds_b32, MCK_SCSrc_b32 }, },
  { 47842 /* v_writelane_b32 */, AMDGPU::V_WRITELANE_B32_e64_gfx12, Convert__Reg1_0__SSrcOrLds_b321_1__SCSrc_b321_2__Tie0_1_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_SSrcOrLds_b32, MCK_SCSrc_b32 }, },
  { 47842 /* v_writelane_b32 */, AMDGPU::V_WRITELANE_B32_gfx10, Convert__Reg1_0__SSrcOrLds_b321_1__SCSrc_b321_2__Tie0_1_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SSrcOrLds_b32, MCK_SCSrc_b32 }, },
  { 47842 /* v_writelane_b32 */, AMDGPU::V_WRITELANE_B32_gfx6_gfx7, Convert__Reg1_0__SSrcOrLds_b321_1__SCSrc_b321_2__Tie0_1_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_SSrcOrLds_b32, MCK_SCSrc_b32 }, },
  { 47842 /* v_writelane_b32 */, AMDGPU::V_WRITELANE_B32_vi, Convert__Reg1_0__SCSrc_b321_1__SCSrc_b321_2__Tie0_1_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_SCSrc_b32, MCK_SCSrc_b32 }, },
  { 47868 /* v_xnor_b32 */, AMDGPU::V_XNOR_B32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_HasDLInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 47868 /* v_xnor_b32 */, AMDGPU::V_XNOR_B32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_HasDLInsts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 47868 /* v_xnor_b32 */, AMDGPU::V_XNOR_B32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_HasDLInsts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 47868 /* v_xnor_b32 */, AMDGPU::V_XNOR_B32_e32_vi, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_HasDLInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_e32_gfx10, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_e32_gfx11, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_e32_gfx12, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_e32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_e32_vi, Convert__Reg1_0__VSrc_b321_1__Reg1_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VGPR_32 }, },
};

static const MatchEntry MatchTable1[] = {
  { 24188 /* v_accvgpr_read_b32 */, AMDGPU::V_ACCVGPR_READ_B32_vi, Convert__Reg1_0__Reg1_1, AMFBS_HasMAIInsts, { MCK_VGPR_32, MCK_AGPR_32 }, },
  { 24207 /* v_accvgpr_write_b32 */, AMDGPU::V_ACCVGPR_WRITE_B32_vi, Convert__Reg1_0__VCSrc_b321_1, AMFBS_HasMAIInsts, { MCK_AGPR_32, MCK_VCSrc_b32 }, },
  { 24227 /* v_add3_u32 */, AMDGPU::V_ADD3_U32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24227 /* v_add3_u32 */, AMDGPU::V_ADD3_U32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24227 /* v_add3_u32 */, AMDGPU::V_ADD3_U32_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24227 /* v_add3_u32 */, AMDGPU::V_ADD3_U32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_BoolReg, MCK_Clamp }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_BoolReg, MCK_Clamp }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_BoolReg, MCK_Clamp }, },
  { 24254 /* v_add_co_u32 */, AMDGPU::V_ADD_I32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VGPR_32, MCK_Clamp }, },
  { 24254 /* v_add_co_u32 */, AMDGPU::V_ADD_CO_U32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 24254 /* v_add_co_u32 */, AMDGPU::V_ADD_CO_U32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 24254 /* v_add_co_u32 */, AMDGPU::V_ADD_CO_U32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 24254 /* v_add_co_u32 */, AMDGPU::V_ADD_CO_U32_e64_gfx9, ConvertCustom_cvtVOP3, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24287 /* v_add_f64 */, AMDGPU::V_ADD_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isNotGFX12Plus_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24287 /* v_add_f64 */, AMDGPU::V_ADD_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24287 /* v_add_f64 */, AMDGPU::V_ADD_F64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isNotGFX12Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24287 /* v_add_f64 */, AMDGPU::V_ADD_F64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isNotGFX12Plus_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24287 /* v_add_f64 */, AMDGPU::V_ADD_F64_vi, ConvertCustom_cvtVOP3, AMFBS_isNotGFX12Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24297 /* v_add_i16 */, AMDGPU::V_ADD_I16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 24307 /* v_add_i32 */, AMDGPU::V_ADD_I32_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 24307 /* v_add_i32 */, AMDGPU::V_ADD_I32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 24317 /* v_add_lshl_u32 */, AMDGPU::V_ADD_LSHL_U32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24317 /* v_add_lshl_u32 */, AMDGPU::V_ADD_LSHL_U32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24317 /* v_add_lshl_u32 */, AMDGPU::V_ADD_LSHL_U32_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24317 /* v_add_lshl_u32 */, AMDGPU::V_ADD_LSHL_U32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24332 /* v_add_max_i32 */, AMDGPU::V_ADD_MAX_I32_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_HasAddMinMaxInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 24346 /* v_add_max_u32 */, AMDGPU::V_ADD_MAX_U32_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_HasAddMinMaxInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 24360 /* v_add_min_i32 */, AMDGPU::V_ADD_MIN_I32_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_HasAddMinMaxInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 24374 /* v_add_min_u32 */, AMDGPU::V_ADD_MIN_U32_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_HasAddMinMaxInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 24388 /* v_add_nc_i16 */, AMDGPU::V_ADD_NC_I16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 24388 /* v_add_nc_i16 */, AMDGPU::V_ADD_NC_I16V_ADD_I16_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 24388 /* v_add_nc_i16 */, AMDGPU::V_ADD_NC_I16V_ADD_I16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 24388 /* v_add_nc_i16 */, AMDGPU::V_ADD_NC_I16V_ADD_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 24388 /* v_add_nc_i16 */, AMDGPU::V_ADD_NC_I16V_ADD_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 24401 /* v_add_nc_i32 */, AMDGPU::V_ADD_NC_I32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 24401 /* v_add_nc_i32 */, AMDGPU::V_ADD_NC_I32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 24401 /* v_add_nc_i32 */, AMDGPU::V_ADD_NC_I32_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX9Plus_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 24414 /* v_add_nc_u16 */, AMDGPU::V_ADD_NC_U16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX10Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 24414 /* v_add_nc_u16 */, AMDGPU::V_ADD_NC_U16_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 24414 /* v_add_nc_u16 */, AMDGPU::V_ADD_NC_U16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 24414 /* v_add_nc_u16 */, AMDGPU::V_ADD_NC_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX10Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 24414 /* v_add_nc_u16 */, AMDGPU::V_ADD_NC_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX10Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 24427 /* v_add_nc_u32 */, AMDGPU::V_ADD_NC_U32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasAddNoCarryInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 24427 /* v_add_nc_u32 */, AMDGPU::V_ADD_NC_U32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasAddNoCarryInsts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 24427 /* v_add_nc_u32 */, AMDGPU::V_ADD_NC_U32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasAddNoCarryInsts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 24440 /* v_add_nc_u64 */, AMDGPU::V_ADD_U64_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_HasAddSubU64Insts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b64, MCK_Clamp }, },
  { 24453 /* v_add_u16 */, AMDGPU::V_ADD_U16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_Clamp }, },
  { 24463 /* v_add_u32 */, AMDGPU::V_ADD_U32_e64_gfx9, ConvertCustom_cvtVOP3, AMFBS_HasAddNoCarryInsts_isGFX9Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 24463 /* v_add_u32 */, AMDGPU::V_ADD_U32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 24473 /* v_addc_co_u32 */, AMDGPU::V_ADDC_CO_U32_e64_gfx9, ConvertCustom_cvtVOP3, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_BoolReg, MCK_Clamp }, },
  { 24487 /* v_addc_u32 */, AMDGPU::V_ADDC_U32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_BoolReg, MCK_Clamp }, },
  { 24487 /* v_addc_u32 */, AMDGPU::V_ADDC_U32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_BoolReg, MCK_Clamp }, },
  { 24498 /* v_alignbit_b32 */, AMDGPU::V_ALIGNBIT_B32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX8Only_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24498 /* v_alignbit_b32 */, AMDGPU::V_ALIGNBIT_B32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX6GFX7_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24498 /* v_alignbit_b32 */, AMDGPU::V_ALIGNBIT_B32V_ALIGNBIT_B32_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 24498 /* v_alignbit_b32 */, AMDGPU::V_ALIGNBIT_B32V_ALIGNBIT_B32_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 24498 /* v_alignbit_b32 */, AMDGPU::V_ALIGNBIT_B32V_ALIGNBIT_B32_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 24498 /* v_alignbit_b32 */, AMDGPU::V_ALIGNBIT_B32V_ALIGNBIT_B32_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 24498 /* v_alignbit_b32 */, AMDGPU::V_ALIGNBIT_B32_opsel_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_OpSel, MCK_Clamp }, },
  { 24498 /* v_alignbit_b32 */, AMDGPU::V_ALIGNBIT_B32_opsel_gfx9, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_OpSel, MCK_Clamp }, },
  { 24513 /* v_alignbyte_b32 */, AMDGPU::V_ALIGNBYTE_B32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX8Only_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24513 /* v_alignbyte_b32 */, AMDGPU::V_ALIGNBYTE_B32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24513 /* v_alignbyte_b32 */, AMDGPU::V_ALIGNBYTE_B32V_ALIGNBYTE_B32_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 24513 /* v_alignbyte_b32 */, AMDGPU::V_ALIGNBYTE_B32V_ALIGNBYTE_B32_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 24513 /* v_alignbyte_b32 */, AMDGPU::V_ALIGNBYTE_B32V_ALIGNBYTE_B32_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 24513 /* v_alignbyte_b32 */, AMDGPU::V_ALIGNBYTE_B32V_ALIGNBYTE_B32_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 24513 /* v_alignbyte_b32 */, AMDGPU::V_ALIGNBYTE_B32_opsel_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_OpSel, MCK_Clamp }, },
  { 24513 /* v_alignbyte_b32 */, AMDGPU::V_ALIGNBYTE_B32_opsel_gfx9, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_OpSel, MCK_Clamp }, },
  { 24529 /* v_and_b16 */, AMDGPU::V_AND_B16_fake16_e64_gfx11, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 24529 /* v_and_b16 */, AMDGPU::V_AND_B16_fake16_e64_gfx12, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 24529 /* v_and_b16 */, AMDGPU::V_AND_B16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX11Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 24529 /* v_and_b16 */, AMDGPU::V_AND_B16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX11Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_e64_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24549 /* v_and_or_b32 */, AMDGPU::V_AND_OR_B32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24549 /* v_and_or_b32 */, AMDGPU::V_AND_OR_B32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24549 /* v_and_or_b32 */, AMDGPU::V_AND_OR_B32_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24549 /* v_and_or_b32 */, AMDGPU::V_AND_OR_B32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24562 /* v_ashr_i32 */, AMDGPU::V_ASHR_I32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24573 /* v_ashr_i64 */, AMDGPU::V_ASHR_I64_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b32 }, },
  { 24584 /* v_ashr_pk_i8_i32 */, AMDGPU::V_ASHR_PK_I8_I32_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_HasAshrPkInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_OpSel }, },
  { 24584 /* v_ashr_pk_i8_i32 */, AMDGPU::V_ASHR_PK_I8_I32_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasAshrPkInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_OpSel }, },
  { 24601 /* v_ashr_pk_u8_i32 */, AMDGPU::V_ASHR_PK_U8_I32_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_HasAshrPkInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_OpSel }, },
  { 24601 /* v_ashr_pk_u8_i32 */, AMDGPU::V_ASHR_PK_U8_I32_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasAshrPkInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_OpSel }, },
  { 24618 /* v_ashrrev_i16 */, AMDGPU::V_ASHRREV_I16_e64_vi, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 24618 /* v_ashrrev_i16 */, AMDGPU::V_ASHRREV_I16_fake16_e64_gfx11, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 24618 /* v_ashrrev_i16 */, AMDGPU::V_ASHRREV_I16_fake16_e64_gfx12, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 24618 /* v_ashrrev_i16 */, AMDGPU::V_ASHRREV_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 24618 /* v_ashrrev_i16 */, AMDGPU::V_ASHRREV_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 24618 /* v_ashrrev_i16 */, AMDGPU::V_ASHRREV_I16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_e64_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24646 /* v_ashrrev_i64 */, AMDGPU::V_ASHRREV_I64_e64_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1__VSrc_b641_2, AMFBS_isGFX8Plus_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_VSrc_b64 }, },
  { 24646 /* v_ashrrev_i64 */, AMDGPU::V_ASHRREV_I64_e64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1__VSrc_b641_2, AMFBS_isGFX8Plus_isGFX12Not12_50, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_VSrc_b64 }, },
  { 24646 /* v_ashrrev_i64 */, AMDGPU::V_ASHRREV_I64_e64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1__VSrc_b641_2, AMFBS_isGFX8Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_VSrc_b64 }, },
  { 24646 /* v_ashrrev_i64 */, AMDGPU::V_ASHRREV_I64_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1__VSrc_b641_2, AMFBS_isGFX8Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_VSrc_b64 }, },
  { 24646 /* v_ashrrev_i64 */, AMDGPU::V_ASHRREV_I64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1__VSrc_b641_2, AMFBS_isGFX8Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_VSrc_b64 }, },
  { 24660 /* v_bcnt_u32_b32 */, AMDGPU::V_BCNT_U32_B32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24660 /* v_bcnt_u32_b32 */, AMDGPU::V_BCNT_U32_B32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24660 /* v_bcnt_u32_b32 */, AMDGPU::V_BCNT_U32_B32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24660 /* v_bcnt_u32_b32 */, AMDGPU::V_BCNT_U32_B32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24660 /* v_bcnt_u32_b32 */, AMDGPU::V_BCNT_U32_B32_e64_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24675 /* v_bfe_i32 */, AMDGPU::V_BFE_I32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24675 /* v_bfe_i32 */, AMDGPU::V_BFE_I32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24675 /* v_bfe_i32 */, AMDGPU::V_BFE_I32_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24675 /* v_bfe_i32 */, AMDGPU::V_BFE_I32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24675 /* v_bfe_i32 */, AMDGPU::V_BFE_I32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24685 /* v_bfe_u32 */, AMDGPU::V_BFE_U32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24685 /* v_bfe_u32 */, AMDGPU::V_BFE_U32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24685 /* v_bfe_u32 */, AMDGPU::V_BFE_U32_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24685 /* v_bfe_u32 */, AMDGPU::V_BFE_U32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24685 /* v_bfe_u32 */, AMDGPU::V_BFE_U32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24695 /* v_bfi_b32 */, AMDGPU::V_BFI_B32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24695 /* v_bfi_b32 */, AMDGPU::V_BFI_B32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24695 /* v_bfi_b32 */, AMDGPU::V_BFI_B32_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24695 /* v_bfi_b32 */, AMDGPU::V_BFI_B32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24695 /* v_bfi_b32 */, AMDGPU::V_BFI_B32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24705 /* v_bfm_b32 */, AMDGPU::V_BFM_B32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24705 /* v_bfm_b32 */, AMDGPU::V_BFM_B32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24705 /* v_bfm_b32 */, AMDGPU::V_BFM_B32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24705 /* v_bfm_b32 */, AMDGPU::V_BFM_B32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24705 /* v_bfm_b32 */, AMDGPU::V_BFM_B32_e64_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_e64_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 24727 /* v_bitop3_b16 */, AMDGPU::V_BITOP3_B16_gfx1250_fake16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_HasBitOp3Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_BitOp3, MCK_OpSel }, },
  { 24727 /* v_bitop3_b16 */, AMDGPU::V_BITOP3_B16_gfx9, ConvertCustom_cvtVOP3OpSel, AMFBS_HasBitOp3Insts_isGFX940Plus_isGFX9Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_BitOp3, MCK_OpSel }, },
  { 24727 /* v_bitop3_b16 */, AMDGPU::V_BITOP3_B16_gfx1250_t16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_HasBitOp3Insts_isGFX1250Plus_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_BitOp3, MCK_OpSel }, },
  { 24740 /* v_bitop3_b32 */, AMDGPU::V_BITOP3_B32_e64_gfx1250, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3__BitOp31_4, AMFBS_HasBitOp3Insts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_BitOp3 }, },
  { 24740 /* v_bitop3_b32 */, AMDGPU::V_BITOP3_B32_gfx9, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3__BitOp31_4, AMFBS_HasBitOp3Insts_isGFX9Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_BitOp3 }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24775 /* v_ceil_f64 */, AMDGPU::V_CEIL_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24775 /* v_ceil_f64 */, AMDGPU::V_CEIL_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24775 /* v_ceil_f64 */, AMDGPU::V_CEIL_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24775 /* v_ceil_f64 */, AMDGPU::V_CEIL_F64_e64_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24775 /* v_ceil_f64 */, AMDGPU::V_CEIL_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 24786 /* v_clrexcp */, AMDGPU::V_CLREXCP_e64_gfx10, Convert_NoOperands, AMFBS_isGFX10Only, {  }, },
  { 24786 /* v_clrexcp */, AMDGPU::V_CLREXCP_e64_gfx6_gfx7, Convert_NoOperands, AMFBS_isGFX6GFX7, {  }, },
  { 24786 /* v_clrexcp */, AMDGPU::V_CLREXCP_e64_vi, Convert_NoOperands, AMFBS_isGFX8GFX9, {  }, },
  { 24796 /* v_cls_i32 */, AMDGPU::V_CLS_I32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 24796 /* v_cls_i32 */, AMDGPU::V_CLS_I32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 24806 /* v_clz_i32_u32 */, AMDGPU::V_CLZ_I32_U32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 24806 /* v_clz_i32_u32 */, AMDGPU::V_CLZ_I32_U32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_VSrc_b32 }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_VSrc_b32 }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32 }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32 }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32 }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32 }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32 }, },
  { 24892 /* v_cmp_class_f64 */, AMDGPU::V_CMP_CLASS_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_VSrc_b32 }, },
  { 24892 /* v_cmp_class_f64 */, AMDGPU::V_CMP_CLASS_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_VSrc_b32 }, },
  { 24892 /* v_cmp_class_f64 */, AMDGPU::V_CMP_CLASS_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_VSrc_b32 }, },
  { 24892 /* v_cmp_class_f64 */, AMDGPU::V_CMP_CLASS_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_VSrc_b32 }, },
  { 24892 /* v_cmp_class_f64 */, AMDGPU::V_CMP_CLASS_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_VSrc_b32 }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 24988 /* v_cmp_eq_f64 */, AMDGPU::V_CMP_EQ_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 24988 /* v_cmp_eq_f64 */, AMDGPU::V_CMP_EQ_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 24988 /* v_cmp_eq_f64 */, AMDGPU::V_CMP_EQ_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 24988 /* v_cmp_eq_f64 */, AMDGPU::V_CMP_EQ_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 24988 /* v_cmp_eq_f64 */, AMDGPU::V_CMP_EQ_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_e64_gfx10, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e64_gfx11, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e64_gfx12, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_e64_gfx10, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_e64_gfx11, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_e64_gfx12, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25078 /* v_cmp_eq_i64 */, AMDGPU::V_CMP_EQ_I64_e64_gfx10, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25078 /* v_cmp_eq_i64 */, AMDGPU::V_CMP_EQ_I64_e64_gfx11, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25078 /* v_cmp_eq_i64 */, AMDGPU::V_CMP_EQ_I64_e64_gfx12, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25078 /* v_cmp_eq_i64 */, AMDGPU::V_CMP_EQ_I64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25078 /* v_cmp_eq_i64 */, AMDGPU::V_CMP_EQ_I64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_e64_gfx10, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e64_gfx11, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e64_gfx12, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_e64_gfx10, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_e64_gfx11, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_e64_gfx12, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25168 /* v_cmp_eq_u64 */, AMDGPU::V_CMP_EQ_U64_e64_gfx10, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25168 /* v_cmp_eq_u64 */, AMDGPU::V_CMP_EQ_U64_e64_gfx11, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25168 /* v_cmp_eq_u64 */, AMDGPU::V_CMP_EQ_U64_e64_gfx12, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25168 /* v_cmp_eq_u64 */, AMDGPU::V_CMP_EQ_U64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25168 /* v_cmp_eq_u64 */, AMDGPU::V_CMP_EQ_U64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 25226 /* v_cmp_f_f32 */, AMDGPU::V_CMP_F_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 25226 /* v_cmp_f_f32 */, AMDGPU::V_CMP_F_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 25226 /* v_cmp_f_f32 */, AMDGPU::V_CMP_F_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 25226 /* v_cmp_f_f32 */, AMDGPU::V_CMP_F_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 25254 /* v_cmp_f_f64 */, AMDGPU::V_CMP_F_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 25254 /* v_cmp_f_f64 */, AMDGPU::V_CMP_F_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 25254 /* v_cmp_f_f64 */, AMDGPU::V_CMP_F_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 25254 /* v_cmp_f_f64 */, AMDGPU::V_CMP_F_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 25282 /* v_cmp_f_i16 */, AMDGPU::V_CMP_F_I16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25310 /* v_cmp_f_i32 */, AMDGPU::V_CMP_F_I32_e64_gfx10, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25310 /* v_cmp_f_i32 */, AMDGPU::V_CMP_F_I32_e64_gfx11, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25310 /* v_cmp_f_i32 */, AMDGPU::V_CMP_F_I32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25310 /* v_cmp_f_i32 */, AMDGPU::V_CMP_F_I32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25338 /* v_cmp_f_i64 */, AMDGPU::V_CMP_F_I64_e64_gfx10, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25338 /* v_cmp_f_i64 */, AMDGPU::V_CMP_F_I64_e64_gfx11, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25338 /* v_cmp_f_i64 */, AMDGPU::V_CMP_F_I64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25338 /* v_cmp_f_i64 */, AMDGPU::V_CMP_F_I64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25366 /* v_cmp_f_u16 */, AMDGPU::V_CMP_F_U16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25394 /* v_cmp_f_u32 */, AMDGPU::V_CMP_F_U32_e64_gfx10, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25394 /* v_cmp_f_u32 */, AMDGPU::V_CMP_F_U32_e64_gfx11, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25394 /* v_cmp_f_u32 */, AMDGPU::V_CMP_F_U32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25394 /* v_cmp_f_u32 */, AMDGPU::V_CMP_F_U32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25422 /* v_cmp_f_u64 */, AMDGPU::V_CMP_F_U64_e64_gfx10, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25422 /* v_cmp_f_u64 */, AMDGPU::V_CMP_F_U64_e64_gfx11, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25422 /* v_cmp_f_u64 */, AMDGPU::V_CMP_F_U64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25422 /* v_cmp_f_u64 */, AMDGPU::V_CMP_F_U64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 25510 /* v_cmp_ge_f64 */, AMDGPU::V_CMP_GE_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 25510 /* v_cmp_ge_f64 */, AMDGPU::V_CMP_GE_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 25510 /* v_cmp_ge_f64 */, AMDGPU::V_CMP_GE_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 25510 /* v_cmp_ge_f64 */, AMDGPU::V_CMP_GE_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 25510 /* v_cmp_ge_f64 */, AMDGPU::V_CMP_GE_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_e64_gfx10, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e64_gfx11, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e64_gfx12, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_e64_gfx10, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_e64_gfx11, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_e64_gfx12, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25600 /* v_cmp_ge_i64 */, AMDGPU::V_CMP_GE_I64_e64_gfx10, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25600 /* v_cmp_ge_i64 */, AMDGPU::V_CMP_GE_I64_e64_gfx11, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25600 /* v_cmp_ge_i64 */, AMDGPU::V_CMP_GE_I64_e64_gfx12, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25600 /* v_cmp_ge_i64 */, AMDGPU::V_CMP_GE_I64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25600 /* v_cmp_ge_i64 */, AMDGPU::V_CMP_GE_I64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_e64_gfx10, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e64_gfx11, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e64_gfx12, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_e64_gfx10, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_e64_gfx11, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_e64_gfx12, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25690 /* v_cmp_ge_u64 */, AMDGPU::V_CMP_GE_U64_e64_gfx10, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25690 /* v_cmp_ge_u64 */, AMDGPU::V_CMP_GE_U64_e64_gfx11, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25690 /* v_cmp_ge_u64 */, AMDGPU::V_CMP_GE_U64_e64_gfx12, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25690 /* v_cmp_ge_u64 */, AMDGPU::V_CMP_GE_U64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25690 /* v_cmp_ge_u64 */, AMDGPU::V_CMP_GE_U64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 25780 /* v_cmp_gt_f64 */, AMDGPU::V_CMP_GT_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 25780 /* v_cmp_gt_f64 */, AMDGPU::V_CMP_GT_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 25780 /* v_cmp_gt_f64 */, AMDGPU::V_CMP_GT_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 25780 /* v_cmp_gt_f64 */, AMDGPU::V_CMP_GT_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 25780 /* v_cmp_gt_f64 */, AMDGPU::V_CMP_GT_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_e64_gfx10, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e64_gfx11, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e64_gfx12, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_e64_gfx10, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_e64_gfx11, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_e64_gfx12, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25870 /* v_cmp_gt_i64 */, AMDGPU::V_CMP_GT_I64_e64_gfx10, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25870 /* v_cmp_gt_i64 */, AMDGPU::V_CMP_GT_I64_e64_gfx11, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25870 /* v_cmp_gt_i64 */, AMDGPU::V_CMP_GT_I64_e64_gfx12, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25870 /* v_cmp_gt_i64 */, AMDGPU::V_CMP_GT_I64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25870 /* v_cmp_gt_i64 */, AMDGPU::V_CMP_GT_I64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_e64_gfx10, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e64_gfx11, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e64_gfx12, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_e64_gfx10, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_e64_gfx11, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_e64_gfx12, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 25960 /* v_cmp_gt_u64 */, AMDGPU::V_CMP_GT_U64_e64_gfx10, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25960 /* v_cmp_gt_u64 */, AMDGPU::V_CMP_GT_U64_e64_gfx11, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25960 /* v_cmp_gt_u64 */, AMDGPU::V_CMP_GT_U64_e64_gfx12, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25960 /* v_cmp_gt_u64 */, AMDGPU::V_CMP_GT_U64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25960 /* v_cmp_gt_u64 */, AMDGPU::V_CMP_GT_U64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26050 /* v_cmp_le_f64 */, AMDGPU::V_CMP_LE_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26050 /* v_cmp_le_f64 */, AMDGPU::V_CMP_LE_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26050 /* v_cmp_le_f64 */, AMDGPU::V_CMP_LE_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26050 /* v_cmp_le_f64 */, AMDGPU::V_CMP_LE_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26050 /* v_cmp_le_f64 */, AMDGPU::V_CMP_LE_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_e64_gfx10, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e64_gfx11, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e64_gfx12, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_e64_gfx10, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_e64_gfx11, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_e64_gfx12, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26140 /* v_cmp_le_i64 */, AMDGPU::V_CMP_LE_I64_e64_gfx10, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26140 /* v_cmp_le_i64 */, AMDGPU::V_CMP_LE_I64_e64_gfx11, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26140 /* v_cmp_le_i64 */, AMDGPU::V_CMP_LE_I64_e64_gfx12, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26140 /* v_cmp_le_i64 */, AMDGPU::V_CMP_LE_I64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26140 /* v_cmp_le_i64 */, AMDGPU::V_CMP_LE_I64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_e64_gfx10, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e64_gfx11, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e64_gfx12, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_e64_gfx10, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_e64_gfx11, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_e64_gfx12, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26230 /* v_cmp_le_u64 */, AMDGPU::V_CMP_LE_U64_e64_gfx10, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26230 /* v_cmp_le_u64 */, AMDGPU::V_CMP_LE_U64_e64_gfx11, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26230 /* v_cmp_le_u64 */, AMDGPU::V_CMP_LE_U64_e64_gfx12, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26230 /* v_cmp_le_u64 */, AMDGPU::V_CMP_LE_U64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26230 /* v_cmp_le_u64 */, AMDGPU::V_CMP_LE_U64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26320 /* v_cmp_lg_f64 */, AMDGPU::V_CMP_LG_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26320 /* v_cmp_lg_f64 */, AMDGPU::V_CMP_LG_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26320 /* v_cmp_lg_f64 */, AMDGPU::V_CMP_LG_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26320 /* v_cmp_lg_f64 */, AMDGPU::V_CMP_LG_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26320 /* v_cmp_lg_f64 */, AMDGPU::V_CMP_LG_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26410 /* v_cmp_lt_f64 */, AMDGPU::V_CMP_LT_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26410 /* v_cmp_lt_f64 */, AMDGPU::V_CMP_LT_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26410 /* v_cmp_lt_f64 */, AMDGPU::V_CMP_LT_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26410 /* v_cmp_lt_f64 */, AMDGPU::V_CMP_LT_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26410 /* v_cmp_lt_f64 */, AMDGPU::V_CMP_LT_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_e64_gfx10, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e64_gfx11, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e64_gfx12, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_e64_gfx10, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_e64_gfx11, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_e64_gfx12, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26500 /* v_cmp_lt_i64 */, AMDGPU::V_CMP_LT_I64_e64_gfx10, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26500 /* v_cmp_lt_i64 */, AMDGPU::V_CMP_LT_I64_e64_gfx11, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26500 /* v_cmp_lt_i64 */, AMDGPU::V_CMP_LT_I64_e64_gfx12, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26500 /* v_cmp_lt_i64 */, AMDGPU::V_CMP_LT_I64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26500 /* v_cmp_lt_i64 */, AMDGPU::V_CMP_LT_I64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_e64_gfx10, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e64_gfx11, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e64_gfx12, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_e64_gfx10, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_e64_gfx11, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_e64_gfx12, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26590 /* v_cmp_lt_u64 */, AMDGPU::V_CMP_LT_U64_e64_gfx10, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26590 /* v_cmp_lt_u64 */, AMDGPU::V_CMP_LT_U64_e64_gfx11, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26590 /* v_cmp_lt_u64 */, AMDGPU::V_CMP_LT_U64_e64_gfx12, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26590 /* v_cmp_lt_u64 */, AMDGPU::V_CMP_LT_U64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26590 /* v_cmp_lt_u64 */, AMDGPU::V_CMP_LT_U64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_e64_gfx10, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e64_gfx11, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e64_gfx12, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_e64_gfx10, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_e64_gfx11, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_e64_gfx12, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26680 /* v_cmp_ne_i64 */, AMDGPU::V_CMP_NE_I64_e64_gfx10, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26680 /* v_cmp_ne_i64 */, AMDGPU::V_CMP_NE_I64_e64_gfx11, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26680 /* v_cmp_ne_i64 */, AMDGPU::V_CMP_NE_I64_e64_gfx12, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26680 /* v_cmp_ne_i64 */, AMDGPU::V_CMP_NE_I64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26680 /* v_cmp_ne_i64 */, AMDGPU::V_CMP_NE_I64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_e64_gfx10, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e64_gfx11, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e64_gfx12, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_e64_gfx10, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_e64_gfx11, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_e64_gfx12, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 26770 /* v_cmp_ne_u64 */, AMDGPU::V_CMP_NE_U64_e64_gfx10, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26770 /* v_cmp_ne_u64 */, AMDGPU::V_CMP_NE_U64_e64_gfx11, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26770 /* v_cmp_ne_u64 */, AMDGPU::V_CMP_NE_U64_e64_gfx12, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26770 /* v_cmp_ne_u64 */, AMDGPU::V_CMP_NE_U64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26770 /* v_cmp_ne_u64 */, AMDGPU::V_CMP_NE_U64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26864 /* v_cmp_neq_f64 */, AMDGPU::V_CMP_NEQ_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26864 /* v_cmp_neq_f64 */, AMDGPU::V_CMP_NEQ_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26864 /* v_cmp_neq_f64 */, AMDGPU::V_CMP_NEQ_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26864 /* v_cmp_neq_f64 */, AMDGPU::V_CMP_NEQ_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26864 /* v_cmp_neq_f64 */, AMDGPU::V_CMP_NEQ_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 26960 /* v_cmp_nge_f64 */, AMDGPU::V_CMP_NGE_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26960 /* v_cmp_nge_f64 */, AMDGPU::V_CMP_NGE_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26960 /* v_cmp_nge_f64 */, AMDGPU::V_CMP_NGE_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26960 /* v_cmp_nge_f64 */, AMDGPU::V_CMP_NGE_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26960 /* v_cmp_nge_f64 */, AMDGPU::V_CMP_NGE_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27056 /* v_cmp_ngt_f64 */, AMDGPU::V_CMP_NGT_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27056 /* v_cmp_ngt_f64 */, AMDGPU::V_CMP_NGT_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27056 /* v_cmp_ngt_f64 */, AMDGPU::V_CMP_NGT_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27056 /* v_cmp_ngt_f64 */, AMDGPU::V_CMP_NGT_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27056 /* v_cmp_ngt_f64 */, AMDGPU::V_CMP_NGT_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27152 /* v_cmp_nle_f64 */, AMDGPU::V_CMP_NLE_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27152 /* v_cmp_nle_f64 */, AMDGPU::V_CMP_NLE_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27152 /* v_cmp_nle_f64 */, AMDGPU::V_CMP_NLE_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27152 /* v_cmp_nle_f64 */, AMDGPU::V_CMP_NLE_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27152 /* v_cmp_nle_f64 */, AMDGPU::V_CMP_NLE_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27248 /* v_cmp_nlg_f64 */, AMDGPU::V_CMP_NLG_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27248 /* v_cmp_nlg_f64 */, AMDGPU::V_CMP_NLG_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27248 /* v_cmp_nlg_f64 */, AMDGPU::V_CMP_NLG_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27248 /* v_cmp_nlg_f64 */, AMDGPU::V_CMP_NLG_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27248 /* v_cmp_nlg_f64 */, AMDGPU::V_CMP_NLG_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27344 /* v_cmp_nlt_f64 */, AMDGPU::V_CMP_NLT_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27344 /* v_cmp_nlt_f64 */, AMDGPU::V_CMP_NLT_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27344 /* v_cmp_nlt_f64 */, AMDGPU::V_CMP_NLT_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27344 /* v_cmp_nlt_f64 */, AMDGPU::V_CMP_NLT_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27344 /* v_cmp_nlt_f64 */, AMDGPU::V_CMP_NLT_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27432 /* v_cmp_o_f64 */, AMDGPU::V_CMP_O_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27432 /* v_cmp_o_f64 */, AMDGPU::V_CMP_O_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27432 /* v_cmp_o_f64 */, AMDGPU::V_CMP_O_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27432 /* v_cmp_o_f64 */, AMDGPU::V_CMP_O_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27432 /* v_cmp_o_f64 */, AMDGPU::V_CMP_O_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 27488 /* v_cmp_t_f32 */, AMDGPU::V_CMP_T_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27516 /* v_cmp_t_f64 */, AMDGPU::V_CMP_T_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27544 /* v_cmp_t_i16 */, AMDGPU::V_CMP_T_I16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 27572 /* v_cmp_t_i32 */, AMDGPU::V_CMP_T_I32_e64_gfx10, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 27572 /* v_cmp_t_i32 */, AMDGPU::V_CMP_T_I32_e64_gfx11, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 27572 /* v_cmp_t_i32 */, AMDGPU::V_CMP_T_I32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 27572 /* v_cmp_t_i32 */, AMDGPU::V_CMP_T_I32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 27600 /* v_cmp_t_i64 */, AMDGPU::V_CMP_T_I64_e64_gfx10, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 27600 /* v_cmp_t_i64 */, AMDGPU::V_CMP_T_I64_e64_gfx11, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 27600 /* v_cmp_t_i64 */, AMDGPU::V_CMP_T_I64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 27600 /* v_cmp_t_i64 */, AMDGPU::V_CMP_T_I64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 27628 /* v_cmp_t_u16 */, AMDGPU::V_CMP_T_U16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 27656 /* v_cmp_t_u32 */, AMDGPU::V_CMP_T_U32_e64_gfx10, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 27656 /* v_cmp_t_u32 */, AMDGPU::V_CMP_T_U32_e64_gfx11, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 27656 /* v_cmp_t_u32 */, AMDGPU::V_CMP_T_U32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 27656 /* v_cmp_t_u32 */, AMDGPU::V_CMP_T_U32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 27684 /* v_cmp_t_u64 */, AMDGPU::V_CMP_T_U64_e64_gfx10, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 27684 /* v_cmp_t_u64 */, AMDGPU::V_CMP_T_U64_e64_gfx11, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 27684 /* v_cmp_t_u64 */, AMDGPU::V_CMP_T_U64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 27684 /* v_cmp_t_u64 */, AMDGPU::V_CMP_T_U64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 27712 /* v_cmp_tru_f16 */, AMDGPU::V_CMP_TRU_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27712 /* v_cmp_tru_f16 */, AMDGPU::V_CMP_TRU_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27744 /* v_cmp_tru_f32 */, AMDGPU::V_CMP_TRU_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27744 /* v_cmp_tru_f32 */, AMDGPU::V_CMP_TRU_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27744 /* v_cmp_tru_f32 */, AMDGPU::V_CMP_TRU_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27776 /* v_cmp_tru_f64 */, AMDGPU::V_CMP_TRU_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27776 /* v_cmp_tru_f64 */, AMDGPU::V_CMP_TRU_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27776 /* v_cmp_tru_f64 */, AMDGPU::V_CMP_TRU_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27864 /* v_cmp_u_f64 */, AMDGPU::V_CMP_U_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27864 /* v_cmp_u_f64 */, AMDGPU::V_CMP_U_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27864 /* v_cmp_u_f64 */, AMDGPU::V_CMP_U_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27864 /* v_cmp_u_f64 */, AMDGPU::V_CMP_U_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27864 /* v_cmp_u_f64 */, AMDGPU::V_CMP_U_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27892 /* v_cmps_eq_f32 */, AMDGPU::V_CMPS_EQ_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27924 /* v_cmps_eq_f64 */, AMDGPU::V_CMPS_EQ_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 27956 /* v_cmps_f_f32 */, AMDGPU::V_CMPS_F_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 27986 /* v_cmps_f_f64 */, AMDGPU::V_CMPS_F_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 28016 /* v_cmps_ge_f32 */, AMDGPU::V_CMPS_GE_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 28048 /* v_cmps_ge_f64 */, AMDGPU::V_CMPS_GE_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 28080 /* v_cmps_gt_f32 */, AMDGPU::V_CMPS_GT_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 28112 /* v_cmps_gt_f64 */, AMDGPU::V_CMPS_GT_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 28144 /* v_cmps_le_f32 */, AMDGPU::V_CMPS_LE_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 28176 /* v_cmps_le_f64 */, AMDGPU::V_CMPS_LE_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 28208 /* v_cmps_lg_f32 */, AMDGPU::V_CMPS_LG_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 28240 /* v_cmps_lg_f64 */, AMDGPU::V_CMPS_LG_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 28272 /* v_cmps_lt_f32 */, AMDGPU::V_CMPS_LT_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 28304 /* v_cmps_lt_f64 */, AMDGPU::V_CMPS_LT_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 28336 /* v_cmps_neq_f32 */, AMDGPU::V_CMPS_NEQ_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 28370 /* v_cmps_neq_f64 */, AMDGPU::V_CMPS_NEQ_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 28404 /* v_cmps_nge_f32 */, AMDGPU::V_CMPS_NGE_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 28438 /* v_cmps_nge_f64 */, AMDGPU::V_CMPS_NGE_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 28472 /* v_cmps_ngt_f32 */, AMDGPU::V_CMPS_NGT_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 28506 /* v_cmps_ngt_f64 */, AMDGPU::V_CMPS_NGT_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 28540 /* v_cmps_nle_f32 */, AMDGPU::V_CMPS_NLE_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 28574 /* v_cmps_nle_f64 */, AMDGPU::V_CMPS_NLE_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 28608 /* v_cmps_nlg_f32 */, AMDGPU::V_CMPS_NLG_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 28642 /* v_cmps_nlg_f64 */, AMDGPU::V_CMPS_NLG_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 28676 /* v_cmps_nlt_f32 */, AMDGPU::V_CMPS_NLT_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 28710 /* v_cmps_nlt_f64 */, AMDGPU::V_CMPS_NLT_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 28744 /* v_cmps_o_f32 */, AMDGPU::V_CMPS_O_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 28774 /* v_cmps_o_f64 */, AMDGPU::V_CMPS_O_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 28804 /* v_cmps_tru_f32 */, AMDGPU::V_CMPS_TRU_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 28838 /* v_cmps_tru_f64 */, AMDGPU::V_CMPS_TRU_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 28872 /* v_cmps_u_f32 */, AMDGPU::V_CMPS_U_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 28902 /* v_cmps_u_f64 */, AMDGPU::V_CMPS_U_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 28932 /* v_cmpsx_eq_f32 */, AMDGPU::V_CMPSX_EQ_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 28966 /* v_cmpsx_eq_f64 */, AMDGPU::V_CMPSX_EQ_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 29000 /* v_cmpsx_f_f32 */, AMDGPU::V_CMPSX_F_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 29032 /* v_cmpsx_f_f64 */, AMDGPU::V_CMPSX_F_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 29064 /* v_cmpsx_ge_f32 */, AMDGPU::V_CMPSX_GE_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 29098 /* v_cmpsx_ge_f64 */, AMDGPU::V_CMPSX_GE_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 29132 /* v_cmpsx_gt_f32 */, AMDGPU::V_CMPSX_GT_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 29166 /* v_cmpsx_gt_f64 */, AMDGPU::V_CMPSX_GT_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 29200 /* v_cmpsx_le_f32 */, AMDGPU::V_CMPSX_LE_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 29234 /* v_cmpsx_le_f64 */, AMDGPU::V_CMPSX_LE_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 29268 /* v_cmpsx_lg_f32 */, AMDGPU::V_CMPSX_LG_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 29302 /* v_cmpsx_lg_f64 */, AMDGPU::V_CMPSX_LG_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 29336 /* v_cmpsx_lt_f32 */, AMDGPU::V_CMPSX_LT_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 29370 /* v_cmpsx_lt_f64 */, AMDGPU::V_CMPSX_LT_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 29404 /* v_cmpsx_neq_f32 */, AMDGPU::V_CMPSX_NEQ_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 29440 /* v_cmpsx_neq_f64 */, AMDGPU::V_CMPSX_NEQ_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 29476 /* v_cmpsx_nge_f32 */, AMDGPU::V_CMPSX_NGE_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 29512 /* v_cmpsx_nge_f64 */, AMDGPU::V_CMPSX_NGE_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 29548 /* v_cmpsx_ngt_f32 */, AMDGPU::V_CMPSX_NGT_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 29584 /* v_cmpsx_ngt_f64 */, AMDGPU::V_CMPSX_NGT_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 29620 /* v_cmpsx_nle_f32 */, AMDGPU::V_CMPSX_NLE_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 29656 /* v_cmpsx_nle_f64 */, AMDGPU::V_CMPSX_NLE_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 29692 /* v_cmpsx_nlg_f32 */, AMDGPU::V_CMPSX_NLG_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 29728 /* v_cmpsx_nlg_f64 */, AMDGPU::V_CMPSX_NLG_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 29764 /* v_cmpsx_nlt_f32 */, AMDGPU::V_CMPSX_NLT_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 29800 /* v_cmpsx_nlt_f64 */, AMDGPU::V_CMPSX_NLT_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 29836 /* v_cmpsx_o_f32 */, AMDGPU::V_CMPSX_O_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 29868 /* v_cmpsx_o_f64 */, AMDGPU::V_CMPSX_O_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 29900 /* v_cmpsx_tru_f32 */, AMDGPU::V_CMPSX_TRU_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 29936 /* v_cmpsx_tru_f64 */, AMDGPU::V_CMPSX_TRU_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 29972 /* v_cmpsx_u_f32 */, AMDGPU::V_CMPSX_U_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 30004 /* v_cmpsx_u_f64 */, AMDGPU::V_CMPSX_U_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_HasNoSdstCMPX_isGFX10Only_NotHasTrue16BitInsts, { MCK_RegOrImmWithFP16InputMods, MCK_VSrc_b32 }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_VSrc_b32 }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_HasNoSdstCMPX_isGFX11Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasNoSdstCMPX_isGFX12Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel }, },
  { 30074 /* v_cmpx_class_f32 */, AMDGPU::V_CMPX_CLASS_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32 }, },
  { 30074 /* v_cmpx_class_f32 */, AMDGPU::V_CMPX_CLASS_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32 }, },
  { 30074 /* v_cmpx_class_f32 */, AMDGPU::V_CMPX_CLASS_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32 }, },
  { 30074 /* v_cmpx_class_f32 */, AMDGPU::V_CMPX_CLASS_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32 }, },
  { 30074 /* v_cmpx_class_f32 */, AMDGPU::V_CMPX_CLASS_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32 }, },
  { 30112 /* v_cmpx_class_f64 */, AMDGPU::V_CMPX_CLASS_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP64InputMods, MCK_VSrc_b32 }, },
  { 30112 /* v_cmpx_class_f64 */, AMDGPU::V_CMPX_CLASS_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP64InputMods, MCK_VSrc_b32 }, },
  { 30112 /* v_cmpx_class_f64 */, AMDGPU::V_CMPX_CLASS_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP64InputMods, MCK_VSrc_b32 }, },
  { 30112 /* v_cmpx_class_f64 */, AMDGPU::V_CMPX_CLASS_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_VSrc_b32 }, },
  { 30112 /* v_cmpx_class_f64 */, AMDGPU::V_CMPX_CLASS_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_VSrc_b32 }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 30182 /* v_cmpx_eq_f32 */, AMDGPU::V_CMPX_EQ_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 30182 /* v_cmpx_eq_f32 */, AMDGPU::V_CMPX_EQ_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 30182 /* v_cmpx_eq_f32 */, AMDGPU::V_CMPX_EQ_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 30182 /* v_cmpx_eq_f32 */, AMDGPU::V_CMPX_EQ_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 30182 /* v_cmpx_eq_f32 */, AMDGPU::V_CMPX_EQ_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 30214 /* v_cmpx_eq_f64 */, AMDGPU::V_CMPX_EQ_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 30214 /* v_cmpx_eq_f64 */, AMDGPU::V_CMPX_EQ_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 30214 /* v_cmpx_eq_f64 */, AMDGPU::V_CMPX_EQ_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 30214 /* v_cmpx_eq_f64 */, AMDGPU::V_CMPX_EQ_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 30214 /* v_cmpx_eq_f64 */, AMDGPU::V_CMPX_EQ_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_e64_gfx10, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_fake16_e64_gfx11, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX11Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_fake16_e64_gfx12, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX12Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 30278 /* v_cmpx_eq_i32 */, AMDGPU::V_CMPX_EQ_I32_e64_gfx10, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30278 /* v_cmpx_eq_i32 */, AMDGPU::V_CMPX_EQ_I32_e64_gfx11, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30278 /* v_cmpx_eq_i32 */, AMDGPU::V_CMPX_EQ_I32_e64_gfx12, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30278 /* v_cmpx_eq_i32 */, AMDGPU::V_CMPX_EQ_I32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30278 /* v_cmpx_eq_i32 */, AMDGPU::V_CMPX_EQ_I32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30310 /* v_cmpx_eq_i64 */, AMDGPU::V_CMPX_EQ_I64_e64_gfx10, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30310 /* v_cmpx_eq_i64 */, AMDGPU::V_CMPX_EQ_I64_e64_gfx11, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30310 /* v_cmpx_eq_i64 */, AMDGPU::V_CMPX_EQ_I64_e64_gfx12, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30310 /* v_cmpx_eq_i64 */, AMDGPU::V_CMPX_EQ_I64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30310 /* v_cmpx_eq_i64 */, AMDGPU::V_CMPX_EQ_I64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_e64_gfx10, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_fake16_e64_gfx11, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX11Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_fake16_e64_gfx12, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX12Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 30374 /* v_cmpx_eq_u32 */, AMDGPU::V_CMPX_EQ_U32_e64_gfx10, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30374 /* v_cmpx_eq_u32 */, AMDGPU::V_CMPX_EQ_U32_e64_gfx11, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30374 /* v_cmpx_eq_u32 */, AMDGPU::V_CMPX_EQ_U32_e64_gfx12, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30374 /* v_cmpx_eq_u32 */, AMDGPU::V_CMPX_EQ_U32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30374 /* v_cmpx_eq_u32 */, AMDGPU::V_CMPX_EQ_U32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30406 /* v_cmpx_eq_u64 */, AMDGPU::V_CMPX_EQ_U64_e64_gfx10, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30406 /* v_cmpx_eq_u64 */, AMDGPU::V_CMPX_EQ_U64_e64_gfx11, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30406 /* v_cmpx_eq_u64 */, AMDGPU::V_CMPX_EQ_U64_e64_gfx12, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30406 /* v_cmpx_eq_u64 */, AMDGPU::V_CMPX_EQ_U64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30406 /* v_cmpx_eq_u64 */, AMDGPU::V_CMPX_EQ_U64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30438 /* v_cmpx_f_f16 */, AMDGPU::V_CMPX_F_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 30438 /* v_cmpx_f_f16 */, AMDGPU::V_CMPX_F_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 30438 /* v_cmpx_f_f16 */, AMDGPU::V_CMPX_F_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 30438 /* v_cmpx_f_f16 */, AMDGPU::V_CMPX_F_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 30468 /* v_cmpx_f_f32 */, AMDGPU::V_CMPX_F_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 30468 /* v_cmpx_f_f32 */, AMDGPU::V_CMPX_F_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 30468 /* v_cmpx_f_f32 */, AMDGPU::V_CMPX_F_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 30468 /* v_cmpx_f_f32 */, AMDGPU::V_CMPX_F_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 30498 /* v_cmpx_f_f64 */, AMDGPU::V_CMPX_F_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 30498 /* v_cmpx_f_f64 */, AMDGPU::V_CMPX_F_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 30498 /* v_cmpx_f_f64 */, AMDGPU::V_CMPX_F_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 30498 /* v_cmpx_f_f64 */, AMDGPU::V_CMPX_F_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 30528 /* v_cmpx_f_i16 */, AMDGPU::V_CMPX_F_I16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 30558 /* v_cmpx_f_i32 */, AMDGPU::V_CMPX_F_I32_e64_gfx10, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30558 /* v_cmpx_f_i32 */, AMDGPU::V_CMPX_F_I32_e64_gfx11, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30558 /* v_cmpx_f_i32 */, AMDGPU::V_CMPX_F_I32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30558 /* v_cmpx_f_i32 */, AMDGPU::V_CMPX_F_I32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30588 /* v_cmpx_f_i64 */, AMDGPU::V_CMPX_F_I64_e64_gfx10, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30588 /* v_cmpx_f_i64 */, AMDGPU::V_CMPX_F_I64_e64_gfx11, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30588 /* v_cmpx_f_i64 */, AMDGPU::V_CMPX_F_I64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30588 /* v_cmpx_f_i64 */, AMDGPU::V_CMPX_F_I64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30618 /* v_cmpx_f_u16 */, AMDGPU::V_CMPX_F_U16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 30648 /* v_cmpx_f_u32 */, AMDGPU::V_CMPX_F_U32_e64_gfx10, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30648 /* v_cmpx_f_u32 */, AMDGPU::V_CMPX_F_U32_e64_gfx11, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30648 /* v_cmpx_f_u32 */, AMDGPU::V_CMPX_F_U32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30648 /* v_cmpx_f_u32 */, AMDGPU::V_CMPX_F_U32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30678 /* v_cmpx_f_u64 */, AMDGPU::V_CMPX_F_U64_e64_gfx10, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30678 /* v_cmpx_f_u64 */, AMDGPU::V_CMPX_F_U64_e64_gfx11, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30678 /* v_cmpx_f_u64 */, AMDGPU::V_CMPX_F_U64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30678 /* v_cmpx_f_u64 */, AMDGPU::V_CMPX_F_U64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 30740 /* v_cmpx_ge_f32 */, AMDGPU::V_CMPX_GE_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 30740 /* v_cmpx_ge_f32 */, AMDGPU::V_CMPX_GE_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 30740 /* v_cmpx_ge_f32 */, AMDGPU::V_CMPX_GE_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 30740 /* v_cmpx_ge_f32 */, AMDGPU::V_CMPX_GE_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 30740 /* v_cmpx_ge_f32 */, AMDGPU::V_CMPX_GE_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 30772 /* v_cmpx_ge_f64 */, AMDGPU::V_CMPX_GE_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 30772 /* v_cmpx_ge_f64 */, AMDGPU::V_CMPX_GE_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 30772 /* v_cmpx_ge_f64 */, AMDGPU::V_CMPX_GE_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 30772 /* v_cmpx_ge_f64 */, AMDGPU::V_CMPX_GE_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 30772 /* v_cmpx_ge_f64 */, AMDGPU::V_CMPX_GE_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_e64_gfx10, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_fake16_e64_gfx11, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX11Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_fake16_e64_gfx12, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX12Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 30836 /* v_cmpx_ge_i32 */, AMDGPU::V_CMPX_GE_I32_e64_gfx10, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30836 /* v_cmpx_ge_i32 */, AMDGPU::V_CMPX_GE_I32_e64_gfx11, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30836 /* v_cmpx_ge_i32 */, AMDGPU::V_CMPX_GE_I32_e64_gfx12, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30836 /* v_cmpx_ge_i32 */, AMDGPU::V_CMPX_GE_I32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30836 /* v_cmpx_ge_i32 */, AMDGPU::V_CMPX_GE_I32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30868 /* v_cmpx_ge_i64 */, AMDGPU::V_CMPX_GE_I64_e64_gfx10, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30868 /* v_cmpx_ge_i64 */, AMDGPU::V_CMPX_GE_I64_e64_gfx11, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30868 /* v_cmpx_ge_i64 */, AMDGPU::V_CMPX_GE_I64_e64_gfx12, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30868 /* v_cmpx_ge_i64 */, AMDGPU::V_CMPX_GE_I64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30868 /* v_cmpx_ge_i64 */, AMDGPU::V_CMPX_GE_I64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_e64_gfx10, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_fake16_e64_gfx11, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX11Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_fake16_e64_gfx12, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX12Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 30932 /* v_cmpx_ge_u32 */, AMDGPU::V_CMPX_GE_U32_e64_gfx10, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30932 /* v_cmpx_ge_u32 */, AMDGPU::V_CMPX_GE_U32_e64_gfx11, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30932 /* v_cmpx_ge_u32 */, AMDGPU::V_CMPX_GE_U32_e64_gfx12, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30932 /* v_cmpx_ge_u32 */, AMDGPU::V_CMPX_GE_U32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30932 /* v_cmpx_ge_u32 */, AMDGPU::V_CMPX_GE_U32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 30964 /* v_cmpx_ge_u64 */, AMDGPU::V_CMPX_GE_U64_e64_gfx10, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30964 /* v_cmpx_ge_u64 */, AMDGPU::V_CMPX_GE_U64_e64_gfx11, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30964 /* v_cmpx_ge_u64 */, AMDGPU::V_CMPX_GE_U64_e64_gfx12, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30964 /* v_cmpx_ge_u64 */, AMDGPU::V_CMPX_GE_U64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30964 /* v_cmpx_ge_u64 */, AMDGPU::V_CMPX_GE_U64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 31028 /* v_cmpx_gt_f32 */, AMDGPU::V_CMPX_GT_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 31028 /* v_cmpx_gt_f32 */, AMDGPU::V_CMPX_GT_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 31028 /* v_cmpx_gt_f32 */, AMDGPU::V_CMPX_GT_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 31028 /* v_cmpx_gt_f32 */, AMDGPU::V_CMPX_GT_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 31028 /* v_cmpx_gt_f32 */, AMDGPU::V_CMPX_GT_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 31060 /* v_cmpx_gt_f64 */, AMDGPU::V_CMPX_GT_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 31060 /* v_cmpx_gt_f64 */, AMDGPU::V_CMPX_GT_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 31060 /* v_cmpx_gt_f64 */, AMDGPU::V_CMPX_GT_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 31060 /* v_cmpx_gt_f64 */, AMDGPU::V_CMPX_GT_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 31060 /* v_cmpx_gt_f64 */, AMDGPU::V_CMPX_GT_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_e64_gfx10, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_fake16_e64_gfx11, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX11Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_fake16_e64_gfx12, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX12Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 31124 /* v_cmpx_gt_i32 */, AMDGPU::V_CMPX_GT_I32_e64_gfx10, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31124 /* v_cmpx_gt_i32 */, AMDGPU::V_CMPX_GT_I32_e64_gfx11, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31124 /* v_cmpx_gt_i32 */, AMDGPU::V_CMPX_GT_I32_e64_gfx12, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31124 /* v_cmpx_gt_i32 */, AMDGPU::V_CMPX_GT_I32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31124 /* v_cmpx_gt_i32 */, AMDGPU::V_CMPX_GT_I32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31156 /* v_cmpx_gt_i64 */, AMDGPU::V_CMPX_GT_I64_e64_gfx10, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31156 /* v_cmpx_gt_i64 */, AMDGPU::V_CMPX_GT_I64_e64_gfx11, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31156 /* v_cmpx_gt_i64 */, AMDGPU::V_CMPX_GT_I64_e64_gfx12, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31156 /* v_cmpx_gt_i64 */, AMDGPU::V_CMPX_GT_I64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31156 /* v_cmpx_gt_i64 */, AMDGPU::V_CMPX_GT_I64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_e64_gfx10, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_fake16_e64_gfx11, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX11Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_fake16_e64_gfx12, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX12Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 31220 /* v_cmpx_gt_u32 */, AMDGPU::V_CMPX_GT_U32_e64_gfx10, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31220 /* v_cmpx_gt_u32 */, AMDGPU::V_CMPX_GT_U32_e64_gfx11, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31220 /* v_cmpx_gt_u32 */, AMDGPU::V_CMPX_GT_U32_e64_gfx12, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31220 /* v_cmpx_gt_u32 */, AMDGPU::V_CMPX_GT_U32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31220 /* v_cmpx_gt_u32 */, AMDGPU::V_CMPX_GT_U32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31252 /* v_cmpx_gt_u64 */, AMDGPU::V_CMPX_GT_U64_e64_gfx10, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31252 /* v_cmpx_gt_u64 */, AMDGPU::V_CMPX_GT_U64_e64_gfx11, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31252 /* v_cmpx_gt_u64 */, AMDGPU::V_CMPX_GT_U64_e64_gfx12, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31252 /* v_cmpx_gt_u64 */, AMDGPU::V_CMPX_GT_U64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31252 /* v_cmpx_gt_u64 */, AMDGPU::V_CMPX_GT_U64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 31316 /* v_cmpx_le_f32 */, AMDGPU::V_CMPX_LE_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 31316 /* v_cmpx_le_f32 */, AMDGPU::V_CMPX_LE_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 31316 /* v_cmpx_le_f32 */, AMDGPU::V_CMPX_LE_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 31316 /* v_cmpx_le_f32 */, AMDGPU::V_CMPX_LE_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 31316 /* v_cmpx_le_f32 */, AMDGPU::V_CMPX_LE_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 31348 /* v_cmpx_le_f64 */, AMDGPU::V_CMPX_LE_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 31348 /* v_cmpx_le_f64 */, AMDGPU::V_CMPX_LE_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 31348 /* v_cmpx_le_f64 */, AMDGPU::V_CMPX_LE_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 31348 /* v_cmpx_le_f64 */, AMDGPU::V_CMPX_LE_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 31348 /* v_cmpx_le_f64 */, AMDGPU::V_CMPX_LE_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_e64_gfx10, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_fake16_e64_gfx11, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX11Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_fake16_e64_gfx12, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX12Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 31412 /* v_cmpx_le_i32 */, AMDGPU::V_CMPX_LE_I32_e64_gfx10, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31412 /* v_cmpx_le_i32 */, AMDGPU::V_CMPX_LE_I32_e64_gfx11, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31412 /* v_cmpx_le_i32 */, AMDGPU::V_CMPX_LE_I32_e64_gfx12, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31412 /* v_cmpx_le_i32 */, AMDGPU::V_CMPX_LE_I32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31412 /* v_cmpx_le_i32 */, AMDGPU::V_CMPX_LE_I32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31444 /* v_cmpx_le_i64 */, AMDGPU::V_CMPX_LE_I64_e64_gfx10, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31444 /* v_cmpx_le_i64 */, AMDGPU::V_CMPX_LE_I64_e64_gfx11, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31444 /* v_cmpx_le_i64 */, AMDGPU::V_CMPX_LE_I64_e64_gfx12, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31444 /* v_cmpx_le_i64 */, AMDGPU::V_CMPX_LE_I64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31444 /* v_cmpx_le_i64 */, AMDGPU::V_CMPX_LE_I64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_e64_gfx10, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_fake16_e64_gfx11, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX11Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_fake16_e64_gfx12, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX12Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 31508 /* v_cmpx_le_u32 */, AMDGPU::V_CMPX_LE_U32_e64_gfx10, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31508 /* v_cmpx_le_u32 */, AMDGPU::V_CMPX_LE_U32_e64_gfx11, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31508 /* v_cmpx_le_u32 */, AMDGPU::V_CMPX_LE_U32_e64_gfx12, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31508 /* v_cmpx_le_u32 */, AMDGPU::V_CMPX_LE_U32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31508 /* v_cmpx_le_u32 */, AMDGPU::V_CMPX_LE_U32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31540 /* v_cmpx_le_u64 */, AMDGPU::V_CMPX_LE_U64_e64_gfx10, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31540 /* v_cmpx_le_u64 */, AMDGPU::V_CMPX_LE_U64_e64_gfx11, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31540 /* v_cmpx_le_u64 */, AMDGPU::V_CMPX_LE_U64_e64_gfx12, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31540 /* v_cmpx_le_u64 */, AMDGPU::V_CMPX_LE_U64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31540 /* v_cmpx_le_u64 */, AMDGPU::V_CMPX_LE_U64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 31604 /* v_cmpx_lg_f32 */, AMDGPU::V_CMPX_LG_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 31604 /* v_cmpx_lg_f32 */, AMDGPU::V_CMPX_LG_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 31604 /* v_cmpx_lg_f32 */, AMDGPU::V_CMPX_LG_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 31604 /* v_cmpx_lg_f32 */, AMDGPU::V_CMPX_LG_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 31604 /* v_cmpx_lg_f32 */, AMDGPU::V_CMPX_LG_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 31636 /* v_cmpx_lg_f64 */, AMDGPU::V_CMPX_LG_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 31636 /* v_cmpx_lg_f64 */, AMDGPU::V_CMPX_LG_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 31636 /* v_cmpx_lg_f64 */, AMDGPU::V_CMPX_LG_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 31636 /* v_cmpx_lg_f64 */, AMDGPU::V_CMPX_LG_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 31636 /* v_cmpx_lg_f64 */, AMDGPU::V_CMPX_LG_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 31700 /* v_cmpx_lt_f32 */, AMDGPU::V_CMPX_LT_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 31700 /* v_cmpx_lt_f32 */, AMDGPU::V_CMPX_LT_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 31700 /* v_cmpx_lt_f32 */, AMDGPU::V_CMPX_LT_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 31700 /* v_cmpx_lt_f32 */, AMDGPU::V_CMPX_LT_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 31700 /* v_cmpx_lt_f32 */, AMDGPU::V_CMPX_LT_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 31732 /* v_cmpx_lt_f64 */, AMDGPU::V_CMPX_LT_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 31732 /* v_cmpx_lt_f64 */, AMDGPU::V_CMPX_LT_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 31732 /* v_cmpx_lt_f64 */, AMDGPU::V_CMPX_LT_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 31732 /* v_cmpx_lt_f64 */, AMDGPU::V_CMPX_LT_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 31732 /* v_cmpx_lt_f64 */, AMDGPU::V_CMPX_LT_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_e64_gfx10, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_fake16_e64_gfx11, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX11Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_fake16_e64_gfx12, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX12Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 31796 /* v_cmpx_lt_i32 */, AMDGPU::V_CMPX_LT_I32_e64_gfx10, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31796 /* v_cmpx_lt_i32 */, AMDGPU::V_CMPX_LT_I32_e64_gfx11, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31796 /* v_cmpx_lt_i32 */, AMDGPU::V_CMPX_LT_I32_e64_gfx12, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31796 /* v_cmpx_lt_i32 */, AMDGPU::V_CMPX_LT_I32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31796 /* v_cmpx_lt_i32 */, AMDGPU::V_CMPX_LT_I32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31828 /* v_cmpx_lt_i64 */, AMDGPU::V_CMPX_LT_I64_e64_gfx10, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31828 /* v_cmpx_lt_i64 */, AMDGPU::V_CMPX_LT_I64_e64_gfx11, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31828 /* v_cmpx_lt_i64 */, AMDGPU::V_CMPX_LT_I64_e64_gfx12, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31828 /* v_cmpx_lt_i64 */, AMDGPU::V_CMPX_LT_I64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31828 /* v_cmpx_lt_i64 */, AMDGPU::V_CMPX_LT_I64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_e64_gfx10, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_fake16_e64_gfx11, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX11Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_fake16_e64_gfx12, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX12Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 31892 /* v_cmpx_lt_u32 */, AMDGPU::V_CMPX_LT_U32_e64_gfx10, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31892 /* v_cmpx_lt_u32 */, AMDGPU::V_CMPX_LT_U32_e64_gfx11, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31892 /* v_cmpx_lt_u32 */, AMDGPU::V_CMPX_LT_U32_e64_gfx12, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31892 /* v_cmpx_lt_u32 */, AMDGPU::V_CMPX_LT_U32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31892 /* v_cmpx_lt_u32 */, AMDGPU::V_CMPX_LT_U32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31924 /* v_cmpx_lt_u64 */, AMDGPU::V_CMPX_LT_U64_e64_gfx10, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31924 /* v_cmpx_lt_u64 */, AMDGPU::V_CMPX_LT_U64_e64_gfx11, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31924 /* v_cmpx_lt_u64 */, AMDGPU::V_CMPX_LT_U64_e64_gfx12, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31924 /* v_cmpx_lt_u64 */, AMDGPU::V_CMPX_LT_U64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31924 /* v_cmpx_lt_u64 */, AMDGPU::V_CMPX_LT_U64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_e64_gfx10, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_fake16_e64_gfx11, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX11Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_fake16_e64_gfx12, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX12Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 31988 /* v_cmpx_ne_i32 */, AMDGPU::V_CMPX_NE_I32_e64_gfx10, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31988 /* v_cmpx_ne_i32 */, AMDGPU::V_CMPX_NE_I32_e64_gfx11, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31988 /* v_cmpx_ne_i32 */, AMDGPU::V_CMPX_NE_I32_e64_gfx12, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31988 /* v_cmpx_ne_i32 */, AMDGPU::V_CMPX_NE_I32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 31988 /* v_cmpx_ne_i32 */, AMDGPU::V_CMPX_NE_I32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 32020 /* v_cmpx_ne_i64 */, AMDGPU::V_CMPX_NE_I64_e64_gfx10, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 32020 /* v_cmpx_ne_i64 */, AMDGPU::V_CMPX_NE_I64_e64_gfx11, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 32020 /* v_cmpx_ne_i64 */, AMDGPU::V_CMPX_NE_I64_e64_gfx12, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 32020 /* v_cmpx_ne_i64 */, AMDGPU::V_CMPX_NE_I64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 32020 /* v_cmpx_ne_i64 */, AMDGPU::V_CMPX_NE_I64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_e64_gfx10, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_fake16_e64_gfx11, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX11Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_fake16_e64_gfx12, Convert__VSrc_b161_0__VSrc_b161_1, AMFBS_Has16BitInsts_isGFX12Only, { MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 32084 /* v_cmpx_ne_u32 */, AMDGPU::V_CMPX_NE_U32_e64_gfx10, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 32084 /* v_cmpx_ne_u32 */, AMDGPU::V_CMPX_NE_U32_e64_gfx11, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 32084 /* v_cmpx_ne_u32 */, AMDGPU::V_CMPX_NE_U32_e64_gfx12, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 32084 /* v_cmpx_ne_u32 */, AMDGPU::V_CMPX_NE_U32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 32084 /* v_cmpx_ne_u32 */, AMDGPU::V_CMPX_NE_U32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 32116 /* v_cmpx_ne_u64 */, AMDGPU::V_CMPX_NE_U64_e64_gfx10, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 32116 /* v_cmpx_ne_u64 */, AMDGPU::V_CMPX_NE_U64_e64_gfx11, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 32116 /* v_cmpx_ne_u64 */, AMDGPU::V_CMPX_NE_U64_e64_gfx12, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 32116 /* v_cmpx_ne_u64 */, AMDGPU::V_CMPX_NE_U64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 32116 /* v_cmpx_ne_u64 */, AMDGPU::V_CMPX_NE_U64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 32182 /* v_cmpx_neq_f32 */, AMDGPU::V_CMPX_NEQ_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32182 /* v_cmpx_neq_f32 */, AMDGPU::V_CMPX_NEQ_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32182 /* v_cmpx_neq_f32 */, AMDGPU::V_CMPX_NEQ_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32182 /* v_cmpx_neq_f32 */, AMDGPU::V_CMPX_NEQ_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32182 /* v_cmpx_neq_f32 */, AMDGPU::V_CMPX_NEQ_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32216 /* v_cmpx_neq_f64 */, AMDGPU::V_CMPX_NEQ_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32216 /* v_cmpx_neq_f64 */, AMDGPU::V_CMPX_NEQ_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32216 /* v_cmpx_neq_f64 */, AMDGPU::V_CMPX_NEQ_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32216 /* v_cmpx_neq_f64 */, AMDGPU::V_CMPX_NEQ_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32216 /* v_cmpx_neq_f64 */, AMDGPU::V_CMPX_NEQ_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 32284 /* v_cmpx_nge_f32 */, AMDGPU::V_CMPX_NGE_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32284 /* v_cmpx_nge_f32 */, AMDGPU::V_CMPX_NGE_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32284 /* v_cmpx_nge_f32 */, AMDGPU::V_CMPX_NGE_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32284 /* v_cmpx_nge_f32 */, AMDGPU::V_CMPX_NGE_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32284 /* v_cmpx_nge_f32 */, AMDGPU::V_CMPX_NGE_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32318 /* v_cmpx_nge_f64 */, AMDGPU::V_CMPX_NGE_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32318 /* v_cmpx_nge_f64 */, AMDGPU::V_CMPX_NGE_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32318 /* v_cmpx_nge_f64 */, AMDGPU::V_CMPX_NGE_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32318 /* v_cmpx_nge_f64 */, AMDGPU::V_CMPX_NGE_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32318 /* v_cmpx_nge_f64 */, AMDGPU::V_CMPX_NGE_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 32386 /* v_cmpx_ngt_f32 */, AMDGPU::V_CMPX_NGT_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32386 /* v_cmpx_ngt_f32 */, AMDGPU::V_CMPX_NGT_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32386 /* v_cmpx_ngt_f32 */, AMDGPU::V_CMPX_NGT_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32386 /* v_cmpx_ngt_f32 */, AMDGPU::V_CMPX_NGT_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32386 /* v_cmpx_ngt_f32 */, AMDGPU::V_CMPX_NGT_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32420 /* v_cmpx_ngt_f64 */, AMDGPU::V_CMPX_NGT_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32420 /* v_cmpx_ngt_f64 */, AMDGPU::V_CMPX_NGT_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32420 /* v_cmpx_ngt_f64 */, AMDGPU::V_CMPX_NGT_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32420 /* v_cmpx_ngt_f64 */, AMDGPU::V_CMPX_NGT_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32420 /* v_cmpx_ngt_f64 */, AMDGPU::V_CMPX_NGT_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 32488 /* v_cmpx_nle_f32 */, AMDGPU::V_CMPX_NLE_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32488 /* v_cmpx_nle_f32 */, AMDGPU::V_CMPX_NLE_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32488 /* v_cmpx_nle_f32 */, AMDGPU::V_CMPX_NLE_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32488 /* v_cmpx_nle_f32 */, AMDGPU::V_CMPX_NLE_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32488 /* v_cmpx_nle_f32 */, AMDGPU::V_CMPX_NLE_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32522 /* v_cmpx_nle_f64 */, AMDGPU::V_CMPX_NLE_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32522 /* v_cmpx_nle_f64 */, AMDGPU::V_CMPX_NLE_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32522 /* v_cmpx_nle_f64 */, AMDGPU::V_CMPX_NLE_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32522 /* v_cmpx_nle_f64 */, AMDGPU::V_CMPX_NLE_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32522 /* v_cmpx_nle_f64 */, AMDGPU::V_CMPX_NLE_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 32590 /* v_cmpx_nlg_f32 */, AMDGPU::V_CMPX_NLG_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32590 /* v_cmpx_nlg_f32 */, AMDGPU::V_CMPX_NLG_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32590 /* v_cmpx_nlg_f32 */, AMDGPU::V_CMPX_NLG_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32590 /* v_cmpx_nlg_f32 */, AMDGPU::V_CMPX_NLG_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32590 /* v_cmpx_nlg_f32 */, AMDGPU::V_CMPX_NLG_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32624 /* v_cmpx_nlg_f64 */, AMDGPU::V_CMPX_NLG_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32624 /* v_cmpx_nlg_f64 */, AMDGPU::V_CMPX_NLG_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32624 /* v_cmpx_nlg_f64 */, AMDGPU::V_CMPX_NLG_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32624 /* v_cmpx_nlg_f64 */, AMDGPU::V_CMPX_NLG_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32624 /* v_cmpx_nlg_f64 */, AMDGPU::V_CMPX_NLG_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 32692 /* v_cmpx_nlt_f32 */, AMDGPU::V_CMPX_NLT_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32692 /* v_cmpx_nlt_f32 */, AMDGPU::V_CMPX_NLT_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32692 /* v_cmpx_nlt_f32 */, AMDGPU::V_CMPX_NLT_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32692 /* v_cmpx_nlt_f32 */, AMDGPU::V_CMPX_NLT_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32692 /* v_cmpx_nlt_f32 */, AMDGPU::V_CMPX_NLT_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32726 /* v_cmpx_nlt_f64 */, AMDGPU::V_CMPX_NLT_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32726 /* v_cmpx_nlt_f64 */, AMDGPU::V_CMPX_NLT_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32726 /* v_cmpx_nlt_f64 */, AMDGPU::V_CMPX_NLT_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32726 /* v_cmpx_nlt_f64 */, AMDGPU::V_CMPX_NLT_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32726 /* v_cmpx_nlt_f64 */, AMDGPU::V_CMPX_NLT_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 32790 /* v_cmpx_o_f32 */, AMDGPU::V_CMPX_O_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32790 /* v_cmpx_o_f32 */, AMDGPU::V_CMPX_O_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32790 /* v_cmpx_o_f32 */, AMDGPU::V_CMPX_O_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32790 /* v_cmpx_o_f32 */, AMDGPU::V_CMPX_O_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32790 /* v_cmpx_o_f32 */, AMDGPU::V_CMPX_O_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32820 /* v_cmpx_o_f64 */, AMDGPU::V_CMPX_O_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32820 /* v_cmpx_o_f64 */, AMDGPU::V_CMPX_O_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32820 /* v_cmpx_o_f64 */, AMDGPU::V_CMPX_O_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32820 /* v_cmpx_o_f64 */, AMDGPU::V_CMPX_O_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32820 /* v_cmpx_o_f64 */, AMDGPU::V_CMPX_O_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32850 /* v_cmpx_t_f16 */, AMDGPU::V_CMPX_T_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 32850 /* v_cmpx_t_f16 */, AMDGPU::V_CMPX_T_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 32880 /* v_cmpx_t_f32 */, AMDGPU::V_CMPX_T_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 32910 /* v_cmpx_t_f64 */, AMDGPU::V_CMPX_T_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 32940 /* v_cmpx_t_i16 */, AMDGPU::V_CMPX_T_I16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 32970 /* v_cmpx_t_i32 */, AMDGPU::V_CMPX_T_I32_e64_gfx10, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 32970 /* v_cmpx_t_i32 */, AMDGPU::V_CMPX_T_I32_e64_gfx11, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 32970 /* v_cmpx_t_i32 */, AMDGPU::V_CMPX_T_I32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 32970 /* v_cmpx_t_i32 */, AMDGPU::V_CMPX_T_I32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 33000 /* v_cmpx_t_i64 */, AMDGPU::V_CMPX_T_I64_e64_gfx10, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 33000 /* v_cmpx_t_i64 */, AMDGPU::V_CMPX_T_I64_e64_gfx11, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 33000 /* v_cmpx_t_i64 */, AMDGPU::V_CMPX_T_I64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 33000 /* v_cmpx_t_i64 */, AMDGPU::V_CMPX_T_I64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 33030 /* v_cmpx_t_u16 */, AMDGPU::V_CMPX_T_U16_e64_vi, Convert__BoolReg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 33060 /* v_cmpx_t_u32 */, AMDGPU::V_CMPX_T_U32_e64_gfx10, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 33060 /* v_cmpx_t_u32 */, AMDGPU::V_CMPX_T_U32_e64_gfx11, Convert__VSrc_b321_0__VSrc_b321_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 33060 /* v_cmpx_t_u32 */, AMDGPU::V_CMPX_T_U32_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 33060 /* v_cmpx_t_u32 */, AMDGPU::V_CMPX_T_U32_e64_vi, Convert__BoolReg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 33090 /* v_cmpx_t_u64 */, AMDGPU::V_CMPX_T_U64_e64_gfx10, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 33090 /* v_cmpx_t_u64 */, AMDGPU::V_CMPX_T_U64_e64_gfx11, Convert__VSrc_b641_0__VSrc_b641_1, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 33090 /* v_cmpx_t_u64 */, AMDGPU::V_CMPX_T_U64_e64_gfx6_gfx7, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 33090 /* v_cmpx_t_u64 */, AMDGPU::V_CMPX_T_U64_e64_vi, Convert__BoolReg1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 33120 /* v_cmpx_tru_f16 */, AMDGPU::V_CMPX_TRU_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 33120 /* v_cmpx_tru_f16 */, AMDGPU::V_CMPX_TRU_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 33154 /* v_cmpx_tru_f32 */, AMDGPU::V_CMPX_TRU_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 33154 /* v_cmpx_tru_f32 */, AMDGPU::V_CMPX_TRU_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 33154 /* v_cmpx_tru_f32 */, AMDGPU::V_CMPX_TRU_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 33188 /* v_cmpx_tru_f64 */, AMDGPU::V_CMPX_TRU_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 33188 /* v_cmpx_tru_f64 */, AMDGPU::V_CMPX_TRU_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 33188 /* v_cmpx_tru_f64 */, AMDGPU::V_CMPX_TRU_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX11Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX12Only, { MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_BoolReg, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX11Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX12Only_UseRealTrue16Insts, { MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 33252 /* v_cmpx_u_f32 */, AMDGPU::V_CMPX_U_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 33252 /* v_cmpx_u_f32 */, AMDGPU::V_CMPX_U_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 33252 /* v_cmpx_u_f32 */, AMDGPU::V_CMPX_U_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 33252 /* v_cmpx_u_f32 */, AMDGPU::V_CMPX_U_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 33252 /* v_cmpx_u_f32 */, AMDGPU::V_CMPX_U_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 33282 /* v_cmpx_u_f64 */, AMDGPU::V_CMPX_U_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 33282 /* v_cmpx_u_f64 */, AMDGPU::V_CMPX_U_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX11Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 33282 /* v_cmpx_u_f64 */, AMDGPU::V_CMPX_U_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasNoSdstCMPX_isGFX12Only, { MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 33282 /* v_cmpx_u_f64 */, AMDGPU::V_CMPX_U_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 33282 /* v_cmpx_u_f64 */, AMDGPU::V_CMPX_U_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp }, },
  { 33312 /* v_cndmask_b16 */, AMDGPU::V_CNDMASK_B16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_BoolReg }, },
  { 33312 /* v_cndmask_b16 */, AMDGPU::V_CNDMASK_B16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_BoolReg }, },
  { 33312 /* v_cndmask_b16 */, AMDGPU::V_CNDMASK_B16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX11Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_BoolReg }, },
  { 33312 /* v_cndmask_b16 */, AMDGPU::V_CNDMASK_B16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX11Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_BoolReg }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_BoolReg }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_BoolReg }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_BoolReg }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_BoolReg }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_BoolReg }, },
  { 33340 /* v_cos_bf16 */, AMDGPU::V_COS_BF16V_COS_BF16_fake16_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods }, },
  { 33340 /* v_cos_bf16 */, AMDGPU::V_COS_BF16V_COS_BF16_t16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33371 /* v_ctz_i32_b32 */, AMDGPU::V_CTZ_I32_B32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33371 /* v_ctz_i32_b32 */, AMDGPU::V_CTZ_I32_B32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 33385 /* v_cubeid_f32 */, AMDGPU::V_CUBEID_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasCubeInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33385 /* v_cubeid_f32 */, AMDGPU::V_CUBEID_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasCubeInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33385 /* v_cubeid_f32 */, AMDGPU::V_CUBEID_F32_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasCubeInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33385 /* v_cubeid_f32 */, AMDGPU::V_CUBEID_F32_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_HasCubeInsts_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33385 /* v_cubeid_f32 */, AMDGPU::V_CUBEID_F32_vi, ConvertCustom_cvtVOP3, AMFBS_HasCubeInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33398 /* v_cubema_f32 */, AMDGPU::V_CUBEMA_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasCubeInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33398 /* v_cubema_f32 */, AMDGPU::V_CUBEMA_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasCubeInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33398 /* v_cubema_f32 */, AMDGPU::V_CUBEMA_F32_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasCubeInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33398 /* v_cubema_f32 */, AMDGPU::V_CUBEMA_F32_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_HasCubeInsts_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33398 /* v_cubema_f32 */, AMDGPU::V_CUBEMA_F32_vi, ConvertCustom_cvtVOP3, AMFBS_HasCubeInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33411 /* v_cubesc_f32 */, AMDGPU::V_CUBESC_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasCubeInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33411 /* v_cubesc_f32 */, AMDGPU::V_CUBESC_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasCubeInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33411 /* v_cubesc_f32 */, AMDGPU::V_CUBESC_F32_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasCubeInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33411 /* v_cubesc_f32 */, AMDGPU::V_CUBESC_F32_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_HasCubeInsts_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33411 /* v_cubesc_f32 */, AMDGPU::V_CUBESC_F32_vi, ConvertCustom_cvtVOP3, AMFBS_HasCubeInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33424 /* v_cubetc_f32 */, AMDGPU::V_CUBETC_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasCubeInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33424 /* v_cubetc_f32 */, AMDGPU::V_CUBETC_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasCubeInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33424 /* v_cubetc_f32 */, AMDGPU::V_CUBETC_F32_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasCubeInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33424 /* v_cubetc_f32 */, AMDGPU::V_CUBETC_F32_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_HasCubeInsts_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33424 /* v_cubetc_f32 */, AMDGPU::V_CUBETC_F32_vi, ConvertCustom_cvtVOP3, AMFBS_HasCubeInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33437 /* v_cvt_f16_bf8 */, AMDGPU::V_CVT_F16_BF8V_CVT_F16_BF8_fake16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_b32, MCK_OpSel, MCK_ByteSel }, },
  { 33437 /* v_cvt_f16_bf8 */, AMDGPU::V_CVT_F16_BF8V_CVT_F16_BF8_t16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16, MCK_VSrc_b32, MCK_OpSel, MCK_ByteSel }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFP32InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFP32InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 33465 /* v_cvt_f16_fp8 */, AMDGPU::V_CVT_F16_FP8V_CVT_F16_FP8_fake16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_b32, MCK_OpSel, MCK_ByteSel }, },
  { 33465 /* v_cvt_f16_fp8 */, AMDGPU::V_CVT_F16_FP8V_CVT_F16_FP8_t16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16, MCK_VSrc_b32, MCK_OpSel, MCK_ByteSel }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_Clamp, MCK_OModSI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b16, MCK_Clamp, MCK_OModSI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_Clamp, MCK_OModSI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_Clamp, MCK_OModSI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_Clamp, MCK_OModSI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b16, MCK_Clamp, MCK_OModSI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_Clamp, MCK_OModSI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_Clamp, MCK_OModSI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 33507 /* v_cvt_f32_bf16 */, AMDGPU::V_CVT_F32_BF16_gfx1250V_CVT_F32_BF16_gfx1250_t16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_HasBF16ConversionInsts_isGFX1250Plus_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_32, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel }, },
  { 33507 /* v_cvt_f32_bf16 */, AMDGPU::V_CVT_F32_BF16_gfx1250V_CVT_F32_BF16_gfx1250_fake16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_HasBF16ConversionInsts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel }, },
  { 33507 /* v_cvt_f32_bf16 */, AMDGPU::V_CVT_F32_BF16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_HasBF16ConversionInsts_HasGFX950Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33522 /* v_cvt_f32_bf8 */, AMDGPU::V_CVT_F32_BF8_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__ByteSel1_2, AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_ByteSel }, },
  { 33522 /* v_cvt_f32_bf8 */, AMDGPU::V_CVT_F32_BF8_e64_vi, ConvertCustom_cvtVOP3, AMFBS_HasFP8ConversionInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 33550 /* v_cvt_f32_f64 */, AMDGPU::V_CVT_F32_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33550 /* v_cvt_f32_f64 */, AMDGPU::V_CVT_F32_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33550 /* v_cvt_f32_f64 */, AMDGPU::V_CVT_F32_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33550 /* v_cvt_f32_f64 */, AMDGPU::V_CVT_F32_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33550 /* v_cvt_f32_f64 */, AMDGPU::V_CVT_F32_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33564 /* v_cvt_f32_fp8 */, AMDGPU::V_CVT_F32_FP8_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__ByteSel1_2, AMFBS_HasFP8ConversionInsts_isGFX12PlusNot12_50_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_ByteSel }, },
  { 33564 /* v_cvt_f32_fp8 */, AMDGPU::V_CVT_F32_FP8_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__ByteSel1_2, AMFBS_HasFP8ConversionInsts_isGFX12PlusNot12_50_isGFX12Not12_50, { MCK_VGPR_32, MCK_VSrc_b32, MCK_ByteSel }, },
  { 33564 /* v_cvt_f32_fp8 */, AMDGPU::V_CVT_F32_FP8_e64_vi, ConvertCustom_cvtVOP3, AMFBS_HasFP8ConversionInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33564 /* v_cvt_f32_fp8 */, AMDGPU::V_CVT_F32_FP8_e64_gfx1250, Convert__Reg1_0__VSrc_b321_1__Clamp1_3__ByteSel1_2, AMFBS_HasFP8ConversionInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_b32, MCK_ByteSel, MCK_Clamp }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33674 /* v_cvt_f64_f32 */, AMDGPU::V_CVT_F64_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33674 /* v_cvt_f64_f32 */, AMDGPU::V_CVT_F64_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33674 /* v_cvt_f64_f32 */, AMDGPU::V_CVT_F64_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33674 /* v_cvt_f64_f32 */, AMDGPU::V_CVT_F64_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33674 /* v_cvt_f64_f32 */, AMDGPU::V_CVT_F64_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33688 /* v_cvt_f64_i32 */, AMDGPU::V_CVT_F64_I32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33688 /* v_cvt_f64_i32 */, AMDGPU::V_CVT_F64_I32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33688 /* v_cvt_f64_i32 */, AMDGPU::V_CVT_F64_I32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33688 /* v_cvt_f64_i32 */, AMDGPU::V_CVT_F64_I32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33688 /* v_cvt_f64_i32 */, AMDGPU::V_CVT_F64_I32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33702 /* v_cvt_f64_u32 */, AMDGPU::V_CVT_F64_U32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33702 /* v_cvt_f64_u32 */, AMDGPU::V_CVT_F64_U32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33702 /* v_cvt_f64_u32 */, AMDGPU::V_CVT_F64_U32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33702 /* v_cvt_f64_u32 */, AMDGPU::V_CVT_F64_U32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33702 /* v_cvt_f64_u32 */, AMDGPU::V_CVT_F64_U32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33716 /* v_cvt_floor_i32_f32 */, AMDGPU::V_CVT_FLOOR_I32_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 33716 /* v_cvt_floor_i32_f32 */, AMDGPU::V_CVT_FLOOR_I32_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 33736 /* v_cvt_flr_i32_f32 */, AMDGPU::V_CVT_FLR_I32_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 33736 /* v_cvt_flr_i32_f32 */, AMDGPU::V_CVT_FLR_I32_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 33736 /* v_cvt_flr_i32_f32 */, AMDGPU::V_CVT_FLR_I32_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33782 /* v_cvt_i32_f64 */, AMDGPU::V_CVT_I32_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33782 /* v_cvt_i32_f64 */, AMDGPU::V_CVT_I32_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33782 /* v_cvt_i32_f64 */, AMDGPU::V_CVT_I32_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33782 /* v_cvt_i32_f64 */, AMDGPU::V_CVT_I32_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33782 /* v_cvt_i32_f64 */, AMDGPU::V_CVT_I32_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_fake16_e64_gfx11, Convert__Reg1_0__VSrc_b161_1, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16 }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_fake16_e64_gfx12, Convert__Reg1_0__VSrc_b161_1, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16 }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrcT_b16, MCK_OpSel }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrcT_b16, MCK_OpSel }, },
  { 33810 /* v_cvt_nearest_i32_f32 */, AMDGPU::V_CVT_NEAREST_I32_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 33810 /* v_cvt_nearest_i32_f32 */, AMDGPU::V_CVT_NEAREST_I32_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasCvtNormInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasCvtNormInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasCvtNormInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasCvtNormInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 33887 /* v_cvt_pk_bf16_f32 */, AMDGPU::V_CVT_PK_BF16_F32_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_HasBF16ConversionInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33887 /* v_cvt_pk_bf16_f32 */, AMDGPU::V_CVT_PK_BF16_F32_vi, ConvertCustom_cvtVOP3, AMFBS_HasBF16ConversionInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33905 /* v_cvt_pk_bf8_f16 */, AMDGPU::V_CVT_PK_BF8_F16_gfx1250_fake16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel, MCK_Clamp }, },
  { 33905 /* v_cvt_pk_bf8_f16 */, AMDGPU::V_CVT_PK_BF8_F16_gfx1250_t16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFP32InputMods, MCK_OpSel, MCK_Clamp }, },
  { 33922 /* v_cvt_pk_bf8_f32 */, AMDGPU::V_CVT_PK_BF8_F32_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionInsts_isGFX9Plus_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 33922 /* v_cvt_pk_bf8_f32 */, AMDGPU::V_CVT_PK_BF8_F32_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionInsts_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 33922 /* v_cvt_pk_bf8_f32 */, AMDGPU::V_CVT_PK_BF8_F32_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionInsts_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 33922 /* v_cvt_pk_bf8_f32 */, AMDGPU::V_CVT_PK_BF8_F32_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionInsts_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 33922 /* v_cvt_pk_bf8_f32 */, AMDGPU::V_CVT_PK_BF8_F32_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionInsts_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 33939 /* v_cvt_pk_f16_bf8 */, AMDGPU::V_CVT_PK_F16_BF8V_CVT_PK_F16_BF8_fake16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_b16, MCK_OpSel }, },
  { 33939 /* v_cvt_pk_f16_bf8 */, AMDGPU::V_CVT_PK_F16_BF8V_CVT_PK_F16_BF8_t16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrcT_b16, MCK_OpSel }, },
  { 33956 /* v_cvt_pk_f16_f32 */, AMDGPU::V_CVT_PK_F16_F32_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_HasCvtPkF16F32Inst_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33956 /* v_cvt_pk_f16_f32 */, AMDGPU::V_CVT_PK_F16_F32_gfx9, ConvertCustom_cvtVOP3, AMFBS_HasCvtPkF16F32Inst_isGFX9Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 33973 /* v_cvt_pk_f16_fp8 */, AMDGPU::V_CVT_PK_F16_FP8V_CVT_PK_F16_FP8_fake16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_b16, MCK_OpSel }, },
  { 33973 /* v_cvt_pk_f16_fp8 */, AMDGPU::V_CVT_PK_F16_FP8V_CVT_PK_F16_FP8_t16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrcT_b16, MCK_OpSel }, },
  { 33990 /* v_cvt_pk_f32_bf8 */, AMDGPU::V_CVT_PK_F32_BF8_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX12Only_UseRealTrue16Insts, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithIntT16InputMods, MCK_OpSel }, },
  { 33990 /* v_cvt_pk_f32_bf8 */, AMDGPU::V_CVT_PK_F32_BF8_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithIntFake16InputMods, MCK_OpSel }, },
  { 33990 /* v_cvt_pk_f32_bf8 */, AMDGPU::V_CVT_PK_F32_BF8_e64_vi, ConvertCustom_cvtVOP3, AMFBS_HasFP8ConversionInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 34007 /* v_cvt_pk_f32_fp8 */, AMDGPU::V_CVT_PK_F32_FP8_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX12Only_UseRealTrue16Insts, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithIntT16InputMods, MCK_OpSel }, },
  { 34007 /* v_cvt_pk_f32_fp8 */, AMDGPU::V_CVT_PK_F32_FP8_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithIntFake16InputMods, MCK_OpSel }, },
  { 34007 /* v_cvt_pk_f32_fp8 */, AMDGPU::V_CVT_PK_F32_FP8_e64_vi, ConvertCustom_cvtVOP3, AMFBS_HasFP8ConversionInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 34024 /* v_cvt_pk_fp8_f16 */, AMDGPU::V_CVT_PK_FP8_F16_gfx1250_fake16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel, MCK_Clamp }, },
  { 34024 /* v_cvt_pk_fp8_f16 */, AMDGPU::V_CVT_PK_FP8_F16_gfx1250_t16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFP32InputMods, MCK_OpSel, MCK_Clamp }, },
  { 34041 /* v_cvt_pk_fp8_f32 */, AMDGPU::V_CVT_PK_FP8_F32_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX9Plus_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 34041 /* v_cvt_pk_fp8_f32 */, AMDGPU::V_CVT_PK_FP8_F32_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 34041 /* v_cvt_pk_fp8_f32 */, AMDGPU::V_CVT_PK_FP8_F32_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX9Plus_isGFX12Not12_50, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 34041 /* v_cvt_pk_fp8_f32 */, AMDGPU::V_CVT_PK_FP8_F32_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 34041 /* v_cvt_pk_fp8_f32 */, AMDGPU::V_CVT_PK_FP8_F32_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX9Plus_isGFX12Not12_50_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 34041 /* v_cvt_pk_fp8_f32 */, AMDGPU::V_CVT_PK_FP8_F32_gfx1250_fake16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionInsts_HasFP8E5M3Insts_isGFX9Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_OpSel, MCK_Clamp }, },
  { 34041 /* v_cvt_pk_fp8_f32 */, AMDGPU::V_CVT_PK_FP8_F32_gfx1250_t16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionInsts_HasFP8E5M3Insts_isGFX9Plus_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_OpSel, MCK_Clamp }, },
  { 34058 /* v_cvt_pk_i16_f32 */, AMDGPU::V_CVT_PK_I16_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 34058 /* v_cvt_pk_i16_f32 */, AMDGPU::V_CVT_PK_I16_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 34075 /* v_cvt_pk_i16_i32 */, AMDGPU::V_CVT_PK_I16_I32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 34075 /* v_cvt_pk_i16_i32 */, AMDGPU::V_CVT_PK_I16_I32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 34075 /* v_cvt_pk_i16_i32 */, AMDGPU::V_CVT_PK_I16_I32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 34075 /* v_cvt_pk_i16_i32 */, AMDGPU::V_CVT_PK_I16_I32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 34075 /* v_cvt_pk_i16_i32 */, AMDGPU::V_CVT_PK_I16_I32_e64_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 34092 /* v_cvt_pk_norm_i16_f16 */, AMDGPU::V_CVT_PK_NORM_I16_F16V_CVT_PKNORM_I16_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_HasCvtPkNormVOP3Insts_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 34092 /* v_cvt_pk_norm_i16_f16 */, AMDGPU::V_CVT_PK_NORM_I16_F16V_CVT_PKNORM_I16_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasCvtPkNormVOP3Insts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 34092 /* v_cvt_pk_norm_i16_f16 */, AMDGPU::V_CVT_PK_NORM_I16_F16V_CVT_PKNORM_I16_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_HasCvtPkNormVOP3Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 34092 /* v_cvt_pk_norm_i16_f16 */, AMDGPU::V_CVT_PK_NORM_I16_F16V_CVT_PKNORM_I16_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasCvtPkNormVOP3Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 34114 /* v_cvt_pk_norm_i16_f32 */, AMDGPU::V_CVT_PK_NORM_I16_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasCvtPkNormVOP2Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 34114 /* v_cvt_pk_norm_i16_f32 */, AMDGPU::V_CVT_PK_NORM_I16_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasCvtPkNormVOP2Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 34136 /* v_cvt_pk_norm_u16_f16 */, AMDGPU::V_CVT_PK_NORM_U16_F16V_CVT_PKNORM_U16_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_HasCvtPkNormVOP3Insts_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 34136 /* v_cvt_pk_norm_u16_f16 */, AMDGPU::V_CVT_PK_NORM_U16_F16V_CVT_PKNORM_U16_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasCvtPkNormVOP3Insts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 34136 /* v_cvt_pk_norm_u16_f16 */, AMDGPU::V_CVT_PK_NORM_U16_F16V_CVT_PKNORM_U16_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_HasCvtPkNormVOP3Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 34136 /* v_cvt_pk_norm_u16_f16 */, AMDGPU::V_CVT_PK_NORM_U16_F16V_CVT_PKNORM_U16_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasCvtPkNormVOP3Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 34158 /* v_cvt_pk_norm_u16_f32 */, AMDGPU::V_CVT_PK_NORM_U16_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasCvtPkNormVOP2Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 34158 /* v_cvt_pk_norm_u16_f32 */, AMDGPU::V_CVT_PK_NORM_U16_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasCvtPkNormVOP2Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 34180 /* v_cvt_pk_rtz_f16_f32 */, AMDGPU::V_CVT_PK_RTZ_F16_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 34180 /* v_cvt_pk_rtz_f16_f32 */, AMDGPU::V_CVT_PK_RTZ_F16_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 34201 /* v_cvt_pk_u16_f32 */, AMDGPU::V_CVT_PK_U16_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 34201 /* v_cvt_pk_u16_f32 */, AMDGPU::V_CVT_PK_U16_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 34218 /* v_cvt_pk_u16_u32 */, AMDGPU::V_CVT_PK_U16_U32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 34218 /* v_cvt_pk_u16_u32 */, AMDGPU::V_CVT_PK_U16_U32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 34218 /* v_cvt_pk_u16_u32 */, AMDGPU::V_CVT_PK_U16_U32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 34218 /* v_cvt_pk_u16_u32 */, AMDGPU::V_CVT_PK_U16_U32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 34218 /* v_cvt_pk_u16_u32 */, AMDGPU::V_CVT_PK_U16_U32_e64_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 34235 /* v_cvt_pk_u8_f32 */, AMDGPU::V_CVT_PK_U8_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 34235 /* v_cvt_pk_u8_f32 */, AMDGPU::V_CVT_PK_U8_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 34235 /* v_cvt_pk_u8_f32 */, AMDGPU::V_CVT_PK_U8_F32_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 34235 /* v_cvt_pk_u8_f32 */, AMDGPU::V_CVT_PK_U8_F32_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 34235 /* v_cvt_pk_u8_f32 */, AMDGPU::V_CVT_PK_U8_F32_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 34251 /* v_cvt_pkaccum_u8_f32 */, AMDGPU::V_CVT_PKACCUM_U8_F32_e64_vi, Convert__Reg1_0__imm_95_0__VCSrc_f321_1__imm_95_0__VCSrc_f321_2__imm_95_0, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VCSrc_f32, MCK_VCSrc_f32 }, },
  { 34251 /* v_cvt_pkaccum_u8_f32 */, AMDGPU::V_CVT_PKACCUM_U8_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_Clamp }, },
  { 34251 /* v_cvt_pkaccum_u8_f32 */, AMDGPU::V_CVT_PKACCUM_U8_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_Clamp }, },
  { 34272 /* v_cvt_pknorm_i16_f16 */, AMDGPU::V_CVT_PKNORM_I16_F16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_HasCvtPkNormVOP3Insts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 34272 /* v_cvt_pknorm_i16_f16 */, AMDGPU::V_CVT_PKNORM_I16_F16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasCvtPkNormVOP3Insts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 34293 /* v_cvt_pknorm_i16_f32 */, AMDGPU::V_CVT_PKNORM_I16_F32_e64_vi, Convert__Reg1_0__imm_95_0__VCSrc_f321_1__imm_95_0__VCSrc_f321_2__imm_95_0, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VCSrc_f32, MCK_VCSrc_f32 }, },
  { 34293 /* v_cvt_pknorm_i16_f32 */, AMDGPU::V_CVT_PKNORM_I16_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasCvtPkNormVOP2Insts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 34293 /* v_cvt_pknorm_i16_f32 */, AMDGPU::V_CVT_PKNORM_I16_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_HasCvtPkNormVOP2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 34293 /* v_cvt_pknorm_i16_f32 */, AMDGPU::V_CVT_PKNORM_I16_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_HasCvtPkNormVOP2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 34314 /* v_cvt_pknorm_u16_f16 */, AMDGPU::V_CVT_PKNORM_U16_F16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_HasCvtPkNormVOP3Insts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 34314 /* v_cvt_pknorm_u16_f16 */, AMDGPU::V_CVT_PKNORM_U16_F16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasCvtPkNormVOP3Insts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 34335 /* v_cvt_pknorm_u16_f32 */, AMDGPU::V_CVT_PKNORM_U16_F32_e64_vi, Convert__Reg1_0__imm_95_0__VCSrc_f321_1__imm_95_0__VCSrc_f321_2__imm_95_0, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VCSrc_f32, MCK_VCSrc_f32 }, },
  { 34335 /* v_cvt_pknorm_u16_f32 */, AMDGPU::V_CVT_PKNORM_U16_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasCvtPkNormVOP2Insts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 34335 /* v_cvt_pknorm_u16_f32 */, AMDGPU::V_CVT_PKNORM_U16_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_HasCvtPkNormVOP2Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 34335 /* v_cvt_pknorm_u16_f32 */, AMDGPU::V_CVT_PKNORM_U16_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_HasCvtPkNormVOP2Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 34356 /* v_cvt_pkrtz_f16_f32 */, AMDGPU::V_CVT_PKRTZ_F16_F32_e64_vi, Convert__Reg1_0__imm_95_0__VCSrc_f321_1__imm_95_0__VCSrc_f321_2__imm_95_0__imm_95_0, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VCSrc_f32, MCK_VCSrc_f32 }, },
  { 34356 /* v_cvt_pkrtz_f16_f32 */, AMDGPU::V_CVT_PKRTZ_F16_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 34356 /* v_cvt_pkrtz_f16_f32 */, AMDGPU::V_CVT_PKRTZ_F16_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 34356 /* v_cvt_pkrtz_f16_f32 */, AMDGPU::V_CVT_PKRTZ_F16_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 34376 /* v_cvt_rpi_i32_f32 */, AMDGPU::V_CVT_RPI_I32_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 34376 /* v_cvt_rpi_i32_f32 */, AMDGPU::V_CVT_RPI_I32_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 34376 /* v_cvt_rpi_i32_f32 */, AMDGPU::V_CVT_RPI_I32_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 34394 /* v_cvt_scale_pk16_bf16_bf6 */, AMDGPU::V_CVT_SCALE_PK16_BF16_BF6_e64_gfx1250, Convert__RegByHwMode_VReg_256_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__VSrc_b321_2__ScaleSel1_3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_VSrc_b32, MCK_ScaleSel }, },
  { 34420 /* v_cvt_scale_pk16_bf16_fp6 */, AMDGPU::V_CVT_SCALE_PK16_BF16_FP6_e64_gfx1250, Convert__RegByHwMode_VReg_256_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__VSrc_b321_2__ScaleSel1_3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_VSrc_b32, MCK_ScaleSel }, },
  { 34446 /* v_cvt_scale_pk16_f16_bf6 */, AMDGPU::V_CVT_SCALE_PK16_F16_BF6_e64_gfx1250, Convert__RegByHwMode_VReg_256_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__VSrc_b321_2__ScaleSel1_3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_VSrc_b32, MCK_ScaleSel }, },
  { 34471 /* v_cvt_scale_pk16_f16_fp6 */, AMDGPU::V_CVT_SCALE_PK16_F16_FP6_e64_gfx1250, Convert__RegByHwMode_VReg_256_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__VSrc_b321_2__ScaleSel1_3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_VSrc_b32, MCK_ScaleSel }, },
  { 34496 /* v_cvt_scale_pk16_f32_bf6 */, AMDGPU::V_CVT_SCALE_PK16_F32_BF6_e64_gfx1250, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__VSrc_b321_2__ScaleSel1_3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_VSrc_b32, MCK_ScaleSel }, },
  { 34521 /* v_cvt_scale_pk16_f32_fp6 */, AMDGPU::V_CVT_SCALE_PK16_F32_FP6_e64_gfx1250, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_VReg_96_AlignTarget1_1__VSrc_b321_2__ScaleSel1_3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_96_AlignTarget, MCK_VSrc_b32, MCK_ScaleSel }, },
  { 34546 /* v_cvt_scale_pk8_bf16_bf8 */, AMDGPU::V_CVT_SCALE_PK8_BF16_BF8_e64_gfx1250, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__VSrc_b321_2__ScaleSel1_3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_ScaleSel }, },
  { 34571 /* v_cvt_scale_pk8_bf16_fp4 */, AMDGPU::V_CVT_SCALE_PK8_BF16_FP4_e64_gfx1250, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__VSrc_b321_2__ScaleSel1_3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_VSrc_b32, MCK_ScaleSel }, },
  { 34596 /* v_cvt_scale_pk8_bf16_fp8 */, AMDGPU::V_CVT_SCALE_PK8_BF16_FP8_e64_gfx1250, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__VSrc_b321_2__ScaleSel1_3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_ScaleSel }, },
  { 34621 /* v_cvt_scale_pk8_f16_bf8 */, AMDGPU::V_CVT_SCALE_PK8_F16_BF8_e64_gfx1250, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__VSrc_b321_2__ScaleSel1_3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_ScaleSel }, },
  { 34645 /* v_cvt_scale_pk8_f16_fp4 */, AMDGPU::V_CVT_SCALE_PK8_F16_FP4_e64_gfx1250, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__VSrc_b321_2__ScaleSel1_3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_VSrc_b32, MCK_ScaleSel }, },
  { 34669 /* v_cvt_scale_pk8_f16_fp8 */, AMDGPU::V_CVT_SCALE_PK8_F16_FP8_e64_gfx1250, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__VSrc_b321_2__ScaleSel1_3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_ScaleSel }, },
  { 34693 /* v_cvt_scale_pk8_f32_bf8 */, AMDGPU::V_CVT_SCALE_PK8_F32_BF8_e64_gfx1250, Convert__RegByHwMode_VReg_256_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__VSrc_b321_2__ScaleSel1_3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_ScaleSel }, },
  { 34717 /* v_cvt_scale_pk8_f32_fp4 */, AMDGPU::V_CVT_SCALE_PK8_F32_FP4_e64_gfx1250, Convert__RegByHwMode_VReg_256_AlignTarget1_0__Reg1_1__VSrc_b321_2__ScaleSel1_3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VGPR_32, MCK_VSrc_b32, MCK_ScaleSel }, },
  { 34741 /* v_cvt_scale_pk8_f32_fp8 */, AMDGPU::V_CVT_SCALE_PK8_F32_FP8_e64_gfx1250, Convert__RegByHwMode_VReg_256_AlignTarget1_0__RegByHwMode_VReg_64_AlignTarget1_1__VSrc_b321_2__ScaleSel1_3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_ScaleSel }, },
  { 34765 /* v_cvt_scalef32_2xpk16_bf6_f32 */, AMDGPU::V_CVT_SCALEF32_2XPK16_BF6_F32_gfx9, Convert__RegByHwMode_VReg_192_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__RegByHwMode_VReg_512_AlignTarget1_2__VSrc_f321_3, AMFBS_HasGFX950Insts_isGFX9Only, { MCK_RegByHwMode_VReg_192_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VSrc_f32 }, },
  { 34795 /* v_cvt_scalef32_2xpk16_fp6_f32 */, AMDGPU::V_CVT_SCALEF32_2XPK16_FP6_F32_gfx9, Convert__RegByHwMode_VReg_192_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__RegByHwMode_VReg_512_AlignTarget1_2__VSrc_f321_3, AMFBS_HasGFX950Insts_isGFX9Only, { MCK_RegByHwMode_VReg_192_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VSrc_f32 }, },
  { 34825 /* v_cvt_scalef32_f16_bf8 */, AMDGPU::V_CVT_SCALEF32_F16_BF8_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasBF8ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 34848 /* v_cvt_scalef32_f16_fp8 */, AMDGPU::V_CVT_SCALEF32_F16_FP8_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 34871 /* v_cvt_scalef32_f32_bf8 */, AMDGPU::V_CVT_SCALEF32_F32_BF8_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasBF8ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 34894 /* v_cvt_scalef32_f32_fp8 */, AMDGPU::V_CVT_SCALEF32_F32_FP8_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 34917 /* v_cvt_scalef32_pk16_bf6_bf16 */, AMDGPU::V_CVT_SCALEF32_PK16_BF6_BF16_e64_gfx1250, Convert__RegByHwMode_VReg_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_f321_2, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VSrc_f32 }, },
  { 34946 /* v_cvt_scalef32_pk16_bf6_f16 */, AMDGPU::V_CVT_SCALEF32_PK16_BF6_F16_e64_gfx1250, Convert__RegByHwMode_VReg_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_f321_2, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VSrc_f32 }, },
  { 34974 /* v_cvt_scalef32_pk16_bf6_f32 */, AMDGPU::V_CVT_SCALEF32_PK16_BF6_F32_e64_gfx1250, Convert__RegByHwMode_VReg_96_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__VSrc_f321_2, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VSrc_f32 }, },
  { 35002 /* v_cvt_scalef32_pk16_fp6_bf16 */, AMDGPU::V_CVT_SCALEF32_PK16_FP6_BF16_e64_gfx1250, Convert__RegByHwMode_VReg_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_f321_2, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VSrc_f32 }, },
  { 35031 /* v_cvt_scalef32_pk16_fp6_f16 */, AMDGPU::V_CVT_SCALEF32_PK16_FP6_F16_e64_gfx1250, Convert__RegByHwMode_VReg_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_f321_2, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VSrc_f32 }, },
  { 35059 /* v_cvt_scalef32_pk16_fp6_f32 */, AMDGPU::V_CVT_SCALEF32_PK16_FP6_F32_e64_gfx1250, Convert__RegByHwMode_VReg_96_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__VSrc_f321_2, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VSrc_f32 }, },
  { 35087 /* v_cvt_scalef32_pk32_bf16_bf6 */, AMDGPU::V_CVT_SCALEF32_PK32_BF16_BF6_gfx9, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__VSrc_f321_2, AMFBS_HasFP6BF6ConversionScaleInsts_isGFX9Only, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_VSrc_f32 }, },
  { 35116 /* v_cvt_scalef32_pk32_bf16_fp6 */, AMDGPU::V_CVT_SCALEF32_PK32_BF16_FP6_gfx9, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__VSrc_f321_2, AMFBS_HasFP6BF6ConversionScaleInsts_isGFX9Only, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_VSrc_f32 }, },
  { 35145 /* v_cvt_scalef32_pk32_bf6_bf16 */, AMDGPU::V_CVT_SCALEF32_PK32_BF6_BF16_gfx9, Convert__RegByHwMode_VReg_192_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__VSrc_f321_2, AMFBS_HasF16BF16ToFP6BF6ConversionScaleInsts_isGFX9Only, { MCK_RegByHwMode_VReg_192_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VSrc_f32 }, },
  { 35174 /* v_cvt_scalef32_pk32_bf6_f16 */, AMDGPU::V_CVT_SCALEF32_PK32_BF6_F16_gfx9, Convert__RegByHwMode_VReg_192_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__VSrc_f321_2, AMFBS_HasF16BF16ToFP6BF6ConversionScaleInsts_isGFX9Only, { MCK_RegByHwMode_VReg_192_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VSrc_f32 }, },
  { 35202 /* v_cvt_scalef32_pk32_f16_bf6 */, AMDGPU::V_CVT_SCALEF32_PK32_F16_BF6_gfx9, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__VSrc_f321_2, AMFBS_HasFP6BF6ConversionScaleInsts_isGFX9Only, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_VSrc_f32 }, },
  { 35230 /* v_cvt_scalef32_pk32_f16_fp6 */, AMDGPU::V_CVT_SCALEF32_PK32_F16_FP6_gfx9, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__VSrc_f321_2, AMFBS_HasFP6BF6ConversionScaleInsts_isGFX9Only, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_VSrc_f32 }, },
  { 35258 /* v_cvt_scalef32_pk32_f32_bf6 */, AMDGPU::V_CVT_SCALEF32_PK32_F32_BF6_gfx9, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__VSrc_f321_2, AMFBS_HasFP6BF6ConversionScaleInsts_isGFX9Only, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_VSrc_f32 }, },
  { 35286 /* v_cvt_scalef32_pk32_f32_fp6 */, AMDGPU::V_CVT_SCALEF32_PK32_F32_FP6_gfx9, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_VReg_192_AlignTarget1_1__VSrc_f321_2, AMFBS_HasFP6BF6ConversionScaleInsts_isGFX9Only, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_VReg_192_AlignTarget, MCK_VSrc_f32 }, },
  { 35314 /* v_cvt_scalef32_pk32_fp6_bf16 */, AMDGPU::V_CVT_SCALEF32_PK32_FP6_BF16_gfx9, Convert__RegByHwMode_VReg_192_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__VSrc_f321_2, AMFBS_HasF16BF16ToFP6BF6ConversionScaleInsts_isGFX9Only, { MCK_RegByHwMode_VReg_192_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VSrc_f32 }, },
  { 35343 /* v_cvt_scalef32_pk32_fp6_f16 */, AMDGPU::V_CVT_SCALEF32_PK32_FP6_F16_gfx9, Convert__RegByHwMode_VReg_192_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__VSrc_f321_2, AMFBS_HasF16BF16ToFP6BF6ConversionScaleInsts_isGFX9Only, { MCK_RegByHwMode_VReg_192_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VSrc_f32 }, },
  { 35371 /* v_cvt_scalef32_pk8_bf8_bf16 */, AMDGPU::V_CVT_SCALEF32_PK8_BF8_BF16_e64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__VSrc_f321_2, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VSrc_f32 }, },
  { 35399 /* v_cvt_scalef32_pk8_bf8_f16 */, AMDGPU::V_CVT_SCALEF32_PK8_BF8_F16_e64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__VSrc_f321_2, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VSrc_f32 }, },
  { 35426 /* v_cvt_scalef32_pk8_bf8_f32 */, AMDGPU::V_CVT_SCALEF32_PK8_BF8_F32_e64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_f321_2, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VSrc_f32 }, },
  { 35453 /* v_cvt_scalef32_pk8_fp4_bf16 */, AMDGPU::V_CVT_SCALEF32_PK8_FP4_BF16_e64_gfx1250, Convert__Reg1_0__RegByHwMode_VReg_128_AlignTarget1_1__VSrc_f321_2, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VSrc_f32 }, },
  { 35481 /* v_cvt_scalef32_pk8_fp4_f16 */, AMDGPU::V_CVT_SCALEF32_PK8_FP4_F16_e64_gfx1250, Convert__Reg1_0__RegByHwMode_VReg_128_AlignTarget1_1__VSrc_f321_2, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VSrc_f32 }, },
  { 35508 /* v_cvt_scalef32_pk8_fp4_f32 */, AMDGPU::V_CVT_SCALEF32_PK8_FP4_F32_e64_gfx1250, Convert__Reg1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_f321_2, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VSrc_f32 }, },
  { 35535 /* v_cvt_scalef32_pk8_fp8_bf16 */, AMDGPU::V_CVT_SCALEF32_PK8_FP8_BF16_e64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__VSrc_f321_2, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VSrc_f32 }, },
  { 35563 /* v_cvt_scalef32_pk8_fp8_f16 */, AMDGPU::V_CVT_SCALEF32_PK8_FP8_F16_e64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__VSrc_f321_2, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VSrc_f32 }, },
  { 35590 /* v_cvt_scalef32_pk8_fp8_f32 */, AMDGPU::V_CVT_SCALEF32_PK8_FP8_F32_e64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_f321_2, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VSrc_f32 }, },
  { 35617 /* v_cvt_scalef32_pk_bf16_bf8 */, AMDGPU::V_CVT_SCALEF32_PK_BF16_BF8_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasBF8ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 35644 /* v_cvt_scalef32_pk_bf16_fp4 */, AMDGPU::V_CVT_SCALEF32_PK_BF16_FP4_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP4ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 35671 /* v_cvt_scalef32_pk_bf16_fp8 */, AMDGPU::V_CVT_SCALEF32_PK_BF16_FP8_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 35698 /* v_cvt_scalef32_pk_bf8_bf16 */, AMDGPU::V_CVT_SCALEF32_PK_BF8_BF16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasBF8ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 35725 /* v_cvt_scalef32_pk_bf8_f16 */, AMDGPU::V_CVT_SCALEF32_PK_BF8_F16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasBF8ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 35751 /* v_cvt_scalef32_pk_bf8_f32 */, AMDGPU::V_CVT_SCALEF32_PK_BF8_F32_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasBF8ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 35777 /* v_cvt_scalef32_pk_f16_bf8 */, AMDGPU::V_CVT_SCALEF32_PK_F16_BF8_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasBF8ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 35803 /* v_cvt_scalef32_pk_f16_fp4 */, AMDGPU::V_CVT_SCALEF32_PK_F16_FP4_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP4ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 35829 /* v_cvt_scalef32_pk_f16_fp8 */, AMDGPU::V_CVT_SCALEF32_PK_F16_FP8_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 35855 /* v_cvt_scalef32_pk_f32_bf8 */, AMDGPU::V_CVT_SCALEF32_PK_F32_BF8_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasBF8ConversionScaleInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 35881 /* v_cvt_scalef32_pk_f32_fp4 */, AMDGPU::V_CVT_SCALEF32_PK_F32_FP4_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP4ConversionScaleInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 35907 /* v_cvt_scalef32_pk_f32_fp8 */, AMDGPU::V_CVT_SCALEF32_PK_F32_FP8_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionScaleInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 35933 /* v_cvt_scalef32_pk_fp4_bf16 */, AMDGPU::V_CVT_SCALEF32_PK_FP4_BF16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP4ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 35960 /* v_cvt_scalef32_pk_fp4_f16 */, AMDGPU::V_CVT_SCALEF32_PK_FP4_F16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP4ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 35986 /* v_cvt_scalef32_pk_fp4_f32 */, AMDGPU::V_CVT_SCALEF32_PK_FP4_F32_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP4ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 36012 /* v_cvt_scalef32_pk_fp8_bf16 */, AMDGPU::V_CVT_SCALEF32_PK_FP8_BF16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 36039 /* v_cvt_scalef32_pk_fp8_f16 */, AMDGPU::V_CVT_SCALEF32_PK_FP8_F16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 36065 /* v_cvt_scalef32_pk_fp8_f32 */, AMDGPU::V_CVT_SCALEF32_PK_FP8_F32_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 36091 /* v_cvt_scalef32_sr_bf8_bf16 */, AMDGPU::V_CVT_SCALEF32_SR_BF8_BF16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasBF8ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 36118 /* v_cvt_scalef32_sr_bf8_f16 */, AMDGPU::V_CVT_SCALEF32_SR_BF8_F16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasBF8ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 36144 /* v_cvt_scalef32_sr_bf8_f32 */, AMDGPU::V_CVT_SCALEF32_SR_BF8_F32_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasBF8ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 36170 /* v_cvt_scalef32_sr_fp8_bf16 */, AMDGPU::V_CVT_SCALEF32_SR_FP8_BF16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 36197 /* v_cvt_scalef32_sr_fp8_f16 */, AMDGPU::V_CVT_SCALEF32_SR_FP8_F16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 36223 /* v_cvt_scalef32_sr_fp8_f32 */, AMDGPU::V_CVT_SCALEF32_SR_FP8_F32_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 36249 /* v_cvt_scalef32_sr_pk16_bf6_bf16 */, AMDGPU::V_CVT_SCALEF32_SR_PK16_BF6_BF16_e64_gfx1250, Convert__RegByHwMode_VReg_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VSrc_b32, MCK_VSrc_f32 }, },
  { 36281 /* v_cvt_scalef32_sr_pk16_bf6_f16 */, AMDGPU::V_CVT_SCALEF32_SR_PK16_BF6_F16_e64_gfx1250, Convert__RegByHwMode_VReg_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VSrc_b32, MCK_VSrc_f32 }, },
  { 36312 /* v_cvt_scalef32_sr_pk16_bf6_f32 */, AMDGPU::V_CVT_SCALEF32_SR_PK16_BF6_F32_e64_gfx1250, Convert__RegByHwMode_VReg_96_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VSrc_b32, MCK_VSrc_f32 }, },
  { 36343 /* v_cvt_scalef32_sr_pk16_fp6_bf16 */, AMDGPU::V_CVT_SCALEF32_SR_PK16_FP6_BF16_e64_gfx1250, Convert__RegByHwMode_VReg_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VSrc_b32, MCK_VSrc_f32 }, },
  { 36375 /* v_cvt_scalef32_sr_pk16_fp6_f16 */, AMDGPU::V_CVT_SCALEF32_SR_PK16_FP6_F16_e64_gfx1250, Convert__RegByHwMode_VReg_96_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VSrc_b32, MCK_VSrc_f32 }, },
  { 36406 /* v_cvt_scalef32_sr_pk16_fp6_f32 */, AMDGPU::V_CVT_SCALEF32_SR_PK16_FP6_F32_e64_gfx1250, Convert__RegByHwMode_VReg_96_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_96_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VSrc_b32, MCK_VSrc_f32 }, },
  { 36437 /* v_cvt_scalef32_sr_pk32_bf6_bf16 */, AMDGPU::V_CVT_SCALEF32_SR_PK32_BF6_BF16_gfx9, Convert__RegByHwMode_VReg_192_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3, AMFBS_HasF16BF16ToFP6BF6ConversionScaleInsts_isGFX9Only, { MCK_RegByHwMode_VReg_192_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VSrc_b32, MCK_VSrc_f32 }, },
  { 36469 /* v_cvt_scalef32_sr_pk32_bf6_f16 */, AMDGPU::V_CVT_SCALEF32_SR_PK32_BF6_F16_gfx9, Convert__RegByHwMode_VReg_192_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3, AMFBS_HasF16BF16ToFP6BF6ConversionScaleInsts_isGFX9Only, { MCK_RegByHwMode_VReg_192_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VSrc_b32, MCK_VSrc_f32 }, },
  { 36500 /* v_cvt_scalef32_sr_pk32_bf6_f32 */, AMDGPU::V_CVT_SCALEF32_SR_PK32_BF6_F32_gfx9, Convert__RegByHwMode_VReg_192_AlignTarget1_0__RegByHwMode_VReg_1024_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3, AMFBS_HasF16BF16ToFP6BF6ConversionScaleInsts_isGFX9Only, { MCK_RegByHwMode_VReg_192_AlignTarget, MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_VSrc_b32, MCK_VSrc_f32 }, },
  { 36531 /* v_cvt_scalef32_sr_pk32_fp6_bf16 */, AMDGPU::V_CVT_SCALEF32_SR_PK32_FP6_BF16_gfx9, Convert__RegByHwMode_VReg_192_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3, AMFBS_HasF16BF16ToFP6BF6ConversionScaleInsts_isGFX9Only, { MCK_RegByHwMode_VReg_192_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VSrc_b32, MCK_VSrc_f32 }, },
  { 36563 /* v_cvt_scalef32_sr_pk32_fp6_f16 */, AMDGPU::V_CVT_SCALEF32_SR_PK32_FP6_F16_gfx9, Convert__RegByHwMode_VReg_192_AlignTarget1_0__RegByHwMode_VReg_512_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3, AMFBS_HasF16BF16ToFP6BF6ConversionScaleInsts_isGFX9Only, { MCK_RegByHwMode_VReg_192_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VSrc_b32, MCK_VSrc_f32 }, },
  { 36594 /* v_cvt_scalef32_sr_pk32_fp6_f32 */, AMDGPU::V_CVT_SCALEF32_SR_PK32_FP6_F32_gfx9, Convert__RegByHwMode_VReg_192_AlignTarget1_0__RegByHwMode_VReg_1024_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3, AMFBS_HasF16BF16ToFP6BF6ConversionScaleInsts_isGFX9Only, { MCK_RegByHwMode_VReg_192_AlignTarget, MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_VSrc_b32, MCK_VSrc_f32 }, },
  { 36625 /* v_cvt_scalef32_sr_pk8_bf8_bf16 */, AMDGPU::V_CVT_SCALEF32_SR_PK8_BF8_BF16_e64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VSrc_b32, MCK_VSrc_f32 }, },
  { 36656 /* v_cvt_scalef32_sr_pk8_bf8_f16 */, AMDGPU::V_CVT_SCALEF32_SR_PK8_BF8_F16_e64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VSrc_b32, MCK_VSrc_f32 }, },
  { 36686 /* v_cvt_scalef32_sr_pk8_bf8_f32 */, AMDGPU::V_CVT_SCALEF32_SR_PK8_BF8_F32_e64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VSrc_b32, MCK_VSrc_f32 }, },
  { 36716 /* v_cvt_scalef32_sr_pk8_fp4_bf16 */, AMDGPU::V_CVT_SCALEF32_SR_PK8_FP4_BF16_e64_gfx1250, Convert__Reg1_0__RegByHwMode_VReg_128_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VSrc_b32, MCK_VSrc_f32 }, },
  { 36747 /* v_cvt_scalef32_sr_pk8_fp4_f16 */, AMDGPU::V_CVT_SCALEF32_SR_PK8_FP4_F16_e64_gfx1250, Convert__Reg1_0__RegByHwMode_VReg_128_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VSrc_b32, MCK_VSrc_f32 }, },
  { 36777 /* v_cvt_scalef32_sr_pk8_fp4_f32 */, AMDGPU::V_CVT_SCALEF32_SR_PK8_FP4_F32_e64_gfx1250, Convert__Reg1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_VGPR_32, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VSrc_b32, MCK_VSrc_f32 }, },
  { 36807 /* v_cvt_scalef32_sr_pk8_fp8_bf16 */, AMDGPU::V_CVT_SCALEF32_SR_PK8_FP8_BF16_e64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VSrc_b32, MCK_VSrc_f32 }, },
  { 36838 /* v_cvt_scalef32_sr_pk8_fp8_f16 */, AMDGPU::V_CVT_SCALEF32_SR_PK8_FP8_F16_e64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_128_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VSrc_b32, MCK_VSrc_f32 }, },
  { 36868 /* v_cvt_scalef32_sr_pk8_fp8_f32 */, AMDGPU::V_CVT_SCALEF32_SR_PK8_FP8_F32_e64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_VReg_256_AlignTarget1_1__VSrc_b321_2__VSrc_f321_3, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VSrc_b32, MCK_VSrc_f32 }, },
  { 36898 /* v_cvt_scalef32_sr_pk_fp4_bf16 */, AMDGPU::V_CVT_SCALEF32_SR_PK_FP4_BF16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP4ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_PackedFP16InputMods, MCK_VSrc_b32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 36928 /* v_cvt_scalef32_sr_pk_fp4_f16 */, AMDGPU::V_CVT_SCALEF32_SR_PK_FP4_F16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP4ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_PackedFP16InputMods, MCK_VSrc_b32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 36957 /* v_cvt_scalef32_sr_pk_fp4_f32 */, AMDGPU::V_CVT_SCALEF32_SR_PK_FP4_F32_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP4ConversionScaleInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_PackedFP32InputMods, MCK_VSrc_b32, MCK_RegOrImmWithFP32InputMods, MCK_OpSel }, },
  { 36986 /* v_cvt_sr_bf16_f32 */, AMDGPU::V_CVT_SR_BF16_F32_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasF32ToF16BF16ConversionSRInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_OpSel }, },
  { 37004 /* v_cvt_sr_bf8_f16 */, AMDGPU::V_CVT_SR_BF8_F16_t16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX1250Plus_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_32, MCK_RegOrImmWithFPT16InputMods, MCK_VSrc_b32, MCK_OpSel, MCK_ByteSel }, },
  { 37004 /* v_cvt_sr_bf8_f16 */, AMDGPU::V_CVT_SR_BF8_F16_fake16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_VSrc_b32, MCK_OpSel, MCK_ByteSel }, },
  { 37021 /* v_cvt_sr_bf8_f32 */, AMDGPU::V_CVT_SR_BF8_F32_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionInsts_isGFX940Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_OpSel }, },
  { 37021 /* v_cvt_sr_bf8_f32 */, AMDGPU::V_CVT_SR_BF8_F32_gfx12_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_ByteSel }, },
  { 37021 /* v_cvt_sr_bf8_f32 */, AMDGPU::V_CVT_SR_BF8_F32_gfx12_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_ByteSel }, },
  { 37038 /* v_cvt_sr_f16_f32 */, AMDGPU::V_CVT_SR_F16_F32_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasF32ToF16BF16ConversionSRInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_OpSel }, },
  { 37055 /* v_cvt_sr_fp8_f16 */, AMDGPU::V_CVT_SR_FP8_F16_t16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX1250Plus_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_32, MCK_RegOrImmWithFPT16InputMods, MCK_VSrc_b32, MCK_OpSel, MCK_ByteSel }, },
  { 37055 /* v_cvt_sr_fp8_f16 */, AMDGPU::V_CVT_SR_FP8_F16_fake16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_VSrc_b32, MCK_OpSel, MCK_ByteSel }, },
  { 37072 /* v_cvt_sr_fp8_f32 */, AMDGPU::V_CVT_SR_FP8_F32_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_HasFP8ConversionInsts_isGFX940Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_OpSel }, },
  { 37072 /* v_cvt_sr_fp8_f32 */, AMDGPU::V_CVT_SR_FP8_F32_gfx12_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX12Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_ByteSel }, },
  { 37072 /* v_cvt_sr_fp8_f32 */, AMDGPU::V_CVT_SR_FP8_F32_gfx12_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX12Plus_isGFX12Not12_50, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_ByteSel }, },
  { 37072 /* v_cvt_sr_fp8_f32 */, AMDGPU::V_CVT_SR_FP8_F32_gfx1250_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_HasFP8ConversionInsts_HasFP8E5M3Insts_isGFX12Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_ByteSel, MCK_Clamp }, },
  { 37089 /* v_cvt_sr_pk_bf16_f32 */, AMDGPU::V_CVT_SR_PK_BF16_F32_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_HasBF16ConversionInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 37110 /* v_cvt_sr_pk_f16_f32 */, AMDGPU::V_CVT_SR_PK_F16_F32_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37158 /* v_cvt_u32_f64 */, AMDGPU::V_CVT_U32_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37158 /* v_cvt_u32_f64 */, AMDGPU::V_CVT_U32_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37158 /* v_cvt_u32_f64 */, AMDGPU::V_CVT_U32_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37158 /* v_cvt_u32_f64 */, AMDGPU::V_CVT_U32_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37158 /* v_cvt_u32_f64 */, AMDGPU::V_CVT_U32_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_fake16_e64_gfx11, Convert__Reg1_0__VSrc_b161_1, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16 }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_fake16_e64_gfx12, Convert__Reg1_0__VSrc_b161_1, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16 }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrcT_b16, MCK_OpSel }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrcT_b16, MCK_OpSel }, },
  { 37186 /* v_div_fixup_f16 */, AMDGPU::V_DIV_FIXUP_F16_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37186 /* v_div_fixup_f16 */, AMDGPU::V_DIV_FIXUP_F16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 37186 /* v_div_fixup_f16 */, AMDGPU::V_DIV_FIXUP_F16_gfx9_gfx9, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX9Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 37186 /* v_div_fixup_f16 */, AMDGPU::V_DIV_FIXUP_F16V_DIV_FIXUP_F16_gfx9_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 37186 /* v_div_fixup_f16 */, AMDGPU::V_DIV_FIXUP_F16V_DIV_FIXUP_F16_gfx9_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 37186 /* v_div_fixup_f16 */, AMDGPU::V_DIV_FIXUP_F16V_DIV_FIXUP_F16_gfx9_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 37186 /* v_div_fixup_f16 */, AMDGPU::V_DIV_FIXUP_F16V_DIV_FIXUP_F16_gfx9_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 37202 /* v_div_fixup_f32 */, AMDGPU::V_DIV_FIXUP_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37202 /* v_div_fixup_f32 */, AMDGPU::V_DIV_FIXUP_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37202 /* v_div_fixup_f32 */, AMDGPU::V_DIV_FIXUP_F32_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37202 /* v_div_fixup_f32 */, AMDGPU::V_DIV_FIXUP_F32_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37202 /* v_div_fixup_f32 */, AMDGPU::V_DIV_FIXUP_F32_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37218 /* v_div_fixup_f64 */, AMDGPU::V_DIV_FIXUP_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37218 /* v_div_fixup_f64 */, AMDGPU::V_DIV_FIXUP_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Not12_50, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37218 /* v_div_fixup_f64 */, AMDGPU::V_DIV_FIXUP_F64_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37218 /* v_div_fixup_f64 */, AMDGPU::V_DIV_FIXUP_F64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37218 /* v_div_fixup_f64 */, AMDGPU::V_DIV_FIXUP_F64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37218 /* v_div_fixup_f64 */, AMDGPU::V_DIV_FIXUP_F64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37234 /* v_div_fixup_legacy_f16 */, AMDGPU::V_DIV_FIXUP_LEGACY_F16_gfx9, ConvertCustom_cvtVOP3, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37257 /* v_div_fmas_f32 */, AMDGPU::V_DIV_FMAS_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37257 /* v_div_fmas_f32 */, AMDGPU::V_DIV_FMAS_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37257 /* v_div_fmas_f32 */, AMDGPU::V_DIV_FMAS_F32_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37257 /* v_div_fmas_f32 */, AMDGPU::V_DIV_FMAS_F32_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37257 /* v_div_fmas_f32 */, AMDGPU::V_DIV_FMAS_F32_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37272 /* v_div_fmas_f64 */, AMDGPU::V_DIV_FMAS_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37272 /* v_div_fmas_f64 */, AMDGPU::V_DIV_FMAS_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Not12_50, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37272 /* v_div_fmas_f64 */, AMDGPU::V_DIV_FMAS_F64_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37272 /* v_div_fmas_f64 */, AMDGPU::V_DIV_FMAS_F64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37272 /* v_div_fmas_f64 */, AMDGPU::V_DIV_FMAS_F64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37272 /* v_div_fmas_f64 */, AMDGPU::V_DIV_FMAS_F64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37287 /* v_div_scale_f32 */, AMDGPU::V_DIV_SCALE_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37287 /* v_div_scale_f32 */, AMDGPU::V_DIV_SCALE_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37287 /* v_div_scale_f32 */, AMDGPU::V_DIV_SCALE_F32_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37287 /* v_div_scale_f32 */, AMDGPU::V_DIV_SCALE_F32_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37287 /* v_div_scale_f32 */, AMDGPU::V_DIV_SCALE_F32_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_BoolReg, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37303 /* v_div_scale_f64 */, AMDGPU::V_DIV_SCALE_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37303 /* v_div_scale_f64 */, AMDGPU::V_DIV_SCALE_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Not12_50, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37303 /* v_div_scale_f64 */, AMDGPU::V_DIV_SCALE_F64_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37303 /* v_div_scale_f64 */, AMDGPU::V_DIV_SCALE_F64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37303 /* v_div_scale_f64 */, AMDGPU::V_DIV_SCALE_F64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37303 /* v_div_scale_f64 */, AMDGPU::V_DIV_SCALE_F64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_BoolReg, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37319 /* v_dot2_bf16_bf16 */, AMDGPU::V_DOT2_BF16_BF16_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_HasDot9Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel }, },
  { 37319 /* v_dot2_bf16_bf16 */, AMDGPU::V_DOT2_BF16_BF16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasDot9Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel }, },
  { 37319 /* v_dot2_bf16_bf16 */, AMDGPU::V_DOT2_BF16_BF16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_HasDot9Insts_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel }, },
  { 37319 /* v_dot2_bf16_bf16 */, AMDGPU::V_DOT2_BF16_BF16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasDot9Insts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel }, },
  { 37336 /* v_dot2_f16_f16 */, AMDGPU::V_DOT2_F16_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_HasDot9Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel }, },
  { 37336 /* v_dot2_f16_f16 */, AMDGPU::V_DOT2_F16_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasDot9Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel }, },
  { 37336 /* v_dot2_f16_f16 */, AMDGPU::V_DOT2_F16_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_HasDot9Insts_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel }, },
  { 37336 /* v_dot2_f16_f16 */, AMDGPU::V_DOT2_F16_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasDot9Insts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel }, },
  { 37351 /* v_dot2_f32_bf16 */, AMDGPU::V_DOT2_F32_BF16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_HasDot12Insts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VSrc_v2bf16, MCK_VSrc_f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37351 /* v_dot2_f32_bf16 */, AMDGPU::V_DOT2_F32_BF16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_HasDot12Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VSrc_v2bf16, MCK_VSrc_f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37351 /* v_dot2_f32_bf16 */, AMDGPU::V_DOT2_F32_BF16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasDot12Insts_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VSrc_v2bf16, MCK_VSrc_f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37367 /* v_dot2_f32_f16 */, AMDGPU::V_DOT2_F32_F16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_HasDot10Insts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_VSrc_f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37367 /* v_dot2_f32_f16 */, AMDGPU::V_DOT2_F32_F16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_HasDot10Insts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_VSrc_f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37367 /* v_dot2_f32_f16 */, AMDGPU::V_DOT2_F32_F16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_HasDot10Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_VSrc_f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37367 /* v_dot2_f32_f16 */, AMDGPU::V_DOT2_F32_F16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasDot10Insts_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_VSrc_f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37382 /* v_dot2_i32_i16 */, AMDGPU::V_DOT2_I32_I16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_HasDot2Insts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_VSrc_b32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37382 /* v_dot2_i32_i16 */, AMDGPU::V_DOT2_I32_I16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasDot2Insts_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_VSrc_b32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37397 /* v_dot2_u32_u16 */, AMDGPU::V_DOT2_U32_U16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_HasDot2Insts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_VSrc_b32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37397 /* v_dot2_u32_u16 */, AMDGPU::V_DOT2_U32_U16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasDot2Insts_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_VSrc_b32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37430 /* v_dot2c_f32_bf16 */, AMDGPU::V_DOT2C_F32_BF16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_HasDot13Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37447 /* v_dot2c_f32_f16 */, AMDGPU::V_DOT2C_F32_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_HasDot5Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 37463 /* v_dot2c_i32_i16 */, AMDGPU::V_DOT2C_I32_I16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_HasDot4Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 37479 /* v_dot4_f32_bf8_bf8 */, AMDGPU::V_DOT4_F32_BF8_BF8_gfx12, ConvertCustom_cvtVOP3P, AMFBS_HasDot11Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_f32, MCK_NegLo, MCK_NegHi }, },
  { 37498 /* v_dot4_f32_bf8_fp8 */, AMDGPU::V_DOT4_F32_BF8_FP8_gfx12, ConvertCustom_cvtVOP3P, AMFBS_HasDot11Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_f32, MCK_NegLo, MCK_NegHi }, },
  { 37517 /* v_dot4_f32_fp8_bf8 */, AMDGPU::V_DOT4_F32_FP8_BF8_gfx12, ConvertCustom_cvtVOP3P, AMFBS_HasDot11Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_f32, MCK_NegLo, MCK_NegHi }, },
  { 37536 /* v_dot4_f32_fp8_fp8 */, AMDGPU::V_DOT4_F32_FP8_FP8_gfx12, ConvertCustom_cvtVOP3P, AMFBS_HasDot11Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_f32, MCK_NegLo, MCK_NegHi }, },
  { 37555 /* v_dot4_i32_i8 */, AMDGPU::V_DOT4_I32_I8_gfx10, ConvertCustom_cvtVOP3P, AMFBS_HasDot1Insts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37555 /* v_dot4_i32_i8 */, AMDGPU::V_DOT4_I32_I8_vi, ConvertCustom_cvtVOP3P, AMFBS_HasDot1Insts_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37569 /* v_dot4_i32_iu8 */, AMDGPU::V_DOT4_I32_IU8_gfx11, ConvertCustom_cvtVOP3P, AMFBS_HasDot8Insts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37569 /* v_dot4_i32_iu8 */, AMDGPU::V_DOT4_I32_IU8_gfx12, ConvertCustom_cvtVOP3P, AMFBS_HasDot8Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37584 /* v_dot4_u32_u8 */, AMDGPU::V_DOT4_U32_U8_gfx10, ConvertCustom_cvtVOP3P, AMFBS_HasDot7Insts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37584 /* v_dot4_u32_u8 */, AMDGPU::V_DOT4_U32_U8_gfx11, ConvertCustom_cvtVOP3P, AMFBS_HasDot7Insts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37584 /* v_dot4_u32_u8 */, AMDGPU::V_DOT4_U32_U8_gfx12, ConvertCustom_cvtVOP3P, AMFBS_HasDot7Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37584 /* v_dot4_u32_u8 */, AMDGPU::V_DOT4_U32_U8_vi, ConvertCustom_cvtVOP3P, AMFBS_HasDot7Insts_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37598 /* v_dot4c_i32_i8 */, AMDGPU::V_DOT4C_I32_I8_e64_vi, ConvertCustom_cvtVOP3, AMFBS_HasDot6Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 37613 /* v_dot8_i32_i4 */, AMDGPU::V_DOT8_I32_I4_gfx10, ConvertCustom_cvtVOP3P, AMFBS_HasDot1Insts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37613 /* v_dot8_i32_i4 */, AMDGPU::V_DOT8_I32_I4_vi, ConvertCustom_cvtVOP3P, AMFBS_HasDot1Insts_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37627 /* v_dot8_i32_iu4 */, AMDGPU::V_DOT8_I32_IU4_gfx11, ConvertCustom_cvtVOP3P, AMFBS_HasDot8Insts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37627 /* v_dot8_i32_iu4 */, AMDGPU::V_DOT8_I32_IU4_gfx12, ConvertCustom_cvtVOP3P, AMFBS_HasDot8Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37642 /* v_dot8_u32_u4 */, AMDGPU::V_DOT8_U32_U4_gfx10, ConvertCustom_cvtVOP3P, AMFBS_HasDot7Insts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37642 /* v_dot8_u32_u4 */, AMDGPU::V_DOT8_U32_U4_gfx11, ConvertCustom_cvtVOP3P, AMFBS_HasDot7Insts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37642 /* v_dot8_u32_u4 */, AMDGPU::V_DOT8_U32_U4_gfx12, ConvertCustom_cvtVOP3P, AMFBS_HasDot7Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37642 /* v_dot8_u32_u4 */, AMDGPU::V_DOT8_U32_U4_vi, ConvertCustom_cvtVOP3P, AMFBS_HasDot7Insts_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 37656 /* v_dot8c_i32_i4 */, AMDGPU::V_DOT8C_I32_I4_e64_vi, ConvertCustom_cvtVOP3, AMFBS_HasDot3Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 38148 /* v_exp_bf16 */, AMDGPU::V_EXP_BF16V_EXP_BF16_fake16_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods }, },
  { 38148 /* v_exp_bf16 */, AMDGPU::V_EXP_BF16V_EXP_BF16_t16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38179 /* v_exp_legacy_f32 */, AMDGPU::V_EXP_LEGACY_F32_e64_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX7GFX8GFX9_isGFX7Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38179 /* v_exp_legacy_f32 */, AMDGPU::V_EXP_LEGACY_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX7GFX8GFX9_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38196 /* v_ffbh_i32 */, AMDGPU::V_FFBH_I32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38196 /* v_ffbh_i32 */, AMDGPU::V_FFBH_I32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38196 /* v_ffbh_i32 */, AMDGPU::V_FFBH_I32_e64_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38207 /* v_ffbh_u32 */, AMDGPU::V_FFBH_U32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38207 /* v_ffbh_u32 */, AMDGPU::V_FFBH_U32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38207 /* v_ffbh_u32 */, AMDGPU::V_FFBH_U32_e64_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38218 /* v_ffbl_b32 */, AMDGPU::V_FFBL_B32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38218 /* v_ffbl_b32 */, AMDGPU::V_FFBL_B32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38218 /* v_ffbl_b32 */, AMDGPU::V_FFBL_B32_e64_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38253 /* v_floor_f64 */, AMDGPU::V_FLOOR_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38253 /* v_floor_f64 */, AMDGPU::V_FLOOR_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38253 /* v_floor_f64 */, AMDGPU::V_FLOOR_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38253 /* v_floor_f64 */, AMDGPU::V_FLOOR_F64_e64_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38253 /* v_floor_f64 */, AMDGPU::V_FLOOR_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38265 /* v_fma_dx9_zero_f32 */, AMDGPU::V_FMA_DX9_ZERO_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasFmaLegacy32_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38265 /* v_fma_dx9_zero_f32 */, AMDGPU::V_FMA_DX9_ZERO_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasFmaLegacy32_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38284 /* v_fma_f16 */, AMDGPU::V_FMA_F16_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38284 /* v_fma_f16 */, AMDGPU::V_FMA_F16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 38284 /* v_fma_f16 */, AMDGPU::V_FMA_F16_gfx9_gfx9, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX9Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 38284 /* v_fma_f16 */, AMDGPU::V_FMA_F16V_FMA_F16_gfx9_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 38284 /* v_fma_f16 */, AMDGPU::V_FMA_F16V_FMA_F16_gfx9_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 38284 /* v_fma_f16 */, AMDGPU::V_FMA_F16V_FMA_F16_gfx9_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 38284 /* v_fma_f16 */, AMDGPU::V_FMA_F16V_FMA_F16_gfx9_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 38294 /* v_fma_f32 */, AMDGPU::V_FMA_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38294 /* v_fma_f32 */, AMDGPU::V_FMA_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38294 /* v_fma_f32 */, AMDGPU::V_FMA_F32_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38294 /* v_fma_f32 */, AMDGPU::V_FMA_F32_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38294 /* v_fma_f32 */, AMDGPU::V_FMA_F32_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38304 /* v_fma_f64 */, AMDGPU::V_FMA_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38304 /* v_fma_f64 */, AMDGPU::V_FMA_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Not12_50, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38304 /* v_fma_f64 */, AMDGPU::V_FMA_F64_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38304 /* v_fma_f64 */, AMDGPU::V_FMA_F64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38304 /* v_fma_f64 */, AMDGPU::V_FMA_F64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38304 /* v_fma_f64 */, AMDGPU::V_FMA_F64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38314 /* v_fma_legacy_f16 */, AMDGPU::V_FMA_LEGACY_F16_gfx9, ConvertCustom_cvtVOP3, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38331 /* v_fma_legacy_f32 */, AMDGPU::V_FMA_LEGACY_F32_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasFmaLegacy32_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38348 /* v_fma_mix_f32 */, AMDGPU::V_FMA_MIX_F32_gfx10, ConvertCustom_cvtVOP3P, AMFBS_HasFmaMixInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 38348 /* v_fma_mix_f32 */, AMDGPU::V_FMA_MIX_F32_gfx11, ConvertCustom_cvtVOP3P, AMFBS_HasFmaMixInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 38348 /* v_fma_mix_f32 */, AMDGPU::V_FMA_MIX_F32_gfx12, ConvertCustom_cvtVOP3P, AMFBS_HasFmaMixInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 38348 /* v_fma_mix_f32 */, AMDGPU::V_FMA_MIX_F32_vi, ConvertCustom_cvtVOP3P, AMFBS_HasFmaMixInsts_HasVOP3PInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 38362 /* v_fma_mix_f32_bf16 */, AMDGPU::V_FMA_MIX_F32_BF16_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_HasFmaMixBF16Insts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 38381 /* v_fma_mixhi_bf16 */, AMDGPU::V_FMA_MIXHI_BF16_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_HasFmaMixBF16Insts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 38398 /* v_fma_mixhi_f16 */, AMDGPU::V_FMA_MIXHI_F16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_HasFmaMixInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 38398 /* v_fma_mixhi_f16 */, AMDGPU::V_FMA_MIXHI_F16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_HasFmaMixInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 38398 /* v_fma_mixhi_f16 */, AMDGPU::V_FMA_MIXHI_F16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_HasFmaMixInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 38398 /* v_fma_mixhi_f16 */, AMDGPU::V_FMA_MIXHI_F16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasFmaMixInsts_HasVOP3PInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 38414 /* v_fma_mixlo_bf16 */, AMDGPU::V_FMA_MIXLO_BF16_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_HasFmaMixBF16Insts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 38431 /* v_fma_mixlo_f16 */, AMDGPU::V_FMA_MIXLO_F16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_HasFmaMixInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 38431 /* v_fma_mixlo_f16 */, AMDGPU::V_FMA_MIXLO_F16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_HasFmaMixInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 38431 /* v_fma_mixlo_f16 */, AMDGPU::V_FMA_MIXLO_F16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_HasFmaMixInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 38431 /* v_fma_mixlo_f16 */, AMDGPU::V_FMA_MIXLO_F16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasFmaMixInsts_HasVOP3PInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 38483 /* v_fmac_dx9_zero_f32 */, AMDGPU::V_FMAC_DX9_ZERO_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasFmacLegacy32_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX10Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX10Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 38514 /* v_fmac_f32 */, AMDGPU::V_FMAC_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasDLInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38514 /* v_fmac_f32 */, AMDGPU::V_FMAC_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasDLInsts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38514 /* v_fmac_f32 */, AMDGPU::V_FMAC_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasDLInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38514 /* v_fmac_f32 */, AMDGPU::V_FMAC_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_HasDLInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38525 /* v_fmac_f64 */, AMDGPU::V_FMAC_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasFmacF64Inst_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38525 /* v_fmac_f64 */, AMDGPU::V_FMAC_F64_e64_gfx90a, ConvertCustom_cvtVOP3, AMFBS_isGFX9Only_HasFmacF64Inst, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38536 /* v_fmac_legacy_f32 */, AMDGPU::V_FMAC_LEGACY_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasFmacLegacy32_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38614 /* v_fract_f64 */, AMDGPU::V_FRACT_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38614 /* v_fract_f64 */, AMDGPU::V_FRACT_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38614 /* v_fract_f64 */, AMDGPU::V_FRACT_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38614 /* v_fract_f64 */, AMDGPU::V_FRACT_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38614 /* v_fract_f64 */, AMDGPU::V_FRACT_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp }, },
  { 38666 /* v_frexp_exp_i32_f64 */, AMDGPU::V_FREXP_EXP_I32_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38666 /* v_frexp_exp_i32_f64 */, AMDGPU::V_FREXP_EXP_I32_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38666 /* v_frexp_exp_i32_f64 */, AMDGPU::V_FREXP_EXP_I32_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38666 /* v_frexp_exp_i32_f64 */, AMDGPU::V_FREXP_EXP_I32_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38666 /* v_frexp_exp_i32_f64 */, AMDGPU::V_FREXP_EXP_I32_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38720 /* v_frexp_mant_f64 */, AMDGPU::V_FREXP_MANT_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38720 /* v_frexp_mant_f64 */, AMDGPU::V_FREXP_MANT_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38720 /* v_frexp_mant_f64 */, AMDGPU::V_FREXP_MANT_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38720 /* v_frexp_mant_f64 */, AMDGPU::V_FREXP_MANT_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38720 /* v_frexp_mant_f64 */, AMDGPU::V_FREXP_MANT_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38747 /* v_interp_mov_f32 */, AMDGPU::V_INTERP_MOV_F32_e64_gfx10, ConvertCustom_cvtVOP3Interp, AMFBS_isNotGFX90APlus_isGFX8Plus_isGFX10Only, { MCK_VGPR_32, MCK_InterpSlot, MCK_InterpAttr, MCK_InterpAttrChan, MCK_Clamp, MCK_OModSI }, },
  { 38747 /* v_interp_mov_f32 */, AMDGPU::V_INTERP_MOV_F32_e64_vi, ConvertCustom_cvtVOP3Interp, AMFBS_isNotGFX90APlus_isGFX8Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_InterpSlot, MCK_InterpAttr, MCK_InterpAttrChan, MCK_Clamp, MCK_OModSI }, },
  { 38764 /* v_interp_p10_f16_f32 */, AMDGPU::V_INTERP_P10_F16_F32_inreg_fake16_gfx11, ConvertCustom_cvtVINTERP, AMFBS_HasVINTERPEncoding_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OpSel, MCK_WaitEXP }, },
  { 38764 /* v_interp_p10_f16_f32 */, AMDGPU::V_INTERP_P10_F16_F32_inreg_fake16_gfx12, ConvertCustom_cvtVINTERP, AMFBS_HasVINTERPEncoding_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OpSel, MCK_WaitEXP }, },
  { 38764 /* v_interp_p10_f16_f32 */, AMDGPU::V_INTERP_P10_F16_F32_inreg_t16_gfx11, ConvertCustom_cvtVINTERP, AMFBS_HasVINTERPEncoding_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_T16VRegWithFPInputMods, MCK_Clamp, MCK_OpSel, MCK_WaitEXP }, },
  { 38764 /* v_interp_p10_f16_f32 */, AMDGPU::V_INTERP_P10_F16_F32_inreg_t16_gfx12, ConvertCustom_cvtVINTERP, AMFBS_HasVINTERPEncoding_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_T16VRegWithFPInputMods, MCK_Clamp, MCK_OpSel, MCK_WaitEXP }, },
  { 38785 /* v_interp_p10_f32 */, AMDGPU::V_INTERP_P10_F32_inreg_gfx11, ConvertCustom_cvtVINTERP, AMFBS_HasVINTERPEncoding_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_WaitEXP }, },
  { 38785 /* v_interp_p10_f32 */, AMDGPU::V_INTERP_P10_F32_inreg_gfx12, ConvertCustom_cvtVINTERP, AMFBS_HasVINTERPEncoding_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_WaitEXP }, },
  { 38802 /* v_interp_p10_rtz_f16_f32 */, AMDGPU::V_INTERP_P10_RTZ_F16_F32_inreg_fake16_gfx11, ConvertCustom_cvtVINTERP, AMFBS_HasVINTERPEncoding_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OpSel, MCK_WaitEXP }, },
  { 38802 /* v_interp_p10_rtz_f16_f32 */, AMDGPU::V_INTERP_P10_RTZ_F16_F32_inreg_fake16_gfx12, ConvertCustom_cvtVINTERP, AMFBS_HasVINTERPEncoding_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OpSel, MCK_WaitEXP }, },
  { 38802 /* v_interp_p10_rtz_f16_f32 */, AMDGPU::V_INTERP_P10_RTZ_F16_F32_inreg_t16_gfx11, ConvertCustom_cvtVINTERP, AMFBS_HasVINTERPEncoding_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_T16VRegWithFPInputMods, MCK_Clamp, MCK_OpSel, MCK_WaitEXP }, },
  { 38802 /* v_interp_p10_rtz_f16_f32 */, AMDGPU::V_INTERP_P10_RTZ_F16_F32_inreg_t16_gfx12, ConvertCustom_cvtVINTERP, AMFBS_HasVINTERPEncoding_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_T16VRegWithFPInputMods, MCK_Clamp, MCK_OpSel, MCK_WaitEXP }, },
  { 38827 /* v_interp_p1_f32 */, AMDGPU::V_INTERP_P1_F32_e64_gfx10, ConvertCustom_cvtVOP3Interp, AMFBS_isNotGFX90APlus_isGFX8Plus_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_InterpAttr, MCK_InterpAttrChan, MCK_Clamp, MCK_OModSI }, },
  { 38827 /* v_interp_p1_f32 */, AMDGPU::V_INTERP_P1_F32_e64_vi, ConvertCustom_cvtVOP3Interp, AMFBS_isNotGFX90APlus_isGFX8Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_InterpAttr, MCK_InterpAttrChan, MCK_Clamp, MCK_OModSI }, },
  { 38843 /* v_interp_p1ll_f16 */, AMDGPU::V_INTERP_P1LL_F16_gfx10, ConvertCustom_cvtVOP3Interp, AMFBS_isNotGFX90APlus_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_InterpAttr, MCK_InterpAttrChan, MCK_High, MCK_Clamp, MCK_OModSI }, },
  { 38843 /* v_interp_p1ll_f16 */, AMDGPU::V_INTERP_P1LL_F16_vi, ConvertCustom_cvtVOP3Interp, AMFBS_isNotGFX90APlus_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_InterpAttr, MCK_InterpAttrChan, MCK_High, MCK_Clamp, MCK_OModSI }, },
  { 38861 /* v_interp_p1lv_f16 */, AMDGPU::V_INTERP_P1LV_F16_gfx10, ConvertCustom_cvtVOP3Interp, AMFBS_isNotGFX90APlus_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_InterpAttr, MCK_InterpAttrChan, MCK_VRegWithFPInputMods, MCK_High, MCK_Clamp, MCK_OModSI }, },
  { 38861 /* v_interp_p1lv_f16 */, AMDGPU::V_INTERP_P1LV_F16_vi, ConvertCustom_cvtVOP3Interp, AMFBS_isNotGFX90APlus_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_InterpAttr, MCK_InterpAttrChan, MCK_VRegWithFPInputMods, MCK_High, MCK_Clamp, MCK_OModSI }, },
  { 38879 /* v_interp_p2_f16 */, AMDGPU::V_INTERP_P2_F16_gfx10, ConvertCustom_cvtVOP3Interp, AMFBS_isNotGFX90APlus_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_InterpAttr, MCK_InterpAttrChan, MCK_VRegWithFPInputMods, MCK_High, MCK_Clamp }, },
  { 38879 /* v_interp_p2_f16 */, AMDGPU::V_INTERP_P2_F16_vi, ConvertCustom_cvtVOP3Interp, AMFBS_isNotGFX90APlus_Has16BitInsts_isGFX8Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_InterpAttr, MCK_InterpAttrChan, MCK_VRegWithFPInputMods, MCK_High, MCK_Clamp }, },
  { 38879 /* v_interp_p2_f16 */, AMDGPU::V_INTERP_P2_F16_opsel_gfx9, ConvertCustom_cvtVOP3Interp, AMFBS_isNotGFX90APlus_isGFX9Plus_isGFX9Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_InterpAttr, MCK_InterpAttrChan, MCK_VRegWithFPInputMods, MCK_High, MCK_Clamp, MCK_OpSel }, },
  { 38895 /* v_interp_p2_f16_f32 */, AMDGPU::V_INTERP_P2_F16_F32_inreg_fake16_gfx11, ConvertCustom_cvtVINTERP, AMFBS_HasVINTERPEncoding_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OpSel, MCK_WaitEXP }, },
  { 38895 /* v_interp_p2_f16_f32 */, AMDGPU::V_INTERP_P2_F16_F32_inreg_fake16_gfx12, ConvertCustom_cvtVINTERP, AMFBS_HasVINTERPEncoding_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OpSel, MCK_WaitEXP }, },
  { 38895 /* v_interp_p2_f16_f32 */, AMDGPU::V_INTERP_P2_F16_F32_inreg_t16_gfx11, ConvertCustom_cvtVINTERP, AMFBS_HasVINTERPEncoding_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OpSel, MCK_WaitEXP }, },
  { 38895 /* v_interp_p2_f16_f32 */, AMDGPU::V_INTERP_P2_F16_F32_inreg_t16_gfx12, ConvertCustom_cvtVINTERP, AMFBS_HasVINTERPEncoding_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OpSel, MCK_WaitEXP }, },
  { 38915 /* v_interp_p2_f32 */, AMDGPU::V_INTERP_P2_F32_inreg_gfx11, ConvertCustom_cvtVINTERP, AMFBS_HasVINTERPEncoding_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_WaitEXP }, },
  { 38915 /* v_interp_p2_f32 */, AMDGPU::V_INTERP_P2_F32_inreg_gfx12, ConvertCustom_cvtVINTERP, AMFBS_HasVINTERPEncoding_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_WaitEXP }, },
  { 38915 /* v_interp_p2_f32 */, AMDGPU::V_INTERP_P2_F32_e64_gfx10, ConvertCustom_cvtVOP3Interp, AMFBS_isNotGFX90APlus_isGFX8Plus_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_InterpAttr, MCK_InterpAttrChan, MCK_Clamp, MCK_OModSI }, },
  { 38915 /* v_interp_p2_f32 */, AMDGPU::V_INTERP_P2_F32_e64_vi, ConvertCustom_cvtVOP3Interp, AMFBS_isNotGFX90APlus_isGFX8Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_InterpAttr, MCK_InterpAttrChan, MCK_Clamp, MCK_OModSI }, },
  { 38931 /* v_interp_p2_legacy_f16 */, AMDGPU::V_INTERP_P2_LEGACY_F16_gfx9, ConvertCustom_cvtVOP3Interp, AMFBS_isNotGFX90APlus_Has16BitInsts_isGFX9Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_InterpAttr, MCK_InterpAttrChan, MCK_VRegWithFPInputMods, MCK_High, MCK_Clamp }, },
  { 38954 /* v_interp_p2_rtz_f16_f32 */, AMDGPU::V_INTERP_P2_RTZ_F16_F32_inreg_fake16_gfx11, ConvertCustom_cvtVINTERP, AMFBS_HasVINTERPEncoding_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OpSel, MCK_WaitEXP }, },
  { 38954 /* v_interp_p2_rtz_f16_f32 */, AMDGPU::V_INTERP_P2_RTZ_F16_F32_inreg_fake16_gfx12, ConvertCustom_cvtVINTERP, AMFBS_HasVINTERPEncoding_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OpSel, MCK_WaitEXP }, },
  { 38954 /* v_interp_p2_rtz_f16_f32 */, AMDGPU::V_INTERP_P2_RTZ_F16_F32_inreg_t16_gfx11, ConvertCustom_cvtVINTERP, AMFBS_HasVINTERPEncoding_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OpSel, MCK_WaitEXP }, },
  { 38954 /* v_interp_p2_rtz_f16_f32 */, AMDGPU::V_INTERP_P2_RTZ_F16_F32_inreg_t16_gfx12, ConvertCustom_cvtVINTERP, AMFBS_HasVINTERPEncoding_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OpSel, MCK_WaitEXP }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_VSrc_f16, MCK_Clamp, MCK_OModSI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_VSrc_f16, MCK_Clamp, MCK_OModSI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithInt32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithInt32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithIntT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithIntT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 38990 /* v_ldexp_f32 */, AMDGPU::V_LDEXP_F32_e64_vi, Convert__Reg1_0__imm_95_0__VCSrc_f321_1__imm_95_0__VCSrc_f321_2__imm_95_0__imm_95_0, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VCSrc_f32, MCK_VCSrc_f32 }, },
  { 38990 /* v_ldexp_f32 */, AMDGPU::V_LDEXP_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 38990 /* v_ldexp_f32 */, AMDGPU::V_LDEXP_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 38990 /* v_ldexp_f32 */, AMDGPU::V_LDEXP_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 38990 /* v_ldexp_f32 */, AMDGPU::V_LDEXP_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 38990 /* v_ldexp_f32 */, AMDGPU::V_LDEXP_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 39002 /* v_ldexp_f64 */, AMDGPU::V_LDEXP_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 39002 /* v_ldexp_f64 */, AMDGPU::V_LDEXP_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Not12_50, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 39002 /* v_ldexp_f64 */, AMDGPU::V_LDEXP_F64_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 39002 /* v_ldexp_f64 */, AMDGPU::V_LDEXP_F64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 39002 /* v_ldexp_f64 */, AMDGPU::V_LDEXP_F64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 39002 /* v_ldexp_f64 */, AMDGPU::V_LDEXP_F64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 39014 /* v_lerp_u8 */, AMDGPU::V_LERP_U8_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_HasLerpInst_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39014 /* v_lerp_u8 */, AMDGPU::V_LERP_U8_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_HasLerpInst_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39014 /* v_lerp_u8 */, AMDGPU::V_LERP_U8_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_HasLerpInst_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39014 /* v_lerp_u8 */, AMDGPU::V_LERP_U8_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_HasLerpInst_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39014 /* v_lerp_u8 */, AMDGPU::V_LERP_U8_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_HasLerpInst_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39024 /* v_log_bf16 */, AMDGPU::V_LOG_BF16V_LOG_BF16_fake16_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods }, },
  { 39024 /* v_log_bf16 */, AMDGPU::V_LOG_BF16V_LOG_BF16_t16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel }, },
  { 39035 /* v_log_clamp_f32 */, AMDGPU::V_LOG_CLAMP_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39071 /* v_log_legacy_f32 */, AMDGPU::V_LOG_LEGACY_F32_e64_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX7GFX8GFX9_isGFX7Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39071 /* v_log_legacy_f32 */, AMDGPU::V_LOG_LEGACY_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX7GFX8GFX9_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39088 /* v_lshl_add_u32 */, AMDGPU::V_LSHL_ADD_U32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39088 /* v_lshl_add_u32 */, AMDGPU::V_LSHL_ADD_U32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39088 /* v_lshl_add_u32 */, AMDGPU::V_LSHL_ADD_U32_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39088 /* v_lshl_add_u32 */, AMDGPU::V_LSHL_ADD_U32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39103 /* v_lshl_add_u64 */, AMDGPU::V_LSHL_ADD_U64_e64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1__VSrc_b321_2__VSrc_b641_3, AMFBS_HasLshlAddU64Inst_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b32, MCK_VSrc_b64 }, },
  { 39103 /* v_lshl_add_u64 */, AMDGPU::V_LSHL_ADD_U64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1__VSrc_b321_2__VSrc_b641_3, AMFBS_HasLshlAddU64Inst_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b32, MCK_VSrc_b64 }, },
  { 39118 /* v_lshl_b32 */, AMDGPU::V_LSHL_B32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39129 /* v_lshl_b64 */, AMDGPU::V_LSHL_B64_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b32 }, },
  { 39140 /* v_lshl_or_b32 */, AMDGPU::V_LSHL_OR_B32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39140 /* v_lshl_or_b32 */, AMDGPU::V_LSHL_OR_B32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39140 /* v_lshl_or_b32 */, AMDGPU::V_LSHL_OR_B32_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39140 /* v_lshl_or_b32 */, AMDGPU::V_LSHL_OR_B32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39154 /* v_lshlrev_b16 */, AMDGPU::V_LSHLREV_B16_e64_vi, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 39154 /* v_lshlrev_b16 */, AMDGPU::V_LSHLREV_B16_fake16_e64_gfx11, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 39154 /* v_lshlrev_b16 */, AMDGPU::V_LSHLREV_B16_fake16_e64_gfx12, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 39154 /* v_lshlrev_b16 */, AMDGPU::V_LSHLREV_B16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 39154 /* v_lshlrev_b16 */, AMDGPU::V_LSHLREV_B16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 39154 /* v_lshlrev_b16 */, AMDGPU::V_LSHLREV_B16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_e64_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39182 /* v_lshlrev_b64 */, AMDGPU::V_LSHLREV_B64_e64_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1__VSrc_b641_2, AMFBS_isGFX8GFX9GFX10GFX11_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_VSrc_b64 }, },
  { 39182 /* v_lshlrev_b64 */, AMDGPU::V_LSHLREV_B64_e64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1__VSrc_b641_2, AMFBS_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_VSrc_b64 }, },
  { 39182 /* v_lshlrev_b64 */, AMDGPU::V_LSHLREV_B64_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1__VSrc_b641_2, AMFBS_isGFX8GFX9GFX10GFX11_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_VSrc_b64 }, },
  { 39182 /* v_lshlrev_b64 */, AMDGPU::V_LSHLREV_B64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1__VSrc_b641_2, AMFBS_isGFX8GFX9GFX10GFX11_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_VSrc_b64 }, },
  { 39196 /* v_lshr_b32 */, AMDGPU::V_LSHR_B32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39207 /* v_lshr_b64 */, AMDGPU::V_LSHR_B64_gfx6_gfx7, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b32 }, },
  { 39218 /* v_lshrrev_b16 */, AMDGPU::V_LSHRREV_B16_e64_vi, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 39218 /* v_lshrrev_b16 */, AMDGPU::V_LSHRREV_B16_fake16_e64_gfx11, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 39218 /* v_lshrrev_b16 */, AMDGPU::V_LSHRREV_B16_fake16_e64_gfx12, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 39218 /* v_lshrrev_b16 */, AMDGPU::V_LSHRREV_B16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 39218 /* v_lshrrev_b16 */, AMDGPU::V_LSHRREV_B16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 39218 /* v_lshrrev_b16 */, AMDGPU::V_LSHRREV_B16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_e64_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39246 /* v_lshrrev_b64 */, AMDGPU::V_LSHRREV_B64_e64_gfx11, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1__VSrc_b641_2, AMFBS_isGFX8Plus_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_VSrc_b64 }, },
  { 39246 /* v_lshrrev_b64 */, AMDGPU::V_LSHRREV_B64_e64_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1__VSrc_b641_2, AMFBS_isGFX8Plus_isGFX12Not12_50, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_VSrc_b64 }, },
  { 39246 /* v_lshrrev_b64 */, AMDGPU::V_LSHRREV_B64_e64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1__VSrc_b641_2, AMFBS_isGFX8Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_VSrc_b64 }, },
  { 39246 /* v_lshrrev_b64 */, AMDGPU::V_LSHRREV_B64_gfx10, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1__VSrc_b641_2, AMFBS_isGFX8Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_VSrc_b64 }, },
  { 39246 /* v_lshrrev_b64 */, AMDGPU::V_LSHRREV_B64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1__VSrc_b641_2, AMFBS_isGFX8Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_VSrc_b64 }, },
  { 39260 /* v_mac_f16 */, AMDGPU::V_MAC_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39270 /* v_mac_f32 */, AMDGPU::V_MAC_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasMadMacF32Insts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39270 /* v_mac_f32 */, AMDGPU::V_MAC_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_HasMadMacF32Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39270 /* v_mac_f32 */, AMDGPU::V_MAC_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_HasMadMacF32Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39280 /* v_mac_legacy_f32 */, AMDGPU::V_MAC_LEGACY_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasMadMacF32Insts_isGFX6GFX7GFX10_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39280 /* v_mac_legacy_f32 */, AMDGPU::V_MAC_LEGACY_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_HasMadMacF32Insts_isGFX6GFX7GFX10_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39297 /* v_mad_co_i64_i32 */, AMDGPU::V_MAD_CO_I64_I32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b64, MCK_Clamp }, },
  { 39314 /* v_mad_co_u64_u32 */, AMDGPU::V_MAD_CO_U64_U32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b64, MCK_Clamp }, },
  { 39331 /* v_mad_f16 */, AMDGPU::V_MAD_F16_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39331 /* v_mad_f16 */, AMDGPU::V_MAD_F16_gfx9_gfx9, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 39341 /* v_mad_f32 */, AMDGPU::V_MAD_F32_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasMadMacF32Insts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39341 /* v_mad_f32 */, AMDGPU::V_MAD_F32_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_HasMadMacF32Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39341 /* v_mad_f32 */, AMDGPU::V_MAD_F32_vi, ConvertCustom_cvtVOP3, AMFBS_HasMadMacF32Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39351 /* v_mad_i16 */, AMDGPU::V_MAD_I16_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_Clamp }, },
  { 39351 /* v_mad_i16 */, AMDGPU::V_MAD_I16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 39351 /* v_mad_i16 */, AMDGPU::V_MAD_I16_gfx9_gfx9, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX9Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 39351 /* v_mad_i16 */, AMDGPU::V_MAD_I16V_MAD_I16_gfx9_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 39351 /* v_mad_i16 */, AMDGPU::V_MAD_I16V_MAD_I16_gfx9_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 39351 /* v_mad_i16 */, AMDGPU::V_MAD_I16V_MAD_I16_gfx9_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 39351 /* v_mad_i16 */, AMDGPU::V_MAD_I16V_MAD_I16_gfx9_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 39361 /* v_mad_i32_i16 */, AMDGPU::V_MAD_I32_I16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b32, MCK_OpSel, MCK_Clamp }, },
  { 39361 /* v_mad_i32_i16 */, AMDGPU::V_MAD_I32_I16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b32, MCK_OpSel, MCK_Clamp }, },
  { 39361 /* v_mad_i32_i16 */, AMDGPU::V_MAD_I32_I16V_MAD_I32_I16_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b32, MCK_OpSel, MCK_Clamp }, },
  { 39361 /* v_mad_i32_i16 */, AMDGPU::V_MAD_I32_I16V_MAD_I32_I16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b32, MCK_OpSel, MCK_Clamp }, },
  { 39361 /* v_mad_i32_i16 */, AMDGPU::V_MAD_I32_I16V_MAD_I32_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_VSrc_b32, MCK_OpSel, MCK_Clamp }, },
  { 39361 /* v_mad_i32_i16 */, AMDGPU::V_MAD_I32_I16V_MAD_I32_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_VSrc_b32, MCK_OpSel, MCK_Clamp }, },
  { 39375 /* v_mad_i32_i24 */, AMDGPU::V_MAD_I32_I24_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 39375 /* v_mad_i32_i24 */, AMDGPU::V_MAD_I32_I24_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 39375 /* v_mad_i32_i24 */, AMDGPU::V_MAD_I32_I24_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 39375 /* v_mad_i32_i24 */, AMDGPU::V_MAD_I32_I24_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 39375 /* v_mad_i32_i24 */, AMDGPU::V_MAD_I32_I24_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 39389 /* v_mad_i64_i32 */, AMDGPU::V_MAD_I64_I32_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b64, MCK_Clamp }, },
  { 39389 /* v_mad_i64_i32 */, AMDGPU::V_MAD_I64_I32_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b64, MCK_Clamp }, },
  { 39389 /* v_mad_i64_i32 */, AMDGPU::V_MAD_I64_I32_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b64, MCK_Clamp }, },
  { 39389 /* v_mad_i64_i32 */, AMDGPU::V_MAD_I64_I32_gfx11_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b64, MCK_Clamp }, },
  { 39403 /* v_mad_legacy_f16 */, AMDGPU::V_MAD_LEGACY_F16_gfx9, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX9Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39420 /* v_mad_legacy_f32 */, AMDGPU::V_MAD_LEGACY_F32_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasMadMacF32Insts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39420 /* v_mad_legacy_f32 */, AMDGPU::V_MAD_LEGACY_F32_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_HasMadMacF32Insts_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39420 /* v_mad_legacy_f32 */, AMDGPU::V_MAD_LEGACY_F32_vi, ConvertCustom_cvtVOP3, AMFBS_HasMadMacF32Insts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39437 /* v_mad_legacy_i16 */, AMDGPU::V_MAD_LEGACY_I16_gfx9, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX9Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_Clamp }, },
  { 39454 /* v_mad_legacy_u16 */, AMDGPU::V_MAD_LEGACY_U16_gfx9, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX9Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_Clamp }, },
  { 39471 /* v_mad_mix_f32 */, AMDGPU::V_MAD_MIX_F32_vi, ConvertCustom_cvtVOP3P, AMFBS_HasMadMixInsts_HasVOP3PInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 39485 /* v_mad_mixhi_f16 */, AMDGPU::V_MAD_MIXHI_F16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasMadMixInsts_HasVOP3PInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 39501 /* v_mad_mixlo_f16 */, AMDGPU::V_MAD_MIXLO_F16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasMadMixInsts_HasVOP3PInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 39517 /* v_mad_nc_i64_i32 */, AMDGPU::V_MAD_NC_I64_I32_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b64, MCK_Clamp }, },
  { 39534 /* v_mad_nc_u64_u32 */, AMDGPU::V_MAD_NC_U64_U32_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b64, MCK_Clamp }, },
  { 39551 /* v_mad_u16 */, AMDGPU::V_MAD_U16_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_Clamp }, },
  { 39551 /* v_mad_u16 */, AMDGPU::V_MAD_U16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 39551 /* v_mad_u16 */, AMDGPU::V_MAD_U16_gfx9_gfx9, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX9Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 39551 /* v_mad_u16 */, AMDGPU::V_MAD_U16V_MAD_U16_gfx9_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 39551 /* v_mad_u16 */, AMDGPU::V_MAD_U16V_MAD_U16_gfx9_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 39551 /* v_mad_u16 */, AMDGPU::V_MAD_U16V_MAD_U16_gfx9_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 39551 /* v_mad_u16 */, AMDGPU::V_MAD_U16V_MAD_U16_gfx9_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 39561 /* v_mad_u32 */, AMDGPU::V_MAD_U32_e64_gfx1250, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_HasMadU32Inst_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39571 /* v_mad_u32_u16 */, AMDGPU::V_MAD_U32_U16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b32, MCK_OpSel, MCK_Clamp }, },
  { 39571 /* v_mad_u32_u16 */, AMDGPU::V_MAD_U32_U16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b32, MCK_OpSel, MCK_Clamp }, },
  { 39571 /* v_mad_u32_u16 */, AMDGPU::V_MAD_U32_U16V_MAD_U32_U16_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b32, MCK_OpSel, MCK_Clamp }, },
  { 39571 /* v_mad_u32_u16 */, AMDGPU::V_MAD_U32_U16V_MAD_U32_U16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b32, MCK_OpSel, MCK_Clamp }, },
  { 39571 /* v_mad_u32_u16 */, AMDGPU::V_MAD_U32_U16V_MAD_U32_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_VSrc_b32, MCK_OpSel, MCK_Clamp }, },
  { 39571 /* v_mad_u32_u16 */, AMDGPU::V_MAD_U32_U16V_MAD_U32_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_VSrc_b32, MCK_OpSel, MCK_Clamp }, },
  { 39585 /* v_mad_u32_u24 */, AMDGPU::V_MAD_U32_U24_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 39585 /* v_mad_u32_u24 */, AMDGPU::V_MAD_U32_U24_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 39585 /* v_mad_u32_u24 */, AMDGPU::V_MAD_U32_U24_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 39585 /* v_mad_u32_u24 */, AMDGPU::V_MAD_U32_U24_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 39585 /* v_mad_u32_u24 */, AMDGPU::V_MAD_U32_U24_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 39599 /* v_mad_u64_u32 */, AMDGPU::V_MAD_U64_U32_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b64, MCK_Clamp }, },
  { 39599 /* v_mad_u64_u32 */, AMDGPU::V_MAD_U64_U32_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b64, MCK_Clamp }, },
  { 39599 /* v_mad_u64_u32 */, AMDGPU::V_MAD_U64_U32_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b64, MCK_Clamp }, },
  { 39599 /* v_mad_u64_u32 */, AMDGPU::V_MAD_U64_U32_gfx11_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b64, MCK_Clamp }, },
  { 39661 /* v_max3_f16 */, AMDGPU::V_MAX3_F16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 39661 /* v_max3_f16 */, AMDGPU::V_MAX3_F16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 39661 /* v_max3_f16 */, AMDGPU::V_MAX3_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 39661 /* v_max3_f16 */, AMDGPU::V_MAX3_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 39672 /* v_max3_f32 */, AMDGPU::V_MAX3_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39672 /* v_max3_f32 */, AMDGPU::V_MAX3_F32_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39672 /* v_max3_f32 */, AMDGPU::V_MAX3_F32_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39672 /* v_max3_f32 */, AMDGPU::V_MAX3_F32_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39683 /* v_max3_i16 */, AMDGPU::V_MAX3_I16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 39683 /* v_max3_i16 */, AMDGPU::V_MAX3_I16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 39683 /* v_max3_i16 */, AMDGPU::V_MAX3_I16_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 39683 /* v_max3_i16 */, AMDGPU::V_MAX3_I16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 39683 /* v_max3_i16 */, AMDGPU::V_MAX3_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 39683 /* v_max3_i16 */, AMDGPU::V_MAX3_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 39694 /* v_max3_i32 */, AMDGPU::V_MAX3_I32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39694 /* v_max3_i32 */, AMDGPU::V_MAX3_I32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39694 /* v_max3_i32 */, AMDGPU::V_MAX3_I32_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39694 /* v_max3_i32 */, AMDGPU::V_MAX3_I32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39694 /* v_max3_i32 */, AMDGPU::V_MAX3_I32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39705 /* v_max3_num_f16 */, AMDGPU::V_MAX3_NUM_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 39705 /* v_max3_num_f16 */, AMDGPU::V_MAX3_NUM_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 39720 /* v_max3_num_f32 */, AMDGPU::V_MAX3_NUM_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39735 /* v_max3_u16 */, AMDGPU::V_MAX3_U16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 39735 /* v_max3_u16 */, AMDGPU::V_MAX3_U16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 39735 /* v_max3_u16 */, AMDGPU::V_MAX3_U16_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 39735 /* v_max3_u16 */, AMDGPU::V_MAX3_U16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 39735 /* v_max3_u16 */, AMDGPU::V_MAX3_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 39735 /* v_max3_u16 */, AMDGPU::V_MAX3_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 39746 /* v_max3_u32 */, AMDGPU::V_MAX3_U32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39746 /* v_max3_u32 */, AMDGPU::V_MAX3_U32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39746 /* v_max3_u32 */, AMDGPU::V_MAX3_U32_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39746 /* v_max3_u32 */, AMDGPU::V_MAX3_U32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39746 /* v_max3_u32 */, AMDGPU::V_MAX3_U32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39757 /* v_max_f16 */, AMDGPU::V_MAX_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39757 /* v_max_f16 */, AMDGPU::V_MAX_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39757 /* v_max_f16 */, AMDGPU::V_MAX_F16V_MAX_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39757 /* v_max_f16 */, AMDGPU::V_MAX_F16V_MAX_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 39767 /* v_max_f32 */, AMDGPU::V_MAX_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39767 /* v_max_f32 */, AMDGPU::V_MAX_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39767 /* v_max_f32 */, AMDGPU::V_MAX_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39767 /* v_max_f32 */, AMDGPU::V_MAX_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39777 /* v_max_f64 */, AMDGPU::V_MAX_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isNotGFX12Plus_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39777 /* v_max_f64 */, AMDGPU::V_MAX_F64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isNotGFX12Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39777 /* v_max_f64 */, AMDGPU::V_MAX_F64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isNotGFX12Plus_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39777 /* v_max_f64 */, AMDGPU::V_MAX_F64_vi, ConvertCustom_cvtVOP3, AMFBS_isNotGFX12Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39787 /* v_max_i16 */, AMDGPU::V_MAX_I16_e64_vi, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 39787 /* v_max_i16 */, AMDGPU::V_MAX_I16_fake16_e64_gfx11, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 39787 /* v_max_i16 */, AMDGPU::V_MAX_I16_fake16_e64_gfx12, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 39787 /* v_max_i16 */, AMDGPU::V_MAX_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 39787 /* v_max_i16 */, AMDGPU::V_MAX_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 39787 /* v_max_i16 */, AMDGPU::V_MAX_I16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_e64_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39807 /* v_max_i64 */, AMDGPU::V_MAX_I64_e64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 39817 /* v_max_legacy_f32 */, AMDGPU::V_MAX_LEGACY_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39834 /* v_max_num_f16 */, AMDGPU::V_MAX_NUM_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39834 /* v_max_num_f16 */, AMDGPU::V_MAX_NUM_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 39848 /* v_max_num_f32 */, AMDGPU::V_MAX_NUM_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39862 /* v_max_num_f64 */, AMDGPU::V_MAX_NUM_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39876 /* v_max_u16 */, AMDGPU::V_MAX_U16_e64_vi, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 39876 /* v_max_u16 */, AMDGPU::V_MAX_U16_fake16_e64_gfx11, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 39876 /* v_max_u16 */, AMDGPU::V_MAX_U16_fake16_e64_gfx12, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 39876 /* v_max_u16 */, AMDGPU::V_MAX_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 39876 /* v_max_u16 */, AMDGPU::V_MAX_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 39876 /* v_max_u16 */, AMDGPU::V_MAX_U16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_e64_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 39896 /* v_max_u64 */, AMDGPU::V_MAX_U64_e64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 39906 /* v_maximum3_f16 */, AMDGPU::V_MAXIMUM3_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasMinimum3Maximum3F16_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 39906 /* v_maximum3_f16 */, AMDGPU::V_MAXIMUM3_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasMinimum3Maximum3F16_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 39921 /* v_maximum3_f32 */, AMDGPU::V_MAXIMUM3_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasMinimum3Maximum3F32_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39921 /* v_maximum3_f32 */, AMDGPU::V_MAXIMUM3_F32_vi, ConvertCustom_cvtVOP3, AMFBS_HasMinimum3Maximum3F32_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39936 /* v_maximum_f16 */, AMDGPU::V_MAXIMUM_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 39936 /* v_maximum_f16 */, AMDGPU::V_MAXIMUM_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 39950 /* v_maximum_f32 */, AMDGPU::V_MAXIMUM_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39964 /* v_maximum_f64 */, AMDGPU::V_MAXIMUM_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasIEEEMinimumMaximumInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39964 /* v_maximum_f64 */, AMDGPU::V_MAXIMUM_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 39978 /* v_maximumminimum_f16 */, AMDGPU::V_MAXIMUMMINIMUM_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 39978 /* v_maximumminimum_f16 */, AMDGPU::V_MAXIMUMMINIMUM_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 39999 /* v_maximumminimum_f32 */, AMDGPU::V_MAXIMUMMINIMUM_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 40020 /* v_maxmin_f16 */, AMDGPU::V_MAXMIN_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 40020 /* v_maxmin_f16 */, AMDGPU::V_MAXMIN_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX11Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 40033 /* v_maxmin_f32 */, AMDGPU::V_MAXMIN_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 40046 /* v_maxmin_i32 */, AMDGPU::V_MAXMIN_I32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40046 /* v_maxmin_i32 */, AMDGPU::V_MAXMIN_I32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40059 /* v_maxmin_num_f16 */, AMDGPU::V_MAXMIN_NUM_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 40059 /* v_maxmin_num_f16 */, AMDGPU::V_MAXMIN_NUM_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX11Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 40076 /* v_maxmin_num_f32 */, AMDGPU::V_MAXMIN_NUM_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 40093 /* v_maxmin_u32 */, AMDGPU::V_MAXMIN_U32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40093 /* v_maxmin_u32 */, AMDGPU::V_MAXMIN_U32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40106 /* v_mbcnt_hi_u32_b32 */, AMDGPU::V_MBCNT_HI_U32_B32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40106 /* v_mbcnt_hi_u32_b32 */, AMDGPU::V_MBCNT_HI_U32_B32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40106 /* v_mbcnt_hi_u32_b32 */, AMDGPU::V_MBCNT_HI_U32_B32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40106 /* v_mbcnt_hi_u32_b32 */, AMDGPU::V_MBCNT_HI_U32_B32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40106 /* v_mbcnt_hi_u32_b32 */, AMDGPU::V_MBCNT_HI_U32_B32_e64_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40125 /* v_mbcnt_lo_u32_b32 */, AMDGPU::V_MBCNT_LO_U32_B32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40125 /* v_mbcnt_lo_u32_b32 */, AMDGPU::V_MBCNT_LO_U32_B32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40125 /* v_mbcnt_lo_u32_b32 */, AMDGPU::V_MBCNT_LO_U32_B32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40125 /* v_mbcnt_lo_u32_b32 */, AMDGPU::V_MBCNT_LO_U32_B32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40125 /* v_mbcnt_lo_u32_b32 */, AMDGPU::V_MBCNT_LO_U32_B32_e64_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40144 /* v_med3_f16 */, AMDGPU::V_MED3_F16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 40144 /* v_med3_f16 */, AMDGPU::V_MED3_F16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 40144 /* v_med3_f16 */, AMDGPU::V_MED3_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 40144 /* v_med3_f16 */, AMDGPU::V_MED3_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 40155 /* v_med3_f32 */, AMDGPU::V_MED3_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 40155 /* v_med3_f32 */, AMDGPU::V_MED3_F32_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 40155 /* v_med3_f32 */, AMDGPU::V_MED3_F32_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 40155 /* v_med3_f32 */, AMDGPU::V_MED3_F32_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 40166 /* v_med3_i16 */, AMDGPU::V_MED3_I16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 40166 /* v_med3_i16 */, AMDGPU::V_MED3_I16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 40166 /* v_med3_i16 */, AMDGPU::V_MED3_I16_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 40166 /* v_med3_i16 */, AMDGPU::V_MED3_I16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 40166 /* v_med3_i16 */, AMDGPU::V_MED3_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 40166 /* v_med3_i16 */, AMDGPU::V_MED3_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 40177 /* v_med3_i32 */, AMDGPU::V_MED3_I32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40177 /* v_med3_i32 */, AMDGPU::V_MED3_I32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40177 /* v_med3_i32 */, AMDGPU::V_MED3_I32_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40177 /* v_med3_i32 */, AMDGPU::V_MED3_I32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40177 /* v_med3_i32 */, AMDGPU::V_MED3_I32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40188 /* v_med3_num_f16 */, AMDGPU::V_MED3_NUM_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 40188 /* v_med3_num_f16 */, AMDGPU::V_MED3_NUM_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 40203 /* v_med3_num_f32 */, AMDGPU::V_MED3_NUM_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 40218 /* v_med3_u16 */, AMDGPU::V_MED3_U16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 40218 /* v_med3_u16 */, AMDGPU::V_MED3_U16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 40218 /* v_med3_u16 */, AMDGPU::V_MED3_U16V_MED3_U16_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 40218 /* v_med3_u16 */, AMDGPU::V_MED3_U16V_MED3_U16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 40218 /* v_med3_u16 */, AMDGPU::V_MED3_U16V_MED3_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 40218 /* v_med3_u16 */, AMDGPU::V_MED3_U16V_MED3_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 40229 /* v_med3_u32 */, AMDGPU::V_MED3_U32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40229 /* v_med3_u32 */, AMDGPU::V_MED3_U32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40229 /* v_med3_u32 */, AMDGPU::V_MED3_U32_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40229 /* v_med3_u32 */, AMDGPU::V_MED3_U32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40229 /* v_med3_u32 */, AMDGPU::V_MED3_U32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 40240 /* v_mfma_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_F32_16X16X128_F8F6F4_f4_f4_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_BLGP }, },
  { 40240 /* v_mfma_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_F32_16X16X128_F8F6F4_f4_f6_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_BLGP }, },
  { 40240 /* v_mfma_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_F32_16X16X128_F8F6F4_f4_f8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_BLGP }, },
  { 40240 /* v_mfma_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_F32_16X16X128_F8F6F4_f6_f4_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_BLGP }, },
  { 40240 /* v_mfma_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_F32_16X16X128_F8F6F4_f6_f6_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_BLGP }, },
  { 40240 /* v_mfma_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_F32_16X16X128_F8F6F4_f6_f8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_BLGP }, },
  { 40240 /* v_mfma_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_F32_16X16X128_F8F6F4_f8_f4_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_BLGP }, },
  { 40240 /* v_mfma_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_F32_16X16X128_F8F6F4_f8_f6_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_BLGP }, },
  { 40240 /* v_mfma_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_F32_16X16X128_F8F6F4_f8_f8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__BLGP1_5, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_BLGP }, },
  { 40240 /* v_mfma_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_F32_16X16X128_F8F6F4_f4_f4_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5, AMFBS_isGFX90APlus_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_BLGP }, },
  { 40240 /* v_mfma_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_F32_16X16X128_F8F6F4_f4_f6_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5, AMFBS_isGFX90APlus_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_BLGP }, },
  { 40240 /* v_mfma_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_F32_16X16X128_F8F6F4_f4_f8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5, AMFBS_isGFX90APlus_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_BLGP }, },
  { 40240 /* v_mfma_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_F32_16X16X128_F8F6F4_f6_f4_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5, AMFBS_isGFX90APlus_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_BLGP }, },
  { 40240 /* v_mfma_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_F32_16X16X128_F8F6F4_f6_f6_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5, AMFBS_isGFX90APlus_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_BLGP }, },
  { 40240 /* v_mfma_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_F32_16X16X128_F8F6F4_f6_f8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5, AMFBS_isGFX90APlus_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_BLGP }, },
  { 40240 /* v_mfma_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_F32_16X16X128_F8F6F4_f8_f4_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5, AMFBS_isGFX90APlus_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_BLGP }, },
  { 40240 /* v_mfma_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_F32_16X16X128_F8F6F4_f8_f6_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5, AMFBS_isGFX90APlus_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_BLGP }, },
  { 40240 /* v_mfma_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_F32_16X16X128_F8F6F4_f8_f8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__BLGP1_5, AMFBS_isGFX90APlus_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_BLGP }, },
  { 40268 /* v_mfma_f32_16x16x16_bf16 */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40268 /* v_mfma_f32_16x16x16_bf16 */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40293 /* v_mfma_f32_16x16x16_f16 */, AMDGPU::V_MFMA_F32_16X16X16F16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40293 /* v_mfma_f32_16x16x16_f16 */, AMDGPU::V_MFMA_F32_16X16X16F16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40317 /* v_mfma_f32_16x16x16bf16 */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40317 /* v_mfma_f32_16x16x16bf16 */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40341 /* v_mfma_f32_16x16x16bf16_1k */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40341 /* v_mfma_f32_16x16x16bf16_1k */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx90a_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40341 /* v_mfma_f32_16x16x16bf16_1k */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx90a_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40341 /* v_mfma_f32_16x16x16bf16_1k */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40368 /* v_mfma_f32_16x16x16f16 */, AMDGPU::V_MFMA_F32_16X16X16F16_vi, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX8GFX9NotGFX90A_HasMAIInsts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40368 /* v_mfma_f32_16x16x16f16 */, AMDGPU::V_MFMA_F32_16X16X16F16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40368 /* v_mfma_f32_16x16x16f16 */, AMDGPU::V_MFMA_F32_16X16X16F16_gfx90a_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40368 /* v_mfma_f32_16x16x16f16 */, AMDGPU::V_MFMA_F32_16X16X16F16_gfx90a_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40368 /* v_mfma_f32_16x16x16f16 */, AMDGPU::V_MFMA_F32_16X16X16F16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40391 /* v_mfma_f32_16x16x1_4b_f32 */, AMDGPU::V_MFMA_F32_16X16X1F32_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40391 /* v_mfma_f32_16x16x1_4b_f32 */, AMDGPU::V_MFMA_F32_16X16X1F32_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40417 /* v_mfma_f32_16x16x1f32 */, AMDGPU::V_MFMA_F32_16X16X1F32_vi, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX8GFX9NotGFX90A_HasMAIInsts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40417 /* v_mfma_f32_16x16x1f32 */, AMDGPU::V_MFMA_F32_16X16X1F32_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40417 /* v_mfma_f32_16x16x1f32 */, AMDGPU::V_MFMA_F32_16X16X1F32_gfx90a_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40417 /* v_mfma_f32_16x16x1f32 */, AMDGPU::V_MFMA_F32_16X16X1F32_gfx90a_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40417 /* v_mfma_f32_16x16x1f32 */, AMDGPU::V_MFMA_F32_16X16X1F32_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40439 /* v_mfma_f32_16x16x2bf16 */, AMDGPU::V_MFMA_F32_16X16X2BF16_vi, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX8GFX9NotGFX90A_HasMAIInsts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40439 /* v_mfma_f32_16x16x2bf16 */, AMDGPU::V_MFMA_F32_16X16X2BF16_gfx90a_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40439 /* v_mfma_f32_16x16x2bf16 */, AMDGPU::V_MFMA_F32_16X16X2BF16_gfx90a_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40462 /* v_mfma_f32_16x16x32_bf16 */, AMDGPU::V_MFMA_F32_16X16X32_BF16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40462 /* v_mfma_f32_16x16x32_bf16 */, AMDGPU::V_MFMA_F32_16X16X32_BF16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40487 /* v_mfma_f32_16x16x32_bf8_bf8 */, AMDGPU::V_MFMA_F32_16X16X32_BF8_BF8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasFP8Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40487 /* v_mfma_f32_16x16x32_bf8_bf8 */, AMDGPU::V_MFMA_F32_16X16X32_BF8_BF8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasFP8Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40515 /* v_mfma_f32_16x16x32_bf8_fp8 */, AMDGPU::V_MFMA_F32_16X16X32_BF8_FP8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasFP8Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40515 /* v_mfma_f32_16x16x32_bf8_fp8 */, AMDGPU::V_MFMA_F32_16X16X32_BF8_FP8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasFP8Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40543 /* v_mfma_f32_16x16x32_f16 */, AMDGPU::V_MFMA_F32_16X16X32_F16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40543 /* v_mfma_f32_16x16x32_f16 */, AMDGPU::V_MFMA_F32_16X16X32_F16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40567 /* v_mfma_f32_16x16x32_fp8_bf8 */, AMDGPU::V_MFMA_F32_16X16X32_FP8_BF8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasFP8Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40567 /* v_mfma_f32_16x16x32_fp8_bf8 */, AMDGPU::V_MFMA_F32_16X16X32_FP8_BF8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasFP8Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40595 /* v_mfma_f32_16x16x32_fp8_fp8 */, AMDGPU::V_MFMA_F32_16X16X32_FP8_FP8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasFP8Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40595 /* v_mfma_f32_16x16x32_fp8_fp8 */, AMDGPU::V_MFMA_F32_16X16X32_FP8_FP8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasFP8Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40623 /* v_mfma_f32_16x16x32bf16 */, AMDGPU::V_MFMA_F32_16X16X32_BF16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40623 /* v_mfma_f32_16x16x32bf16 */, AMDGPU::V_MFMA_F32_16X16X32_BF16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40647 /* v_mfma_f32_16x16x32f16 */, AMDGPU::V_MFMA_F32_16X16X32_F16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40647 /* v_mfma_f32_16x16x32f16 */, AMDGPU::V_MFMA_F32_16X16X32_F16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40670 /* v_mfma_f32_16x16x4_4b_bf16 */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40670 /* v_mfma_f32_16x16x4_4b_bf16 */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40697 /* v_mfma_f32_16x16x4_4b_f16 */, AMDGPU::V_MFMA_F32_16X16X4F16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40697 /* v_mfma_f32_16x16x4_4b_f16 */, AMDGPU::V_MFMA_F32_16X16X4F16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40723 /* v_mfma_f32_16x16x4_f32 */, AMDGPU::V_MFMA_F32_16X16X4F32_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40723 /* v_mfma_f32_16x16x4_f32 */, AMDGPU::V_MFMA_F32_16X16X4F32_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40746 /* v_mfma_f32_16x16x4bf16 */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40746 /* v_mfma_f32_16x16x4bf16 */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40769 /* v_mfma_f32_16x16x4bf16_1k */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40769 /* v_mfma_f32_16x16x4bf16_1k */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx90a_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40769 /* v_mfma_f32_16x16x4bf16_1k */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx90a_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40769 /* v_mfma_f32_16x16x4bf16_1k */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40795 /* v_mfma_f32_16x16x4f16 */, AMDGPU::V_MFMA_F32_16X16X4F16_vi, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX8GFX9NotGFX90A_HasMAIInsts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40795 /* v_mfma_f32_16x16x4f16 */, AMDGPU::V_MFMA_F32_16X16X4F16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40795 /* v_mfma_f32_16x16x4f16 */, AMDGPU::V_MFMA_F32_16X16X4F16_gfx90a_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40795 /* v_mfma_f32_16x16x4f16 */, AMDGPU::V_MFMA_F32_16X16X4F16_gfx90a_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40795 /* v_mfma_f32_16x16x4f16 */, AMDGPU::V_MFMA_F32_16X16X4F16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40817 /* v_mfma_f32_16x16x4f32 */, AMDGPU::V_MFMA_F32_16X16X4F32_vi, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX8GFX9NotGFX90A_HasMAIInsts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40817 /* v_mfma_f32_16x16x4f32 */, AMDGPU::V_MFMA_F32_16X16X4F32_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40817 /* v_mfma_f32_16x16x4f32 */, AMDGPU::V_MFMA_F32_16X16X4F32_gfx90a_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40817 /* v_mfma_f32_16x16x4f32 */, AMDGPU::V_MFMA_F32_16X16X4F32_gfx90a_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40817 /* v_mfma_f32_16x16x4f32 */, AMDGPU::V_MFMA_F32_16X16X4F32_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40839 /* v_mfma_f32_16x16x8_xf32 */, AMDGPU::V_MFMA_F32_16X16X8XF32_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40839 /* v_mfma_f32_16x16x8_xf32 */, AMDGPU::V_MFMA_F32_16X16X8XF32_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40863 /* v_mfma_f32_16x16x8bf16 */, AMDGPU::V_MFMA_F32_16X16X8BF16_vi, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX8GFX9NotGFX90A_HasMAIInsts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40863 /* v_mfma_f32_16x16x8bf16 */, AMDGPU::V_MFMA_F32_16X16X8BF16_gfx90a_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40863 /* v_mfma_f32_16x16x8bf16 */, AMDGPU::V_MFMA_F32_16X16X8BF16_gfx90a_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40886 /* v_mfma_f32_16x16x8xf32 */, AMDGPU::V_MFMA_F32_16X16X8XF32_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40886 /* v_mfma_f32_16x16x8xf32 */, AMDGPU::V_MFMA_F32_16X16X8XF32_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40909 /* v_mfma_f32_32x32x16_bf16 */, AMDGPU::V_MFMA_F32_32X32X16_BF16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40909 /* v_mfma_f32_32x32x16_bf16 */, AMDGPU::V_MFMA_F32_32X32X16_BF16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40934 /* v_mfma_f32_32x32x16_bf8_bf8 */, AMDGPU::V_MFMA_F32_32X32X16_BF8_BF8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasFP8Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40934 /* v_mfma_f32_32x32x16_bf8_bf8 */, AMDGPU::V_MFMA_F32_32X32X16_BF8_BF8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasFP8Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40962 /* v_mfma_f32_32x32x16_bf8_fp8 */, AMDGPU::V_MFMA_F32_32X32X16_BF8_FP8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasFP8Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40962 /* v_mfma_f32_32x32x16_bf8_fp8 */, AMDGPU::V_MFMA_F32_32X32X16_BF8_FP8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasFP8Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40990 /* v_mfma_f32_32x32x16_f16 */, AMDGPU::V_MFMA_F32_32X32X16_F16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40990 /* v_mfma_f32_32x32x16_f16 */, AMDGPU::V_MFMA_F32_32X32X16_F16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41014 /* v_mfma_f32_32x32x16_fp8_bf8 */, AMDGPU::V_MFMA_F32_32X32X16_FP8_BF8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasFP8Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41014 /* v_mfma_f32_32x32x16_fp8_bf8 */, AMDGPU::V_MFMA_F32_32X32X16_FP8_BF8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasFP8Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41042 /* v_mfma_f32_32x32x16_fp8_fp8 */, AMDGPU::V_MFMA_F32_32X32X16_FP8_FP8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasFP8Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41042 /* v_mfma_f32_32x32x16_fp8_fp8 */, AMDGPU::V_MFMA_F32_32X32X16_FP8_FP8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasFP8Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41070 /* v_mfma_f32_32x32x16bf16 */, AMDGPU::V_MFMA_F32_32X32X16_BF16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41070 /* v_mfma_f32_32x32x16bf16 */, AMDGPU::V_MFMA_F32_32X32X16_BF16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41094 /* v_mfma_f32_32x32x16f16 */, AMDGPU::V_MFMA_F32_32X32X16_F16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41094 /* v_mfma_f32_32x32x16f16 */, AMDGPU::V_MFMA_F32_32X32X16_F16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41117 /* v_mfma_f32_32x32x1_2b_f32 */, AMDGPU::V_MFMA_F32_32X32X1F32_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_1024_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41117 /* v_mfma_f32_32x32x1_2b_f32 */, AMDGPU::V_MFMA_F32_32X32X1F32_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_1024_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_1024_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41143 /* v_mfma_f32_32x32x1f32 */, AMDGPU::V_MFMA_F32_32X32X1F32_vi, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX8GFX9NotGFX90A_HasMAIInsts, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_1024_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41143 /* v_mfma_f32_32x32x1f32 */, AMDGPU::V_MFMA_F32_32X32X1F32_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_1024_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41143 /* v_mfma_f32_32x32x1f32 */, AMDGPU::V_MFMA_F32_32X32X1F32_gfx90a_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_1024_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41143 /* v_mfma_f32_32x32x1f32 */, AMDGPU::V_MFMA_F32_32X32X1F32_gfx90a_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_1024_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_1024_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41143 /* v_mfma_f32_32x32x1f32 */, AMDGPU::V_MFMA_F32_32X32X1F32_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_1024_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_1024_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41165 /* v_mfma_f32_32x32x2_f32 */, AMDGPU::V_MFMA_F32_32X32X2F32_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41165 /* v_mfma_f32_32x32x2_f32 */, AMDGPU::V_MFMA_F32_32X32X2F32_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41188 /* v_mfma_f32_32x32x2bf16 */, AMDGPU::V_MFMA_F32_32X32X2BF16_vi, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX8GFX9NotGFX90A_HasMAIInsts, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41188 /* v_mfma_f32_32x32x2bf16 */, AMDGPU::V_MFMA_F32_32X32X2BF16_gfx90a_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41188 /* v_mfma_f32_32x32x2bf16 */, AMDGPU::V_MFMA_F32_32X32X2BF16_gfx90a_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41211 /* v_mfma_f32_32x32x2f32 */, AMDGPU::V_MFMA_F32_32X32X2F32_vi, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX8GFX9NotGFX90A_HasMAIInsts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41211 /* v_mfma_f32_32x32x2f32 */, AMDGPU::V_MFMA_F32_32X32X2F32_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41211 /* v_mfma_f32_32x32x2f32 */, AMDGPU::V_MFMA_F32_32X32X2F32_gfx90a_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41211 /* v_mfma_f32_32x32x2f32 */, AMDGPU::V_MFMA_F32_32X32X2F32_gfx90a_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41211 /* v_mfma_f32_32x32x2f32 */, AMDGPU::V_MFMA_F32_32X32X2F32_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41233 /* v_mfma_f32_32x32x4_2b_bf16 */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41233 /* v_mfma_f32_32x32x4_2b_bf16 */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41260 /* v_mfma_f32_32x32x4_2b_f16 */, AMDGPU::V_MFMA_F32_32X32X4F16_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41260 /* v_mfma_f32_32x32x4_2b_f16 */, AMDGPU::V_MFMA_F32_32X32X4F16_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41286 /* v_mfma_f32_32x32x4_xf32 */, AMDGPU::V_MFMA_F32_32X32X4XF32_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41286 /* v_mfma_f32_32x32x4_xf32 */, AMDGPU::V_MFMA_F32_32X32X4XF32_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41310 /* v_mfma_f32_32x32x4bf16 */, AMDGPU::V_MFMA_F32_32X32X4BF16_vi, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX8GFX9NotGFX90A_HasMAIInsts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41310 /* v_mfma_f32_32x32x4bf16 */, AMDGPU::V_MFMA_F32_32X32X4BF16_gfx90a_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41310 /* v_mfma_f32_32x32x4bf16 */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41310 /* v_mfma_f32_32x32x4bf16 */, AMDGPU::V_MFMA_F32_32X32X4BF16_gfx90a_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41310 /* v_mfma_f32_32x32x4bf16 */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41333 /* v_mfma_f32_32x32x4bf16_1k */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41333 /* v_mfma_f32_32x32x4bf16_1k */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx90a_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41333 /* v_mfma_f32_32x32x4bf16_1k */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx90a_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41333 /* v_mfma_f32_32x32x4bf16_1k */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41359 /* v_mfma_f32_32x32x4f16 */, AMDGPU::V_MFMA_F32_32X32X4F16_vi, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX8GFX9NotGFX90A_HasMAIInsts, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41359 /* v_mfma_f32_32x32x4f16 */, AMDGPU::V_MFMA_F32_32X32X4F16_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41359 /* v_mfma_f32_32x32x4f16 */, AMDGPU::V_MFMA_F32_32X32X4F16_gfx90a_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41359 /* v_mfma_f32_32x32x4f16 */, AMDGPU::V_MFMA_F32_32X32X4F16_gfx90a_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41359 /* v_mfma_f32_32x32x4f16 */, AMDGPU::V_MFMA_F32_32X32X4F16_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41381 /* v_mfma_f32_32x32x4xf32 */, AMDGPU::V_MFMA_F32_32X32X4XF32_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41381 /* v_mfma_f32_32x32x4xf32 */, AMDGPU::V_MFMA_F32_32X32X4XF32_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41404 /* v_mfma_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_F32_32X32X64_F8F6F4_f4_f4_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_BLGP }, },
  { 41404 /* v_mfma_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_F32_32X32X64_F8F6F4_f4_f6_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_BLGP }, },
  { 41404 /* v_mfma_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_F32_32X32X64_F8F6F4_f4_f8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_BLGP }, },
  { 41404 /* v_mfma_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_F32_32X32X64_F8F6F4_f6_f4_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_BLGP }, },
  { 41404 /* v_mfma_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_F32_32X32X64_F8F6F4_f6_f6_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_BLGP }, },
  { 41404 /* v_mfma_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_F32_32X32X64_F8F6F4_f6_f8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_BLGP }, },
  { 41404 /* v_mfma_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_F32_32X32X64_F8F6F4_f8_f4_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_BLGP }, },
  { 41404 /* v_mfma_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_F32_32X32X64_F8F6F4_f8_f6_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_BLGP }, },
  { 41404 /* v_mfma_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_F32_32X32X64_F8F6F4_f8_f8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__BLGP1_5, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_BLGP }, },
  { 41404 /* v_mfma_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_F32_32X32X64_F8F6F4_f4_f4_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5, AMFBS_isGFX90APlus_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_BLGP }, },
  { 41404 /* v_mfma_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_F32_32X32X64_F8F6F4_f4_f6_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5, AMFBS_isGFX90APlus_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_BLGP }, },
  { 41404 /* v_mfma_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_F32_32X32X64_F8F6F4_f4_f8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5, AMFBS_isGFX90APlus_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_BLGP }, },
  { 41404 /* v_mfma_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_F32_32X32X64_F8F6F4_f6_f4_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5, AMFBS_isGFX90APlus_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_BLGP }, },
  { 41404 /* v_mfma_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_F32_32X32X64_F8F6F4_f6_f6_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5, AMFBS_isGFX90APlus_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_BLGP }, },
  { 41404 /* v_mfma_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_F32_32X32X64_F8F6F4_f6_f8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_192_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5, AMFBS_isGFX90APlus_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_BLGP }, },
  { 41404 /* v_mfma_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_F32_32X32X64_F8F6F4_f8_f4_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5, AMFBS_isGFX90APlus_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_BLGP }, },
  { 41404 /* v_mfma_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_F32_32X32X64_F8F6F4_f8_f6_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_192_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5, AMFBS_isGFX90APlus_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_BLGP }, },
  { 41404 /* v_mfma_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_F32_32X32X64_F8F6F4_f8_f8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_256_AlignTarget1_1__RegByHwMode_AV_256_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__BLGP1_5, AMFBS_isGFX90APlus_HasGFX950Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_BLGP }, },
  { 41431 /* v_mfma_f32_32x32x8_bf16 */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41431 /* v_mfma_f32_32x32x8_bf16 */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41455 /* v_mfma_f32_32x32x8_f16 */, AMDGPU::V_MFMA_F32_32X32X8F16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41455 /* v_mfma_f32_32x32x8_f16 */, AMDGPU::V_MFMA_F32_32X32X8F16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41478 /* v_mfma_f32_32x32x8bf16 */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41478 /* v_mfma_f32_32x32x8bf16 */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41501 /* v_mfma_f32_32x32x8bf16_1k */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41501 /* v_mfma_f32_32x32x8bf16_1k */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx90a_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41501 /* v_mfma_f32_32x32x8bf16_1k */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx90a_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41501 /* v_mfma_f32_32x32x8bf16_1k */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41527 /* v_mfma_f32_32x32x8f16 */, AMDGPU::V_MFMA_F32_32X32X8F16_vi, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX8GFX9NotGFX90A_HasMAIInsts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41527 /* v_mfma_f32_32x32x8f16 */, AMDGPU::V_MFMA_F32_32X32X8F16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41527 /* v_mfma_f32_32x32x8f16 */, AMDGPU::V_MFMA_F32_32X32X8F16_gfx90a_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41527 /* v_mfma_f32_32x32x8f16 */, AMDGPU::V_MFMA_F32_32X32X8F16_gfx90a_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41527 /* v_mfma_f32_32x32x8f16 */, AMDGPU::V_MFMA_F32_32X32X8F16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41549 /* v_mfma_f32_4x4x1_16b_f32 */, AMDGPU::V_MFMA_F32_4X4X1F32_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41549 /* v_mfma_f32_4x4x1_16b_f32 */, AMDGPU::V_MFMA_F32_4X4X1F32_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41574 /* v_mfma_f32_4x4x1f32 */, AMDGPU::V_MFMA_F32_4X4X1F32_vi, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX8GFX9NotGFX90A_HasMAIInsts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41574 /* v_mfma_f32_4x4x1f32 */, AMDGPU::V_MFMA_F32_4X4X1F32_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41574 /* v_mfma_f32_4x4x1f32 */, AMDGPU::V_MFMA_F32_4X4X1F32_gfx90a_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41574 /* v_mfma_f32_4x4x1f32 */, AMDGPU::V_MFMA_F32_4X4X1F32_gfx90a_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41574 /* v_mfma_f32_4x4x1f32 */, AMDGPU::V_MFMA_F32_4X4X1F32_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41594 /* v_mfma_f32_4x4x2bf16 */, AMDGPU::V_MFMA_F32_4X4X2BF16_vi, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX8GFX9NotGFX90A_HasMAIInsts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41594 /* v_mfma_f32_4x4x2bf16 */, AMDGPU::V_MFMA_F32_4X4X2BF16_gfx90a_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41594 /* v_mfma_f32_4x4x2bf16 */, AMDGPU::V_MFMA_F32_4X4X2BF16_gfx90a_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41615 /* v_mfma_f32_4x4x4_16b_bf16 */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41615 /* v_mfma_f32_4x4x4_16b_bf16 */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41641 /* v_mfma_f32_4x4x4_16b_f16 */, AMDGPU::V_MFMA_F32_4X4X4F16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41641 /* v_mfma_f32_4x4x4_16b_f16 */, AMDGPU::V_MFMA_F32_4X4X4F16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41666 /* v_mfma_f32_4x4x4bf16 */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41666 /* v_mfma_f32_4x4x4bf16 */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41687 /* v_mfma_f32_4x4x4bf16_1k */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41687 /* v_mfma_f32_4x4x4bf16_1k */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx90a_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41687 /* v_mfma_f32_4x4x4bf16_1k */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx90a_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41687 /* v_mfma_f32_4x4x4bf16_1k */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41711 /* v_mfma_f32_4x4x4f16 */, AMDGPU::V_MFMA_F32_4X4X4F16_vi, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX8GFX9NotGFX90A_HasMAIInsts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41711 /* v_mfma_f32_4x4x4f16 */, AMDGPU::V_MFMA_F32_4X4X4F16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41711 /* v_mfma_f32_4x4x4f16 */, AMDGPU::V_MFMA_F32_4X4X4F16_gfx90a_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41711 /* v_mfma_f32_4x4x4f16 */, AMDGPU::V_MFMA_F32_4X4X4F16_gfx90a_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41711 /* v_mfma_f32_4x4x4f16 */, AMDGPU::V_MFMA_F32_4X4X4F16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41731 /* v_mfma_f64_16x16x4_f64 */, AMDGPU::V_MFMA_F64_16X16X4F64_gfx940_acd, Convert__RegByHwMode_AReg_256_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_256_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_256_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_256_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41731 /* v_mfma_f64_16x16x4_f64 */, AMDGPU::V_MFMA_F64_16X16X4F64_gfx940_vcd, Convert__RegByHwMode_VReg_256_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_256_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_256_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41754 /* v_mfma_f64_16x16x4f64 */, AMDGPU::V_MFMA_F64_16X16X4F64_gfx940_acd, Convert__RegByHwMode_AReg_256_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_256_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_256_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_256_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41754 /* v_mfma_f64_16x16x4f64 */, AMDGPU::V_MFMA_F64_16X16X4F64_gfx90a_acd, Convert__RegByHwMode_AReg_256_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_256_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_256_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_256_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41754 /* v_mfma_f64_16x16x4f64 */, AMDGPU::V_MFMA_F64_16X16X4F64_gfx90a_vcd, Convert__RegByHwMode_VReg_256_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_256_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_256_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41754 /* v_mfma_f64_16x16x4f64 */, AMDGPU::V_MFMA_F64_16X16X4F64_gfx940_vcd, Convert__RegByHwMode_VReg_256_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_256_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_256_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41776 /* v_mfma_f64_4x4x4_4b_f64 */, AMDGPU::V_MFMA_F64_4X4X4F64_gfx940_acd, Convert__RegByHwMode_AReg_64_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_64_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_64_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41776 /* v_mfma_f64_4x4x4_4b_f64 */, AMDGPU::V_MFMA_F64_4X4X4F64_gfx940_vcd, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_64_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_64_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41800 /* v_mfma_f64_4x4x4f64 */, AMDGPU::V_MFMA_F64_4X4X4F64_gfx940_acd, Convert__RegByHwMode_AReg_64_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_64_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_64_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41800 /* v_mfma_f64_4x4x4f64 */, AMDGPU::V_MFMA_F64_4X4X4F64_gfx90a_acd, Convert__RegByHwMode_AReg_64_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_64_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_64_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41800 /* v_mfma_f64_4x4x4f64 */, AMDGPU::V_MFMA_F64_4X4X4F64_gfx90a_vcd, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_64_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_64_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41800 /* v_mfma_f64_4x4x4f64 */, AMDGPU::V_MFMA_F64_4X4X4F64_gfx940_vcd, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_64_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_64_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41820 /* v_mfma_i32_16x16x16i8 */, AMDGPU::V_MFMA_I32_16X16X16I8_vi, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX8GFX9NotGFX90A_HasMAIInsts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41820 /* v_mfma_i32_16x16x16i8 */, AMDGPU::V_MFMA_I32_16X16X16I8_gfx90a_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41820 /* v_mfma_i32_16x16x16i8 */, AMDGPU::V_MFMA_I32_16X16X16I8_gfx90a_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41842 /* v_mfma_i32_16x16x32_i8 */, AMDGPU::V_MFMA_I32_16X16X32I8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41842 /* v_mfma_i32_16x16x32_i8 */, AMDGPU::V_MFMA_I32_16X16X32I8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41865 /* v_mfma_i32_16x16x32i8 */, AMDGPU::V_MFMA_I32_16X16X32I8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41865 /* v_mfma_i32_16x16x32i8 */, AMDGPU::V_MFMA_I32_16X16X32I8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41887 /* v_mfma_i32_16x16x4_4b_i8 */, AMDGPU::V_MFMA_I32_16X16X4I8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41887 /* v_mfma_i32_16x16x4_4b_i8 */, AMDGPU::V_MFMA_I32_16X16X4I8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41912 /* v_mfma_i32_16x16x4i8 */, AMDGPU::V_MFMA_I32_16X16X4I8_vi, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX8GFX9NotGFX90A_HasMAIInsts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41912 /* v_mfma_i32_16x16x4i8 */, AMDGPU::V_MFMA_I32_16X16X4I8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41912 /* v_mfma_i32_16x16x4i8 */, AMDGPU::V_MFMA_I32_16X16X4I8_gfx90a_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41912 /* v_mfma_i32_16x16x4i8 */, AMDGPU::V_MFMA_I32_16X16X4I8_gfx90a_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41912 /* v_mfma_i32_16x16x4i8 */, AMDGPU::V_MFMA_I32_16X16X4I8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41933 /* v_mfma_i32_16x16x64_i8 */, AMDGPU::V_MFMA_I32_16X16X64_I8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41933 /* v_mfma_i32_16x16x64_i8 */, AMDGPU::V_MFMA_I32_16X16X64_I8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41956 /* v_mfma_i32_16x16x64i8 */, AMDGPU::V_MFMA_I32_16X16X64_I8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41956 /* v_mfma_i32_16x16x64i8 */, AMDGPU::V_MFMA_I32_16X16X64_I8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41978 /* v_mfma_i32_32x32x16_i8 */, AMDGPU::V_MFMA_I32_32X32X16I8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41978 /* v_mfma_i32_32x32x16_i8 */, AMDGPU::V_MFMA_I32_32X32X16I8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42001 /* v_mfma_i32_32x32x16i8 */, AMDGPU::V_MFMA_I32_32X32X16I8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42001 /* v_mfma_i32_32x32x16i8 */, AMDGPU::V_MFMA_I32_32X32X16I8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42023 /* v_mfma_i32_32x32x32_i8 */, AMDGPU::V_MFMA_I32_32X32X32_I8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42023 /* v_mfma_i32_32x32x32_i8 */, AMDGPU::V_MFMA_I32_32X32X32_I8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42046 /* v_mfma_i32_32x32x32i8 */, AMDGPU::V_MFMA_I32_32X32X32_I8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42046 /* v_mfma_i32_32x32x32i8 */, AMDGPU::V_MFMA_I32_32X32X32_I8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42068 /* v_mfma_i32_32x32x4_2b_i8 */, AMDGPU::V_MFMA_I32_32X32X4I8_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42068 /* v_mfma_i32_32x32x4_2b_i8 */, AMDGPU::V_MFMA_I32_32X32X4I8_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42093 /* v_mfma_i32_32x32x4i8 */, AMDGPU::V_MFMA_I32_32X32X4I8_vi, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX8GFX9NotGFX90A_HasMAIInsts, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42093 /* v_mfma_i32_32x32x4i8 */, AMDGPU::V_MFMA_I32_32X32X4I8_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42093 /* v_mfma_i32_32x32x4i8 */, AMDGPU::V_MFMA_I32_32X32X4I8_gfx90a_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42093 /* v_mfma_i32_32x32x4i8 */, AMDGPU::V_MFMA_I32_32X32X4I8_gfx90a_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42093 /* v_mfma_i32_32x32x4i8 */, AMDGPU::V_MFMA_I32_32X32X4I8_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42114 /* v_mfma_i32_32x32x8i8 */, AMDGPU::V_MFMA_I32_32X32X8I8_vi, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX8GFX9NotGFX90A_HasMAIInsts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42114 /* v_mfma_i32_32x32x8i8 */, AMDGPU::V_MFMA_I32_32X32X8I8_gfx90a_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42114 /* v_mfma_i32_32x32x8i8 */, AMDGPU::V_MFMA_I32_32X32X8I8_gfx90a_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42135 /* v_mfma_i32_4x4x4_16b_i8 */, AMDGPU::V_MFMA_I32_4X4X4I8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42135 /* v_mfma_i32_4x4x4_16b_i8 */, AMDGPU::V_MFMA_I32_4X4X4I8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42159 /* v_mfma_i32_4x4x4i8 */, AMDGPU::V_MFMA_I32_4X4X4I8_vi, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX8GFX9NotGFX90A_HasMAIInsts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42159 /* v_mfma_i32_4x4x4i8 */, AMDGPU::V_MFMA_I32_4X4X4I8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42159 /* v_mfma_i32_4x4x4i8 */, AMDGPU::V_MFMA_I32_4X4X4I8_gfx90a_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90AOnly, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42159 /* v_mfma_i32_4x4x4i8 */, AMDGPU::V_MFMA_I32_4X4X4I8_gfx90a_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX90AOnly, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42159 /* v_mfma_i32_4x4x4i8 */, AMDGPU::V_MFMA_I32_4X4X4I8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42178 /* v_mfma_ld_scale_b32 */, AMDGPU::V_MFMA_LD_SCALE_B32_vi, ConvertCustom_cvtVOP3P, AMFBS_HasGFX950Insts_HasVOP3PInsts, { MCK_VSrc_b32, MCK_VSrc_b32, MCK_OpSel, MCK_OpSelHi }, },
  { 42198 /* v_mfma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_16X16X128_F8F6F4_f4_f4_gfx940_acd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42198 /* v_mfma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_16X16X128_F8F6F4_f4_f6_gfx940_acd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_AISrc_128_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42198 /* v_mfma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_16X16X128_F8F6F4_f4_f8_gfx940_acd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_AISrc_128_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42198 /* v_mfma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_16X16X128_F8F6F4_f6_f4_gfx940_acd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42198 /* v_mfma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_16X16X128_F8F6F4_f6_f6_gfx940_acd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_AISrc_128_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42198 /* v_mfma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_16X16X128_F8F6F4_f6_f8_gfx940_acd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_AISrc_128_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42198 /* v_mfma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_16X16X128_F8F6F4_f8_f4_gfx940_acd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42198 /* v_mfma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_16X16X128_F8F6F4_f8_f6_gfx940_acd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_AISrc_128_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42198 /* v_mfma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_16X16X128_F8F6F4_f8_f8_gfx940_acd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_AISrc_128_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42198 /* v_mfma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_16X16X128_F8F6F4_f4_f4_gfx940_vcd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42198 /* v_mfma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_16X16X128_F8F6F4_f4_f6_gfx940_vcd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_VISrc_128_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42198 /* v_mfma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_16X16X128_F8F6F4_f4_f8_gfx940_vcd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_VISrc_128_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42198 /* v_mfma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_16X16X128_F8F6F4_f6_f4_gfx940_vcd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42198 /* v_mfma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_16X16X128_F8F6F4_f6_f6_gfx940_vcd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_VISrc_128_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42198 /* v_mfma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_16X16X128_F8F6F4_f6_f8_gfx940_vcd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_VISrc_128_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42198 /* v_mfma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_16X16X128_F8F6F4_f8_f4_gfx940_vcd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42198 /* v_mfma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_16X16X128_F8F6F4_f8_f6_gfx940_vcd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_VISrc_128_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42198 /* v_mfma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_16X16X128_F8F6F4_f8_f8_gfx940_vcd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_VISrc_128_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42232 /* v_mfma_scale_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_32X32X64_F8F6F4_f4_f4_gfx940_acd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42232 /* v_mfma_scale_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_32X32X64_F8F6F4_f4_f6_gfx940_acd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_AISrc_512_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42232 /* v_mfma_scale_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_32X32X64_F8F6F4_f4_f8_gfx940_acd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_AISrc_512_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42232 /* v_mfma_scale_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_32X32X64_F8F6F4_f6_f4_gfx940_acd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42232 /* v_mfma_scale_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_32X32X64_F8F6F4_f6_f6_gfx940_acd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_AISrc_512_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42232 /* v_mfma_scale_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_32X32X64_F8F6F4_f6_f8_gfx940_acd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_AISrc_512_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42232 /* v_mfma_scale_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_32X32X64_F8F6F4_f8_f4_gfx940_acd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42232 /* v_mfma_scale_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_32X32X64_F8F6F4_f8_f6_gfx940_acd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_AISrc_512_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42232 /* v_mfma_scale_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_32X32X64_F8F6F4_f8_f8_gfx940_acd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_AISrc_512_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42232 /* v_mfma_scale_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_32X32X64_F8F6F4_f4_f4_gfx940_vcd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42232 /* v_mfma_scale_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_32X32X64_F8F6F4_f4_f6_gfx940_vcd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_VISrc_512_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42232 /* v_mfma_scale_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_32X32X64_F8F6F4_f4_f8_gfx940_vcd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_VISrc_512_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42232 /* v_mfma_scale_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_32X32X64_F8F6F4_f6_f4_gfx940_vcd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42232 /* v_mfma_scale_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_32X32X64_F8F6F4_f6_f6_gfx940_vcd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_VISrc_512_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42232 /* v_mfma_scale_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_32X32X64_F8F6F4_f6_f8_gfx940_vcd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_VISrc_512_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42232 /* v_mfma_scale_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_32X32X64_F8F6F4_f8_f4_gfx940_vcd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42232 /* v_mfma_scale_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_32X32X64_F8F6F4_f8_f6_gfx940_vcd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_192_AlignTarget, MCK_VISrc_512_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42232 /* v_mfma_scale_f32_32x32x64_f8f6f4 */, AMDGPU::V_MFMA_SCALE_F32_32X32X64_F8F6F4_f8_f8_gfx940_vcd, ConvertCustom_cvtScaledMFMA, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_RegByHwMode_AV_256_AlignTarget, MCK_VISrc_512_f32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_OpSelHi, MCK_CBSZ, MCK_BLGP }, },
  { 42265 /* v_min3_f16 */, AMDGPU::V_MIN3_F16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 42265 /* v_min3_f16 */, AMDGPU::V_MIN3_F16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 42265 /* v_min3_f16 */, AMDGPU::V_MIN3_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 42265 /* v_min3_f16 */, AMDGPU::V_MIN3_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 42276 /* v_min3_f32 */, AMDGPU::V_MIN3_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42276 /* v_min3_f32 */, AMDGPU::V_MIN3_F32_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42276 /* v_min3_f32 */, AMDGPU::V_MIN3_F32_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42276 /* v_min3_f32 */, AMDGPU::V_MIN3_F32_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42287 /* v_min3_i16 */, AMDGPU::V_MIN3_I16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 42287 /* v_min3_i16 */, AMDGPU::V_MIN3_I16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 42287 /* v_min3_i16 */, AMDGPU::V_MIN3_I16V_MIN3_I16_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 42287 /* v_min3_i16 */, AMDGPU::V_MIN3_I16V_MIN3_I16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 42287 /* v_min3_i16 */, AMDGPU::V_MIN3_I16V_MIN3_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 42287 /* v_min3_i16 */, AMDGPU::V_MIN3_I16V_MIN3_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 42298 /* v_min3_i32 */, AMDGPU::V_MIN3_I32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42298 /* v_min3_i32 */, AMDGPU::V_MIN3_I32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42298 /* v_min3_i32 */, AMDGPU::V_MIN3_I32_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42298 /* v_min3_i32 */, AMDGPU::V_MIN3_I32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42298 /* v_min3_i32 */, AMDGPU::V_MIN3_I32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42309 /* v_min3_num_f16 */, AMDGPU::V_MIN3_NUM_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 42309 /* v_min3_num_f16 */, AMDGPU::V_MIN3_NUM_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 42324 /* v_min3_num_f32 */, AMDGPU::V_MIN3_NUM_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42339 /* v_min3_u16 */, AMDGPU::V_MIN3_U16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 42339 /* v_min3_u16 */, AMDGPU::V_MIN3_U16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 42339 /* v_min3_u16 */, AMDGPU::V_MIN3_U16V_MIN3_U16_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 42339 /* v_min3_u16 */, AMDGPU::V_MIN3_U16V_MIN3_U16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 42339 /* v_min3_u16 */, AMDGPU::V_MIN3_U16V_MIN3_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 42339 /* v_min3_u16 */, AMDGPU::V_MIN3_U16V_MIN3_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 42350 /* v_min3_u32 */, AMDGPU::V_MIN3_U32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42350 /* v_min3_u32 */, AMDGPU::V_MIN3_U32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42350 /* v_min3_u32 */, AMDGPU::V_MIN3_U32_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42350 /* v_min3_u32 */, AMDGPU::V_MIN3_U32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42350 /* v_min3_u32 */, AMDGPU::V_MIN3_U32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42361 /* v_min_f16 */, AMDGPU::V_MIN_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42361 /* v_min_f16 */, AMDGPU::V_MIN_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42361 /* v_min_f16 */, AMDGPU::V_MIN_F16V_MIN_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42361 /* v_min_f16 */, AMDGPU::V_MIN_F16V_MIN_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 42371 /* v_min_f32 */, AMDGPU::V_MIN_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42371 /* v_min_f32 */, AMDGPU::V_MIN_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42371 /* v_min_f32 */, AMDGPU::V_MIN_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42371 /* v_min_f32 */, AMDGPU::V_MIN_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42381 /* v_min_f64 */, AMDGPU::V_MIN_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isNotGFX12Plus_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42381 /* v_min_f64 */, AMDGPU::V_MIN_F64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isNotGFX12Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42381 /* v_min_f64 */, AMDGPU::V_MIN_F64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isNotGFX12Plus_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42381 /* v_min_f64 */, AMDGPU::V_MIN_F64_vi, ConvertCustom_cvtVOP3, AMFBS_isNotGFX12Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42391 /* v_min_i16 */, AMDGPU::V_MIN_I16_e64_vi, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 42391 /* v_min_i16 */, AMDGPU::V_MIN_I16_fake16_e64_gfx11, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 42391 /* v_min_i16 */, AMDGPU::V_MIN_I16_fake16_e64_gfx12, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 42391 /* v_min_i16 */, AMDGPU::V_MIN_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 42391 /* v_min_i16 */, AMDGPU::V_MIN_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 42391 /* v_min_i16 */, AMDGPU::V_MIN_I16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_e64_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42411 /* v_min_i64 */, AMDGPU::V_MIN_I64_e64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 42421 /* v_min_legacy_f32 */, AMDGPU::V_MIN_LEGACY_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42438 /* v_min_num_f16 */, AMDGPU::V_MIN_NUM_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42438 /* v_min_num_f16 */, AMDGPU::V_MIN_NUM_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 42452 /* v_min_num_f32 */, AMDGPU::V_MIN_NUM_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42466 /* v_min_num_f64 */, AMDGPU::V_MIN_NUM_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42480 /* v_min_u16 */, AMDGPU::V_MIN_U16_e64_vi, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 42480 /* v_min_u16 */, AMDGPU::V_MIN_U16_fake16_e64_gfx11, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 42480 /* v_min_u16 */, AMDGPU::V_MIN_U16_fake16_e64_gfx12, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 42480 /* v_min_u16 */, AMDGPU::V_MIN_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 42480 /* v_min_u16 */, AMDGPU::V_MIN_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 42480 /* v_min_u16 */, AMDGPU::V_MIN_U16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_e64_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42500 /* v_min_u64 */, AMDGPU::V_MIN_U64_e64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 42510 /* v_minimum3_f16 */, AMDGPU::V_MINIMUM3_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasMinimum3Maximum3F16_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 42510 /* v_minimum3_f16 */, AMDGPU::V_MINIMUM3_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasMinimum3Maximum3F16_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 42525 /* v_minimum3_f32 */, AMDGPU::V_MINIMUM3_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasMinimum3Maximum3F32_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42525 /* v_minimum3_f32 */, AMDGPU::V_MINIMUM3_F32_vi, ConvertCustom_cvtVOP3, AMFBS_HasMinimum3Maximum3F32_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42540 /* v_minimum_f16 */, AMDGPU::V_MINIMUM_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 42540 /* v_minimum_f16 */, AMDGPU::V_MINIMUM_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 42554 /* v_minimum_f32 */, AMDGPU::V_MINIMUM_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42568 /* v_minimum_f64 */, AMDGPU::V_MINIMUM_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasIEEEMinimumMaximumInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42568 /* v_minimum_f64 */, AMDGPU::V_MINIMUM_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42582 /* v_minimummaximum_f16 */, AMDGPU::V_MINIMUMMAXIMUM_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 42582 /* v_minimummaximum_f16 */, AMDGPU::V_MINIMUMMAXIMUM_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 42603 /* v_minimummaximum_f32 */, AMDGPU::V_MINIMUMMAXIMUM_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42624 /* v_minmax_f16 */, AMDGPU::V_MINMAX_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 42624 /* v_minmax_f16 */, AMDGPU::V_MINMAX_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX11Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 42637 /* v_minmax_f32 */, AMDGPU::V_MINMAX_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42650 /* v_minmax_i32 */, AMDGPU::V_MINMAX_I32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42650 /* v_minmax_i32 */, AMDGPU::V_MINMAX_I32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42663 /* v_minmax_num_f16 */, AMDGPU::V_MINMAX_NUM_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 42663 /* v_minmax_num_f16 */, AMDGPU::V_MINMAX_NUM_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX11Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 42680 /* v_minmax_num_f32 */, AMDGPU::V_MINMAX_NUM_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42697 /* v_minmax_u32 */, AMDGPU::V_MINMAX_U32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42697 /* v_minmax_u32 */, AMDGPU::V_MINMAX_U32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42710 /* v_mov_b16 */, AMDGPU::V_MOV_B16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 42710 /* v_mov_b16 */, AMDGPU::V_MOV_B16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_e64_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 42730 /* v_mov_b64 */, AMDGPU::V_MOV_B64_e64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1, AMFBS_isGFX940orGFX1250_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64 }, },
  { 42730 /* v_mov_b64 */, AMDGPU::V_MOV_B64_e64_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1, AMFBS_isGFX940orGFX1250_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64 }, },
  { 42740 /* v_movreld_b32 */, AMDGPU::V_MOVRELD_B32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_HasMovrel_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 42740 /* v_movreld_b32 */, AMDGPU::V_MOVRELD_B32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_HasMovrel_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 42740 /* v_movreld_b32 */, AMDGPU::V_MOVRELD_B32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_HasMovrel_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 42740 /* v_movreld_b32 */, AMDGPU::V_MOVRELD_B32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1, AMFBS_HasMovrel_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 42740 /* v_movreld_b32 */, AMDGPU::V_MOVRELD_B32_e64_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_HasMovrel_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 42754 /* v_movrels_b32 */, AMDGPU::V_MOVRELS_B32_e64_gfx10, Convert__Reg1_0__Reg1_1, AMFBS_HasMovrel_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42754 /* v_movrels_b32 */, AMDGPU::V_MOVRELS_B32_e64_gfx11, Convert__Reg1_0__Reg1_1, AMFBS_HasMovrel_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42754 /* v_movrels_b32 */, AMDGPU::V_MOVRELS_B32_e64_gfx12, Convert__Reg1_0__Reg1_1, AMFBS_HasMovrel_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42754 /* v_movrels_b32 */, AMDGPU::V_MOVRELS_B32_e64_gfx6_gfx7, Convert__Reg1_0__Reg1_1, AMFBS_HasMovrel_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42754 /* v_movrels_b32 */, AMDGPU::V_MOVRELS_B32_e64_vi, Convert__Reg1_0__Reg1_1, AMFBS_HasMovrel_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42768 /* v_movrelsd_2_b32 */, AMDGPU::V_MOVRELSD_2_B32_e64_gfx10, Convert__Reg1_0__Reg1_1, AMFBS_isGFX10Plus_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42768 /* v_movrelsd_2_b32 */, AMDGPU::V_MOVRELSD_2_B32_e64_gfx11, Convert__Reg1_0__Reg1_1, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42768 /* v_movrelsd_2_b32 */, AMDGPU::V_MOVRELSD_2_B32_e64_gfx12, Convert__Reg1_0__Reg1_1, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42785 /* v_movrelsd_b32 */, AMDGPU::V_MOVRELSD_B32_e64_gfx10, Convert__Reg1_0__Reg1_1, AMFBS_HasMovrel_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42785 /* v_movrelsd_b32 */, AMDGPU::V_MOVRELSD_B32_e64_gfx11, Convert__Reg1_0__Reg1_1, AMFBS_HasMovrel_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42785 /* v_movrelsd_b32 */, AMDGPU::V_MOVRELSD_B32_e64_gfx12, Convert__Reg1_0__Reg1_1, AMFBS_HasMovrel_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42785 /* v_movrelsd_b32 */, AMDGPU::V_MOVRELSD_B32_e64_gfx6_gfx7, Convert__Reg1_0__Reg1_1, AMFBS_HasMovrel_isGFX6GFX7, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42785 /* v_movrelsd_b32 */, AMDGPU::V_MOVRELSD_B32_e64_vi, Convert__Reg1_0__Reg1_1, AMFBS_HasMovrel_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32 }, },
  { 42800 /* v_mqsad_pk_u16_u8 */, AMDGPU::V_MQSAD_PK_U16_U8_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b32, MCK_VSrc_b64, MCK_Clamp }, },
  { 42800 /* v_mqsad_pk_u16_u8 */, AMDGPU::V_MQSAD_PK_U16_U8_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b32, MCK_VSrc_b64, MCK_Clamp }, },
  { 42800 /* v_mqsad_pk_u16_u8 */, AMDGPU::V_MQSAD_PK_U16_U8_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b32, MCK_VSrc_b64, MCK_Clamp }, },
  { 42800 /* v_mqsad_pk_u16_u8 */, AMDGPU::V_MQSAD_PK_U16_U8_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b32, MCK_VSrc_b64, MCK_Clamp }, },
  { 42800 /* v_mqsad_pk_u16_u8 */, AMDGPU::V_MQSAD_PK_U16_U8_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b32, MCK_VSrc_b64, MCK_Clamp }, },
  { 42818 /* v_mqsad_u32_u8 */, AMDGPU::V_MQSAD_U32_U8_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX11Only, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_Clamp }, },
  { 42818 /* v_mqsad_u32_u8 */, AMDGPU::V_MQSAD_U32_U8_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX12Only, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_Clamp }, },
  { 42818 /* v_mqsad_u32_u8 */, AMDGPU::V_MQSAD_U32_U8_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX10Only, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_Clamp }, },
  { 42818 /* v_mqsad_u32_u8 */, AMDGPU::V_MQSAD_U32_U8_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX7Only, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_Clamp }, },
  { 42818 /* v_mqsad_u32_u8 */, AMDGPU::V_MQSAD_U32_U8_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b32, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_Clamp }, },
  { 42833 /* v_msad_u8 */, AMDGPU::V_MSAD_U8_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 42833 /* v_msad_u8 */, AMDGPU::V_MSAD_U8_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 42833 /* v_msad_u8 */, AMDGPU::V_MSAD_U8_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 42833 /* v_msad_u8 */, AMDGPU::V_MSAD_U8_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 42833 /* v_msad_u8 */, AMDGPU::V_MSAD_U8_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 42843 /* v_mul_dx9_zero_f32 */, AMDGPU::V_MUL_DX9_ZERO_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42843 /* v_mul_dx9_zero_f32 */, AMDGPU::V_MUL_DX9_ZERO_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42882 /* v_mul_f64 */, AMDGPU::V_MUL_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isNotGFX12Plus_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42882 /* v_mul_f64 */, AMDGPU::V_MUL_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42882 /* v_mul_f64 */, AMDGPU::V_MUL_F64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isNotGFX12Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42882 /* v_mul_f64 */, AMDGPU::V_MUL_F64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isNotGFX12Plus_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42882 /* v_mul_f64 */, AMDGPU::V_MUL_F64_vi, ConvertCustom_cvtVOP3, AMFBS_isNotGFX12Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42892 /* v_mul_hi_i32 */, AMDGPU::V_MUL_HI_I32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42892 /* v_mul_hi_i32 */, AMDGPU::V_MUL_HI_I32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Not12_50, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42892 /* v_mul_hi_i32 */, AMDGPU::V_MUL_HI_I32_e64_gfx1250, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42892 /* v_mul_hi_i32 */, AMDGPU::V_MUL_HI_I32_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42892 /* v_mul_hi_i32 */, AMDGPU::V_MUL_HI_I32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42892 /* v_mul_hi_i32 */, AMDGPU::V_MUL_HI_I32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_e64_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_e64_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42922 /* v_mul_hi_u32 */, AMDGPU::V_MUL_HI_U32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42922 /* v_mul_hi_u32 */, AMDGPU::V_MUL_HI_U32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Not12_50, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42922 /* v_mul_hi_u32 */, AMDGPU::V_MUL_HI_U32_e64_gfx1250, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42922 /* v_mul_hi_u32 */, AMDGPU::V_MUL_HI_U32_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42922 /* v_mul_hi_u32 */, AMDGPU::V_MUL_HI_U32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42922 /* v_mul_hi_u32 */, AMDGPU::V_MUL_HI_U32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_e64_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_e64_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 42966 /* v_mul_legacy_f32 */, AMDGPU::V_MUL_LEGACY_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGCN3ExcludingGFX90A_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42966 /* v_mul_legacy_f32 */, AMDGPU::V_MUL_LEGACY_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42966 /* v_mul_legacy_f32 */, AMDGPU::V_MUL_LEGACY_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42966 /* v_mul_legacy_f32 */, AMDGPU::V_MUL_LEGACY_F32_e64_gfx90a, ConvertCustom_cvtVOP3, AMFBS_None, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 42983 /* v_mul_lo_i32 */, AMDGPU::V_MUL_LO_I32_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Before1030_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42983 /* v_mul_lo_i32 */, AMDGPU::V_MUL_LO_I32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42983 /* v_mul_lo_i32 */, AMDGPU::V_MUL_LO_I32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 42996 /* v_mul_lo_u16 */, AMDGPU::V_MUL_LO_U16_e64_vi, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 42996 /* v_mul_lo_u16 */, AMDGPU::V_MUL_LO_U16_fake16_e64_gfx11, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 42996 /* v_mul_lo_u16 */, AMDGPU::V_MUL_LO_U16_fake16_e64_gfx12, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 42996 /* v_mul_lo_u16 */, AMDGPU::V_MUL_LO_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 42996 /* v_mul_lo_u16 */, AMDGPU::V_MUL_LO_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 42996 /* v_mul_lo_u16 */, AMDGPU::V_MUL_LO_U16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 43009 /* v_mul_lo_u32 */, AMDGPU::V_MUL_LO_U32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 43009 /* v_mul_lo_u32 */, AMDGPU::V_MUL_LO_U32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Not12_50, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 43009 /* v_mul_lo_u32 */, AMDGPU::V_MUL_LO_U32_e64_gfx1250, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 43009 /* v_mul_lo_u32 */, AMDGPU::V_MUL_LO_U32_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 43009 /* v_mul_lo_u32 */, AMDGPU::V_MUL_LO_U32_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 43009 /* v_mul_lo_u32 */, AMDGPU::V_MUL_LO_U32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 43036 /* v_mul_u64 */, AMDGPU::V_MUL_U64_e64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b641_1__VSrc_b641_2, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b64 }, },
  { 43046 /* v_mullit_f32 */, AMDGPU::V_MULLIT_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 43046 /* v_mullit_f32 */, AMDGPU::V_MULLIT_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7GFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 43046 /* v_mullit_f32 */, AMDGPU::V_MULLIT_F32_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 43046 /* v_mullit_f32 */, AMDGPU::V_MULLIT_F32_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 43059 /* v_nop */, AMDGPU::V_NOP_e64_gfx10, Convert_NoOperands, AMFBS_isGFX10Only, {  }, },
  { 43059 /* v_nop */, AMDGPU::V_NOP_e64_gfx11, Convert_NoOperands, AMFBS_isGFX11Only, {  }, },
  { 43059 /* v_nop */, AMDGPU::V_NOP_e64_gfx12, Convert_NoOperands, AMFBS_isGFX12Only, {  }, },
  { 43059 /* v_nop */, AMDGPU::V_NOP_e64_gfx6_gfx7, Convert_NoOperands, AMFBS_isGFX6GFX7, {  }, },
  { 43059 /* v_nop */, AMDGPU::V_NOP_e64_vi, Convert_NoOperands, AMFBS_isGFX8GFX9, {  }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_fake16_e64_gfx11, Convert__Reg1_0__VSrc_b161_1, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16 }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_fake16_e64_gfx12, Convert__Reg1_0__VSrc_b161_1, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16 }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_e64_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 43085 /* v_or3_b32 */, AMDGPU::V_OR3_B32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 43085 /* v_or3_b32 */, AMDGPU::V_OR3_B32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 43085 /* v_or3_b32 */, AMDGPU::V_OR3_B32_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 43085 /* v_or3_b32 */, AMDGPU::V_OR3_B32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 43095 /* v_or_b16 */, AMDGPU::V_OR_B16_fake16_e64_gfx11, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 43095 /* v_or_b16 */, AMDGPU::V_OR_B16_fake16_e64_gfx12, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 43095 /* v_or_b16 */, AMDGPU::V_OR_B16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX11Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 43095 /* v_or_b16 */, AMDGPU::V_OR_B16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX11Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_e64_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 43113 /* v_pack_b32_f16 */, AMDGPU::V_PACK_B32_F16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 43113 /* v_pack_b32_f16 */, AMDGPU::V_PACK_B32_F16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 43113 /* v_pack_b32_f16 */, AMDGPU::V_PACK_B32_F16V_PACK_B32_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 43113 /* v_pack_b32_f16 */, AMDGPU::V_PACK_B32_F16V_PACK_B32_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 43113 /* v_pack_b32_f16 */, AMDGPU::V_PACK_B32_F16V_PACK_B32_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 43113 /* v_pack_b32_f16 */, AMDGPU::V_PACK_B32_F16V_PACK_B32_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp }, },
  { 43128 /* v_perm_b32 */, AMDGPU::V_PERM_B32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX8Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 43128 /* v_perm_b32 */, AMDGPU::V_PERM_B32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX8Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 43128 /* v_perm_b32 */, AMDGPU::V_PERM_B32_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX8Plus_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 43128 /* v_perm_b32 */, AMDGPU::V_PERM_B32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX8Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 43139 /* v_perm_pk16_b4_u4 */, AMDGPU::V_PERM_PK16_B4_U4_e64_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__VSrc_b321_1__VSrc_b321_2__VSrc_v2b321_3, AMFBS_HasTensorCvtLutInsts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_v2b32 }, },
  { 43157 /* v_perm_pk16_b6_u4 */, AMDGPU::V_PERM_PK16_B6_U4_e64_gfx1250, Convert__RegByHwMode_VReg_96_AlignTarget1_0__VSrc_b321_1__VSrc_b641_2__VSrc_v2b321_3, AMFBS_HasTensorCvtLutInsts_isGFX125xOnly, { MCK_RegByHwMode_VReg_96_AlignTarget, MCK_VSrc_b32, MCK_VSrc_b64, MCK_VSrc_v2b32 }, },
  { 43175 /* v_perm_pk16_b8_u4 */, AMDGPU::V_PERM_PK16_B8_U4_e64_gfx1250, Convert__RegByHwMode_VReg_128_AlignTarget1_0__VSrc_b641_1__VSrc_b641_2__VSrc_v2b321_3, AMFBS_HasTensorCvtLutInsts_isGFX125xOnly, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b64, MCK_VSrc_v2b32 }, },
  { 43193 /* v_permlane16_b32 */, AMDGPU::V_PERMLANE16_B32_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SSrc_b32, MCK_SSrc_b32, MCK_OpSel }, },
  { 43193 /* v_permlane16_b32 */, AMDGPU::V_PERMLANE16_B32_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SSrc_b32, MCK_SSrc_b32, MCK_OpSel }, },
  { 43193 /* v_permlane16_b32 */, AMDGPU::V_PERMLANE16_B32_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX10Plus_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SSrc_b32, MCK_SSrc_b32, MCK_OpSel }, },
  { 43210 /* v_permlane16_swap_b32 */, AMDGPU::V_PERMLANE16_SWAP_B32_e64_gfx1250, Convert__Reg1_0__Reg1_1__Tie0_1_1__Tie1_2_2__DppFI1_3__DppBoundCtrl1_2, AMFBS_HasPermlane16Swap_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43210 /* v_permlane16_swap_b32 */, AMDGPU::V_PERMLANE16_SWAP_B32_e64_gfx9, Convert__Reg1_0__Reg1_1__Tie0_1_1__Tie1_2_2__DppFI1_3__DppBoundCtrl1_2, AMFBS_HasPermlane16Swap_isGFX9Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43232 /* v_permlane16_var_b32 */, AMDGPU::V_PERMLANE16_VAR_B32_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel }, },
  { 43253 /* v_permlane32_swap_b32 */, AMDGPU::V_PERMLANE32_SWAP_B32_e64_gfx9, Convert__Reg1_0__Reg1_1__Tie0_1_1__Tie1_2_2__DppFI1_3__DppBoundCtrl1_2, AMFBS_HasPermlane32Swap_isGFX9Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43292 /* v_permlane_bcast_b32 */, AMDGPU::V_PERMLANE_BCAST_B32_e64_gfx12, Convert__Reg1_0__Reg1_1__SSrc_b321_2__SSrc_b321_3, AMFBS_isGFX1250Plus_isGFX12Only_isWave32, { MCK_VGPR_32, MCK_VGPR_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 43313 /* v_permlane_down_b32 */, AMDGPU::V_PERMLANE_DOWN_B32_e64_gfx12, Convert__Reg1_0__Reg1_1__SSrc_b321_2__SSrc_b321_3, AMFBS_isGFX1250Plus_isGFX12Only_isWave32, { MCK_VGPR_32, MCK_VGPR_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 43333 /* v_permlane_idx_gen_b32 */, AMDGPU::V_PERMLANE_IDX_GEN_B32_e64_gfx12, Convert__Reg1_0__Reg1_1__SSrc_b321_2, AMFBS_isGFX1250Plus_isGFX12Only_isWave32, { MCK_VGPR_32, MCK_VGPR_32, MCK_SSrc_b32 }, },
  { 43356 /* v_permlane_up_b32 */, AMDGPU::V_PERMLANE_UP_B32_e64_gfx12, Convert__Reg1_0__Reg1_1__SSrc_b321_2__SSrc_b321_3, AMFBS_isGFX1250Plus_isGFX12Only_isWave32, { MCK_VGPR_32, MCK_VGPR_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 43374 /* v_permlane_xor_b32 */, AMDGPU::V_PERMLANE_XOR_B32_e64_gfx12, Convert__Reg1_0__Reg1_1__SSrc_b321_2__SSrc_b321_3, AMFBS_isGFX1250Plus_isGFX12Only_isWave32, { MCK_VGPR_32, MCK_VGPR_32, MCK_SSrc_b32, MCK_SSrc_b32 }, },
  { 43393 /* v_permlanex16_b32 */, AMDGPU::V_PERMLANEX16_B32_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SSrc_b32, MCK_SSrc_b32, MCK_OpSel }, },
  { 43393 /* v_permlanex16_b32 */, AMDGPU::V_PERMLANEX16_B32_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SSrc_b32, MCK_SSrc_b32, MCK_OpSel }, },
  { 43393 /* v_permlanex16_b32 */, AMDGPU::V_PERMLANEX16_B32_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX10Plus_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_SSrc_b32, MCK_SSrc_b32, MCK_OpSel }, },
  { 43411 /* v_permlanex16_var_b32 */, AMDGPU::V_PERMLANEX16_VAR_B32_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel }, },
  { 43433 /* v_pipeflush */, AMDGPU::V_PIPEFLUSH_e64_gfx10, Convert_NoOperands, AMFBS_isGFX10Plus_isGFX10Only, {  }, },
  { 43433 /* v_pipeflush */, AMDGPU::V_PIPEFLUSH_e64_gfx11, Convert_NoOperands, AMFBS_isGFX10Plus_isGFX11Only, {  }, },
  { 43433 /* v_pipeflush */, AMDGPU::V_PIPEFLUSH_e64_gfx12, Convert_NoOperands, AMFBS_isGFX10Plus_isGFX12Only, {  }, },
  { 43445 /* v_pk_add_bf16 */, AMDGPU::V_PK_ADD_BF16_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_HasBF16PackedInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VSrc_v2bf16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43459 /* v_pk_add_f16 */, AMDGPU::V_PK_ADD_F16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43459 /* v_pk_add_f16 */, AMDGPU::V_PK_ADD_F16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43459 /* v_pk_add_f16 */, AMDGPU::V_PK_ADD_F16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43459 /* v_pk_add_f16 */, AMDGPU::V_PK_ADD_F16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43472 /* v_pk_add_f32 */, AMDGPU::V_PK_ADD_F32_gfx12, ConvertCustom_cvtVOP3P, AMFBS_HasPackedFP32Ops_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_v2f32, MCK_VSrc_v2f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43472 /* v_pk_add_f32 */, AMDGPU::V_PK_ADD_F32_vi, ConvertCustom_cvtVOP3P, AMFBS_HasPackedFP32Ops_HasVOP3PInsts, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_v2f32, MCK_VSrc_v2f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43485 /* v_pk_add_i16 */, AMDGPU::V_PK_ADD_I16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43485 /* v_pk_add_i16 */, AMDGPU::V_PK_ADD_I16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43485 /* v_pk_add_i16 */, AMDGPU::V_PK_ADD_I16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43485 /* v_pk_add_i16 */, AMDGPU::V_PK_ADD_I16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43498 /* v_pk_add_max_i16 */, AMDGPU::V_PK_ADD_MAX_I16_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_HasPkAddMinMaxInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 43515 /* v_pk_add_max_u16 */, AMDGPU::V_PK_ADD_MAX_U16_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_HasPkAddMinMaxInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 43532 /* v_pk_add_min_i16 */, AMDGPU::V_PK_ADD_MIN_I16_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_HasPkAddMinMaxInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 43549 /* v_pk_add_min_u16 */, AMDGPU::V_PK_ADD_MIN_U16_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_HasPkAddMinMaxInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 43566 /* v_pk_add_u16 */, AMDGPU::V_PK_ADD_U16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43566 /* v_pk_add_u16 */, AMDGPU::V_PK_ADD_U16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43566 /* v_pk_add_u16 */, AMDGPU::V_PK_ADD_U16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43566 /* v_pk_add_u16 */, AMDGPU::V_PK_ADD_U16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43579 /* v_pk_ashrrev_i16 */, AMDGPU::V_PK_ASHRREV_I16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43579 /* v_pk_ashrrev_i16 */, AMDGPU::V_PK_ASHRREV_I16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43579 /* v_pk_ashrrev_i16 */, AMDGPU::V_PK_ASHRREV_I16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43579 /* v_pk_ashrrev_i16 */, AMDGPU::V_PK_ASHRREV_I16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43596 /* v_pk_fma_bf16 */, AMDGPU::V_PK_FMA_BF16_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_HasBF16PackedInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VSrc_v2bf16, MCK_VSrc_v2bf16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43610 /* v_pk_fma_f16 */, AMDGPU::V_PK_FMA_F16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43610 /* v_pk_fma_f16 */, AMDGPU::V_PK_FMA_F16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43610 /* v_pk_fma_f16 */, AMDGPU::V_PK_FMA_F16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43610 /* v_pk_fma_f16 */, AMDGPU::V_PK_FMA_F16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43623 /* v_pk_fma_f32 */, AMDGPU::V_PK_FMA_F32_gfx12, ConvertCustom_cvtVOP3P, AMFBS_HasPackedFP32Ops_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_v2f32, MCK_VSrc_v2f32, MCK_VSrc_v2f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43623 /* v_pk_fma_f32 */, AMDGPU::V_PK_FMA_F32_vi, ConvertCustom_cvtVOP3P, AMFBS_HasPackedFP32Ops_HasVOP3PInsts, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_v2f32, MCK_VSrc_v2f32, MCK_VSrc_v2f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43636 /* v_pk_fmac_f16 */, AMDGPU::V_PK_FMAC_F16_e64_gfx9, ConvertCustom_cvtVOP3OpSel, AMFBS_HasPkFmacF16Inst_isGFX9Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 43650 /* v_pk_lshlrev_b16 */, AMDGPU::V_PK_LSHLREV_B16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43650 /* v_pk_lshlrev_b16 */, AMDGPU::V_PK_LSHLREV_B16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43650 /* v_pk_lshlrev_b16 */, AMDGPU::V_PK_LSHLREV_B16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43650 /* v_pk_lshlrev_b16 */, AMDGPU::V_PK_LSHLREV_B16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43667 /* v_pk_lshrrev_b16 */, AMDGPU::V_PK_LSHRREV_B16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43667 /* v_pk_lshrrev_b16 */, AMDGPU::V_PK_LSHRREV_B16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43667 /* v_pk_lshrrev_b16 */, AMDGPU::V_PK_LSHRREV_B16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43667 /* v_pk_lshrrev_b16 */, AMDGPU::V_PK_LSHRREV_B16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43684 /* v_pk_mad_i16 */, AMDGPU::V_PK_MAD_I16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43684 /* v_pk_mad_i16 */, AMDGPU::V_PK_MAD_I16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43684 /* v_pk_mad_i16 */, AMDGPU::V_PK_MAD_I16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43684 /* v_pk_mad_i16 */, AMDGPU::V_PK_MAD_I16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43697 /* v_pk_mad_u16 */, AMDGPU::V_PK_MAD_U16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43697 /* v_pk_mad_u16 */, AMDGPU::V_PK_MAD_U16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43697 /* v_pk_mad_u16 */, AMDGPU::V_PK_MAD_U16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43697 /* v_pk_mad_u16 */, AMDGPU::V_PK_MAD_U16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43710 /* v_pk_max3_i16 */, AMDGPU::V_PK_MAX3_I16_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_HasPkMinMax3Insts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 43724 /* v_pk_max3_num_f16 */, AMDGPU::V_PK_MAX3_NUM_F16_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_HasMin3Max3PKF16_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43742 /* v_pk_max3_u16 */, AMDGPU::V_PK_MAX3_U16_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_HasPkMinMax3Insts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 43756 /* v_pk_max_f16 */, AMDGPU::V_PK_MAX_F16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43756 /* v_pk_max_f16 */, AMDGPU::V_PK_MAX_F16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43756 /* v_pk_max_f16 */, AMDGPU::V_PK_MAX_F16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43769 /* v_pk_max_i16 */, AMDGPU::V_PK_MAX_I16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43769 /* v_pk_max_i16 */, AMDGPU::V_PK_MAX_I16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43769 /* v_pk_max_i16 */, AMDGPU::V_PK_MAX_I16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43769 /* v_pk_max_i16 */, AMDGPU::V_PK_MAX_I16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43782 /* v_pk_max_num_bf16 */, AMDGPU::V_PK_MAX_NUM_BF16_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_HasBF16PackedInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VSrc_v2bf16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43800 /* v_pk_max_num_f16 */, AMDGPU::V_PK_MAX_NUM_F16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43817 /* v_pk_max_u16 */, AMDGPU::V_PK_MAX_U16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43817 /* v_pk_max_u16 */, AMDGPU::V_PK_MAX_U16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43817 /* v_pk_max_u16 */, AMDGPU::V_PK_MAX_U16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43817 /* v_pk_max_u16 */, AMDGPU::V_PK_MAX_U16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43830 /* v_pk_maximum3_f16 */, AMDGPU::V_PK_MAXIMUM3_F16_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_HasMinimum3Maximum3PKF16_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43830 /* v_pk_maximum3_f16 */, AMDGPU::V_PK_MAXIMUM3_F16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasMinimum3Maximum3PKF16_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43848 /* v_pk_maximum_f16 */, AMDGPU::V_PK_MAXIMUM_F16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43865 /* v_pk_min3_i16 */, AMDGPU::V_PK_MIN3_I16_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_HasPkMinMax3Insts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 43879 /* v_pk_min3_num_f16 */, AMDGPU::V_PK_MIN3_NUM_F16_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_HasMin3Max3PKF16_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43897 /* v_pk_min3_u16 */, AMDGPU::V_PK_MIN3_U16_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_HasPkMinMax3Insts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_Clamp }, },
  { 43911 /* v_pk_min_f16 */, AMDGPU::V_PK_MIN_F16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43911 /* v_pk_min_f16 */, AMDGPU::V_PK_MIN_F16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43911 /* v_pk_min_f16 */, AMDGPU::V_PK_MIN_F16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43924 /* v_pk_min_i16 */, AMDGPU::V_PK_MIN_I16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43924 /* v_pk_min_i16 */, AMDGPU::V_PK_MIN_I16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43924 /* v_pk_min_i16 */, AMDGPU::V_PK_MIN_I16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43924 /* v_pk_min_i16 */, AMDGPU::V_PK_MIN_I16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43937 /* v_pk_min_num_bf16 */, AMDGPU::V_PK_MIN_NUM_BF16_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_HasBF16PackedInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VSrc_v2bf16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43955 /* v_pk_min_num_f16 */, AMDGPU::V_PK_MIN_NUM_F16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43972 /* v_pk_min_u16 */, AMDGPU::V_PK_MIN_U16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43972 /* v_pk_min_u16 */, AMDGPU::V_PK_MIN_U16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43972 /* v_pk_min_u16 */, AMDGPU::V_PK_MIN_U16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43972 /* v_pk_min_u16 */, AMDGPU::V_PK_MIN_U16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43985 /* v_pk_minimum3_f16 */, AMDGPU::V_PK_MINIMUM3_F16_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_HasMinimum3Maximum3PKF16_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 43985 /* v_pk_minimum3_f16 */, AMDGPU::V_PK_MINIMUM3_F16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasMinimum3Maximum3PKF16_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 44003 /* v_pk_minimum_f16 */, AMDGPU::V_PK_MINIMUM_F16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 44020 /* v_pk_mov_b32 */, AMDGPU::V_PK_MOV_B32_vi, ConvertCustom_cvtVOP3P, AMFBS_HasPkMovB32_HasVOP3PInsts, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_v2b32, MCK_VSrc_v2b32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 44033 /* v_pk_mul_bf16 */, AMDGPU::V_PK_MUL_BF16_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_HasBF16PackedInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_v2bf16, MCK_VSrc_v2bf16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 44047 /* v_pk_mul_f16 */, AMDGPU::V_PK_MUL_F16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 44047 /* v_pk_mul_f16 */, AMDGPU::V_PK_MUL_F16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 44047 /* v_pk_mul_f16 */, AMDGPU::V_PK_MUL_F16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 44047 /* v_pk_mul_f16 */, AMDGPU::V_PK_MUL_F16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2f16, MCK_VSrc_v2f16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 44060 /* v_pk_mul_f32 */, AMDGPU::V_PK_MUL_F32_gfx12, ConvertCustom_cvtVOP3P, AMFBS_HasPackedFP32Ops_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_v2f32, MCK_VSrc_v2f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 44060 /* v_pk_mul_f32 */, AMDGPU::V_PK_MUL_F32_vi, ConvertCustom_cvtVOP3P, AMFBS_HasPackedFP32Ops_HasVOP3PInsts, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_v2f32, MCK_VSrc_v2f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 44073 /* v_pk_mul_lo_u16 */, AMDGPU::V_PK_MUL_LO_U16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 44073 /* v_pk_mul_lo_u16 */, AMDGPU::V_PK_MUL_LO_U16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 44073 /* v_pk_mul_lo_u16 */, AMDGPU::V_PK_MUL_LO_U16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 44073 /* v_pk_mul_lo_u16 */, AMDGPU::V_PK_MUL_LO_U16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 44089 /* v_pk_sub_i16 */, AMDGPU::V_PK_SUB_I16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 44089 /* v_pk_sub_i16 */, AMDGPU::V_PK_SUB_I16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 44089 /* v_pk_sub_i16 */, AMDGPU::V_PK_SUB_I16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 44089 /* v_pk_sub_i16 */, AMDGPU::V_PK_SUB_I16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 44102 /* v_pk_sub_u16 */, AMDGPU::V_PK_SUB_U16_gfx10, ConvertCustom_cvtVOP3P, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 44102 /* v_pk_sub_u16 */, AMDGPU::V_PK_SUB_U16_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 44102 /* v_pk_sub_u16 */, AMDGPU::V_PK_SUB_U16_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 44102 /* v_pk_sub_u16 */, AMDGPU::V_PK_SUB_U16_vi, ConvertCustom_cvtVOP3P, AMFBS_HasVOP3PInsts, { MCK_VGPR_32, MCK_VSrc_v2b16, MCK_VSrc_v2b16, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 44115 /* v_prng_b32 */, AMDGPU::V_PRNG_B32_e64_gfx1250, Convert__Reg1_0__VSrc_b321_1, AMFBS_HasPrngInst_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 44115 /* v_prng_b32 */, AMDGPU::V_PRNG_B32_e64_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_HasPrngInst_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 44126 /* v_qsad_pk_u16_u8 */, AMDGPU::V_QSAD_PK_U16_U8_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasQsadInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b32, MCK_VSrc_b64, MCK_Clamp }, },
  { 44126 /* v_qsad_pk_u16_u8 */, AMDGPU::V_QSAD_PK_U16_U8_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasQsadInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b32, MCK_VSrc_b64, MCK_Clamp }, },
  { 44126 /* v_qsad_pk_u16_u8 */, AMDGPU::V_QSAD_PK_U16_U8_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasQsadInsts_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b32, MCK_VSrc_b64, MCK_Clamp }, },
  { 44126 /* v_qsad_pk_u16_u8 */, AMDGPU::V_QSAD_PK_U16_U8_gfx7, ConvertCustom_cvtVOP3, AMFBS_HasQsadInsts_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b32, MCK_VSrc_b64, MCK_Clamp }, },
  { 44126 /* v_qsad_pk_u16_u8 */, AMDGPU::V_QSAD_PK_U16_U8_vi, ConvertCustom_cvtVOP3, AMFBS_HasQsadInsts_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b32, MCK_VSrc_b64, MCK_Clamp }, },
  { 44143 /* v_rcp_bf16 */, AMDGPU::V_RCP_BF16V_RCP_BF16_fake16_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods }, },
  { 44143 /* v_rcp_bf16 */, AMDGPU::V_RCP_BF16V_RCP_BF16_t16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel }, },
  { 44154 /* v_rcp_clamp_f32 */, AMDGPU::V_RCP_CLAMP_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44170 /* v_rcp_clamp_f64 */, AMDGPU::V_RCP_CLAMP_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44206 /* v_rcp_f64 */, AMDGPU::V_RCP_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44206 /* v_rcp_f64 */, AMDGPU::V_RCP_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44206 /* v_rcp_f64 */, AMDGPU::V_RCP_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44206 /* v_rcp_f64 */, AMDGPU::V_RCP_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44206 /* v_rcp_f64 */, AMDGPU::V_RCP_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44232 /* v_rcp_legacy_f32 */, AMDGPU::V_RCP_LEGACY_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44308 /* v_rndne_f64 */, AMDGPU::V_RNDNE_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44308 /* v_rndne_f64 */, AMDGPU::V_RNDNE_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44308 /* v_rndne_f64 */, AMDGPU::V_RNDNE_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44308 /* v_rndne_f64 */, AMDGPU::V_RNDNE_F64_e64_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44308 /* v_rndne_f64 */, AMDGPU::V_RNDNE_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44320 /* v_rsq_bf16 */, AMDGPU::V_RSQ_BF16V_RSQ_BF16_fake16_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods }, },
  { 44320 /* v_rsq_bf16 */, AMDGPU::V_RSQ_BF16V_RSQ_BF16_t16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel }, },
  { 44331 /* v_rsq_clamp_f32 */, AMDGPU::V_RSQ_CLAMP_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44347 /* v_rsq_clamp_f64 */, AMDGPU::V_RSQ_CLAMP_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44383 /* v_rsq_f64 */, AMDGPU::V_RSQ_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44383 /* v_rsq_f64 */, AMDGPU::V_RSQ_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44383 /* v_rsq_f64 */, AMDGPU::V_RSQ_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44383 /* v_rsq_f64 */, AMDGPU::V_RSQ_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44383 /* v_rsq_f64 */, AMDGPU::V_RSQ_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44393 /* v_rsq_legacy_f32 */, AMDGPU::V_RSQ_LEGACY_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44410 /* v_s_exp_f16 */, AMDGPU::V_S_EXP_F16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasPseudoScalarTrans_isGFX12Only, { MCK_SReg_32_XEXEC, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44422 /* v_s_exp_f32 */, AMDGPU::V_S_EXP_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasPseudoScalarTrans_isGFX12Only, { MCK_SReg_32_XEXEC, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44434 /* v_s_log_f16 */, AMDGPU::V_S_LOG_F16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasPseudoScalarTrans_isGFX12Only, { MCK_SReg_32_XEXEC, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44446 /* v_s_log_f32 */, AMDGPU::V_S_LOG_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasPseudoScalarTrans_isGFX12Only, { MCK_SReg_32_XEXEC, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44458 /* v_s_rcp_f16 */, AMDGPU::V_S_RCP_F16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasPseudoScalarTrans_isGFX12Only, { MCK_SReg_32_XEXEC, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44470 /* v_s_rcp_f32 */, AMDGPU::V_S_RCP_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasPseudoScalarTrans_isGFX12Only, { MCK_SReg_32_XEXEC, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44482 /* v_s_rsq_f16 */, AMDGPU::V_S_RSQ_F16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasPseudoScalarTrans_isGFX12Only, { MCK_SReg_32_XEXEC, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44494 /* v_s_rsq_f32 */, AMDGPU::V_S_RSQ_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasPseudoScalarTrans_isGFX12Only, { MCK_SReg_32_XEXEC, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44506 /* v_s_sqrt_f16 */, AMDGPU::V_S_SQRT_F16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasPseudoScalarTrans_isGFX12Only, { MCK_SReg_32_XEXEC, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44519 /* v_s_sqrt_f32 */, AMDGPU::V_S_SQRT_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasPseudoScalarTrans_isGFX12Only, { MCK_SReg_32_XEXEC, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44532 /* v_sad_hi_u8 */, AMDGPU::V_SAD_HI_U8_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasSadInsts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 44532 /* v_sad_hi_u8 */, AMDGPU::V_SAD_HI_U8_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasSadInsts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 44532 /* v_sad_hi_u8 */, AMDGPU::V_SAD_HI_U8_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasSadInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 44532 /* v_sad_hi_u8 */, AMDGPU::V_SAD_HI_U8_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_HasSadInsts_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 44532 /* v_sad_hi_u8 */, AMDGPU::V_SAD_HI_U8_vi, ConvertCustom_cvtVOP3, AMFBS_HasSadInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 44544 /* v_sad_u16 */, AMDGPU::V_SAD_U16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasSadInsts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 44544 /* v_sad_u16 */, AMDGPU::V_SAD_U16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasSadInsts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 44544 /* v_sad_u16 */, AMDGPU::V_SAD_U16_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasSadInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 44544 /* v_sad_u16 */, AMDGPU::V_SAD_U16_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_HasSadInsts_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 44544 /* v_sad_u16 */, AMDGPU::V_SAD_U16_vi, ConvertCustom_cvtVOP3, AMFBS_HasSadInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 44554 /* v_sad_u32 */, AMDGPU::V_SAD_U32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasSadInsts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 44554 /* v_sad_u32 */, AMDGPU::V_SAD_U32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasSadInsts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 44554 /* v_sad_u32 */, AMDGPU::V_SAD_U32_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasSadInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 44554 /* v_sad_u32 */, AMDGPU::V_SAD_U32_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_HasSadInsts_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 44554 /* v_sad_u32 */, AMDGPU::V_SAD_U32_vi, ConvertCustom_cvtVOP3, AMFBS_HasSadInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 44564 /* v_sad_u8 */, AMDGPU::V_SAD_U8_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasSadInsts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 44564 /* v_sad_u8 */, AMDGPU::V_SAD_U8_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasSadInsts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 44564 /* v_sad_u8 */, AMDGPU::V_SAD_U8_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasSadInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 44564 /* v_sad_u8 */, AMDGPU::V_SAD_U8_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_HasSadInsts_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 44564 /* v_sad_u8 */, AMDGPU::V_SAD_U8_vi, ConvertCustom_cvtVOP3, AMFBS_HasSadInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 44573 /* v_sat_pk4_i4_i8 */, AMDGPU::V_SAT_PK4_I4_I8V_SAT_PK4_I4_I8_fake16_e64_gfx1250, Convert__Reg1_0__VSrc_b321_1, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 44573 /* v_sat_pk4_i4_i8 */, AMDGPU::V_SAT_PK4_I4_I8V_SAT_PK4_I4_I8_t16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16, MCK_VSrc_b32, MCK_OpSel }, },
  { 44589 /* v_sat_pk4_u4_u8 */, AMDGPU::V_SAT_PK4_U4_U8V_SAT_PK4_U4_U8_fake16_e64_gfx1250, Convert__Reg1_0__VSrc_b321_1, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 44589 /* v_sat_pk4_u4_u8 */, AMDGPU::V_SAT_PK4_U4_U8V_SAT_PK4_U4_U8_t16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16, MCK_VSrc_b32, MCK_OpSel }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16_e64_gfx10, Convert__Reg1_0__VSrc_b321_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX9Plus_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16_e64_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX9Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_fake16_e64_gfx11, Convert__Reg1_0__VSrc_b321_1, AMFBS_UseFakeTrue16Insts_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_fake16_e64_gfx12, Convert__Reg1_0__VSrc_b321_1, AMFBS_UseFakeTrue16Insts_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX9Plus_isGFX11Only, { MCK_VGPR_16, MCK_VSrc_b32, MCK_OpSel }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX9Plus_isGFX12Only, { MCK_VGPR_16, MCK_VSrc_b32, MCK_OpSel }, },
  { 44621 /* v_screen_partition_4se_b32 */, AMDGPU::V_SCREEN_PARTITION_4SE_B32_e64_vi, Convert__Reg1_0__VSrc_b321_1, AMFBS_isGFX9Only_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32 }, },
  { 44648 /* v_sin_bf16 */, AMDGPU::V_SIN_BF16V_SIN_BF16_fake16_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods }, },
  { 44648 /* v_sin_bf16 */, AMDGPU::V_SIN_BF16V_SIN_BF16_t16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 44679 /* v_smfmac_f32_16x16x128_bf8_bf8 */, AMDGPU::V_SMFMAC_F32_16X16X128_BF8_BF8_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_AV_128_Align2, MCK_AV_128_Align2, MCK_AV_256_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 44710 /* v_smfmac_f32_16x16x128_bf8_fp8 */, AMDGPU::V_SMFMAC_F32_16X16X128_BF8_FP8_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_AV_128_Align2, MCK_AV_128_Align2, MCK_AV_256_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 44741 /* v_smfmac_f32_16x16x128_fp8_bf8 */, AMDGPU::V_SMFMAC_F32_16X16X128_FP8_BF8_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_AV_128_Align2, MCK_AV_128_Align2, MCK_AV_256_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 44772 /* v_smfmac_f32_16x16x128_fp8_fp8 */, AMDGPU::V_SMFMAC_F32_16X16X128_FP8_FP8_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_AV_128_Align2, MCK_AV_128_Align2, MCK_AV_256_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 44803 /* v_smfmac_f32_16x16x32_bf16 */, AMDGPU::V_SMFMAC_F32_16X16X32_BF16_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_isGFX940Plus, { MCK_AV_128_Align2, MCK_AV_64_Align2, MCK_AV_128_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 44830 /* v_smfmac_f32_16x16x32_f16 */, AMDGPU::V_SMFMAC_F32_16X16X32_F16_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_isGFX940Plus, { MCK_AV_128_Align2, MCK_AV_64_Align2, MCK_AV_128_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 44856 /* v_smfmac_f32_16x16x64_bf16 */, AMDGPU::V_SMFMAC_F32_16X16X64_BF16_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_AV_128_Align2, MCK_AV_128_Align2, MCK_AV_256_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 44883 /* v_smfmac_f32_16x16x64_bf8_bf8 */, AMDGPU::V_SMFMAC_F32_16X16X64_BF8_BF8_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_HasFP8Insts_isGFX940Plus, { MCK_AV_128_Align2, MCK_AV_64_Align2, MCK_AV_128_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 44913 /* v_smfmac_f32_16x16x64_bf8_fp8 */, AMDGPU::V_SMFMAC_F32_16X16X64_BF8_FP8_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_HasFP8Insts_isGFX940Plus, { MCK_AV_128_Align2, MCK_AV_64_Align2, MCK_AV_128_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 44943 /* v_smfmac_f32_16x16x64_f16 */, AMDGPU::V_SMFMAC_F32_16X16X64_F16_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_AV_128_Align2, MCK_AV_128_Align2, MCK_AV_256_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 44969 /* v_smfmac_f32_16x16x64_fp8_bf8 */, AMDGPU::V_SMFMAC_F32_16X16X64_FP8_BF8_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_HasFP8Insts_isGFX940Plus, { MCK_AV_128_Align2, MCK_AV_64_Align2, MCK_AV_128_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 44999 /* v_smfmac_f32_16x16x64_fp8_fp8 */, AMDGPU::V_SMFMAC_F32_16X16X64_FP8_FP8_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_HasFP8Insts_isGFX940Plus, { MCK_AV_128_Align2, MCK_AV_64_Align2, MCK_AV_128_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 45029 /* v_smfmac_f32_32x32x16_bf16 */, AMDGPU::V_SMFMAC_F32_32X32X16_BF16_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_isGFX940Plus, { MCK_AV_512_Align2, MCK_AV_64_Align2, MCK_AV_128_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 45056 /* v_smfmac_f32_32x32x16_f16 */, AMDGPU::V_SMFMAC_F32_32X32X16_F16_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_isGFX940Plus, { MCK_AV_512_Align2, MCK_AV_64_Align2, MCK_AV_128_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 45082 /* v_smfmac_f32_32x32x32_bf16 */, AMDGPU::V_SMFMAC_F32_32X32X32_BF16_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_AV_512_Align2, MCK_AV_128_Align2, MCK_AV_256_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 45109 /* v_smfmac_f32_32x32x32_bf8_bf8 */, AMDGPU::V_SMFMAC_F32_32X32X32_BF8_BF8_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_HasFP8Insts_isGFX940Plus, { MCK_AV_512_Align2, MCK_AV_64_Align2, MCK_AV_128_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 45139 /* v_smfmac_f32_32x32x32_bf8_fp8 */, AMDGPU::V_SMFMAC_F32_32X32X32_BF8_FP8_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_HasFP8Insts_isGFX940Plus, { MCK_AV_512_Align2, MCK_AV_64_Align2, MCK_AV_128_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 45169 /* v_smfmac_f32_32x32x32_f16 */, AMDGPU::V_SMFMAC_F32_32X32X32_F16_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_AV_512_Align2, MCK_AV_128_Align2, MCK_AV_256_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 45195 /* v_smfmac_f32_32x32x32_fp8_bf8 */, AMDGPU::V_SMFMAC_F32_32X32X32_FP8_BF8_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_HasFP8Insts_isGFX940Plus, { MCK_AV_512_Align2, MCK_AV_64_Align2, MCK_AV_128_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 45225 /* v_smfmac_f32_32x32x32_fp8_fp8 */, AMDGPU::V_SMFMAC_F32_32X32X32_FP8_FP8_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_HasFP8Insts_isGFX940Plus, { MCK_AV_512_Align2, MCK_AV_64_Align2, MCK_AV_128_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 45255 /* v_smfmac_f32_32x32x64_bf8_bf8 */, AMDGPU::V_SMFMAC_F32_32X32X64_BF8_BF8_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_AV_512_Align2, MCK_AV_128_Align2, MCK_AV_256_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 45285 /* v_smfmac_f32_32x32x64_bf8_fp8 */, AMDGPU::V_SMFMAC_F32_32X32X64_BF8_FP8_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_AV_512_Align2, MCK_AV_128_Align2, MCK_AV_256_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 45315 /* v_smfmac_f32_32x32x64_fp8_bf8 */, AMDGPU::V_SMFMAC_F32_32X32X64_FP8_BF8_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_AV_512_Align2, MCK_AV_128_Align2, MCK_AV_256_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 45345 /* v_smfmac_f32_32x32x64_fp8_fp8 */, AMDGPU::V_SMFMAC_F32_32X32X64_FP8_FP8_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_AV_512_Align2, MCK_AV_128_Align2, MCK_AV_256_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 45375 /* v_smfmac_i32_16x16x128_i8 */, AMDGPU::V_SMFMAC_I32_16X16X128_I8_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_AV_128_Align2, MCK_AV_128_Align2, MCK_AV_256_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 45401 /* v_smfmac_i32_16x16x64_i8 */, AMDGPU::V_SMFMAC_I32_16X16X64_I8_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_isGFX940Plus, { MCK_AV_128_Align2, MCK_AV_64_Align2, MCK_AV_128_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 45426 /* v_smfmac_i32_32x32x32_i8 */, AMDGPU::V_SMFMAC_I32_32X32X32_I8_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_isGFX940Plus, { MCK_AV_512_Align2, MCK_AV_64_Align2, MCK_AV_128_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 45451 /* v_smfmac_i32_32x32x64_i8 */, AMDGPU::V_SMFMAC_I32_32X32X64_I8_gfx940, Convert__Reg1_0__Reg1_1__Reg1_2__Reg1_3__CBSZ1_4__ABID1_5__Tie0_1_1, AMFBS_HasGFX950Insts_isGFX940Plus, { MCK_AV_512_Align2, MCK_AV_128_Align2, MCK_AV_256_Align2, MCK_VGPR_32, MCK_CBSZ, MCK_ABID }, },
  { 45476 /* v_sqrt_bf16 */, AMDGPU::V_SQRT_BF16V_SQRT_BF16_fake16_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods }, },
  { 45476 /* v_sqrt_bf16 */, AMDGPU::V_SQRT_BF16V_SQRT_BF16_t16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45510 /* v_sqrt_f64 */, AMDGPU::V_SQRT_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45510 /* v_sqrt_f64 */, AMDGPU::V_SQRT_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45510 /* v_sqrt_f64 */, AMDGPU::V_SQRT_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45510 /* v_sqrt_f64 */, AMDGPU::V_SQRT_F64_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45510 /* v_sqrt_f64 */, AMDGPU::V_SQRT_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_BoolReg, MCK_Clamp }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_BoolReg, MCK_Clamp }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_BoolReg, MCK_Clamp }, },
  { 45537 /* v_sub_co_u32 */, AMDGPU::V_SUB_I32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VGPR_32, MCK_Clamp }, },
  { 45537 /* v_sub_co_u32 */, AMDGPU::V_SUB_CO_U32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45537 /* v_sub_co_u32 */, AMDGPU::V_SUB_CO_U32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45537 /* v_sub_co_u32 */, AMDGPU::V_SUB_CO_U32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45537 /* v_sub_co_u32 */, AMDGPU::V_SUB_CO_U32_e64_gfx9, ConvertCustom_cvtVOP3, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45570 /* v_sub_i16 */, AMDGPU::V_SUB_I16_vi, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 45580 /* v_sub_i32 */, AMDGPU::V_SUB_I32_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45580 /* v_sub_i32 */, AMDGPU::V_SUB_I32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45590 /* v_sub_nc_i16 */, AMDGPU::V_SUB_NC_I16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 45590 /* v_sub_nc_i16 */, AMDGPU::V_SUB_NC_I16V_SUB_I16_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 45590 /* v_sub_nc_i16 */, AMDGPU::V_SUB_NC_I16V_SUB_I16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 45590 /* v_sub_nc_i16 */, AMDGPU::V_SUB_NC_I16V_SUB_I16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 45590 /* v_sub_nc_i16 */, AMDGPU::V_SUB_NC_I16V_SUB_I16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 45603 /* v_sub_nc_i32 */, AMDGPU::V_SUB_NC_I32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45603 /* v_sub_nc_i32 */, AMDGPU::V_SUB_NC_I32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45603 /* v_sub_nc_i32 */, AMDGPU::V_SUB_NC_I32_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX9Plus_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45616 /* v_sub_nc_u16 */, AMDGPU::V_SUB_NC_U16_gfx10, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX10Plus_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 45616 /* v_sub_nc_u16 */, AMDGPU::V_SUB_NC_U16_fake16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 45616 /* v_sub_nc_u16 */, AMDGPU::V_SUB_NC_U16_fake16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_OpSel, MCK_Clamp }, },
  { 45616 /* v_sub_nc_u16 */, AMDGPU::V_SUB_NC_U16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX10Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 45616 /* v_sub_nc_u16 */, AMDGPU::V_SUB_NC_U16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX10Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel, MCK_Clamp }, },
  { 45629 /* v_sub_nc_u32 */, AMDGPU::V_SUB_NC_U32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasAddNoCarryInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45629 /* v_sub_nc_u32 */, AMDGPU::V_SUB_NC_U32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasAddNoCarryInsts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45629 /* v_sub_nc_u32 */, AMDGPU::V_SUB_NC_U32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasAddNoCarryInsts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45642 /* v_sub_nc_u64 */, AMDGPU::V_SUB_U64_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_HasAddSubU64Insts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VSrc_b64, MCK_VSrc_b64, MCK_Clamp }, },
  { 45655 /* v_sub_u16 */, AMDGPU::V_SUB_U16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_Clamp }, },
  { 45665 /* v_sub_u32 */, AMDGPU::V_SUB_U32_e64_gfx9, ConvertCustom_cvtVOP3, AMFBS_HasAddNoCarryInsts_isGFX9Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45665 /* v_sub_u32 */, AMDGPU::V_SUB_U32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45675 /* v_subb_co_u32 */, AMDGPU::V_SUBB_CO_U32_e64_gfx9, ConvertCustom_cvtVOP3, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_BoolReg, MCK_Clamp }, },
  { 45689 /* v_subb_u32 */, AMDGPU::V_SUBB_U32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_BoolReg, MCK_Clamp }, },
  { 45689 /* v_subb_u32 */, AMDGPU::V_SUBB_U32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_BoolReg, MCK_Clamp }, },
  { 45700 /* v_subbrev_co_u32 */, AMDGPU::V_SUBBREV_CO_U32_e64_gfx9, ConvertCustom_cvtVOP3, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_BoolReg, MCK_Clamp }, },
  { 45717 /* v_subbrev_u32 */, AMDGPU::V_SUBBREV_U32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_BoolReg, MCK_Clamp }, },
  { 45717 /* v_subbrev_u32 */, AMDGPU::V_SUBBREV_U32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_BoolReg, MCK_Clamp }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_BoolReg, MCK_Clamp }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_BoolReg, MCK_Clamp }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_BoolReg, MCK_Clamp }, },
  { 45750 /* v_subrev_co_u32 */, AMDGPU::V_SUBREV_I32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VGPR_32, MCK_Clamp }, },
  { 45750 /* v_subrev_co_u32 */, AMDGPU::V_SUBREV_CO_U32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45750 /* v_subrev_co_u32 */, AMDGPU::V_SUBREV_CO_U32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45750 /* v_subrev_co_u32 */, AMDGPU::V_SUBREV_CO_U32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45750 /* v_subrev_co_u32 */, AMDGPU::V_SUBREV_CO_U32_e64_gfx9, ConvertCustom_cvtVOP3, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX10Only_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_Has16BitInsts_isGFX8GFX9_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 45792 /* v_subrev_i32 */, AMDGPU::V_SUBREV_I32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45805 /* v_subrev_nc_u32 */, AMDGPU::V_SUBREV_NC_U32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_HasAddNoCarryInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45805 /* v_subrev_nc_u32 */, AMDGPU::V_SUBREV_NC_U32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_HasAddNoCarryInsts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45805 /* v_subrev_nc_u32 */, AMDGPU::V_SUBREV_NC_U32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_HasAddNoCarryInsts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45821 /* v_subrev_u16 */, AMDGPU::V_SUBREV_U16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16, MCK_Clamp }, },
  { 45834 /* v_subrev_u32 */, AMDGPU::V_SUBREV_U32_e64_gfx9, ConvertCustom_cvtVOP3, AMFBS_HasAddNoCarryInsts_isGFX9Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45834 /* v_subrev_u32 */, AMDGPU::V_SUBREV_U32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VSrc_b32, MCK_VSrc_b32, MCK_Clamp }, },
  { 45883 /* v_swmmac_bf16_16x16x32_bf16 */, AMDGPU::V_SWMMAC_BF16_16X16X32_BF16_w64_twoaddr_gfx12, ConvertCustom_cvtSWMMAC, AMFBS_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_IndexKey8bit, MCK_NegLo, MCK_NegHi }, },
  { 45883 /* v_swmmac_bf16_16x16x32_bf16 */, AMDGPU::V_SWMMAC_BF16_16X16X32_BF16_w32_twoaddr_gfx12, ConvertCustom_cvtSWMMAC, AMFBS_isGFX12Only_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VGPR_32, MCK_IndexKey16bit, MCK_NegLo, MCK_NegHi }, },
  { 45911 /* v_swmmac_bf16_16x16x64_bf16 */, AMDGPU::V_SWMMAC_BF16_16X16X64_BF16_w32_twoaddr_gfx1250, ConvertCustom_cvtSWMMAC, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VGPR_32, MCK_IndexKey16bit, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 45939 /* v_swmmac_bf16f32_16x16x64_bf16 */, AMDGPU::V_SWMMAC_BF16F32_16X16X64_BF16_w32_twoaddr_gfx1250, ConvertCustom_cvtSWMMAC, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VGPR_32, MCK_IndexKey16bit, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 45970 /* v_swmmac_f16_16x16x128_bf8_bf8 */, AMDGPU::V_SWMMAC_F16_16X16X128_BF8_BF8_w32_twoaddr_gfx1250, ConvertCustom_cvtSWMMAC, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_IndexKey32bit, MCK_MatrixAReuse, MCK_MatrixBReuse }, },
  { 46001 /* v_swmmac_f16_16x16x128_bf8_fp8 */, AMDGPU::V_SWMMAC_F16_16X16X128_BF8_FP8_w32_twoaddr_gfx1250, ConvertCustom_cvtSWMMAC, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_IndexKey32bit, MCK_MatrixAReuse, MCK_MatrixBReuse }, },
  { 46032 /* v_swmmac_f16_16x16x128_fp8_bf8 */, AMDGPU::V_SWMMAC_F16_16X16X128_FP8_BF8_w32_twoaddr_gfx1250, ConvertCustom_cvtSWMMAC, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_IndexKey32bit, MCK_MatrixAReuse, MCK_MatrixBReuse }, },
  { 46063 /* v_swmmac_f16_16x16x128_fp8_fp8 */, AMDGPU::V_SWMMAC_F16_16X16X128_FP8_FP8_w32_twoaddr_gfx1250, ConvertCustom_cvtSWMMAC, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_IndexKey32bit, MCK_MatrixAReuse, MCK_MatrixBReuse }, },
  { 46094 /* v_swmmac_f16_16x16x32_f16 */, AMDGPU::V_SWMMAC_F16_16X16X32_F16_w64_twoaddr_gfx12, ConvertCustom_cvtSWMMAC, AMFBS_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_IndexKey8bit, MCK_NegLo, MCK_NegHi }, },
  { 46094 /* v_swmmac_f16_16x16x32_f16 */, AMDGPU::V_SWMMAC_F16_16X16X32_F16_w32_twoaddr_gfx12, ConvertCustom_cvtSWMMAC, AMFBS_isGFX12Only_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VGPR_32, MCK_IndexKey16bit, MCK_NegLo, MCK_NegHi }, },
  { 46120 /* v_swmmac_f16_16x16x64_f16 */, AMDGPU::V_SWMMAC_F16_16X16X64_F16_w32_twoaddr_gfx1250, ConvertCustom_cvtSWMMAC, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VGPR_32, MCK_IndexKey16bit, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 46146 /* v_swmmac_f32_16x16x128_bf8_bf8 */, AMDGPU::V_SWMMAC_F32_16X16X128_BF8_BF8_w32_twoaddr_gfx1250, ConvertCustom_cvtSWMMAC, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_IndexKey32bit, MCK_MatrixAReuse, MCK_MatrixBReuse }, },
  { 46177 /* v_swmmac_f32_16x16x128_bf8_fp8 */, AMDGPU::V_SWMMAC_F32_16X16X128_BF8_FP8_w32_twoaddr_gfx1250, ConvertCustom_cvtSWMMAC, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_IndexKey32bit, MCK_MatrixAReuse, MCK_MatrixBReuse }, },
  { 46208 /* v_swmmac_f32_16x16x128_fp8_bf8 */, AMDGPU::V_SWMMAC_F32_16X16X128_FP8_BF8_w32_twoaddr_gfx1250, ConvertCustom_cvtSWMMAC, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_IndexKey32bit, MCK_MatrixAReuse, MCK_MatrixBReuse }, },
  { 46239 /* v_swmmac_f32_16x16x128_fp8_fp8 */, AMDGPU::V_SWMMAC_F32_16X16X128_FP8_FP8_w32_twoaddr_gfx1250, ConvertCustom_cvtSWMMAC, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_IndexKey32bit, MCK_MatrixAReuse, MCK_MatrixBReuse }, },
  { 46270 /* v_swmmac_f32_16x16x32_bf16 */, AMDGPU::V_SWMMAC_F32_16X16X32_BF16_w64_twoaddr_gfx12, ConvertCustom_cvtSWMMAC, AMFBS_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_IndexKey8bit, MCK_NegLo, MCK_NegHi }, },
  { 46270 /* v_swmmac_f32_16x16x32_bf16 */, AMDGPU::V_SWMMAC_F32_16X16X32_BF16_w32_twoaddr_gfx12, ConvertCustom_cvtSWMMAC, AMFBS_isGFX12Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VGPR_32, MCK_IndexKey16bit, MCK_NegLo, MCK_NegHi }, },
  { 46297 /* v_swmmac_f32_16x16x32_bf8_bf8 */, AMDGPU::V_SWMMAC_F32_16X16X32_BF8_BF8_w64_twoaddr_gfx12, ConvertCustom_cvtSWMMAC, AMFBS_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_IndexKey8bit }, },
  { 46297 /* v_swmmac_f32_16x16x32_bf8_bf8 */, AMDGPU::V_SWMMAC_F32_16X16X32_BF8_BF8_w32_twoaddr_gfx12, ConvertCustom_cvtSWMMAC, AMFBS_isGFX12Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_IndexKey16bit }, },
  { 46327 /* v_swmmac_f32_16x16x32_bf8_fp8 */, AMDGPU::V_SWMMAC_F32_16X16X32_BF8_FP8_w64_twoaddr_gfx12, ConvertCustom_cvtSWMMAC, AMFBS_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_IndexKey8bit }, },
  { 46327 /* v_swmmac_f32_16x16x32_bf8_fp8 */, AMDGPU::V_SWMMAC_F32_16X16X32_BF8_FP8_w32_twoaddr_gfx12, ConvertCustom_cvtSWMMAC, AMFBS_isGFX12Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_IndexKey16bit }, },
  { 46357 /* v_swmmac_f32_16x16x32_f16 */, AMDGPU::V_SWMMAC_F32_16X16X32_F16_w64_twoaddr_gfx12, ConvertCustom_cvtSWMMAC, AMFBS_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_IndexKey8bit, MCK_NegLo, MCK_NegHi }, },
  { 46357 /* v_swmmac_f32_16x16x32_f16 */, AMDGPU::V_SWMMAC_F32_16X16X32_F16_w32_twoaddr_gfx12, ConvertCustom_cvtSWMMAC, AMFBS_isGFX12Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VGPR_32, MCK_IndexKey16bit, MCK_NegLo, MCK_NegHi }, },
  { 46383 /* v_swmmac_f32_16x16x32_fp8_bf8 */, AMDGPU::V_SWMMAC_F32_16X16X32_FP8_BF8_w64_twoaddr_gfx12, ConvertCustom_cvtSWMMAC, AMFBS_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_IndexKey8bit }, },
  { 46383 /* v_swmmac_f32_16x16x32_fp8_bf8 */, AMDGPU::V_SWMMAC_F32_16X16X32_FP8_BF8_w32_twoaddr_gfx12, ConvertCustom_cvtSWMMAC, AMFBS_isGFX12Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_IndexKey16bit }, },
  { 46413 /* v_swmmac_f32_16x16x32_fp8_fp8 */, AMDGPU::V_SWMMAC_F32_16X16X32_FP8_FP8_w64_twoaddr_gfx12, ConvertCustom_cvtSWMMAC, AMFBS_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_IndexKey8bit }, },
  { 46413 /* v_swmmac_f32_16x16x32_fp8_fp8 */, AMDGPU::V_SWMMAC_F32_16X16X32_FP8_FP8_w32_twoaddr_gfx12, ConvertCustom_cvtSWMMAC, AMFBS_isGFX12Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_IndexKey16bit }, },
  { 46443 /* v_swmmac_f32_16x16x64_bf16 */, AMDGPU::V_SWMMAC_F32_16X16X64_BF16_w32_twoaddr_gfx1250, ConvertCustom_cvtSWMMAC, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VGPR_32, MCK_IndexKey16bit, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 46470 /* v_swmmac_f32_16x16x64_f16 */, AMDGPU::V_SWMMAC_F32_16X16X64_F16_w32_twoaddr_gfx1250, ConvertCustom_cvtSWMMAC, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VGPR_32, MCK_IndexKey16bit, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 46496 /* v_swmmac_i32_16x16x128_iu8 */, AMDGPU::V_SWMMAC_I32_16X16X128_IU8_w32_twoaddr_gfx1250, ConvertCustom_cvtSWMMAC, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_IndexKey32bit, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_Clamp }, },
  { 46523 /* v_swmmac_i32_16x16x32_iu4 */, AMDGPU::V_SWMMAC_I32_16X16X32_IU4_w64_twoaddr_gfx12, ConvertCustom_cvtSWMMAC, AMFBS_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_IndexKey16bit, MCK_NegLo, MCK_Clamp }, },
  { 46523 /* v_swmmac_i32_16x16x32_iu4 */, AMDGPU::V_SWMMAC_I32_16X16X32_IU4_w32_twoaddr_gfx12, ConvertCustom_cvtSWMMAC, AMFBS_isGFX12Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_IndexKey16bit, MCK_NegLo, MCK_Clamp }, },
  { 46549 /* v_swmmac_i32_16x16x32_iu8 */, AMDGPU::V_SWMMAC_I32_16X16X32_IU8_w64_twoaddr_gfx12, ConvertCustom_cvtSWMMAC, AMFBS_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_IndexKey8bit, MCK_NegLo, MCK_Clamp }, },
  { 46549 /* v_swmmac_i32_16x16x32_iu8 */, AMDGPU::V_SWMMAC_I32_16X16X32_IU8_w32_twoaddr_gfx12, ConvertCustom_cvtSWMMAC, AMFBS_isGFX12Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_IndexKey16bit, MCK_NegLo, MCK_Clamp }, },
  { 46575 /* v_swmmac_i32_16x16x64_iu4 */, AMDGPU::V_SWMMAC_I32_16X16X64_IU4_w32_twoaddr_gfx12, ConvertCustom_cvtSWMMAC, AMFBS_isGFX12Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_NegLo, MCK_Clamp }, },
  { 46575 /* v_swmmac_i32_16x16x64_iu4 */, AMDGPU::V_SWMMAC_I32_16X16X64_IU4_w64_twoaddr_gfx12, ConvertCustom_cvtSWMMAC, AMFBS_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_IndexKey16bit, MCK_NegLo, MCK_Clamp }, },
  { 46601 /* v_tanh_bf16 */, AMDGPU::V_TANH_BF16V_TANH_BF16_fake16_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods }, },
  { 46601 /* v_tanh_bf16 */, AMDGPU::V_TANH_BF16V_TANH_BF16_t16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel }, },
  { 46613 /* v_tanh_f16 */, AMDGPU::V_TANH_F16V_TANH_F16_fake16_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_HasTanhInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 46613 /* v_tanh_f16 */, AMDGPU::V_TANH_F16V_TANH_F16_t16_e64_gfx1250, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_HasTanhInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 46624 /* v_tanh_f32 */, AMDGPU::V_TANH_F32_e64_gfx1250, ConvertCustom_cvtVOP3, AMFBS_HasTanhInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 46635 /* v_trig_preop_f64 */, AMDGPU::V_TRIG_PREOP_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 46635 /* v_trig_preop_f64 */, AMDGPU::V_TRIG_PREOP_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 46635 /* v_trig_preop_f64 */, AMDGPU::V_TRIG_PREOP_F64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 46635 /* v_trig_preop_f64 */, AMDGPU::V_TRIG_PREOP_F64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 46635 /* v_trig_preop_f64 */, AMDGPU::V_TRIG_PREOP_F64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_VSrc_b32, MCK_Clamp, MCK_OModSI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16_e64_vi, ConvertCustom_cvtVOP3, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_fake16_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_fake16_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_RegOrImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_e64_gfx6_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_RegOrImmWithFP32InputMods, MCK_Clamp, MCK_OModSI }, },
  { 46676 /* v_trunc_f64 */, AMDGPU::V_TRUNC_F64_e64_gfx10, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX10Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 46676 /* v_trunc_f64 */, AMDGPU::V_TRUNC_F64_e64_gfx11, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 46676 /* v_trunc_f64 */, AMDGPU::V_TRUNC_F64_e64_gfx12, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 46676 /* v_trunc_f64 */, AMDGPU::V_TRUNC_F64_e64_gfx7, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX7Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 46676 /* v_trunc_f64 */, AMDGPU::V_TRUNC_F64_e64_vi, ConvertCustom_cvtVOP3, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegOrImmWithFP64InputMods, MCK_Clamp, MCK_OModSI }, },
  { 46688 /* v_wmma_bf16_16x16x16_bf16 */, AMDGPU::V_WMMA_BF16_16X16X16_BF16_w64_twoaddr_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VISrc_64_bf16, MCK_NegLo, MCK_NegHi }, },
  { 46688 /* v_wmma_bf16_16x16x16_bf16 */, AMDGPU::V_WMMA_BF16_16X16X16_BF16_w32_twoaddr_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VISrc_128_bf16, MCK_NegLo, MCK_NegHi }, },
  { 46688 /* v_wmma_bf16_16x16x16_bf16 */, AMDGPU::V_WMMA_BF16_16X16X16_BF16_twoaddr_w64_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_128_f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi }, },
  { 46688 /* v_wmma_bf16_16x16x16_bf16 */, AMDGPU::V_WMMA_BF16_16X16X16_BF16_twoaddr_w32_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_256_f64, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi }, },
  { 46714 /* v_wmma_bf16_16x16x32_bf16 */, AMDGPU::V_WMMA_BF16_16X16X32_BF16_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_128_bf16, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 46740 /* v_wmma_bf16f32_16x16x32_bf16 */, AMDGPU::V_WMMA_BF16F32_16X16X32_BF16_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_256_f32, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 46769 /* v_wmma_f16_16x16x128_bf8_bf8 */, AMDGPU::V_WMMA_F16_16X16X128_BF8_BF8_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VISrc_128_f16, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 46798 /* v_wmma_f16_16x16x128_bf8_fp8 */, AMDGPU::V_WMMA_F16_16X16X128_BF8_FP8_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VISrc_128_f16, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 46827 /* v_wmma_f16_16x16x128_fp8_bf8 */, AMDGPU::V_WMMA_F16_16X16X128_FP8_BF8_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VISrc_128_f16, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 46856 /* v_wmma_f16_16x16x128_fp8_fp8 */, AMDGPU::V_WMMA_F16_16X16X128_FP8_FP8_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VISrc_128_f16, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 46885 /* v_wmma_f16_16x16x16_f16 */, AMDGPU::V_WMMA_F16_16X16X16_F16_w64_twoaddr_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VISrc_64_f16, MCK_NegLo, MCK_NegHi }, },
  { 46885 /* v_wmma_f16_16x16x16_f16 */, AMDGPU::V_WMMA_F16_16X16X16_F16_w32_twoaddr_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VISrc_128_f16, MCK_NegLo, MCK_NegHi }, },
  { 46885 /* v_wmma_f16_16x16x16_f16 */, AMDGPU::V_WMMA_F16_16X16X16_F16_twoaddr_w64_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_128_f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi }, },
  { 46885 /* v_wmma_f16_16x16x16_f16 */, AMDGPU::V_WMMA_F16_16X16X16_F16_twoaddr_w32_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_256_f64, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi }, },
  { 46909 /* v_wmma_f16_16x16x32_f16 */, AMDGPU::V_WMMA_F16_16X16X32_F16_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_128_f16, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 46933 /* v_wmma_f16_16x16x64_bf8_bf8 */, AMDGPU::V_WMMA_F16_16X16X64_BF8_BF8_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_128_f16, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 46961 /* v_wmma_f16_16x16x64_bf8_fp8 */, AMDGPU::V_WMMA_F16_16X16X64_BF8_FP8_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_128_f16, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 46989 /* v_wmma_f16_16x16x64_fp8_bf8 */, AMDGPU::V_WMMA_F16_16X16X64_FP8_BF8_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_128_f16, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47017 /* v_wmma_f16_16x16x64_fp8_fp8 */, AMDGPU::V_WMMA_F16_16X16X64_FP8_FP8_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_128_f16, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47045 /* v_wmma_f32_16x16x128_bf8_bf8 */, AMDGPU::V_WMMA_F32_16X16X128_BF8_BF8_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VISrc_256_f32, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47074 /* v_wmma_f32_16x16x128_bf8_fp8 */, AMDGPU::V_WMMA_F32_16X16X128_BF8_FP8_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VISrc_256_f32, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47103 /* v_wmma_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_F32_16X16X128_F8F6F4_f4_f4_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_256_f32, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_NegLo, MCK_NegHi }, },
  { 47103 /* v_wmma_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_F32_16X16X128_F8F6F4_f4_f6_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_VISrc_256_f32, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_NegLo, MCK_NegHi }, },
  { 47103 /* v_wmma_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_F32_16X16X128_F8F6F4_f4_f8_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VISrc_256_f32, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_NegLo, MCK_NegHi }, },
  { 47103 /* v_wmma_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_F32_16X16X128_F8F6F4_f6_f4_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_256_f32, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_NegLo, MCK_NegHi }, },
  { 47103 /* v_wmma_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_F32_16X16X128_F8F6F4_f6_f6_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_VISrc_256_f32, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_NegLo, MCK_NegHi }, },
  { 47103 /* v_wmma_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_F32_16X16X128_F8F6F4_f6_f8_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VISrc_256_f32, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_NegLo, MCK_NegHi }, },
  { 47103 /* v_wmma_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_F32_16X16X128_F8F6F4_f8_f4_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_256_f32, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_NegLo, MCK_NegHi }, },
  { 47103 /* v_wmma_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_F32_16X16X128_F8F6F4_f8_f6_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_VISrc_256_f32, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_NegLo, MCK_NegHi }, },
  { 47103 /* v_wmma_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_F32_16X16X128_F8F6F4_f8_f8_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VISrc_256_f32, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_NegLo, MCK_NegHi }, },
  { 47131 /* v_wmma_f32_16x16x128_fp8_bf8 */, AMDGPU::V_WMMA_F32_16X16X128_FP8_BF8_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VISrc_256_f32, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47160 /* v_wmma_f32_16x16x128_fp8_fp8 */, AMDGPU::V_WMMA_F32_16X16X128_FP8_FP8_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VISrc_256_f32, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47189 /* v_wmma_f32_16x16x16_bf16 */, AMDGPU::V_WMMA_F32_16X16X16_BF16_w64_twoaddr_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VISrc_128_f32, MCK_NegLo, MCK_NegHi }, },
  { 47189 /* v_wmma_f32_16x16x16_bf16 */, AMDGPU::V_WMMA_F32_16X16X16_BF16_twoaddr_w64_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_128_f32, MCK_NegLo, MCK_NegHi }, },
  { 47189 /* v_wmma_f32_16x16x16_bf16 */, AMDGPU::V_WMMA_F32_16X16X16_BF16_w32_twoaddr_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VISrc_256_f32, MCK_NegLo, MCK_NegHi }, },
  { 47189 /* v_wmma_f32_16x16x16_bf16 */, AMDGPU::V_WMMA_F32_16X16X16_BF16_twoaddr_w32_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_256_f64, MCK_NegLo, MCK_NegHi }, },
  { 47214 /* v_wmma_f32_16x16x16_bf8_bf8 */, AMDGPU::V_WMMA_F32_16X16X16_BF8_BF8_w64_twoaddr_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_VGPR_32, MCK_VISrc_128_f32, MCK_NegLo, MCK_NegHi }, },
  { 47214 /* v_wmma_f32_16x16x16_bf8_bf8 */, AMDGPU::V_WMMA_F32_16X16X16_BF8_BF8_w32_twoaddr_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VISrc_256_f32, MCK_NegLo, MCK_NegHi }, },
  { 47242 /* v_wmma_f32_16x16x16_bf8_fp8 */, AMDGPU::V_WMMA_F32_16X16X16_BF8_FP8_w64_twoaddr_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_VGPR_32, MCK_VISrc_128_f32, MCK_NegLo, MCK_NegHi }, },
  { 47242 /* v_wmma_f32_16x16x16_bf8_fp8 */, AMDGPU::V_WMMA_F32_16X16X16_BF8_FP8_w32_twoaddr_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VISrc_256_f32, MCK_NegLo, MCK_NegHi }, },
  { 47270 /* v_wmma_f32_16x16x16_f16 */, AMDGPU::V_WMMA_F32_16X16X16_F16_w64_twoaddr_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VISrc_128_f32, MCK_NegLo, MCK_NegHi }, },
  { 47270 /* v_wmma_f32_16x16x16_f16 */, AMDGPU::V_WMMA_F32_16X16X16_F16_twoaddr_w64_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_128_f32, MCK_NegLo, MCK_NegHi }, },
  { 47270 /* v_wmma_f32_16x16x16_f16 */, AMDGPU::V_WMMA_F32_16X16X16_F16_w32_twoaddr_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VISrc_256_f32, MCK_NegLo, MCK_NegHi }, },
  { 47270 /* v_wmma_f32_16x16x16_f16 */, AMDGPU::V_WMMA_F32_16X16X16_F16_twoaddr_w32_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_256_f64, MCK_NegLo, MCK_NegHi }, },
  { 47294 /* v_wmma_f32_16x16x16_fp8_bf8 */, AMDGPU::V_WMMA_F32_16X16X16_FP8_BF8_w64_twoaddr_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_VGPR_32, MCK_VISrc_128_f32, MCK_NegLo, MCK_NegHi }, },
  { 47294 /* v_wmma_f32_16x16x16_fp8_bf8 */, AMDGPU::V_WMMA_F32_16X16X16_FP8_BF8_w32_twoaddr_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VISrc_256_f32, MCK_NegLo, MCK_NegHi }, },
  { 47322 /* v_wmma_f32_16x16x16_fp8_fp8 */, AMDGPU::V_WMMA_F32_16X16X16_FP8_FP8_w64_twoaddr_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_VGPR_32, MCK_VISrc_128_f32, MCK_NegLo, MCK_NegHi }, },
  { 47322 /* v_wmma_f32_16x16x16_fp8_fp8 */, AMDGPU::V_WMMA_F32_16X16X16_FP8_FP8_w32_twoaddr_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VISrc_256_f32, MCK_NegLo, MCK_NegHi }, },
  { 47350 /* v_wmma_f32_16x16x32_bf16 */, AMDGPU::V_WMMA_F32_16X16X32_BF16_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_256_f32, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47375 /* v_wmma_f32_16x16x32_f16 */, AMDGPU::V_WMMA_F32_16X16X32_F16_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_256_f32, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47399 /* v_wmma_f32_16x16x4_f32 */, AMDGPU::V_WMMA_F32_16X16X4_F32_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VISrc_256_f32, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47422 /* v_wmma_f32_16x16x64_bf8_bf8 */, AMDGPU::V_WMMA_F32_16X16X64_BF8_BF8_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_256_f32, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47450 /* v_wmma_f32_16x16x64_bf8_fp8 */, AMDGPU::V_WMMA_F32_16X16X64_BF8_FP8_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_256_f32, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47478 /* v_wmma_f32_16x16x64_fp8_bf8 */, AMDGPU::V_WMMA_F32_16X16X64_FP8_BF8_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_256_f32, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47506 /* v_wmma_f32_16x16x64_fp8_fp8 */, AMDGPU::V_WMMA_F32_16X16X64_FP8_FP8_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_256_f32, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47534 /* v_wmma_f32_32x16x128_f4 */, AMDGPU::V_WMMA_F32_32X16X128_F4_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_512_b32, MCK_NegLo, MCK_NegHi }, },
  { 47558 /* v_wmma_i32_16x16x16_iu4 */, AMDGPU::V_WMMA_I32_16X16X16_IU4_w64_twoaddr_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_VGPR_32, MCK_VISrc_128_b32, MCK_NegLo, MCK_Clamp }, },
  { 47558 /* v_wmma_i32_16x16x16_iu4 */, AMDGPU::V_WMMA_I32_16X16X16_IU4_w32_twoaddr_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VGPR_32, MCK_VGPR_32, MCK_VISrc_256_b32, MCK_NegLo, MCK_Clamp }, },
  { 47558 /* v_wmma_i32_16x16x16_iu4 */, AMDGPU::V_WMMA_I32_16X16X16_IU4_twoaddr_w64_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VISrc_128_f32, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 47558 /* v_wmma_i32_16x16x16_iu4 */, AMDGPU::V_WMMA_I32_16X16X16_IU4_twoaddr_w32_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VISrc_256_f64, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 47582 /* v_wmma_i32_16x16x16_iu8 */, AMDGPU::V_WMMA_I32_16X16X16_IU8_w64_twoaddr_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_VGPR_32, MCK_VISrc_128_b32, MCK_NegLo, MCK_Clamp }, },
  { 47582 /* v_wmma_i32_16x16x16_iu8 */, AMDGPU::V_WMMA_I32_16X16X16_IU8_w32_twoaddr_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VISrc_256_b32, MCK_NegLo, MCK_Clamp }, },
  { 47582 /* v_wmma_i32_16x16x16_iu8 */, AMDGPU::V_WMMA_I32_16X16X16_IU8_twoaddr_w64_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VISrc_128_f32, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 47582 /* v_wmma_i32_16x16x16_iu8 */, AMDGPU::V_WMMA_I32_16X16X16_IU8_twoaddr_w32_gfx11, ConvertCustom_cvtVOP3P, AMFBS_isGFX11Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VISrc_256_f64, MCK_NegLo, MCK_NegHi, MCK_Clamp }, },
  { 47606 /* v_wmma_i32_16x16x32_iu4 */, AMDGPU::V_WMMA_I32_16X16X32_IU4_w64_twoaddr_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only_isWave64, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_VGPR_32, MCK_VGPR_32, MCK_VISrc_128_b32, MCK_NegLo, MCK_Clamp }, },
  { 47606 /* v_wmma_i32_16x16x32_iu4 */, AMDGPU::V_WMMA_I32_16X16X32_IU4_w32_twoaddr_gfx12, ConvertCustom_cvtVOP3P, AMFBS_isGFX12Only_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VISrc_256_b32, MCK_NegLo, MCK_Clamp }, },
  { 47630 /* v_wmma_i32_16x16x64_iu8 */, AMDGPU::V_WMMA_I32_16X16X64_IU8_w32_twoaddr_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_256_b32, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_Clamp }, },
  { 47654 /* v_wmma_ld_scale16_paired_b64 */, AMDGPU::V_WMMA_LD_SCALE16_PAIRED_B64_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_VCSrc_b64_Lo256, MCK_VCSrc_b64_Lo256, MCK_MatrixAScale, MCK_MatrixBScale, MCK_MatrixAScaleFmt, MCK_MatrixBScaleFmt, MCK_MatrixAReuse, MCK_MatrixBReuse }, },
  { 47683 /* v_wmma_ld_scale_paired_b32 */, AMDGPU::V_WMMA_LD_SCALE_PAIRED_B32_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX125xOnly_isWave32, { MCK_VCSrc_b32_Lo256, MCK_VCSrc_b32_Lo256, MCK_MatrixAScale, MCK_MatrixBScale, MCK_MatrixAScaleFmt, MCK_MatrixBScaleFmt, MCK_MatrixAReuse, MCK_MatrixBReuse }, },
  { 47710 /* v_wmma_scale16_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_SCALE16_F32_16X16X128_F8F6F4_f4_f4_w32_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_256_f32, MCK_VCSrc_b64_Lo256, MCK_VCSrc_b64_Lo256, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_MatrixAScale, MCK_MatrixBScale, MCK_MatrixAScaleFmt, MCK_MatrixBScaleFmt, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47710 /* v_wmma_scale16_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_SCALE16_F32_16X16X128_F8F6F4_f4_f6_w32_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_VISrc_256_f32, MCK_VCSrc_b64_Lo256, MCK_VCSrc_b64_Lo256, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_MatrixAScale, MCK_MatrixBScale, MCK_MatrixAScaleFmt, MCK_MatrixBScaleFmt, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47710 /* v_wmma_scale16_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_SCALE16_F32_16X16X128_F8F6F4_f4_f8_w32_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VISrc_256_f32, MCK_VCSrc_b64_Lo256, MCK_VCSrc_b64_Lo256, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_MatrixAScale, MCK_MatrixBScale, MCK_MatrixAScaleFmt, MCK_MatrixBScaleFmt, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47710 /* v_wmma_scale16_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_SCALE16_F32_16X16X128_F8F6F4_f6_f4_w32_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_256_f32, MCK_VCSrc_b64_Lo256, MCK_VCSrc_b64_Lo256, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_MatrixAScale, MCK_MatrixBScale, MCK_MatrixAScaleFmt, MCK_MatrixBScaleFmt, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47710 /* v_wmma_scale16_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_SCALE16_F32_16X16X128_F8F6F4_f6_f6_w32_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_VISrc_256_f32, MCK_VCSrc_b64_Lo256, MCK_VCSrc_b64_Lo256, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_MatrixAScale, MCK_MatrixBScale, MCK_MatrixAScaleFmt, MCK_MatrixBScaleFmt, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47710 /* v_wmma_scale16_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_SCALE16_F32_16X16X128_F8F6F4_f6_f8_w32_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VISrc_256_f32, MCK_VCSrc_b64_Lo256, MCK_VCSrc_b64_Lo256, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_MatrixAScale, MCK_MatrixBScale, MCK_MatrixAScaleFmt, MCK_MatrixBScaleFmt, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47710 /* v_wmma_scale16_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_SCALE16_F32_16X16X128_F8F6F4_f8_f4_w32_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_256_f32, MCK_VCSrc_b64_Lo256, MCK_VCSrc_b64_Lo256, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_MatrixAScale, MCK_MatrixBScale, MCK_MatrixAScaleFmt, MCK_MatrixBScaleFmt, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47710 /* v_wmma_scale16_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_SCALE16_F32_16X16X128_F8F6F4_f8_f6_w32_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_VISrc_256_f32, MCK_VCSrc_b64_Lo256, MCK_VCSrc_b64_Lo256, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_MatrixAScale, MCK_MatrixBScale, MCK_MatrixAScaleFmt, MCK_MatrixBScaleFmt, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47710 /* v_wmma_scale16_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_SCALE16_F32_16X16X128_F8F6F4_f8_f8_w32_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VISrc_256_f32, MCK_VCSrc_b64_Lo256, MCK_VCSrc_b64_Lo256, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_MatrixAScale, MCK_MatrixBScale, MCK_MatrixAScaleFmt, MCK_MatrixBScaleFmt, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47746 /* v_wmma_scale16_f32_32x16x128_f4 */, AMDGPU::V_WMMA_SCALE16_F32_32X16X128_F4_w32_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_512_b32, MCK_VCSrc_b64_Lo256, MCK_VCSrc_b64_Lo256, MCK_MatrixAScale, MCK_MatrixBScale, MCK_MatrixAScaleFmt, MCK_MatrixBScaleFmt, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47778 /* v_wmma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_SCALE_F32_16X16X128_F8F6F4_f4_f4_w32_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_256_f32, MCK_VCSrc_b32_Lo256, MCK_VCSrc_b32_Lo256, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_MatrixAScale, MCK_MatrixBScale, MCK_MatrixAScaleFmt, MCK_MatrixBScaleFmt, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47778 /* v_wmma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_SCALE_F32_16X16X128_F8F6F4_f4_f6_w32_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_VISrc_256_f32, MCK_VCSrc_b32_Lo256, MCK_VCSrc_b32_Lo256, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_MatrixAScale, MCK_MatrixBScale, MCK_MatrixAScaleFmt, MCK_MatrixBScaleFmt, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47778 /* v_wmma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_SCALE_F32_16X16X128_F8F6F4_f4_f8_w32_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VISrc_256_f32, MCK_VCSrc_b32_Lo256, MCK_VCSrc_b32_Lo256, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_MatrixAScale, MCK_MatrixBScale, MCK_MatrixAScaleFmt, MCK_MatrixBScaleFmt, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47778 /* v_wmma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_SCALE_F32_16X16X128_F8F6F4_f6_f4_w32_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_256_f32, MCK_VCSrc_b32_Lo256, MCK_VCSrc_b32_Lo256, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_MatrixAScale, MCK_MatrixBScale, MCK_MatrixAScaleFmt, MCK_MatrixBScaleFmt, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47778 /* v_wmma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_SCALE_F32_16X16X128_F8F6F4_f6_f6_w32_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_VISrc_256_f32, MCK_VCSrc_b32_Lo256, MCK_VCSrc_b32_Lo256, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_MatrixAScale, MCK_MatrixBScale, MCK_MatrixAScaleFmt, MCK_MatrixBScaleFmt, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47778 /* v_wmma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_SCALE_F32_16X16X128_F8F6F4_f6_f8_w32_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VISrc_256_f32, MCK_VCSrc_b32_Lo256, MCK_VCSrc_b32_Lo256, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_MatrixAScale, MCK_MatrixBScale, MCK_MatrixAScaleFmt, MCK_MatrixBScaleFmt, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47778 /* v_wmma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_SCALE_F32_16X16X128_F8F6F4_f8_f4_w32_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_256_f32, MCK_VCSrc_b32_Lo256, MCK_VCSrc_b32_Lo256, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_MatrixAScale, MCK_MatrixBScale, MCK_MatrixAScaleFmt, MCK_MatrixBScaleFmt, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47778 /* v_wmma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_SCALE_F32_16X16X128_F8F6F4_f8_f6_w32_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_384_AlignTarget, MCK_VISrc_256_f32, MCK_VCSrc_b32_Lo256, MCK_VCSrc_b32_Lo256, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_MatrixAScale, MCK_MatrixBScale, MCK_MatrixAScaleFmt, MCK_MatrixBScaleFmt, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47778 /* v_wmma_scale_f32_16x16x128_f8f6f4 */, AMDGPU::V_WMMA_SCALE_F32_16X16X128_F8F6F4_f8_f8_w32_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_VISrc_256_f32, MCK_VCSrc_b32_Lo256, MCK_VCSrc_b32_Lo256, MCK_MatrixAFMT, MCK_MatrixBFMT, MCK_MatrixAScale, MCK_MatrixBScale, MCK_MatrixAScaleFmt, MCK_MatrixBScaleFmt, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47812 /* v_wmma_scale_f32_32x16x128_f4 */, AMDGPU::V_WMMA_SCALE_F32_32X16X128_F4_w32_gfx1250, ConvertCustom_cvtVOP3P, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_VReg_256_AlignTarget, MCK_VISrc_512_b32, MCK_VCSrc_b32_Lo256, MCK_VCSrc_b32_Lo256, MCK_MatrixAScale, MCK_MatrixBScale, MCK_MatrixAScaleFmt, MCK_MatrixBScaleFmt, MCK_MatrixAReuse, MCK_MatrixBReuse, MCK_NegLo, MCK_NegHi }, },
  { 47858 /* v_xad_u32 */, AMDGPU::V_XAD_U32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 47858 /* v_xad_u32 */, AMDGPU::V_XAD_U32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 47858 /* v_xad_u32 */, AMDGPU::V_XAD_U32_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 47858 /* v_xad_u32 */, AMDGPU::V_XAD_U32_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX9Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 47868 /* v_xnor_b32 */, AMDGPU::V_XNOR_B32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_HasDLInsts_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 47868 /* v_xnor_b32 */, AMDGPU::V_XNOR_B32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_HasDLInsts_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 47868 /* v_xnor_b32 */, AMDGPU::V_XNOR_B32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_HasDLInsts_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 47868 /* v_xnor_b32 */, AMDGPU::V_XNOR_B32_e64_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_HasDLInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 47879 /* v_xor3_b32 */, AMDGPU::V_XOR3_B32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 47879 /* v_xor3_b32 */, AMDGPU::V_XOR3_B32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 47879 /* v_xor3_b32 */, AMDGPU::V_XOR3_B32_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2__VSrc_b321_3, AMFBS_isGFX10Plus_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 47890 /* v_xor_b16 */, AMDGPU::V_XOR_B16_fake16_e64_gfx11, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 47890 /* v_xor_b16 */, AMDGPU::V_XOR_B16_fake16_e64_gfx12, Convert__Reg1_0__VSrc_b161_1__VSrc_b161_2, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b16, MCK_VSrc_b16 }, },
  { 47890 /* v_xor_b16 */, AMDGPU::V_XOR_B16_t16_e64_gfx11, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX11Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 47890 /* v_xor_b16 */, AMDGPU::V_XOR_B16_t16_e64_gfx12, ConvertCustom_cvtVOP3OpSel, AMFBS_isGFX11Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VSrcT_b16, MCK_VSrcT_b16, MCK_OpSel }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_e64_gfx10, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_e64_gfx11, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_e64_gfx12, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_e64_gfx6_gfx7, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX6GFX7, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_e64_vi, Convert__Reg1_0__VSrc_b321_1__VSrc_b321_2, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VSrc_b32, MCK_VSrc_b32 }, },
};

static const MatchEntry MatchTable2[] = {
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24453 /* v_add_u16 */, AMDGPU::V_ADD_U16_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX8GFX9_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24463 /* v_add_u32 */, AMDGPU::V_ADD_U32_sdwa_vi, ConvertCustom_cvtSdwaVOP2b, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24487 /* v_addc_u32 */, AMDGPU::V_ADDC_U32_sdwa_vi, ConvertCustom_cvtSdwaVOP2b, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_VCC, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24618 /* v_ashrrev_i16 */, AMDGPU::V_ASHRREV_I16_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25226 /* v_cmp_f_f32 */, AMDGPU::V_CMP_F_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25282 /* v_cmp_f_i16 */, AMDGPU::V_CMP_F_I16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25310 /* v_cmp_f_i32 */, AMDGPU::V_CMP_F_I32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25366 /* v_cmp_f_u16 */, AMDGPU::V_CMP_F_U16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25394 /* v_cmp_f_u32 */, AMDGPU::V_CMP_F_U32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27544 /* v_cmp_t_i16 */, AMDGPU::V_CMP_T_I16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27572 /* v_cmp_t_i32 */, AMDGPU::V_CMP_T_I32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27628 /* v_cmp_t_u16 */, AMDGPU::V_CMP_T_U16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27656 /* v_cmp_t_u32 */, AMDGPU::V_CMP_T_U32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27712 /* v_cmp_tru_f16 */, AMDGPU::V_CMP_TRU_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27744 /* v_cmp_tru_f32 */, AMDGPU::V_CMP_TRU_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30074 /* v_cmpx_class_f32 */, AMDGPU::V_CMPX_CLASS_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30182 /* v_cmpx_eq_f32 */, AMDGPU::V_CMPX_EQ_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30278 /* v_cmpx_eq_i32 */, AMDGPU::V_CMPX_EQ_I32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30374 /* v_cmpx_eq_u32 */, AMDGPU::V_CMPX_EQ_U32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30438 /* v_cmpx_f_f16 */, AMDGPU::V_CMPX_F_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30468 /* v_cmpx_f_f32 */, AMDGPU::V_CMPX_F_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30528 /* v_cmpx_f_i16 */, AMDGPU::V_CMPX_F_I16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30558 /* v_cmpx_f_i32 */, AMDGPU::V_CMPX_F_I32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30618 /* v_cmpx_f_u16 */, AMDGPU::V_CMPX_F_U16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30648 /* v_cmpx_f_u32 */, AMDGPU::V_CMPX_F_U32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30740 /* v_cmpx_ge_f32 */, AMDGPU::V_CMPX_GE_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30836 /* v_cmpx_ge_i32 */, AMDGPU::V_CMPX_GE_I32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30932 /* v_cmpx_ge_u32 */, AMDGPU::V_CMPX_GE_U32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31028 /* v_cmpx_gt_f32 */, AMDGPU::V_CMPX_GT_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31124 /* v_cmpx_gt_i32 */, AMDGPU::V_CMPX_GT_I32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31220 /* v_cmpx_gt_u32 */, AMDGPU::V_CMPX_GT_U32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31316 /* v_cmpx_le_f32 */, AMDGPU::V_CMPX_LE_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31412 /* v_cmpx_le_i32 */, AMDGPU::V_CMPX_LE_I32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31508 /* v_cmpx_le_u32 */, AMDGPU::V_CMPX_LE_U32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31604 /* v_cmpx_lg_f32 */, AMDGPU::V_CMPX_LG_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31700 /* v_cmpx_lt_f32 */, AMDGPU::V_CMPX_LT_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31796 /* v_cmpx_lt_i32 */, AMDGPU::V_CMPX_LT_I32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31892 /* v_cmpx_lt_u32 */, AMDGPU::V_CMPX_LT_U32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31988 /* v_cmpx_ne_i32 */, AMDGPU::V_CMPX_NE_I32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32084 /* v_cmpx_ne_u32 */, AMDGPU::V_CMPX_NE_U32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32182 /* v_cmpx_neq_f32 */, AMDGPU::V_CMPX_NEQ_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32284 /* v_cmpx_nge_f32 */, AMDGPU::V_CMPX_NGE_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32386 /* v_cmpx_ngt_f32 */, AMDGPU::V_CMPX_NGT_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32488 /* v_cmpx_nle_f32 */, AMDGPU::V_CMPX_NLE_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32590 /* v_cmpx_nlg_f32 */, AMDGPU::V_CMPX_NLG_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32692 /* v_cmpx_nlt_f32 */, AMDGPU::V_CMPX_NLT_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32790 /* v_cmpx_o_f32 */, AMDGPU::V_CMPX_O_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32940 /* v_cmpx_t_i16 */, AMDGPU::V_CMPX_T_I16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32970 /* v_cmpx_t_i32 */, AMDGPU::V_CMPX_T_I32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33030 /* v_cmpx_t_u16 */, AMDGPU::V_CMPX_T_U16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33060 /* v_cmpx_t_u32 */, AMDGPU::V_CMPX_T_U32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33120 /* v_cmpx_tru_f16 */, AMDGPU::V_CMPX_TRU_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33154 /* v_cmpx_tru_f32 */, AMDGPU::V_CMPX_TRU_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33252 /* v_cmpx_u_f32 */, AMDGPU::V_CMPX_U_F32_sdwa_vi, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA8, { MCK_VCC, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_sdwa_vi, ConvertCustom_cvtSdwaVOP2e, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_VCC, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33736 /* v_cvt_flr_i32_f32 */, AMDGPU::V_CVT_FLR_I32_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasCvtNormInsts_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasCvtNormInsts_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 34376 /* v_cvt_rpi_i32_f32 */, AMDGPU::V_CVT_RPI_I32_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38179 /* v_exp_legacy_f32 */, AMDGPU::V_EXP_LEGACY_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX7GFX8GFX9_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38196 /* v_ffbh_i32 */, AMDGPU::V_FFBH_I32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38207 /* v_ffbh_u32 */, AMDGPU::V_FFBH_U32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38218 /* v_ffbl_b32 */, AMDGPU::V_FFBL_B32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38514 /* v_fmac_f32 */, AMDGPU::V_FMAC_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasDLInsts_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 39071 /* v_log_legacy_f32 */, AMDGPU::V_LOG_LEGACY_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX7GFX8GFX9_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 39154 /* v_lshlrev_b16 */, AMDGPU::V_LSHLREV_B16_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39218 /* v_lshrrev_b16 */, AMDGPU::V_LSHRREV_B16_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39260 /* v_mac_f16 */, AMDGPU::V_MAC_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39270 /* v_mac_f32 */, AMDGPU::V_MAC_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39757 /* v_max_f16 */, AMDGPU::V_MAX_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39767 /* v_max_f32 */, AMDGPU::V_MAX_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39787 /* v_max_i16 */, AMDGPU::V_MAX_I16_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39876 /* v_max_u16 */, AMDGPU::V_MAX_U16_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 40317 /* v_mfma_f32_16x16x16bf16 */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40317 /* v_mfma_f32_16x16x16bf16 */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40341 /* v_mfma_f32_16x16x16bf16_1k */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40341 /* v_mfma_f32_16x16x16bf16_1k */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40368 /* v_mfma_f32_16x16x16f16 */, AMDGPU::V_MFMA_F32_16X16X16F16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40368 /* v_mfma_f32_16x16x16f16 */, AMDGPU::V_MFMA_F32_16X16X16F16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40417 /* v_mfma_f32_16x16x1f32 */, AMDGPU::V_MFMA_F32_16X16X1F32_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40417 /* v_mfma_f32_16x16x1f32 */, AMDGPU::V_MFMA_F32_16X16X1F32_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40623 /* v_mfma_f32_16x16x32bf16 */, AMDGPU::V_MFMA_F32_16X16X32_BF16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40623 /* v_mfma_f32_16x16x32bf16 */, AMDGPU::V_MFMA_F32_16X16X32_BF16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40647 /* v_mfma_f32_16x16x32f16 */, AMDGPU::V_MFMA_F32_16X16X32_F16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40647 /* v_mfma_f32_16x16x32f16 */, AMDGPU::V_MFMA_F32_16X16X32_F16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40746 /* v_mfma_f32_16x16x4bf16 */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40746 /* v_mfma_f32_16x16x4bf16 */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40769 /* v_mfma_f32_16x16x4bf16_1k */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40769 /* v_mfma_f32_16x16x4bf16_1k */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40795 /* v_mfma_f32_16x16x4f16 */, AMDGPU::V_MFMA_F32_16X16X4F16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40795 /* v_mfma_f32_16x16x4f16 */, AMDGPU::V_MFMA_F32_16X16X4F16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40817 /* v_mfma_f32_16x16x4f32 */, AMDGPU::V_MFMA_F32_16X16X4F32_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40817 /* v_mfma_f32_16x16x4f32 */, AMDGPU::V_MFMA_F32_16X16X4F32_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40886 /* v_mfma_f32_16x16x8xf32 */, AMDGPU::V_MFMA_F32_16X16X8XF32_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40886 /* v_mfma_f32_16x16x8xf32 */, AMDGPU::V_MFMA_F32_16X16X8XF32_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41070 /* v_mfma_f32_32x32x16bf16 */, AMDGPU::V_MFMA_F32_32X32X16_BF16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41070 /* v_mfma_f32_32x32x16bf16 */, AMDGPU::V_MFMA_F32_32X32X16_BF16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41094 /* v_mfma_f32_32x32x16f16 */, AMDGPU::V_MFMA_F32_32X32X16_F16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41094 /* v_mfma_f32_32x32x16f16 */, AMDGPU::V_MFMA_F32_32X32X16_F16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41143 /* v_mfma_f32_32x32x1f32 */, AMDGPU::V_MFMA_F32_32X32X1F32_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_1024_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41143 /* v_mfma_f32_32x32x1f32 */, AMDGPU::V_MFMA_F32_32X32X1F32_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_1024_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_1024_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41211 /* v_mfma_f32_32x32x2f32 */, AMDGPU::V_MFMA_F32_32X32X2F32_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41211 /* v_mfma_f32_32x32x2f32 */, AMDGPU::V_MFMA_F32_32X32X2F32_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41310 /* v_mfma_f32_32x32x4bf16 */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41310 /* v_mfma_f32_32x32x4bf16 */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41333 /* v_mfma_f32_32x32x4bf16_1k */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41333 /* v_mfma_f32_32x32x4bf16_1k */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41359 /* v_mfma_f32_32x32x4f16 */, AMDGPU::V_MFMA_F32_32X32X4F16_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41359 /* v_mfma_f32_32x32x4f16 */, AMDGPU::V_MFMA_F32_32X32X4F16_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41381 /* v_mfma_f32_32x32x4xf32 */, AMDGPU::V_MFMA_F32_32X32X4XF32_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41381 /* v_mfma_f32_32x32x4xf32 */, AMDGPU::V_MFMA_F32_32X32X4XF32_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41478 /* v_mfma_f32_32x32x8bf16 */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41478 /* v_mfma_f32_32x32x8bf16 */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41501 /* v_mfma_f32_32x32x8bf16_1k */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41501 /* v_mfma_f32_32x32x8bf16_1k */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41527 /* v_mfma_f32_32x32x8f16 */, AMDGPU::V_MFMA_F32_32X32X8F16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41527 /* v_mfma_f32_32x32x8f16 */, AMDGPU::V_MFMA_F32_32X32X8F16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41574 /* v_mfma_f32_4x4x1f32 */, AMDGPU::V_MFMA_F32_4X4X1F32_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41574 /* v_mfma_f32_4x4x1f32 */, AMDGPU::V_MFMA_F32_4X4X1F32_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41666 /* v_mfma_f32_4x4x4bf16 */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41666 /* v_mfma_f32_4x4x4bf16 */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41687 /* v_mfma_f32_4x4x4bf16_1k */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41687 /* v_mfma_f32_4x4x4bf16_1k */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41711 /* v_mfma_f32_4x4x4f16 */, AMDGPU::V_MFMA_F32_4X4X4F16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41711 /* v_mfma_f32_4x4x4f16 */, AMDGPU::V_MFMA_F32_4X4X4F16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41754 /* v_mfma_f64_16x16x4f64 */, AMDGPU::V_MFMA_F64_16X16X4F64_gfx940_acd, Convert__RegByHwMode_AReg_256_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_256_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_256_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_256_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41754 /* v_mfma_f64_16x16x4f64 */, AMDGPU::V_MFMA_F64_16X16X4F64_gfx940_vcd, Convert__RegByHwMode_VReg_256_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_256_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_256_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41800 /* v_mfma_f64_4x4x4f64 */, AMDGPU::V_MFMA_F64_4X4X4F64_gfx940_acd, Convert__RegByHwMode_AReg_64_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_64_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_64_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41800 /* v_mfma_f64_4x4x4f64 */, AMDGPU::V_MFMA_F64_4X4X4F64_gfx940_vcd, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_64_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_64_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41865 /* v_mfma_i32_16x16x32i8 */, AMDGPU::V_MFMA_I32_16X16X32I8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41865 /* v_mfma_i32_16x16x32i8 */, AMDGPU::V_MFMA_I32_16X16X32I8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41912 /* v_mfma_i32_16x16x4i8 */, AMDGPU::V_MFMA_I32_16X16X4I8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41912 /* v_mfma_i32_16x16x4i8 */, AMDGPU::V_MFMA_I32_16X16X4I8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41956 /* v_mfma_i32_16x16x64i8 */, AMDGPU::V_MFMA_I32_16X16X64_I8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41956 /* v_mfma_i32_16x16x64i8 */, AMDGPU::V_MFMA_I32_16X16X64_I8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42001 /* v_mfma_i32_32x32x16i8 */, AMDGPU::V_MFMA_I32_32X32X16I8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42001 /* v_mfma_i32_32x32x16i8 */, AMDGPU::V_MFMA_I32_32X32X16I8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42046 /* v_mfma_i32_32x32x32i8 */, AMDGPU::V_MFMA_I32_32X32X32_I8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42046 /* v_mfma_i32_32x32x32i8 */, AMDGPU::V_MFMA_I32_32X32X32_I8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42093 /* v_mfma_i32_32x32x4i8 */, AMDGPU::V_MFMA_I32_32X32X4I8_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42093 /* v_mfma_i32_32x32x4i8 */, AMDGPU::V_MFMA_I32_32X32X4I8_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42159 /* v_mfma_i32_4x4x4i8 */, AMDGPU::V_MFMA_I32_4X4X4I8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42159 /* v_mfma_i32_4x4x4i8 */, AMDGPU::V_MFMA_I32_4X4X4I8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42361 /* v_min_f16 */, AMDGPU::V_MIN_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42371 /* v_min_f32 */, AMDGPU::V_MIN_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42391 /* v_min_i16 */, AMDGPU::V_MIN_I16_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42480 /* v_min_u16 */, AMDGPU::V_MIN_U16_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42966 /* v_mul_legacy_f32 */, AMDGPU::V_MUL_LEGACY_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_isGCN3ExcludingGFX90A_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42996 /* v_mul_lo_u16 */, AMDGPU::V_MUL_LO_U16_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 43059 /* v_nop */, AMDGPU::V_NOP_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, {  }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX9Plus_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45655 /* v_sub_u16 */, AMDGPU::V_SUB_U16_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX8GFX9_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45665 /* v_sub_u32 */, AMDGPU::V_SUB_U32_sdwa_vi, ConvertCustom_cvtSdwaVOP2b, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45689 /* v_subb_u32 */, AMDGPU::V_SUBB_U32_sdwa_vi, ConvertCustom_cvtSdwaVOP2b, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_VCC, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45717 /* v_subbrev_u32 */, AMDGPU::V_SUBBREV_U32_sdwa_vi, ConvertCustom_cvtSdwaVOP2b, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_VCC, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45821 /* v_subrev_u16 */, AMDGPU::V_SUBREV_U16_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX8GFX9_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45834 /* v_subrev_u32 */, AMDGPU::V_SUBREV_U32_sdwa_vi, ConvertCustom_cvtSdwaVOP2b, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_sdwa_vi, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 47868 /* v_xnor_b32 */, AMDGPU::V_XNOR_B32_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasDLInsts_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_sdwa_vi, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA8, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
};

static const MatchEntry MatchTable3[] = {
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2b, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_sdwa_w64_gfx10, ConvertCustom_cvtSdwaVOP2b, AMFBS_isGFX10Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_VCC, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_sdwa_w32_gfx10, ConvertCustom_cvtSdwaVOP2b, AMFBS_isGFX10Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_VCC_LO, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24254 /* v_add_co_u32 */, AMDGPU::V_ADD_CO_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2b, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24427 /* v_add_nc_u32 */, AMDGPU::V_ADD_NC_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_HasAddNoCarryInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24453 /* v_add_u16 */, AMDGPU::V_ADD_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX8GFX9_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24463 /* v_add_u32 */, AMDGPU::V_ADD_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasAddNoCarryInsts_isGFX9Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24473 /* v_addc_co_u32 */, AMDGPU::V_ADDC_CO_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2b, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_VCC, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24618 /* v_ashrrev_i16 */, AMDGPU::V_ASHRREV_I16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25226 /* v_cmp_f_f32 */, AMDGPU::V_CMP_F_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25226 /* v_cmp_f_f32 */, AMDGPU::V_CMP_F_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25282 /* v_cmp_f_i16 */, AMDGPU::V_CMP_F_I16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25310 /* v_cmp_f_i32 */, AMDGPU::V_CMP_F_I32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25310 /* v_cmp_f_i32 */, AMDGPU::V_CMP_F_I32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25366 /* v_cmp_f_u16 */, AMDGPU::V_CMP_F_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25394 /* v_cmp_f_u32 */, AMDGPU::V_CMP_F_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25394 /* v_cmp_f_u32 */, AMDGPU::V_CMP_F_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27544 /* v_cmp_t_i16 */, AMDGPU::V_CMP_T_I16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27572 /* v_cmp_t_i32 */, AMDGPU::V_CMP_T_I32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27572 /* v_cmp_t_i32 */, AMDGPU::V_CMP_T_I32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27628 /* v_cmp_t_u16 */, AMDGPU::V_CMP_T_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27656 /* v_cmp_t_u32 */, AMDGPU::V_CMP_T_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27656 /* v_cmp_t_u32 */, AMDGPU::V_CMP_T_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27712 /* v_cmp_tru_f16 */, AMDGPU::V_CMP_TRU_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27712 /* v_cmp_tru_f16 */, AMDGPU::V_CMP_TRU_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27744 /* v_cmp_tru_f32 */, AMDGPU::V_CMP_TRU_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27744 /* v_cmp_tru_f32 */, AMDGPU::V_CMP_TRU_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_isGFX10Only, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithFP16InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30074 /* v_cmpx_class_f32 */, AMDGPU::V_CMPX_CLASS_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithFP32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30074 /* v_cmpx_class_f32 */, AMDGPU::V_CMPX_CLASS_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30182 /* v_cmpx_eq_f32 */, AMDGPU::V_CMPX_EQ_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30182 /* v_cmpx_eq_f32 */, AMDGPU::V_CMPX_EQ_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30278 /* v_cmpx_eq_i32 */, AMDGPU::V_CMPX_EQ_I32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30278 /* v_cmpx_eq_i32 */, AMDGPU::V_CMPX_EQ_I32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30374 /* v_cmpx_eq_u32 */, AMDGPU::V_CMPX_EQ_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30374 /* v_cmpx_eq_u32 */, AMDGPU::V_CMPX_EQ_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30438 /* v_cmpx_f_f16 */, AMDGPU::V_CMPX_F_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30438 /* v_cmpx_f_f16 */, AMDGPU::V_CMPX_F_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30468 /* v_cmpx_f_f32 */, AMDGPU::V_CMPX_F_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30468 /* v_cmpx_f_f32 */, AMDGPU::V_CMPX_F_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30528 /* v_cmpx_f_i16 */, AMDGPU::V_CMPX_F_I16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30558 /* v_cmpx_f_i32 */, AMDGPU::V_CMPX_F_I32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30558 /* v_cmpx_f_i32 */, AMDGPU::V_CMPX_F_I32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30618 /* v_cmpx_f_u16 */, AMDGPU::V_CMPX_F_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30648 /* v_cmpx_f_u32 */, AMDGPU::V_CMPX_F_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30648 /* v_cmpx_f_u32 */, AMDGPU::V_CMPX_F_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30740 /* v_cmpx_ge_f32 */, AMDGPU::V_CMPX_GE_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30740 /* v_cmpx_ge_f32 */, AMDGPU::V_CMPX_GE_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30836 /* v_cmpx_ge_i32 */, AMDGPU::V_CMPX_GE_I32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30836 /* v_cmpx_ge_i32 */, AMDGPU::V_CMPX_GE_I32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30932 /* v_cmpx_ge_u32 */, AMDGPU::V_CMPX_GE_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30932 /* v_cmpx_ge_u32 */, AMDGPU::V_CMPX_GE_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31028 /* v_cmpx_gt_f32 */, AMDGPU::V_CMPX_GT_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31028 /* v_cmpx_gt_f32 */, AMDGPU::V_CMPX_GT_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31124 /* v_cmpx_gt_i32 */, AMDGPU::V_CMPX_GT_I32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31124 /* v_cmpx_gt_i32 */, AMDGPU::V_CMPX_GT_I32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31220 /* v_cmpx_gt_u32 */, AMDGPU::V_CMPX_GT_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31220 /* v_cmpx_gt_u32 */, AMDGPU::V_CMPX_GT_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31316 /* v_cmpx_le_f32 */, AMDGPU::V_CMPX_LE_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31316 /* v_cmpx_le_f32 */, AMDGPU::V_CMPX_LE_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31412 /* v_cmpx_le_i32 */, AMDGPU::V_CMPX_LE_I32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31412 /* v_cmpx_le_i32 */, AMDGPU::V_CMPX_LE_I32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31508 /* v_cmpx_le_u32 */, AMDGPU::V_CMPX_LE_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31508 /* v_cmpx_le_u32 */, AMDGPU::V_CMPX_LE_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31604 /* v_cmpx_lg_f32 */, AMDGPU::V_CMPX_LG_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31604 /* v_cmpx_lg_f32 */, AMDGPU::V_CMPX_LG_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31700 /* v_cmpx_lt_f32 */, AMDGPU::V_CMPX_LT_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31700 /* v_cmpx_lt_f32 */, AMDGPU::V_CMPX_LT_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31796 /* v_cmpx_lt_i32 */, AMDGPU::V_CMPX_LT_I32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31796 /* v_cmpx_lt_i32 */, AMDGPU::V_CMPX_LT_I32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31892 /* v_cmpx_lt_u32 */, AMDGPU::V_CMPX_LT_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31892 /* v_cmpx_lt_u32 */, AMDGPU::V_CMPX_LT_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31988 /* v_cmpx_ne_i32 */, AMDGPU::V_CMPX_NE_I32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 31988 /* v_cmpx_ne_i32 */, AMDGPU::V_CMPX_NE_I32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32084 /* v_cmpx_ne_u32 */, AMDGPU::V_CMPX_NE_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32084 /* v_cmpx_ne_u32 */, AMDGPU::V_CMPX_NE_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32182 /* v_cmpx_neq_f32 */, AMDGPU::V_CMPX_NEQ_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32182 /* v_cmpx_neq_f32 */, AMDGPU::V_CMPX_NEQ_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32284 /* v_cmpx_nge_f32 */, AMDGPU::V_CMPX_NGE_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32284 /* v_cmpx_nge_f32 */, AMDGPU::V_CMPX_NGE_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32386 /* v_cmpx_ngt_f32 */, AMDGPU::V_CMPX_NGT_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32386 /* v_cmpx_ngt_f32 */, AMDGPU::V_CMPX_NGT_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32488 /* v_cmpx_nle_f32 */, AMDGPU::V_CMPX_NLE_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32488 /* v_cmpx_nle_f32 */, AMDGPU::V_CMPX_NLE_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32590 /* v_cmpx_nlg_f32 */, AMDGPU::V_CMPX_NLG_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32590 /* v_cmpx_nlg_f32 */, AMDGPU::V_CMPX_NLG_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32692 /* v_cmpx_nlt_f32 */, AMDGPU::V_CMPX_NLT_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32692 /* v_cmpx_nlt_f32 */, AMDGPU::V_CMPX_NLT_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32790 /* v_cmpx_o_f32 */, AMDGPU::V_CMPX_O_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32790 /* v_cmpx_o_f32 */, AMDGPU::V_CMPX_O_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32940 /* v_cmpx_t_i16 */, AMDGPU::V_CMPX_T_I16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32970 /* v_cmpx_t_i32 */, AMDGPU::V_CMPX_T_I32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 32970 /* v_cmpx_t_i32 */, AMDGPU::V_CMPX_T_I32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33030 /* v_cmpx_t_u16 */, AMDGPU::V_CMPX_T_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33060 /* v_cmpx_t_u32 */, AMDGPU::V_CMPX_T_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33060 /* v_cmpx_t_u32 */, AMDGPU::V_CMPX_T_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33120 /* v_cmpx_tru_f16 */, AMDGPU::V_CMPX_TRU_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33120 /* v_cmpx_tru_f16 */, AMDGPU::V_CMPX_TRU_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33154 /* v_cmpx_tru_f32 */, AMDGPU::V_CMPX_TRU_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33154 /* v_cmpx_tru_f32 */, AMDGPU::V_CMPX_TRU_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_isGFX10Only, { MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_Has16BitInsts_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33252 /* v_cmpx_u_f32 */, AMDGPU::V_CMPX_U_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOPC, AMFBS_HasNoSdstCMPX_isGFX10Only, { MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33252 /* v_cmpx_u_f32 */, AMDGPU::V_CMPX_U_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOPC, AMFBS_HasSDWA9, { MCK_BoolReg, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2e, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_sdwa_w64_gfx10, ConvertCustom_cvtSdwaVOP2e, AMFBS_isGFX10Only_isWave64, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_VCC, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2e, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_VCC, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_sdwa_w32_gfx10, ConvertCustom_cvtSdwaVOP2e, AMFBS_isGFX10Only_isWave32, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_VCC_LO, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33507 /* v_cvt_f32_bf16 */, AMDGPU::V_CVT_F32_BF16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasBF16ConversionInsts_HasGFX950Insts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33522 /* v_cvt_f32_bf8 */, AMDGPU::V_CVT_F32_BF8_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasFP8ConversionInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithBin32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWASrc0Sel }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33564 /* v_cvt_f32_fp8 */, AMDGPU::V_CVT_F32_FP8_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasFP8ConversionInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithBin32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWASrc0Sel }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33736 /* v_cvt_flr_i32_f32 */, AMDGPU::V_CVT_FLR_I32_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33736 /* v_cvt_flr_i32_f32 */, AMDGPU::V_CVT_FLR_I32_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasCvtNormInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasCvtNormInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasCvtNormInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasCvtNormInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 33990 /* v_cvt_pk_f32_bf8 */, AMDGPU::V_CVT_PK_F32_BF8_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasFP8ConversionInsts_HasSDWA9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SDWAWithBin32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWASrc0Sel }, },
  { 34007 /* v_cvt_pk_f32_fp8 */, AMDGPU::V_CVT_PK_F32_FP8_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasFP8ConversionInsts_HasSDWA9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_SDWAWithBin32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWASrc0Sel }, },
  { 34356 /* v_cvt_pkrtz_f16_f32 */, AMDGPU::V_CVT_PKRTZ_F16_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 34376 /* v_cvt_rpi_i32_f32 */, AMDGPU::V_CVT_RPI_I32_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 34376 /* v_cvt_rpi_i32_f32 */, AMDGPU::V_CVT_RPI_I32_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38179 /* v_exp_legacy_f32 */, AMDGPU::V_EXP_LEGACY_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX7GFX8GFX9_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38196 /* v_ffbh_i32 */, AMDGPU::V_FFBH_I32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38196 /* v_ffbh_i32 */, AMDGPU::V_FFBH_I32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38207 /* v_ffbh_u32 */, AMDGPU::V_FFBH_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38207 /* v_ffbh_u32 */, AMDGPU::V_FFBH_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38218 /* v_ffbl_b32 */, AMDGPU::V_FFBL_B32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38218 /* v_ffbl_b32 */, AMDGPU::V_FFBL_B32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 39071 /* v_log_legacy_f32 */, AMDGPU::V_LOG_LEGACY_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX7GFX8GFX9_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 39154 /* v_lshlrev_b16 */, AMDGPU::V_LSHLREV_B16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39218 /* v_lshrrev_b16 */, AMDGPU::V_LSHRREV_B16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39757 /* v_max_f16 */, AMDGPU::V_MAX_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39757 /* v_max_f16 */, AMDGPU::V_MAX_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39767 /* v_max_f32 */, AMDGPU::V_MAX_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39767 /* v_max_f32 */, AMDGPU::V_MAX_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39787 /* v_max_i16 */, AMDGPU::V_MAX_I16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39876 /* v_max_u16 */, AMDGPU::V_MAX_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 40317 /* v_mfma_f32_16x16x16bf16 */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40317 /* v_mfma_f32_16x16x16bf16 */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40341 /* v_mfma_f32_16x16x16bf16_1k */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40341 /* v_mfma_f32_16x16x16bf16_1k */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40368 /* v_mfma_f32_16x16x16f16 */, AMDGPU::V_MFMA_F32_16X16X16F16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40368 /* v_mfma_f32_16x16x16f16 */, AMDGPU::V_MFMA_F32_16X16X16F16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40417 /* v_mfma_f32_16x16x1f32 */, AMDGPU::V_MFMA_F32_16X16X1F32_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40417 /* v_mfma_f32_16x16x1f32 */, AMDGPU::V_MFMA_F32_16X16X1F32_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40623 /* v_mfma_f32_16x16x32bf16 */, AMDGPU::V_MFMA_F32_16X16X32_BF16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40623 /* v_mfma_f32_16x16x32bf16 */, AMDGPU::V_MFMA_F32_16X16X32_BF16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40647 /* v_mfma_f32_16x16x32f16 */, AMDGPU::V_MFMA_F32_16X16X32_F16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40647 /* v_mfma_f32_16x16x32f16 */, AMDGPU::V_MFMA_F32_16X16X32_F16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40746 /* v_mfma_f32_16x16x4bf16 */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40746 /* v_mfma_f32_16x16x4bf16 */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40769 /* v_mfma_f32_16x16x4bf16_1k */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40769 /* v_mfma_f32_16x16x4bf16_1k */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40795 /* v_mfma_f32_16x16x4f16 */, AMDGPU::V_MFMA_F32_16X16X4F16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40795 /* v_mfma_f32_16x16x4f16 */, AMDGPU::V_MFMA_F32_16X16X4F16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40817 /* v_mfma_f32_16x16x4f32 */, AMDGPU::V_MFMA_F32_16X16X4F32_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40817 /* v_mfma_f32_16x16x4f32 */, AMDGPU::V_MFMA_F32_16X16X4F32_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40886 /* v_mfma_f32_16x16x8xf32 */, AMDGPU::V_MFMA_F32_16X16X8XF32_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40886 /* v_mfma_f32_16x16x8xf32 */, AMDGPU::V_MFMA_F32_16X16X8XF32_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41070 /* v_mfma_f32_32x32x16bf16 */, AMDGPU::V_MFMA_F32_32X32X16_BF16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41070 /* v_mfma_f32_32x32x16bf16 */, AMDGPU::V_MFMA_F32_32X32X16_BF16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41094 /* v_mfma_f32_32x32x16f16 */, AMDGPU::V_MFMA_F32_32X32X16_F16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41094 /* v_mfma_f32_32x32x16f16 */, AMDGPU::V_MFMA_F32_32X32X16_F16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41143 /* v_mfma_f32_32x32x1f32 */, AMDGPU::V_MFMA_F32_32X32X1F32_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_1024_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41143 /* v_mfma_f32_32x32x1f32 */, AMDGPU::V_MFMA_F32_32X32X1F32_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_1024_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_1024_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41211 /* v_mfma_f32_32x32x2f32 */, AMDGPU::V_MFMA_F32_32X32X2F32_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41211 /* v_mfma_f32_32x32x2f32 */, AMDGPU::V_MFMA_F32_32X32X2F32_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41310 /* v_mfma_f32_32x32x4bf16 */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41310 /* v_mfma_f32_32x32x4bf16 */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41333 /* v_mfma_f32_32x32x4bf16_1k */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41333 /* v_mfma_f32_32x32x4bf16_1k */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41359 /* v_mfma_f32_32x32x4f16 */, AMDGPU::V_MFMA_F32_32X32X4F16_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41359 /* v_mfma_f32_32x32x4f16 */, AMDGPU::V_MFMA_F32_32X32X4F16_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41381 /* v_mfma_f32_32x32x4xf32 */, AMDGPU::V_MFMA_F32_32X32X4XF32_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41381 /* v_mfma_f32_32x32x4xf32 */, AMDGPU::V_MFMA_F32_32X32X4XF32_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41478 /* v_mfma_f32_32x32x8bf16 */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41478 /* v_mfma_f32_32x32x8bf16 */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41501 /* v_mfma_f32_32x32x8bf16_1k */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41501 /* v_mfma_f32_32x32x8bf16_1k */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41527 /* v_mfma_f32_32x32x8f16 */, AMDGPU::V_MFMA_F32_32X32X8F16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41527 /* v_mfma_f32_32x32x8f16 */, AMDGPU::V_MFMA_F32_32X32X8F16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41574 /* v_mfma_f32_4x4x1f32 */, AMDGPU::V_MFMA_F32_4X4X1F32_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41574 /* v_mfma_f32_4x4x1f32 */, AMDGPU::V_MFMA_F32_4X4X1F32_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41666 /* v_mfma_f32_4x4x4bf16 */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41666 /* v_mfma_f32_4x4x4bf16 */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41687 /* v_mfma_f32_4x4x4bf16_1k */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41687 /* v_mfma_f32_4x4x4bf16_1k */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41711 /* v_mfma_f32_4x4x4f16 */, AMDGPU::V_MFMA_F32_4X4X4F16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41711 /* v_mfma_f32_4x4x4f16 */, AMDGPU::V_MFMA_F32_4X4X4F16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41754 /* v_mfma_f64_16x16x4f64 */, AMDGPU::V_MFMA_F64_16X16X4F64_gfx940_acd, Convert__RegByHwMode_AReg_256_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_256_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_256_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_256_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41754 /* v_mfma_f64_16x16x4f64 */, AMDGPU::V_MFMA_F64_16X16X4F64_gfx940_vcd, Convert__RegByHwMode_VReg_256_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_256_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_256_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41800 /* v_mfma_f64_4x4x4f64 */, AMDGPU::V_MFMA_F64_4X4X4F64_gfx940_acd, Convert__RegByHwMode_AReg_64_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_64_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_64_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41800 /* v_mfma_f64_4x4x4f64 */, AMDGPU::V_MFMA_F64_4X4X4F64_gfx940_vcd, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_64_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_64_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41865 /* v_mfma_i32_16x16x32i8 */, AMDGPU::V_MFMA_I32_16X16X32I8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41865 /* v_mfma_i32_16x16x32i8 */, AMDGPU::V_MFMA_I32_16X16X32I8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41912 /* v_mfma_i32_16x16x4i8 */, AMDGPU::V_MFMA_I32_16X16X4I8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41912 /* v_mfma_i32_16x16x4i8 */, AMDGPU::V_MFMA_I32_16X16X4I8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41956 /* v_mfma_i32_16x16x64i8 */, AMDGPU::V_MFMA_I32_16X16X64_I8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41956 /* v_mfma_i32_16x16x64i8 */, AMDGPU::V_MFMA_I32_16X16X64_I8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42001 /* v_mfma_i32_32x32x16i8 */, AMDGPU::V_MFMA_I32_32X32X16I8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42001 /* v_mfma_i32_32x32x16i8 */, AMDGPU::V_MFMA_I32_32X32X16I8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42046 /* v_mfma_i32_32x32x32i8 */, AMDGPU::V_MFMA_I32_32X32X32_I8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42046 /* v_mfma_i32_32x32x32i8 */, AMDGPU::V_MFMA_I32_32X32X32_I8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42093 /* v_mfma_i32_32x32x4i8 */, AMDGPU::V_MFMA_I32_32X32X4I8_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42093 /* v_mfma_i32_32x32x4i8 */, AMDGPU::V_MFMA_I32_32X32X4I8_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42159 /* v_mfma_i32_4x4x4i8 */, AMDGPU::V_MFMA_I32_4X4X4I8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42159 /* v_mfma_i32_4x4x4i8 */, AMDGPU::V_MFMA_I32_4X4X4I8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42361 /* v_min_f16 */, AMDGPU::V_MIN_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42361 /* v_min_f16 */, AMDGPU::V_MIN_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42371 /* v_min_f32 */, AMDGPU::V_MIN_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42371 /* v_min_f32 */, AMDGPU::V_MIN_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42391 /* v_min_i16 */, AMDGPU::V_MIN_I16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42480 /* v_min_u16 */, AMDGPU::V_MIN_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 42740 /* v_movreld_b32 */, AMDGPU::V_MOVRELD_B32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_HasMovrel_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 42754 /* v_movrels_b32 */, AMDGPU::V_MOVRELS_B32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_HasMovrel_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 42768 /* v_movrelsd_2_b32 */, AMDGPU::V_MOVRELSD_2_B32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Plus_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 42785 /* v_movrelsd_b32 */, AMDGPU::V_MOVRELSD_B32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_HasMovrel_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42966 /* v_mul_legacy_f32 */, AMDGPU::V_MUL_LEGACY_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_isGCN3ExcludingGFX90A_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42966 /* v_mul_legacy_f32 */, AMDGPU::V_MUL_LEGACY_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 42996 /* v_mul_lo_u16 */, AMDGPU::V_MUL_LO_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 43059 /* v_nop */, AMDGPU::V_NOP_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, {  }, },
  { 43059 /* v_nop */, AMDGPU::V_NOP_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, {  }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 43636 /* v_pk_fmac_f16 */, AMDGPU::V_PK_FMAC_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasPkFmacF16Inst_isGFX9Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 44115 /* v_prng_b32 */, AMDGPU::V_PRNG_B32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasPrngInst_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX9Plus_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX9Plus_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44621 /* v_screen_partition_4se_b32 */, AMDGPU::V_SCREEN_PARTITION_4SE_B32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX9Only_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2b, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_sdwa_w64_gfx10, ConvertCustom_cvtSdwaVOP2b, AMFBS_isGFX10Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_VCC, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_sdwa_w32_gfx10, ConvertCustom_cvtSdwaVOP2b, AMFBS_isGFX10Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_VCC_LO, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45537 /* v_sub_co_u32 */, AMDGPU::V_SUB_CO_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2b, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45629 /* v_sub_nc_u32 */, AMDGPU::V_SUB_NC_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_HasAddNoCarryInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45655 /* v_sub_u16 */, AMDGPU::V_SUB_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX8GFX9_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45665 /* v_sub_u32 */, AMDGPU::V_SUB_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasAddNoCarryInsts_isGFX9Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45675 /* v_subb_co_u32 */, AMDGPU::V_SUBB_CO_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2b, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_VCC, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45700 /* v_subbrev_co_u32 */, AMDGPU::V_SUBBREV_CO_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2b, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_VCC, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2b, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_sdwa_w64_gfx10, ConvertCustom_cvtSdwaVOP2b, AMFBS_isGFX10Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_VCC, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_sdwa_w32_gfx10, ConvertCustom_cvtSdwaVOP2b, AMFBS_isGFX10Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_VCC_LO, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45750 /* v_subrev_co_u32 */, AMDGPU::V_SUBREV_CO_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2b, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_VCC, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45805 /* v_subrev_nc_u32 */, AMDGPU::V_SUBREV_NC_U32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_HasAddNoCarryInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45821 /* v_subrev_u16 */, AMDGPU::V_SUBREV_U16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX8GFX9_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt16InputMods, MCK_SDWAWithInt16InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 45834 /* v_subrev_u32 */, AMDGPU::V_SUBREV_U32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasAddNoCarryInsts_isGFX9Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP16InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP1, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP1, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel }, },
  { 47868 /* v_xnor_b32 */, AMDGPU::V_XNOR_B32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_HasDLInsts_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 47868 /* v_xnor_b32 */, AMDGPU::V_XNOR_B32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasDLInsts_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_sdwa_gfx10, ConvertCustom_cvtSdwaVOP2, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_sdwa_gfx9, ConvertCustom_cvtSdwaVOP2, AMFBS_HasSDWA9, { MCK_VGPR_32, MCK_SDWAWithInt32InputMods, MCK_SDWAWithInt32InputMods, MCK_Clamp, MCK_SDWADstSel, MCK_SDWADstUnused, MCK_SDWASrc0Sel, MCK_SDWASrc1Sel }, },
};

static const MatchEntry MatchTable4[] = {
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_dpp8_w64_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPP8, MCK_DppFI }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPP8, MCK_DppFI }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPP8, MCK_DppFI }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_dpp8_w32_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC_LO, MCK_DPP8, MCK_DppFI }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC_LO, MCK_DPP8, MCK_DppFI }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC_LO, MCK_DPP8, MCK_DppFI }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_dpp_w64_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8__DppFI1_9, AMFBS_isGFX10Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_dpp_w64_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8__DppFI1_9, AMFBS_isGFX11Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_dpp_w64_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8__DppFI1_9, AMFBS_isGFX12Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_dpp_w32_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8__DppFI1_9, AMFBS_isGFX10Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC_LO, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_dpp_w32_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8__DppFI1_9, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC_LO, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_dpp_w32_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8__DppFI1_9, AMFBS_isGFX12Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC_LO, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24254 /* v_add_co_u32 */, AMDGPU::V_ADD_CO_U32_dpp_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_4__DppRowMask1_5__DppBankMask1_6__DppBoundCtrl1_7, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_Has16BitInsts_HasDPP_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_HasDPP, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24287 /* v_add_f64 */, AMDGPU::V_ADD_F64_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPALU_DPP_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24427 /* v_add_nc_u32 */, AMDGPU::V_ADD_NC_U32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_HasAddNoCarryInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24427 /* v_add_nc_u32 */, AMDGPU::V_ADD_NC_U32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_HasAddNoCarryInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24427 /* v_add_nc_u32 */, AMDGPU::V_ADD_NC_U32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_HasAddNoCarryInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24427 /* v_add_nc_u32 */, AMDGPU::V_ADD_NC_U32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_HasAddNoCarryInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24427 /* v_add_nc_u32 */, AMDGPU::V_ADD_NC_U32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_HasAddNoCarryInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24427 /* v_add_nc_u32 */, AMDGPU::V_ADD_NC_U32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_HasAddNoCarryInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24440 /* v_add_nc_u64 */, AMDGPU::V_ADD_U64_dpp_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_HasDPALU_DPP_HasAddSubU64Insts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24453 /* v_add_u16 */, AMDGPU::V_ADD_U16_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_isGFX8GFX9_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 24463 /* v_add_u32 */, AMDGPU::V_ADD_U32_dpp_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_HasAddNoCarryInsts_isGFX9Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 24463 /* v_add_u32 */, AMDGPU::V_ADD_U32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_4__DppRowMask1_5__DppBankMask1_6__DppBoundCtrl1_7, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 24473 /* v_addc_co_u32 */, AMDGPU::V_ADDC_CO_U32_dpp_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 24487 /* v_addc_u32 */, AMDGPU::V_ADDC_U32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24618 /* v_ashrrev_i16 */, AMDGPU::V_ASHRREV_I16_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_Has16BitInsts_HasDPP_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24775 /* v_ceil_f64 */, AMDGPU::V_CEIL_F64_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 24775 /* v_ceil_f64 */, AMDGPU::V_CEIL_F64_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPALU_DPP_isGFX7Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24796 /* v_cls_i32 */, AMDGPU::V_CLS_I32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24796 /* v_cls_i32 */, AMDGPU::V_CLS_I32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24796 /* v_cls_i32 */, AMDGPU::V_CLS_I32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24796 /* v_cls_i32 */, AMDGPU::V_CLS_I32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24806 /* v_clz_i32_u32 */, AMDGPU::V_CLZ_I32_U32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24806 /* v_clz_i32_u32 */, AMDGPU::V_CLZ_I32_U32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24806 /* v_clz_i32_u32 */, AMDGPU::V_CLZ_I32_U32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24806 /* v_clz_i32_u32 */, AMDGPU::V_CLZ_I32_U32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25226 /* v_cmp_f_f32 */, AMDGPU::V_CMP_F_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25226 /* v_cmp_f_f32 */, AMDGPU::V_CMP_F_F32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25226 /* v_cmp_f_f32 */, AMDGPU::V_CMP_F_F32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25226 /* v_cmp_f_f32 */, AMDGPU::V_CMP_F_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25226 /* v_cmp_f_f32 */, AMDGPU::V_CMP_F_F32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25226 /* v_cmp_f_f32 */, AMDGPU::V_CMP_F_F32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25310 /* v_cmp_f_i32 */, AMDGPU::V_CMP_F_I32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25310 /* v_cmp_f_i32 */, AMDGPU::V_CMP_F_I32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25310 /* v_cmp_f_i32 */, AMDGPU::V_CMP_F_I32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25310 /* v_cmp_f_i32 */, AMDGPU::V_CMP_F_I32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25310 /* v_cmp_f_i32 */, AMDGPU::V_CMP_F_I32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25310 /* v_cmp_f_i32 */, AMDGPU::V_CMP_F_I32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25394 /* v_cmp_f_u32 */, AMDGPU::V_CMP_F_U32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25394 /* v_cmp_f_u32 */, AMDGPU::V_CMP_F_U32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25394 /* v_cmp_f_u32 */, AMDGPU::V_CMP_F_U32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25394 /* v_cmp_f_u32 */, AMDGPU::V_CMP_F_U32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25394 /* v_cmp_f_u32 */, AMDGPU::V_CMP_F_U32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25394 /* v_cmp_f_u32 */, AMDGPU::V_CMP_F_U32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27488 /* v_cmp_t_f32 */, AMDGPU::V_CMP_T_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27488 /* v_cmp_t_f32 */, AMDGPU::V_CMP_T_F32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27488 /* v_cmp_t_f32 */, AMDGPU::V_CMP_T_F32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27488 /* v_cmp_t_f32 */, AMDGPU::V_CMP_T_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27488 /* v_cmp_t_f32 */, AMDGPU::V_CMP_T_F32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27488 /* v_cmp_t_f32 */, AMDGPU::V_CMP_T_F32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27572 /* v_cmp_t_i32 */, AMDGPU::V_CMP_T_I32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27572 /* v_cmp_t_i32 */, AMDGPU::V_CMP_T_I32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27572 /* v_cmp_t_i32 */, AMDGPU::V_CMP_T_I32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27572 /* v_cmp_t_i32 */, AMDGPU::V_CMP_T_I32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27572 /* v_cmp_t_i32 */, AMDGPU::V_CMP_T_I32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27572 /* v_cmp_t_i32 */, AMDGPU::V_CMP_T_I32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27656 /* v_cmp_t_u32 */, AMDGPU::V_CMP_T_U32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27656 /* v_cmp_t_u32 */, AMDGPU::V_CMP_T_U32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27656 /* v_cmp_t_u32 */, AMDGPU::V_CMP_T_U32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27656 /* v_cmp_t_u32 */, AMDGPU::V_CMP_T_U32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27656 /* v_cmp_t_u32 */, AMDGPU::V_CMP_T_U32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27656 /* v_cmp_t_u32 */, AMDGPU::V_CMP_T_U32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseRealTrue16Insts, { MCK_VCC, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64_UseFakeTrue16Insts, { MCK_VCC, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseRealTrue16Insts, { MCK_VCC_LO, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32_UseFakeTrue16Insts, { MCK_VCC_LO, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_e32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_e32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_e32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_e32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_e32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_e32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave64, { MCK_VCC, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_e32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_e32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_isWave32, { MCK_VCC_LO, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30074 /* v_cmpx_class_f32 */, AMDGPU::V_CMPX_CLASS_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 30074 /* v_cmpx_class_f32 */, AMDGPU::V_CMPX_CLASS_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 30074 /* v_cmpx_class_f32 */, AMDGPU::V_CMPX_CLASS_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30074 /* v_cmpx_class_f32 */, AMDGPU::V_CMPX_CLASS_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30182 /* v_cmpx_eq_f32 */, AMDGPU::V_CMPX_EQ_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 30182 /* v_cmpx_eq_f32 */, AMDGPU::V_CMPX_EQ_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 30182 /* v_cmpx_eq_f32 */, AMDGPU::V_CMPX_EQ_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30182 /* v_cmpx_eq_f32 */, AMDGPU::V_CMPX_EQ_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30278 /* v_cmpx_eq_i32 */, AMDGPU::V_CMPX_EQ_I32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 30278 /* v_cmpx_eq_i32 */, AMDGPU::V_CMPX_EQ_I32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 30278 /* v_cmpx_eq_i32 */, AMDGPU::V_CMPX_EQ_I32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30278 /* v_cmpx_eq_i32 */, AMDGPU::V_CMPX_EQ_I32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30374 /* v_cmpx_eq_u32 */, AMDGPU::V_CMPX_EQ_U32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 30374 /* v_cmpx_eq_u32 */, AMDGPU::V_CMPX_EQ_U32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 30374 /* v_cmpx_eq_u32 */, AMDGPU::V_CMPX_EQ_U32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30374 /* v_cmpx_eq_u32 */, AMDGPU::V_CMPX_EQ_U32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30438 /* v_cmpx_f_f16 */, AMDGPU::V_CMPX_F_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30438 /* v_cmpx_f_f16 */, AMDGPU::V_CMPX_F_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30438 /* v_cmpx_f_f16 */, AMDGPU::V_CMPX_F_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30438 /* v_cmpx_f_f16 */, AMDGPU::V_CMPX_F_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30468 /* v_cmpx_f_f32 */, AMDGPU::V_CMPX_F_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 30468 /* v_cmpx_f_f32 */, AMDGPU::V_CMPX_F_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30558 /* v_cmpx_f_i32 */, AMDGPU::V_CMPX_F_I32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 30558 /* v_cmpx_f_i32 */, AMDGPU::V_CMPX_F_I32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30648 /* v_cmpx_f_u32 */, AMDGPU::V_CMPX_F_U32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 30648 /* v_cmpx_f_u32 */, AMDGPU::V_CMPX_F_U32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30740 /* v_cmpx_ge_f32 */, AMDGPU::V_CMPX_GE_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 30740 /* v_cmpx_ge_f32 */, AMDGPU::V_CMPX_GE_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 30740 /* v_cmpx_ge_f32 */, AMDGPU::V_CMPX_GE_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30740 /* v_cmpx_ge_f32 */, AMDGPU::V_CMPX_GE_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30836 /* v_cmpx_ge_i32 */, AMDGPU::V_CMPX_GE_I32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 30836 /* v_cmpx_ge_i32 */, AMDGPU::V_CMPX_GE_I32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 30836 /* v_cmpx_ge_i32 */, AMDGPU::V_CMPX_GE_I32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30836 /* v_cmpx_ge_i32 */, AMDGPU::V_CMPX_GE_I32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30932 /* v_cmpx_ge_u32 */, AMDGPU::V_CMPX_GE_U32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 30932 /* v_cmpx_ge_u32 */, AMDGPU::V_CMPX_GE_U32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 30932 /* v_cmpx_ge_u32 */, AMDGPU::V_CMPX_GE_U32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30932 /* v_cmpx_ge_u32 */, AMDGPU::V_CMPX_GE_U32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31028 /* v_cmpx_gt_f32 */, AMDGPU::V_CMPX_GT_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 31028 /* v_cmpx_gt_f32 */, AMDGPU::V_CMPX_GT_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 31028 /* v_cmpx_gt_f32 */, AMDGPU::V_CMPX_GT_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31028 /* v_cmpx_gt_f32 */, AMDGPU::V_CMPX_GT_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31124 /* v_cmpx_gt_i32 */, AMDGPU::V_CMPX_GT_I32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 31124 /* v_cmpx_gt_i32 */, AMDGPU::V_CMPX_GT_I32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 31124 /* v_cmpx_gt_i32 */, AMDGPU::V_CMPX_GT_I32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31124 /* v_cmpx_gt_i32 */, AMDGPU::V_CMPX_GT_I32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31220 /* v_cmpx_gt_u32 */, AMDGPU::V_CMPX_GT_U32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 31220 /* v_cmpx_gt_u32 */, AMDGPU::V_CMPX_GT_U32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 31220 /* v_cmpx_gt_u32 */, AMDGPU::V_CMPX_GT_U32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31220 /* v_cmpx_gt_u32 */, AMDGPU::V_CMPX_GT_U32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31316 /* v_cmpx_le_f32 */, AMDGPU::V_CMPX_LE_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 31316 /* v_cmpx_le_f32 */, AMDGPU::V_CMPX_LE_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 31316 /* v_cmpx_le_f32 */, AMDGPU::V_CMPX_LE_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31316 /* v_cmpx_le_f32 */, AMDGPU::V_CMPX_LE_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31412 /* v_cmpx_le_i32 */, AMDGPU::V_CMPX_LE_I32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 31412 /* v_cmpx_le_i32 */, AMDGPU::V_CMPX_LE_I32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 31412 /* v_cmpx_le_i32 */, AMDGPU::V_CMPX_LE_I32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31412 /* v_cmpx_le_i32 */, AMDGPU::V_CMPX_LE_I32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31508 /* v_cmpx_le_u32 */, AMDGPU::V_CMPX_LE_U32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 31508 /* v_cmpx_le_u32 */, AMDGPU::V_CMPX_LE_U32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 31508 /* v_cmpx_le_u32 */, AMDGPU::V_CMPX_LE_U32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31508 /* v_cmpx_le_u32 */, AMDGPU::V_CMPX_LE_U32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31604 /* v_cmpx_lg_f32 */, AMDGPU::V_CMPX_LG_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 31604 /* v_cmpx_lg_f32 */, AMDGPU::V_CMPX_LG_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 31604 /* v_cmpx_lg_f32 */, AMDGPU::V_CMPX_LG_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31604 /* v_cmpx_lg_f32 */, AMDGPU::V_CMPX_LG_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31700 /* v_cmpx_lt_f32 */, AMDGPU::V_CMPX_LT_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 31700 /* v_cmpx_lt_f32 */, AMDGPU::V_CMPX_LT_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 31700 /* v_cmpx_lt_f32 */, AMDGPU::V_CMPX_LT_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31700 /* v_cmpx_lt_f32 */, AMDGPU::V_CMPX_LT_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31796 /* v_cmpx_lt_i32 */, AMDGPU::V_CMPX_LT_I32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 31796 /* v_cmpx_lt_i32 */, AMDGPU::V_CMPX_LT_I32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 31796 /* v_cmpx_lt_i32 */, AMDGPU::V_CMPX_LT_I32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31796 /* v_cmpx_lt_i32 */, AMDGPU::V_CMPX_LT_I32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31892 /* v_cmpx_lt_u32 */, AMDGPU::V_CMPX_LT_U32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 31892 /* v_cmpx_lt_u32 */, AMDGPU::V_CMPX_LT_U32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 31892 /* v_cmpx_lt_u32 */, AMDGPU::V_CMPX_LT_U32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31892 /* v_cmpx_lt_u32 */, AMDGPU::V_CMPX_LT_U32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31988 /* v_cmpx_ne_i32 */, AMDGPU::V_CMPX_NE_I32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 31988 /* v_cmpx_ne_i32 */, AMDGPU::V_CMPX_NE_I32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 31988 /* v_cmpx_ne_i32 */, AMDGPU::V_CMPX_NE_I32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31988 /* v_cmpx_ne_i32 */, AMDGPU::V_CMPX_NE_I32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithIntInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32084 /* v_cmpx_ne_u32 */, AMDGPU::V_CMPX_NE_U32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 32084 /* v_cmpx_ne_u32 */, AMDGPU::V_CMPX_NE_U32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 32084 /* v_cmpx_ne_u32 */, AMDGPU::V_CMPX_NE_U32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32084 /* v_cmpx_ne_u32 */, AMDGPU::V_CMPX_NE_U32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32182 /* v_cmpx_neq_f32 */, AMDGPU::V_CMPX_NEQ_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 32182 /* v_cmpx_neq_f32 */, AMDGPU::V_CMPX_NEQ_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 32182 /* v_cmpx_neq_f32 */, AMDGPU::V_CMPX_NEQ_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32182 /* v_cmpx_neq_f32 */, AMDGPU::V_CMPX_NEQ_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32284 /* v_cmpx_nge_f32 */, AMDGPU::V_CMPX_NGE_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 32284 /* v_cmpx_nge_f32 */, AMDGPU::V_CMPX_NGE_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 32284 /* v_cmpx_nge_f32 */, AMDGPU::V_CMPX_NGE_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32284 /* v_cmpx_nge_f32 */, AMDGPU::V_CMPX_NGE_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32386 /* v_cmpx_ngt_f32 */, AMDGPU::V_CMPX_NGT_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 32386 /* v_cmpx_ngt_f32 */, AMDGPU::V_CMPX_NGT_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 32386 /* v_cmpx_ngt_f32 */, AMDGPU::V_CMPX_NGT_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32386 /* v_cmpx_ngt_f32 */, AMDGPU::V_CMPX_NGT_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32488 /* v_cmpx_nle_f32 */, AMDGPU::V_CMPX_NLE_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 32488 /* v_cmpx_nle_f32 */, AMDGPU::V_CMPX_NLE_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 32488 /* v_cmpx_nle_f32 */, AMDGPU::V_CMPX_NLE_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32488 /* v_cmpx_nle_f32 */, AMDGPU::V_CMPX_NLE_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32590 /* v_cmpx_nlg_f32 */, AMDGPU::V_CMPX_NLG_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 32590 /* v_cmpx_nlg_f32 */, AMDGPU::V_CMPX_NLG_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 32590 /* v_cmpx_nlg_f32 */, AMDGPU::V_CMPX_NLG_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32590 /* v_cmpx_nlg_f32 */, AMDGPU::V_CMPX_NLG_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32692 /* v_cmpx_nlt_f32 */, AMDGPU::V_CMPX_NLT_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 32692 /* v_cmpx_nlt_f32 */, AMDGPU::V_CMPX_NLT_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 32692 /* v_cmpx_nlt_f32 */, AMDGPU::V_CMPX_NLT_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32692 /* v_cmpx_nlt_f32 */, AMDGPU::V_CMPX_NLT_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32790 /* v_cmpx_o_f32 */, AMDGPU::V_CMPX_O_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 32790 /* v_cmpx_o_f32 */, AMDGPU::V_CMPX_O_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 32790 /* v_cmpx_o_f32 */, AMDGPU::V_CMPX_O_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32790 /* v_cmpx_o_f32 */, AMDGPU::V_CMPX_O_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32850 /* v_cmpx_t_f16 */, AMDGPU::V_CMPX_T_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32850 /* v_cmpx_t_f16 */, AMDGPU::V_CMPX_T_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 32850 /* v_cmpx_t_f16 */, AMDGPU::V_CMPX_T_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32850 /* v_cmpx_t_f16 */, AMDGPU::V_CMPX_T_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32880 /* v_cmpx_t_f32 */, AMDGPU::V_CMPX_T_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 32880 /* v_cmpx_t_f32 */, AMDGPU::V_CMPX_T_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32970 /* v_cmpx_t_i32 */, AMDGPU::V_CMPX_T_I32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 32970 /* v_cmpx_t_i32 */, AMDGPU::V_CMPX_T_I32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33060 /* v_cmpx_t_u32 */, AMDGPU::V_CMPX_T_U32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33060 /* v_cmpx_t_u32 */, AMDGPU::V_CMPX_T_U32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_fake16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_fake16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_t16_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_t16_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_t16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_t16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_fake16_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_fake16_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33252 /* v_cmpx_u_f32 */, AMDGPU::V_CMPX_U_F32_e32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33252 /* v_cmpx_u_f32 */, AMDGPU::V_CMPX_U_F32_e32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33252 /* v_cmpx_u_f32 */, AMDGPU::V_CMPX_U_F32_e32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33252 /* v_cmpx_u_f32 */, AMDGPU::V_CMPX_U_F32_e32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_dpp8_w64_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only_isWave64, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPP8, MCK_DppFI }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPP8, MCK_DppFI }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPP8, MCK_DppFI }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_dpp8_w32_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only_isWave32, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC_LO, MCK_DPP8, MCK_DppFI }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC_LO, MCK_DPP8, MCK_DppFI }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC_LO, MCK_DPP8, MCK_DppFI }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_HasDPP, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_VCC, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_dpp_w64_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only_isWave64, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_VCC, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_dpp_w64_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only_isWave64, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_VCC, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_dpp_w64_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only_isWave64, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_VCC, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_dpp_w32_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only_isWave32, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_VCC_LO, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_dpp_w32_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_VCC_LO, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_dpp_w32_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only_isWave32, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_VCC_LO, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33340 /* v_cos_bf16 */, AMDGPU::V_COS_BF16V_COS_BF16_fake16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33340 /* v_cos_bf16 */, AMDGPU::V_COS_BF16V_COS_BF16_t16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33340 /* v_cos_bf16 */, AMDGPU::V_COS_BF16V_COS_BF16_fake16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33340 /* v_cos_bf16 */, AMDGPU::V_COS_BF16V_COS_BF16_t16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33371 /* v_ctz_i32_b32 */, AMDGPU::V_CTZ_I32_B32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33371 /* v_ctz_i32_b32 */, AMDGPU::V_CTZ_I32_B32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33371 /* v_ctz_i32_b32 */, AMDGPU::V_CTZ_I32_B32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33371 /* v_ctz_i32_b32 */, AMDGPU::V_CTZ_I32_B32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33437 /* v_cvt_f16_bf8 */, AMDGPU::V_CVT_F16_BF8V_CVT_F16_BF8_fake16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33437 /* v_cvt_f16_bf8 */, AMDGPU::V_CVT_F16_BF8V_CVT_F16_BF8_t16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33437 /* v_cvt_f16_bf8 */, AMDGPU::V_CVT_F16_BF8V_CVT_F16_BF8_fake16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33437 /* v_cvt_f16_bf8 */, AMDGPU::V_CVT_F16_BF8V_CVT_F16_BF8_t16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33465 /* v_cvt_f16_fp8 */, AMDGPU::V_CVT_F16_FP8V_CVT_F16_FP8_fake16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33465 /* v_cvt_f16_fp8 */, AMDGPU::V_CVT_F16_FP8V_CVT_F16_FP8_t16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33465 /* v_cvt_f16_fp8 */, AMDGPU::V_CVT_F16_FP8V_CVT_F16_FP8_fake16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33465 /* v_cvt_f16_fp8 */, AMDGPU::V_CVT_F16_FP8V_CVT_F16_FP8_t16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_fake16_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_fake16_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_fake16_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_fake16_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33507 /* v_cvt_f32_bf16 */, AMDGPU::V_CVT_F32_BF16_gfx1250V_CVT_F32_BF16_gfx1250_fake16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_HasBF16ConversionInsts_isGFX1250Plus_isGFX125xOnly_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33507 /* v_cvt_f32_bf16 */, AMDGPU::V_CVT_F32_BF16_gfx1250V_CVT_F32_BF16_gfx1250_t16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_HasBF16ConversionInsts_isGFX1250Plus_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33507 /* v_cvt_f32_bf16 */, AMDGPU::V_CVT_F32_BF16_dpp_gfx9, ConvertCustom_cvtDPP, AMFBS_HasBF16ConversionInsts_HasGFX950Insts_HasDPP, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33507 /* v_cvt_f32_bf16 */, AMDGPU::V_CVT_F32_BF16_gfx1250V_CVT_F32_BF16_gfx1250_t16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_HasBF16ConversionInsts_isGFX1250Plus_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33507 /* v_cvt_f32_bf16 */, AMDGPU::V_CVT_F32_BF16_gfx1250V_CVT_F32_BF16_gfx1250_fake16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_HasBF16ConversionInsts_isGFX1250Plus_isGFX125xOnly_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33522 /* v_cvt_f32_bf8 */, AMDGPU::V_CVT_F32_BF8_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33522 /* v_cvt_f32_bf8 */, AMDGPU::V_CVT_F32_BF8_dpp_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_HasFP8ConversionInsts_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33522 /* v_cvt_f32_bf8 */, AMDGPU::V_CVT_F32_BF8_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33550 /* v_cvt_f32_f64 */, AMDGPU::V_CVT_F32_F64_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33550 /* v_cvt_f32_f64 */, AMDGPU::V_CVT_F32_F64_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPALU_DPP_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33564 /* v_cvt_f32_fp8 */, AMDGPU::V_CVT_F32_FP8_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_HasFP8ConversionInsts_isGFX12PlusNot12_50_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33564 /* v_cvt_f32_fp8 */, AMDGPU::V_CVT_F32_FP8_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_HasFP8ConversionInsts_isGFX12PlusNot12_50_isGFX12Not12_50, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33564 /* v_cvt_f32_fp8 */, AMDGPU::V_CVT_F32_FP8_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_HasFP8ConversionInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33564 /* v_cvt_f32_fp8 */, AMDGPU::V_CVT_F32_FP8_dpp_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_HasFP8ConversionInsts_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33564 /* v_cvt_f32_fp8 */, AMDGPU::V_CVT_F32_FP8_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_HasFP8ConversionInsts_isGFX12PlusNot12_50_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33564 /* v_cvt_f32_fp8 */, AMDGPU::V_CVT_F32_FP8_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_HasFP8ConversionInsts_isGFX12PlusNot12_50_isGFX12Not12_50, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33564 /* v_cvt_f32_fp8 */, AMDGPU::V_CVT_F32_FP8_dpp_gfx1250, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_HasFP8ConversionInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33674 /* v_cvt_f64_f32 */, AMDGPU::V_CVT_F64_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33674 /* v_cvt_f64_f32 */, AMDGPU::V_CVT_F64_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPALU_DPP_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33688 /* v_cvt_f64_i32 */, AMDGPU::V_CVT_F64_I32_dpp_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33688 /* v_cvt_f64_i32 */, AMDGPU::V_CVT_F64_I32_dpp_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_HasDPALU_DPP_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33702 /* v_cvt_f64_u32 */, AMDGPU::V_CVT_F64_U32_dpp_vi, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33702 /* v_cvt_f64_u32 */, AMDGPU::V_CVT_F64_U32_dpp_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_HasDPALU_DPP_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33716 /* v_cvt_floor_i32_f32 */, AMDGPU::V_CVT_FLOOR_I32_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33716 /* v_cvt_floor_i32_f32 */, AMDGPU::V_CVT_FLOOR_I32_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33716 /* v_cvt_floor_i32_f32 */, AMDGPU::V_CVT_FLOOR_I32_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33716 /* v_cvt_floor_i32_f32 */, AMDGPU::V_CVT_FLOOR_I32_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33736 /* v_cvt_flr_i32_f32 */, AMDGPU::V_CVT_FLR_I32_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33736 /* v_cvt_flr_i32_f32 */, AMDGPU::V_CVT_FLR_I32_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33736 /* v_cvt_flr_i32_f32 */, AMDGPU::V_CVT_FLR_I32_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33782 /* v_cvt_i32_f64 */, AMDGPU::V_CVT_I32_F64_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33782 /* v_cvt_i32_f64 */, AMDGPU::V_CVT_I32_F64_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPALU_DPP_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_fake16_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_fake16_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33810 /* v_cvt_nearest_i32_f32 */, AMDGPU::V_CVT_NEAREST_I32_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33810 /* v_cvt_nearest_i32_f32 */, AMDGPU::V_CVT_NEAREST_I32_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33810 /* v_cvt_nearest_i32_f32 */, AMDGPU::V_CVT_NEAREST_I32_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33810 /* v_cvt_nearest_i32_f32 */, AMDGPU::V_CVT_NEAREST_I32_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasCvtNormInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasCvtNormInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasCvtNormInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasCvtNormInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasCvtNormInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_HasCvtNormInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33939 /* v_cvt_pk_f16_bf8 */, AMDGPU::V_CVT_PK_F16_BF8V_CVT_PK_F16_BF8_fake16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33939 /* v_cvt_pk_f16_bf8 */, AMDGPU::V_CVT_PK_F16_BF8V_CVT_PK_F16_BF8_t16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33939 /* v_cvt_pk_f16_bf8 */, AMDGPU::V_CVT_PK_F16_BF8V_CVT_PK_F16_BF8_t16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33939 /* v_cvt_pk_f16_bf8 */, AMDGPU::V_CVT_PK_F16_BF8V_CVT_PK_F16_BF8_fake16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33973 /* v_cvt_pk_f16_fp8 */, AMDGPU::V_CVT_PK_F16_FP8V_CVT_PK_F16_FP8_fake16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33973 /* v_cvt_pk_f16_fp8 */, AMDGPU::V_CVT_PK_F16_FP8V_CVT_PK_F16_FP8_t16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 33973 /* v_cvt_pk_f16_fp8 */, AMDGPU::V_CVT_PK_F16_FP8V_CVT_PK_F16_FP8_t16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33973 /* v_cvt_pk_f16_fp8 */, AMDGPU::V_CVT_PK_F16_FP8V_CVT_PK_F16_FP8_fake16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33990 /* v_cvt_pk_f32_bf8 */, AMDGPU::V_CVT_PK_F32_BF8_dpp_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_HasFP8ConversionInsts_HasDPALU_DPP, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 34007 /* v_cvt_pk_f32_fp8 */, AMDGPU::V_CVT_PK_F32_FP8_dpp_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_HasFP8ConversionInsts_HasDPALU_DPP, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 34180 /* v_cvt_pk_rtz_f16_f32 */, AMDGPU::V_CVT_PK_RTZ_F16_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 34180 /* v_cvt_pk_rtz_f16_f32 */, AMDGPU::V_CVT_PK_RTZ_F16_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 34180 /* v_cvt_pk_rtz_f16_f32 */, AMDGPU::V_CVT_PK_RTZ_F16_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34180 /* v_cvt_pk_rtz_f16_f32 */, AMDGPU::V_CVT_PK_RTZ_F16_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34356 /* v_cvt_pkrtz_f16_f32 */, AMDGPU::V_CVT_PKRTZ_F16_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 34356 /* v_cvt_pkrtz_f16_f32 */, AMDGPU::V_CVT_PKRTZ_F16_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34376 /* v_cvt_rpi_i32_f32 */, AMDGPU::V_CVT_RPI_I32_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 34376 /* v_cvt_rpi_i32_f32 */, AMDGPU::V_CVT_RPI_I32_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 34376 /* v_cvt_rpi_i32_f32 */, AMDGPU::V_CVT_RPI_I32_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37158 /* v_cvt_u32_f64 */, AMDGPU::V_CVT_U32_F64_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 37158 /* v_cvt_u32_f64 */, AMDGPU::V_CVT_U32_F64_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPALU_DPP_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_fake16_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_fake16_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37412 /* v_dot2acc_f32_f16 */, AMDGPU::V_DOT2ACC_F32_F16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_HasDot5Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 37412 /* v_dot2acc_f32_f16 */, AMDGPU::V_DOT2ACC_F32_F16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDot5Insts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37430 /* v_dot2c_f32_bf16 */, AMDGPU::V_DOT2C_F32_BF16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_HasDot13Insts_isGFX9Only_HasDPP, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 37447 /* v_dot2c_f32_f16 */, AMDGPU::V_DOT2C_F32_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_HasDot5Insts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 37447 /* v_dot2c_f32_f16 */, AMDGPU::V_DOT2C_F32_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_HasDot5Insts_isGFX9Only_HasDPP, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 37447 /* v_dot2c_f32_f16 */, AMDGPU::V_DOT2C_F32_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_HasDot5Insts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37463 /* v_dot2c_i32_i16 */, AMDGPU::V_DOT2C_I32_I16_dpp_vi, Convert__Reg1_0__imm_95_0__Reg1_1__imm_95_0__Reg1_2__Tie0_1_1__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_HasDot4Insts_isGFX9Only_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 37598 /* v_dot4c_i32_i8 */, AMDGPU::V_DOT4C_I32_I8_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_HasDot6Insts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 37598 /* v_dot4c_i32_i8 */, AMDGPU::V_DOT4C_I32_I8_dpp_vi, Convert__Reg1_0__imm_95_0__Reg1_1__imm_95_0__Reg1_2__Tie0_1_1__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_HasDot6Insts_isGFX9Only_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 37598 /* v_dot4c_i32_i8 */, AMDGPU::V_DOT4C_I32_I8_dpp_gfx10, Convert__Reg1_0__imm_95_0__Reg1_1__imm_95_0__Reg1_2__Tie0_1_1__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_HasDot6Insts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37656 /* v_dot8c_i32_i4 */, AMDGPU::V_DOT8C_I32_I4_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_HasDot3Insts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 37656 /* v_dot8c_i32_i4 */, AMDGPU::V_DOT8C_I32_I4_dpp_vi, Convert__Reg1_0__imm_95_0__Reg1_1__imm_95_0__Reg1_2__Tie0_1_1__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_HasDot3Insts_isGFX9Only_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 37656 /* v_dot8c_i32_i4 */, AMDGPU::V_DOT8C_I32_I4_dpp_gfx10, Convert__Reg1_0__imm_95_0__Reg1_1__imm_95_0__Reg1_2__Tie0_1_1__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_HasDot3Insts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38148 /* v_exp_bf16 */, AMDGPU::V_EXP_BF16V_EXP_BF16_fake16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38148 /* v_exp_bf16 */, AMDGPU::V_EXP_BF16V_EXP_BF16_t16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38148 /* v_exp_bf16 */, AMDGPU::V_EXP_BF16V_EXP_BF16_fake16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38148 /* v_exp_bf16 */, AMDGPU::V_EXP_BF16V_EXP_BF16_t16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38179 /* v_exp_legacy_f32 */, AMDGPU::V_EXP_LEGACY_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX7GFX8GFX9_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 38196 /* v_ffbh_i32 */, AMDGPU::V_FFBH_I32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38196 /* v_ffbh_i32 */, AMDGPU::V_FFBH_I32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 38196 /* v_ffbh_i32 */, AMDGPU::V_FFBH_I32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38207 /* v_ffbh_u32 */, AMDGPU::V_FFBH_U32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38207 /* v_ffbh_u32 */, AMDGPU::V_FFBH_U32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 38207 /* v_ffbh_u32 */, AMDGPU::V_FFBH_U32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38218 /* v_ffbl_b32 */, AMDGPU::V_FFBL_B32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38218 /* v_ffbl_b32 */, AMDGPU::V_FFBL_B32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 38218 /* v_ffbl_b32 */, AMDGPU::V_FFBL_B32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38253 /* v_floor_f64 */, AMDGPU::V_FLOOR_F64_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 38253 /* v_floor_f64 */, AMDGPU::V_FLOOR_F64_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPALU_DPP_isGFX7Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX10Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX10Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Plus_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX10Plus_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX10Plus_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Plus_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38514 /* v_fmac_f32 */, AMDGPU::V_FMAC_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_HasDLInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38514 /* v_fmac_f32 */, AMDGPU::V_FMAC_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_HasDLInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38514 /* v_fmac_f32 */, AMDGPU::V_FMAC_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_HasDLInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38514 /* v_fmac_f32 */, AMDGPU::V_FMAC_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_HasDLInsts_HasDPP, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 38514 /* v_fmac_f32 */, AMDGPU::V_FMAC_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_HasDLInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38514 /* v_fmac_f32 */, AMDGPU::V_FMAC_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_HasDLInsts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38514 /* v_fmac_f32 */, AMDGPU::V_FMAC_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDLInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38525 /* v_fmac_f64 */, AMDGPU::V_FMAC_F64_dpp_gfx90a, ConvertCustom_cvtDPP, AMFBS_isGFX9Only_HasFmacF64Inst_HasDPALU_DPP, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 38525 /* v_fmac_f64 */, AMDGPU::V_FMAC_F64_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPALU_DPP_HasFmacF64Inst_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38614 /* v_fract_f64 */, AMDGPU::V_FRACT_F64_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 38614 /* v_fract_f64 */, AMDGPU::V_FRACT_F64_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPALU_DPP_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38666 /* v_frexp_exp_i32_f64 */, AMDGPU::V_FREXP_EXP_I32_F64_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 38666 /* v_frexp_exp_i32_f64 */, AMDGPU::V_FREXP_EXP_I32_F64_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPALU_DPP_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38720 /* v_frexp_mant_f64 */, AMDGPU::V_FREXP_MANT_F64_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 38720 /* v_frexp_mant_f64 */, AMDGPU::V_FREXP_MANT_F64_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPALU_DPP_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_Has16BitInsts_HasDPP_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39024 /* v_log_bf16 */, AMDGPU::V_LOG_BF16V_LOG_BF16_fake16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 39024 /* v_log_bf16 */, AMDGPU::V_LOG_BF16V_LOG_BF16_t16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 39024 /* v_log_bf16 */, AMDGPU::V_LOG_BF16V_LOG_BF16_fake16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39024 /* v_log_bf16 */, AMDGPU::V_LOG_BF16V_LOG_BF16_t16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39071 /* v_log_legacy_f32 */, AMDGPU::V_LOG_LEGACY_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX7GFX8GFX9_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 39154 /* v_lshlrev_b16 */, AMDGPU::V_LSHLREV_B16_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_Has16BitInsts_HasDPP_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39182 /* v_lshlrev_b64 */, AMDGPU::V_LSHLREV_B64_dpp_gfx12, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__Reg1_1__RegByHwMode_VReg_64_AlignTarget1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_HasDPALU_DPP_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39218 /* v_lshrrev_b16 */, AMDGPU::V_LSHRREV_B16_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_Has16BitInsts_HasDPP_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39260 /* v_mac_f16 */, AMDGPU::V_MAC_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_Has16BitInsts_HasDPP, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 39270 /* v_mac_f32 */, AMDGPU::V_MAC_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_HasMadMacF32Insts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 39270 /* v_mac_f32 */, AMDGPU::V_MAC_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_HasMadMacF32Insts_HasDPP, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 39270 /* v_mac_f32 */, AMDGPU::V_MAC_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_HasMadMacF32Insts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39757 /* v_max_f16 */, AMDGPU::V_MAX_F16V_MAX_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 39757 /* v_max_f16 */, AMDGPU::V_MAX_F16V_MAX_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 39757 /* v_max_f16 */, AMDGPU::V_MAX_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 39757 /* v_max_f16 */, AMDGPU::V_MAX_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_Has16BitInsts_HasDPP_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 39757 /* v_max_f16 */, AMDGPU::V_MAX_F16V_MAX_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39757 /* v_max_f16 */, AMDGPU::V_MAX_F16V_MAX_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39757 /* v_max_f16 */, AMDGPU::V_MAX_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39767 /* v_max_f32 */, AMDGPU::V_MAX_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 39767 /* v_max_f32 */, AMDGPU::V_MAX_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 39767 /* v_max_f32 */, AMDGPU::V_MAX_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_HasDPP, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 39767 /* v_max_f32 */, AMDGPU::V_MAX_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39767 /* v_max_f32 */, AMDGPU::V_MAX_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39787 /* v_max_i16 */, AMDGPU::V_MAX_I16_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_Has16BitInsts_HasDPP_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39834 /* v_max_num_f16 */, AMDGPU::V_MAX_NUM_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 39834 /* v_max_num_f16 */, AMDGPU::V_MAX_NUM_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 39834 /* v_max_num_f16 */, AMDGPU::V_MAX_NUM_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39834 /* v_max_num_f16 */, AMDGPU::V_MAX_NUM_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39848 /* v_max_num_f32 */, AMDGPU::V_MAX_NUM_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 39848 /* v_max_num_f32 */, AMDGPU::V_MAX_NUM_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39862 /* v_max_num_f64 */, AMDGPU::V_MAX_NUM_F64_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPALU_DPP_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39876 /* v_max_u16 */, AMDGPU::V_MAX_U16_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_Has16BitInsts_HasDPP_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40317 /* v_mfma_f32_16x16x16bf16 */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40317 /* v_mfma_f32_16x16x16bf16 */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40341 /* v_mfma_f32_16x16x16bf16_1k */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40341 /* v_mfma_f32_16x16x16bf16_1k */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40368 /* v_mfma_f32_16x16x16f16 */, AMDGPU::V_MFMA_F32_16X16X16F16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40368 /* v_mfma_f32_16x16x16f16 */, AMDGPU::V_MFMA_F32_16X16X16F16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40417 /* v_mfma_f32_16x16x1f32 */, AMDGPU::V_MFMA_F32_16X16X1F32_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40417 /* v_mfma_f32_16x16x1f32 */, AMDGPU::V_MFMA_F32_16X16X1F32_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40623 /* v_mfma_f32_16x16x32bf16 */, AMDGPU::V_MFMA_F32_16X16X32_BF16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40623 /* v_mfma_f32_16x16x32bf16 */, AMDGPU::V_MFMA_F32_16X16X32_BF16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40647 /* v_mfma_f32_16x16x32f16 */, AMDGPU::V_MFMA_F32_16X16X32_F16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40647 /* v_mfma_f32_16x16x32f16 */, AMDGPU::V_MFMA_F32_16X16X32_F16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40746 /* v_mfma_f32_16x16x4bf16 */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40746 /* v_mfma_f32_16x16x4bf16 */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40769 /* v_mfma_f32_16x16x4bf16_1k */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40769 /* v_mfma_f32_16x16x4bf16_1k */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40795 /* v_mfma_f32_16x16x4f16 */, AMDGPU::V_MFMA_F32_16X16X4F16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40795 /* v_mfma_f32_16x16x4f16 */, AMDGPU::V_MFMA_F32_16X16X4F16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40817 /* v_mfma_f32_16x16x4f32 */, AMDGPU::V_MFMA_F32_16X16X4F32_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40817 /* v_mfma_f32_16x16x4f32 */, AMDGPU::V_MFMA_F32_16X16X4F32_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40886 /* v_mfma_f32_16x16x8xf32 */, AMDGPU::V_MFMA_F32_16X16X8XF32_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40886 /* v_mfma_f32_16x16x8xf32 */, AMDGPU::V_MFMA_F32_16X16X8XF32_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41070 /* v_mfma_f32_32x32x16bf16 */, AMDGPU::V_MFMA_F32_32X32X16_BF16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41070 /* v_mfma_f32_32x32x16bf16 */, AMDGPU::V_MFMA_F32_32X32X16_BF16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41094 /* v_mfma_f32_32x32x16f16 */, AMDGPU::V_MFMA_F32_32X32X16_F16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41094 /* v_mfma_f32_32x32x16f16 */, AMDGPU::V_MFMA_F32_32X32X16_F16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41143 /* v_mfma_f32_32x32x1f32 */, AMDGPU::V_MFMA_F32_32X32X1F32_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_1024_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41143 /* v_mfma_f32_32x32x1f32 */, AMDGPU::V_MFMA_F32_32X32X1F32_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_1024_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_1024_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41211 /* v_mfma_f32_32x32x2f32 */, AMDGPU::V_MFMA_F32_32X32X2F32_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41211 /* v_mfma_f32_32x32x2f32 */, AMDGPU::V_MFMA_F32_32X32X2F32_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41310 /* v_mfma_f32_32x32x4bf16 */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41310 /* v_mfma_f32_32x32x4bf16 */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41333 /* v_mfma_f32_32x32x4bf16_1k */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41333 /* v_mfma_f32_32x32x4bf16_1k */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41359 /* v_mfma_f32_32x32x4f16 */, AMDGPU::V_MFMA_F32_32X32X4F16_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41359 /* v_mfma_f32_32x32x4f16 */, AMDGPU::V_MFMA_F32_32X32X4F16_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41381 /* v_mfma_f32_32x32x4xf32 */, AMDGPU::V_MFMA_F32_32X32X4XF32_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41381 /* v_mfma_f32_32x32x4xf32 */, AMDGPU::V_MFMA_F32_32X32X4XF32_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41478 /* v_mfma_f32_32x32x8bf16 */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41478 /* v_mfma_f32_32x32x8bf16 */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41501 /* v_mfma_f32_32x32x8bf16_1k */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41501 /* v_mfma_f32_32x32x8bf16_1k */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41527 /* v_mfma_f32_32x32x8f16 */, AMDGPU::V_MFMA_F32_32X32X8F16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41527 /* v_mfma_f32_32x32x8f16 */, AMDGPU::V_MFMA_F32_32X32X8F16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41574 /* v_mfma_f32_4x4x1f32 */, AMDGPU::V_MFMA_F32_4X4X1F32_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41574 /* v_mfma_f32_4x4x1f32 */, AMDGPU::V_MFMA_F32_4X4X1F32_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41666 /* v_mfma_f32_4x4x4bf16 */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41666 /* v_mfma_f32_4x4x4bf16 */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41687 /* v_mfma_f32_4x4x4bf16_1k */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41687 /* v_mfma_f32_4x4x4bf16_1k */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41711 /* v_mfma_f32_4x4x4f16 */, AMDGPU::V_MFMA_F32_4X4X4F16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41711 /* v_mfma_f32_4x4x4f16 */, AMDGPU::V_MFMA_F32_4X4X4F16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41754 /* v_mfma_f64_16x16x4f64 */, AMDGPU::V_MFMA_F64_16X16X4F64_gfx940_acd, Convert__RegByHwMode_AReg_256_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_256_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_256_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_256_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41754 /* v_mfma_f64_16x16x4f64 */, AMDGPU::V_MFMA_F64_16X16X4F64_gfx940_vcd, Convert__RegByHwMode_VReg_256_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_256_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_256_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41800 /* v_mfma_f64_4x4x4f64 */, AMDGPU::V_MFMA_F64_4X4X4F64_gfx940_acd, Convert__RegByHwMode_AReg_64_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_64_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_64_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41800 /* v_mfma_f64_4x4x4f64 */, AMDGPU::V_MFMA_F64_4X4X4F64_gfx940_vcd, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_64_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_64_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41865 /* v_mfma_i32_16x16x32i8 */, AMDGPU::V_MFMA_I32_16X16X32I8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41865 /* v_mfma_i32_16x16x32i8 */, AMDGPU::V_MFMA_I32_16X16X32I8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41912 /* v_mfma_i32_16x16x4i8 */, AMDGPU::V_MFMA_I32_16X16X4I8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41912 /* v_mfma_i32_16x16x4i8 */, AMDGPU::V_MFMA_I32_16X16X4I8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41956 /* v_mfma_i32_16x16x64i8 */, AMDGPU::V_MFMA_I32_16X16X64_I8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41956 /* v_mfma_i32_16x16x64i8 */, AMDGPU::V_MFMA_I32_16X16X64_I8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42001 /* v_mfma_i32_32x32x16i8 */, AMDGPU::V_MFMA_I32_32X32X16I8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42001 /* v_mfma_i32_32x32x16i8 */, AMDGPU::V_MFMA_I32_32X32X16I8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42046 /* v_mfma_i32_32x32x32i8 */, AMDGPU::V_MFMA_I32_32X32X32_I8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42046 /* v_mfma_i32_32x32x32i8 */, AMDGPU::V_MFMA_I32_32X32X32_I8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42093 /* v_mfma_i32_32x32x4i8 */, AMDGPU::V_MFMA_I32_32X32X4I8_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42093 /* v_mfma_i32_32x32x4i8 */, AMDGPU::V_MFMA_I32_32X32X4I8_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42159 /* v_mfma_i32_4x4x4i8 */, AMDGPU::V_MFMA_I32_4X4X4I8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42159 /* v_mfma_i32_4x4x4i8 */, AMDGPU::V_MFMA_I32_4X4X4I8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42361 /* v_min_f16 */, AMDGPU::V_MIN_F16V_MIN_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 42361 /* v_min_f16 */, AMDGPU::V_MIN_F16V_MIN_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 42361 /* v_min_f16 */, AMDGPU::V_MIN_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42361 /* v_min_f16 */, AMDGPU::V_MIN_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_Has16BitInsts_HasDPP_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 42361 /* v_min_f16 */, AMDGPU::V_MIN_F16V_MIN_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42361 /* v_min_f16 */, AMDGPU::V_MIN_F16V_MIN_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42361 /* v_min_f16 */, AMDGPU::V_MIN_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42371 /* v_min_f32 */, AMDGPU::V_MIN_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42371 /* v_min_f32 */, AMDGPU::V_MIN_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42371 /* v_min_f32 */, AMDGPU::V_MIN_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_HasDPP, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 42371 /* v_min_f32 */, AMDGPU::V_MIN_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42371 /* v_min_f32 */, AMDGPU::V_MIN_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42391 /* v_min_i16 */, AMDGPU::V_MIN_I16_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_Has16BitInsts_HasDPP_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42438 /* v_min_num_f16 */, AMDGPU::V_MIN_NUM_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 42438 /* v_min_num_f16 */, AMDGPU::V_MIN_NUM_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 42438 /* v_min_num_f16 */, AMDGPU::V_MIN_NUM_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42438 /* v_min_num_f16 */, AMDGPU::V_MIN_NUM_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42452 /* v_min_num_f32 */, AMDGPU::V_MIN_NUM_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42452 /* v_min_num_f32 */, AMDGPU::V_MIN_NUM_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42466 /* v_min_num_f64 */, AMDGPU::V_MIN_NUM_F64_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPALU_DPP_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42480 /* v_min_u16 */, AMDGPU::V_MIN_U16_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_Has16BitInsts_HasDPP_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42710 /* v_mov_b16 */, AMDGPU::V_MOV_B16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 42710 /* v_mov_b16 */, AMDGPU::V_MOV_B16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 42710 /* v_mov_b16 */, AMDGPU::V_MOV_B16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42710 /* v_mov_b16 */, AMDGPU::V_MOV_B16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42730 /* v_mov_b64 */, AMDGPU::V_MOV_B64_dpp_gfx9, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__RegByHwMode_VReg_64_AlignTarget1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_isGFX940orGFX1250_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 42730 /* v_mov_b64 */, AMDGPU::V_MOV_B64_dpp_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__RegByHwMode_VReg_64_AlignTarget1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_HasDPALU_DPP_isGFX940orGFX1250_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42740 /* v_movreld_b32 */, AMDGPU::V_MOVRELD_B32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_HasMovrel_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42740 /* v_movreld_b32 */, AMDGPU::V_MOVRELD_B32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_HasMovrel_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42740 /* v_movreld_b32 */, AMDGPU::V_MOVRELD_B32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_HasMovrel_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42740 /* v_movreld_b32 */, AMDGPU::V_MOVRELD_B32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_HasMovrel_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42740 /* v_movreld_b32 */, AMDGPU::V_MOVRELD_B32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_HasMovrel_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42740 /* v_movreld_b32 */, AMDGPU::V_MOVRELD_B32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_HasMovrel_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42754 /* v_movrels_b32 */, AMDGPU::V_MOVRELS_B32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_HasMovrel_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42754 /* v_movrels_b32 */, AMDGPU::V_MOVRELS_B32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_HasMovrel_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42754 /* v_movrels_b32 */, AMDGPU::V_MOVRELS_B32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_HasMovrel_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42754 /* v_movrels_b32 */, AMDGPU::V_MOVRELS_B32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_HasMovrel_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42754 /* v_movrels_b32 */, AMDGPU::V_MOVRELS_B32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_HasMovrel_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42754 /* v_movrels_b32 */, AMDGPU::V_MOVRELS_B32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_HasMovrel_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42768 /* v_movrelsd_2_b32 */, AMDGPU::V_MOVRELSD_2_B32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Plus_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42768 /* v_movrelsd_2_b32 */, AMDGPU::V_MOVRELSD_2_B32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42768 /* v_movrelsd_2_b32 */, AMDGPU::V_MOVRELSD_2_B32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42768 /* v_movrelsd_2_b32 */, AMDGPU::V_MOVRELSD_2_B32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX10Plus_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42768 /* v_movrelsd_2_b32 */, AMDGPU::V_MOVRELSD_2_B32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42768 /* v_movrelsd_2_b32 */, AMDGPU::V_MOVRELSD_2_B32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42785 /* v_movrelsd_b32 */, AMDGPU::V_MOVRELSD_B32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_HasMovrel_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42785 /* v_movrelsd_b32 */, AMDGPU::V_MOVRELSD_B32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_HasMovrel_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42785 /* v_movrelsd_b32 */, AMDGPU::V_MOVRELSD_B32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_HasMovrel_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42785 /* v_movrelsd_b32 */, AMDGPU::V_MOVRELSD_B32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_HasMovrel_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42785 /* v_movrelsd_b32 */, AMDGPU::V_MOVRELSD_B32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_HasMovrel_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42785 /* v_movrelsd_b32 */, AMDGPU::V_MOVRELSD_B32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_HasMovrel_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42843 /* v_mul_dx9_zero_f32 */, AMDGPU::V_MUL_DX9_ZERO_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42843 /* v_mul_dx9_zero_f32 */, AMDGPU::V_MUL_DX9_ZERO_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42843 /* v_mul_dx9_zero_f32 */, AMDGPU::V_MUL_DX9_ZERO_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42843 /* v_mul_dx9_zero_f32 */, AMDGPU::V_MUL_DX9_ZERO_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_Has16BitInsts_HasDPP_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_HasDPP, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42882 /* v_mul_f64 */, AMDGPU::V_MUL_F64_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPALU_DPP_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42966 /* v_mul_legacy_f32 */, AMDGPU::V_MUL_LEGACY_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42966 /* v_mul_legacy_f32 */, AMDGPU::V_MUL_LEGACY_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGCN3ExcludingGFX90A_HasDPP, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 42966 /* v_mul_legacy_f32 */, AMDGPU::V_MUL_LEGACY_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42996 /* v_mul_lo_u16 */, AMDGPU::V_MUL_LO_U16_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_Has16BitInsts_HasDPP_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43059 /* v_nop */, AMDGPU::V_NOP_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_DPP8, MCK_DppFI }, },
  { 43059 /* v_nop */, AMDGPU::V_NOP_dpp_vi, Convert__DPPCtrl1_0__DppRowMask1_1__DppBankMask1_2__DppBoundCtrl1_3, AMFBS_isGFX8GFX9, { MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 43059 /* v_nop */, AMDGPU::V_NOP_dpp_gfx10, Convert__DPPCtrl1_0__DppRowMask1_1__DppBankMask1_2__DppBoundCtrl1_3__DppFI1_4, AMFBS_isGFX10Only, { MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_fake16_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_fake16_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43636 /* v_pk_fmac_f16 */, AMDGPU::V_PK_FMAC_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_HasPkFmacF16Inst_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 43636 /* v_pk_fmac_f16 */, AMDGPU::V_PK_FMAC_F16_dpp_gfx9, ConvertCustom_cvtDPP, AMFBS_HasPkFmacF16Inst_isGFX9Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 43636 /* v_pk_fmac_f16 */, AMDGPU::V_PK_FMAC_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_HasPkFmacF16Inst_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44115 /* v_prng_b32 */, AMDGPU::V_PRNG_B32_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_HasPrngInst_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44115 /* v_prng_b32 */, AMDGPU::V_PRNG_B32_dpp_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_HasPrngInst_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 44115 /* v_prng_b32 */, AMDGPU::V_PRNG_B32_dpp_gfx1250, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_HasPrngInst_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44143 /* v_rcp_bf16 */, AMDGPU::V_RCP_BF16V_RCP_BF16_fake16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 44143 /* v_rcp_bf16 */, AMDGPU::V_RCP_BF16V_RCP_BF16_t16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 44143 /* v_rcp_bf16 */, AMDGPU::V_RCP_BF16V_RCP_BF16_fake16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44143 /* v_rcp_bf16 */, AMDGPU::V_RCP_BF16V_RCP_BF16_t16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44206 /* v_rcp_f64 */, AMDGPU::V_RCP_F64_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44308 /* v_rndne_f64 */, AMDGPU::V_RNDNE_F64_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 44308 /* v_rndne_f64 */, AMDGPU::V_RNDNE_F64_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPALU_DPP_isGFX7Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44320 /* v_rsq_bf16 */, AMDGPU::V_RSQ_BF16V_RSQ_BF16_fake16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 44320 /* v_rsq_bf16 */, AMDGPU::V_RSQ_BF16V_RSQ_BF16_t16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 44320 /* v_rsq_bf16 */, AMDGPU::V_RSQ_BF16V_RSQ_BF16_fake16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44320 /* v_rsq_bf16 */, AMDGPU::V_RSQ_BF16V_RSQ_BF16_t16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44383 /* v_rsq_f64 */, AMDGPU::V_RSQ_F64_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 44573 /* v_sat_pk4_i4_i8 */, AMDGPU::V_SAT_PK4_I4_I8V_SAT_PK4_I4_I8_fake16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44573 /* v_sat_pk4_i4_i8 */, AMDGPU::V_SAT_PK4_I4_I8V_SAT_PK4_I4_I8_t16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44573 /* v_sat_pk4_i4_i8 */, AMDGPU::V_SAT_PK4_I4_I8V_SAT_PK4_I4_I8_fake16_dpp_gfx1250, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44573 /* v_sat_pk4_i4_i8 */, AMDGPU::V_SAT_PK4_I4_I8V_SAT_PK4_I4_I8_t16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44589 /* v_sat_pk4_u4_u8 */, AMDGPU::V_SAT_PK4_U4_U8V_SAT_PK4_U4_U8_fake16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44589 /* v_sat_pk4_u4_u8 */, AMDGPU::V_SAT_PK4_U4_U8V_SAT_PK4_U4_U8_t16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44589 /* v_sat_pk4_u4_u8 */, AMDGPU::V_SAT_PK4_U4_U8V_SAT_PK4_U4_U8_fake16_dpp_gfx1250, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44589 /* v_sat_pk4_u4_u8 */, AMDGPU::V_SAT_PK4_U4_U8V_SAT_PK4_U4_U8_t16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX9Plus_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX9Plus_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX9Plus_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX9Plus_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX9Plus_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX9Plus_isGFX8GFX9, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_fake16_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_UseFakeTrue16Insts_isGFX9Plus_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_fake16_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_UseFakeTrue16Insts_isGFX9Plus_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX9Plus_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX9Plus_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VRegWithIntInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5__DppFI1_6, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX9Plus_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44621 /* v_screen_partition_4se_b32 */, AMDGPU::V_SCREEN_PARTITION_4SE_B32_dpp_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__DPPCtrl1_2__DppRowMask1_3__DppBankMask1_4__DppBoundCtrl1_5, AMFBS_isGFX9Only_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 44648 /* v_sin_bf16 */, AMDGPU::V_SIN_BF16V_SIN_BF16_fake16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 44648 /* v_sin_bf16 */, AMDGPU::V_SIN_BF16V_SIN_BF16_t16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 44648 /* v_sin_bf16 */, AMDGPU::V_SIN_BF16V_SIN_BF16_fake16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44648 /* v_sin_bf16 */, AMDGPU::V_SIN_BF16V_SIN_BF16_t16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45476 /* v_sqrt_bf16 */, AMDGPU::V_SQRT_BF16V_SQRT_BF16_fake16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 45476 /* v_sqrt_bf16 */, AMDGPU::V_SQRT_BF16V_SQRT_BF16_t16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 45476 /* v_sqrt_bf16 */, AMDGPU::V_SQRT_BF16V_SQRT_BF16_fake16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45476 /* v_sqrt_bf16 */, AMDGPU::V_SQRT_BF16V_SQRT_BF16_t16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45510 /* v_sqrt_f64 */, AMDGPU::V_SQRT_F64_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_dpp8_w64_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPP8, MCK_DppFI }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPP8, MCK_DppFI }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPP8, MCK_DppFI }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_dpp8_w32_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC_LO, MCK_DPP8, MCK_DppFI }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC_LO, MCK_DPP8, MCK_DppFI }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC_LO, MCK_DPP8, MCK_DppFI }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_dpp_w64_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8__DppFI1_9, AMFBS_isGFX10Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_dpp_w64_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8__DppFI1_9, AMFBS_isGFX11Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_dpp_w64_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8__DppFI1_9, AMFBS_isGFX12Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_dpp_w32_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8__DppFI1_9, AMFBS_isGFX10Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC_LO, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_dpp_w32_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8__DppFI1_9, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC_LO, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_dpp_w32_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8__DppFI1_9, AMFBS_isGFX12Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC_LO, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45537 /* v_sub_co_u32 */, AMDGPU::V_SUB_CO_U32_dpp_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_4__DppRowMask1_5__DppBankMask1_6__DppBoundCtrl1_7, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_Has16BitInsts_HasDPP_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_HasDPP, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45629 /* v_sub_nc_u32 */, AMDGPU::V_SUB_NC_U32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_HasAddNoCarryInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45629 /* v_sub_nc_u32 */, AMDGPU::V_SUB_NC_U32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_HasAddNoCarryInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45629 /* v_sub_nc_u32 */, AMDGPU::V_SUB_NC_U32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_HasAddNoCarryInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45629 /* v_sub_nc_u32 */, AMDGPU::V_SUB_NC_U32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_HasAddNoCarryInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45629 /* v_sub_nc_u32 */, AMDGPU::V_SUB_NC_U32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_HasAddNoCarryInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45629 /* v_sub_nc_u32 */, AMDGPU::V_SUB_NC_U32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_HasAddNoCarryInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45642 /* v_sub_nc_u64 */, AMDGPU::V_SUB_U64_dpp_gfx1250, Convert__RegByHwMode_VReg_64_AlignTarget1_0__Tie0_1_1__RegByHwMode_VReg_64_AlignTarget1_1__RegByHwMode_VReg_64_AlignTarget1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_HasDPALU_DPP_HasAddSubU64Insts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45655 /* v_sub_u16 */, AMDGPU::V_SUB_U16_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_isGFX8GFX9_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 45665 /* v_sub_u32 */, AMDGPU::V_SUB_U32_dpp_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_HasAddNoCarryInsts_isGFX9Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 45665 /* v_sub_u32 */, AMDGPU::V_SUB_U32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_4__DppRowMask1_5__DppBankMask1_6__DppBoundCtrl1_7, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 45675 /* v_subb_co_u32 */, AMDGPU::V_SUBB_CO_U32_dpp_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 45689 /* v_subb_u32 */, AMDGPU::V_SUBB_U32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 45700 /* v_subbrev_co_u32 */, AMDGPU::V_SUBBREV_CO_U32_dpp_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 45717 /* v_subbrev_u32 */, AMDGPU::V_SUBBREV_U32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_dpp8_w64_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPP8, MCK_DppFI }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_dpp8_w64_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPP8, MCK_DppFI }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_dpp8_w64_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPP8, MCK_DppFI }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_dpp8_w32_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC_LO, MCK_DPP8, MCK_DppFI }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_dpp8_w32_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC_LO, MCK_DPP8, MCK_DppFI }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_dpp8_w32_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC_LO, MCK_DPP8, MCK_DppFI }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_dpp_w64_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8__DppFI1_9, AMFBS_isGFX10Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_dpp_w64_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8__DppFI1_9, AMFBS_isGFX11Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_dpp_w64_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8__DppFI1_9, AMFBS_isGFX12Only_isWave64, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_dpp_w32_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8__DppFI1_9, AMFBS_isGFX10Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC_LO, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_dpp_w32_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8__DppFI1_9, AMFBS_isGFX11Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC_LO, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_dpp_w32_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_5__DppRowMask1_6__DppBankMask1_7__DppBoundCtrl1_8__DppFI1_9, AMFBS_isGFX12Only_isWave32, { MCK_VGPR_32, MCK_VCC_LO, MCK_VGPR_32, MCK_VGPR_32, MCK_VCC_LO, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45750 /* v_subrev_co_u32 */, AMDGPU::V_SUBREV_CO_U32_dpp_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_4__DppRowMask1_5__DppBankMask1_6__DppBoundCtrl1_7, AMFBS_isGFX9Only, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_Has16BitInsts_HasDPP_NotHasTrue16BitInsts, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_HasDPP, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45805 /* v_subrev_nc_u32 */, AMDGPU::V_SUBREV_NC_U32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_HasAddNoCarryInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45805 /* v_subrev_nc_u32 */, AMDGPU::V_SUBREV_NC_U32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_HasAddNoCarryInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45805 /* v_subrev_nc_u32 */, AMDGPU::V_SUBREV_NC_U32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_HasAddNoCarryInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 45805 /* v_subrev_nc_u32 */, AMDGPU::V_SUBREV_NC_U32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_HasAddNoCarryInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45805 /* v_subrev_nc_u32 */, AMDGPU::V_SUBREV_NC_U32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_HasAddNoCarryInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45805 /* v_subrev_nc_u32 */, AMDGPU::V_SUBREV_NC_U32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_HasAddNoCarryInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45821 /* v_subrev_u16 */, AMDGPU::V_SUBREV_U16_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_isGFX8GFX9_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 45834 /* v_subrev_u32 */, AMDGPU::V_SUBREV_U32_dpp_gfx9, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_HasAddNoCarryInsts_isGFX9Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 45834 /* v_subrev_u32 */, AMDGPU::V_SUBREV_U32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_2__Reg1_3__DPPCtrl1_4__DppRowMask1_5__DppBankMask1_6__DppBoundCtrl1_7, AMFBS_isGFX8Only, { MCK_VGPR_32, MCK_VCC, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 46601 /* v_tanh_bf16 */, AMDGPU::V_TANH_BF16V_TANH_BF16_fake16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 46601 /* v_tanh_bf16 */, AMDGPU::V_TANH_BF16V_TANH_BF16_t16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 46601 /* v_tanh_bf16 */, AMDGPU::V_TANH_BF16V_TANH_BF16_fake16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46601 /* v_tanh_bf16 */, AMDGPU::V_TANH_BF16V_TANH_BF16_t16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46613 /* v_tanh_f16 */, AMDGPU::V_TANH_F16V_TANH_F16_fake16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_HasTanhInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 46613 /* v_tanh_f16 */, AMDGPU::V_TANH_F16V_TANH_F16_t16_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_HasTanhInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 46613 /* v_tanh_f16 */, AMDGPU::V_TANH_F16V_TANH_F16_fake16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_HasTanhInsts_isGFX125xOnly, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46613 /* v_tanh_f16 */, AMDGPU::V_TANH_F16V_TANH_F16_t16_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_HasTanhInsts_isGFX125xOnly, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46624 /* v_tanh_f32 */, AMDGPU::V_TANH_F32_dpp8_gfx1250, ConvertCustom_cvtDPP8, AMFBS_HasTanhInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 46624 /* v_tanh_f32 */, AMDGPU::V_TANH_F32_dpp_gfx1250, ConvertCustom_cvtDPP, AMFBS_HasTanhInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_fake16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_fake16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_VGPR_32_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_t16_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_t16_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_VGPR_16_Lo128, MCK_DPP8, MCK_DppFI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16_dpp_vi, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_fake16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_fake16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32_Lo128, MCK_Fake16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_t16_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_t16_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16_Lo128, MCK_T16_Lo128VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_NotHasTrue16BitInsts_Has16BitInsts_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX8GFX9, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_dpp_gfx10, ConvertCustom_cvtDPP, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_dpp_gfx11, ConvertCustom_cvtDPP, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46676 /* v_trunc_f64 */, AMDGPU::V_TRUNC_F64_dpp_vi, ConvertCustom_cvtDPP, AMFBS_isGFX7Plus_isGFX8GFX9, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 46676 /* v_trunc_f64 */, AMDGPU::V_TRUNC_F64_dpp_gfx12, ConvertCustom_cvtDPP, AMFBS_HasDPALU_DPP_isGFX7Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 47868 /* v_xnor_b32 */, AMDGPU::V_XNOR_B32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_HasDLInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 47868 /* v_xnor_b32 */, AMDGPU::V_XNOR_B32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_HasDLInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 47868 /* v_xnor_b32 */, AMDGPU::V_XNOR_B32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_HasDLInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 47868 /* v_xnor_b32 */, AMDGPU::V_XNOR_B32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_HasDLInsts_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 47868 /* v_xnor_b32 */, AMDGPU::V_XNOR_B32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_HasDLInsts_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 47868 /* v_xnor_b32 */, AMDGPU::V_XNOR_B32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_HasDLInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 47868 /* v_xnor_b32 */, AMDGPU::V_XNOR_B32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_HasDLInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_dpp8_gfx10, ConvertCustom_cvtDPP8, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_dpp8_gfx11, ConvertCustom_cvtDPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_dpp8_gfx12, ConvertCustom_cvtDPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_dpp_vi, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6, AMFBS_HasDPP, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_dpp_gfx10, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX10Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_dpp_gfx11, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_dpp_gfx12, Convert__Reg1_0__Tie0_1_1__Reg1_1__Reg1_2__DPPCtrl1_3__DppRowMask1_4__DppBankMask1_5__DppBoundCtrl1_6__DppFI1_7, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
};

static const MatchEntry MatchTable5[] = {
  { 24227 /* v_add3_u32 */, AMDGPU::V_ADD3_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 24227 /* v_add3_u32 */, AMDGPU::V_ADD3_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 24227 /* v_add3_u32 */, AMDGPU::V_ADD3_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24227 /* v_add3_u32 */, AMDGPU::V_ADD3_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_BoolReg, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_BoolReg, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_BoolReg, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24238 /* v_add_co_ci_u32 */, AMDGPU::V_ADD_CO_CI_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_BoolReg, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24254 /* v_add_co_u32 */, AMDGPU::V_ADD_CO_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24254 /* v_add_co_u32 */, AMDGPU::V_ADD_CO_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24254 /* v_add_co_u32 */, AMDGPU::V_ADD_CO_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24254 /* v_add_co_u32 */, AMDGPU::V_ADD_CO_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24267 /* v_add_f16 */, AMDGPU::V_ADD_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24277 /* v_add_f32 */, AMDGPU::V_ADD_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24287 /* v_add_f64 */, AMDGPU::V_ADD_F64_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP64InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24317 /* v_add_lshl_u32 */, AMDGPU::V_ADD_LSHL_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 24317 /* v_add_lshl_u32 */, AMDGPU::V_ADD_LSHL_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 24317 /* v_add_lshl_u32 */, AMDGPU::V_ADD_LSHL_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24317 /* v_add_lshl_u32 */, AMDGPU::V_ADD_LSHL_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24332 /* v_add_max_i32 */, AMDGPU::V_ADD_MAX_I32_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasAddMinMaxInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24332 /* v_add_max_i32 */, AMDGPU::V_ADD_MAX_I32_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasAddMinMaxInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24346 /* v_add_max_u32 */, AMDGPU::V_ADD_MAX_U32_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasAddMinMaxInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24346 /* v_add_max_u32 */, AMDGPU::V_ADD_MAX_U32_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasAddMinMaxInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24360 /* v_add_min_i32 */, AMDGPU::V_ADD_MIN_I32_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasAddMinMaxInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24360 /* v_add_min_i32 */, AMDGPU::V_ADD_MIN_I32_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasAddMinMaxInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24374 /* v_add_min_u32 */, AMDGPU::V_ADD_MIN_U32_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasAddMinMaxInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24374 /* v_add_min_u32 */, AMDGPU::V_ADD_MIN_U32_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasAddMinMaxInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24388 /* v_add_nc_i16 */, AMDGPU::V_ADD_NC_I16V_ADD_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24388 /* v_add_nc_i16 */, AMDGPU::V_ADD_NC_I16V_ADD_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24388 /* v_add_nc_i16 */, AMDGPU::V_ADD_NC_I16V_ADD_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24388 /* v_add_nc_i16 */, AMDGPU::V_ADD_NC_I16V_ADD_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24388 /* v_add_nc_i16 */, AMDGPU::V_ADD_NC_I16V_ADD_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24388 /* v_add_nc_i16 */, AMDGPU::V_ADD_NC_I16V_ADD_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24388 /* v_add_nc_i16 */, AMDGPU::V_ADD_NC_I16V_ADD_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24388 /* v_add_nc_i16 */, AMDGPU::V_ADD_NC_I16V_ADD_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24401 /* v_add_nc_i32 */, AMDGPU::V_ADD_NC_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24401 /* v_add_nc_i32 */, AMDGPU::V_ADD_NC_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24401 /* v_add_nc_i32 */, AMDGPU::V_ADD_NC_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24401 /* v_add_nc_i32 */, AMDGPU::V_ADD_NC_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24414 /* v_add_nc_u16 */, AMDGPU::V_ADD_NC_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24414 /* v_add_nc_u16 */, AMDGPU::V_ADD_NC_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24414 /* v_add_nc_u16 */, AMDGPU::V_ADD_NC_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX10Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24414 /* v_add_nc_u16 */, AMDGPU::V_ADD_NC_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX10Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24414 /* v_add_nc_u16 */, AMDGPU::V_ADD_NC_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24414 /* v_add_nc_u16 */, AMDGPU::V_ADD_NC_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24414 /* v_add_nc_u16 */, AMDGPU::V_ADD_NC_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX10Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24414 /* v_add_nc_u16 */, AMDGPU::V_ADD_NC_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX10Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24427 /* v_add_nc_u32 */, AMDGPU::V_ADD_NC_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasAddNoCarryInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24427 /* v_add_nc_u32 */, AMDGPU::V_ADD_NC_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasAddNoCarryInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24427 /* v_add_nc_u32 */, AMDGPU::V_ADD_NC_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasAddNoCarryInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24427 /* v_add_nc_u32 */, AMDGPU::V_ADD_NC_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasAddNoCarryInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24440 /* v_add_nc_u64 */, AMDGPU::V_ADD_U64_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_HasAddSubU64Insts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VCSrc_b64, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24498 /* v_alignbit_b32 */, AMDGPU::V_ALIGNBIT_B32V_ALIGNBIT_B32_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24498 /* v_alignbit_b32 */, AMDGPU::V_ALIGNBIT_B32V_ALIGNBIT_B32_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24498 /* v_alignbit_b32 */, AMDGPU::V_ALIGNBIT_B32V_ALIGNBIT_B32_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24498 /* v_alignbit_b32 */, AMDGPU::V_ALIGNBIT_B32V_ALIGNBIT_B32_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24498 /* v_alignbit_b32 */, AMDGPU::V_ALIGNBIT_B32V_ALIGNBIT_B32_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24498 /* v_alignbit_b32 */, AMDGPU::V_ALIGNBIT_B32V_ALIGNBIT_B32_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24498 /* v_alignbit_b32 */, AMDGPU::V_ALIGNBIT_B32V_ALIGNBIT_B32_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24498 /* v_alignbit_b32 */, AMDGPU::V_ALIGNBIT_B32V_ALIGNBIT_B32_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24513 /* v_alignbyte_b32 */, AMDGPU::V_ALIGNBYTE_B32V_ALIGNBYTE_B32_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24513 /* v_alignbyte_b32 */, AMDGPU::V_ALIGNBYTE_B32V_ALIGNBYTE_B32_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24513 /* v_alignbyte_b32 */, AMDGPU::V_ALIGNBYTE_B32V_ALIGNBYTE_B32_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24513 /* v_alignbyte_b32 */, AMDGPU::V_ALIGNBYTE_B32V_ALIGNBYTE_B32_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24513 /* v_alignbyte_b32 */, AMDGPU::V_ALIGNBYTE_B32V_ALIGNBYTE_B32_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24513 /* v_alignbyte_b32 */, AMDGPU::V_ALIGNBYTE_B32V_ALIGNBYTE_B32_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24513 /* v_alignbyte_b32 */, AMDGPU::V_ALIGNBYTE_B32V_ALIGNBYTE_B32_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24513 /* v_alignbyte_b32 */, AMDGPU::V_ALIGNBYTE_B32V_ALIGNBYTE_B32_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24529 /* v_and_b16 */, AMDGPU::V_AND_B16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 24529 /* v_and_b16 */, AMDGPU::V_AND_B16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 24529 /* v_and_b16 */, AMDGPU::V_AND_B16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 24529 /* v_and_b16 */, AMDGPU::V_AND_B16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 24529 /* v_and_b16 */, AMDGPU::V_AND_B16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24529 /* v_and_b16 */, AMDGPU::V_AND_B16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24529 /* v_and_b16 */, AMDGPU::V_AND_B16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24529 /* v_and_b16 */, AMDGPU::V_AND_B16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24539 /* v_and_b32 */, AMDGPU::V_AND_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24549 /* v_and_or_b32 */, AMDGPU::V_AND_OR_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 24549 /* v_and_or_b32 */, AMDGPU::V_AND_OR_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 24549 /* v_and_or_b32 */, AMDGPU::V_AND_OR_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24549 /* v_and_or_b32 */, AMDGPU::V_AND_OR_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24584 /* v_ashr_pk_i8_i32 */, AMDGPU::V_ASHR_PK_I8_I32_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasAshrPkInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 24584 /* v_ashr_pk_i8_i32 */, AMDGPU::V_ASHR_PK_I8_I32_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasAshrPkInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24601 /* v_ashr_pk_u8_i32 */, AMDGPU::V_ASHR_PK_U8_I32_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasAshrPkInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 24601 /* v_ashr_pk_u8_i32 */, AMDGPU::V_ASHR_PK_U8_I32_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasAshrPkInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24618 /* v_ashrrev_i16 */, AMDGPU::V_ASHRREV_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 24618 /* v_ashrrev_i16 */, AMDGPU::V_ASHRREV_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 24618 /* v_ashrrev_i16 */, AMDGPU::V_ASHRREV_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 24618 /* v_ashrrev_i16 */, AMDGPU::V_ASHRREV_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 24618 /* v_ashrrev_i16 */, AMDGPU::V_ASHRREV_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24618 /* v_ashrrev_i16 */, AMDGPU::V_ASHRREV_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24618 /* v_ashrrev_i16 */, AMDGPU::V_ASHRREV_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24618 /* v_ashrrev_i16 */, AMDGPU::V_ASHRREV_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24632 /* v_ashrrev_i32 */, AMDGPU::V_ASHRREV_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24646 /* v_ashrrev_i64 */, AMDGPU::V_ASHRREV_I64_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX8Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_VCSrc_b64, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24660 /* v_bcnt_u32_b32 */, AMDGPU::V_BCNT_U32_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 24660 /* v_bcnt_u32_b32 */, AMDGPU::V_BCNT_U32_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 24660 /* v_bcnt_u32_b32 */, AMDGPU::V_BCNT_U32_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24660 /* v_bcnt_u32_b32 */, AMDGPU::V_BCNT_U32_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24675 /* v_bfe_i32 */, AMDGPU::V_BFE_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 24675 /* v_bfe_i32 */, AMDGPU::V_BFE_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 24675 /* v_bfe_i32 */, AMDGPU::V_BFE_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24675 /* v_bfe_i32 */, AMDGPU::V_BFE_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24685 /* v_bfe_u32 */, AMDGPU::V_BFE_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 24685 /* v_bfe_u32 */, AMDGPU::V_BFE_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 24685 /* v_bfe_u32 */, AMDGPU::V_BFE_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24685 /* v_bfe_u32 */, AMDGPU::V_BFE_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24695 /* v_bfi_b32 */, AMDGPU::V_BFI_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 24695 /* v_bfi_b32 */, AMDGPU::V_BFI_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 24695 /* v_bfi_b32 */, AMDGPU::V_BFI_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24695 /* v_bfi_b32 */, AMDGPU::V_BFI_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24705 /* v_bfm_b32 */, AMDGPU::V_BFM_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 24705 /* v_bfm_b32 */, AMDGPU::V_BFM_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 24705 /* v_bfm_b32 */, AMDGPU::V_BFM_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24705 /* v_bfm_b32 */, AMDGPU::V_BFM_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24715 /* v_bfrev_b32 */, AMDGPU::V_BFREV_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24727 /* v_bitop3_b16 */, AMDGPU::V_BITOP3_B16_gfx1250_fake16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasBitOp3Insts_isGFX1250Plus_isGFX125xOnly_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_BitOp3, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 24727 /* v_bitop3_b16 */, AMDGPU::V_BITOP3_B16_gfx1250_t16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasBitOp3Insts_isGFX1250Plus_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_BitOp3, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 24727 /* v_bitop3_b16 */, AMDGPU::V_BITOP3_B16_gfx1250_fake16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasBitOp3Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_BitOp3, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24727 /* v_bitop3_b16 */, AMDGPU::V_BITOP3_B16_gfx1250_t16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasBitOp3Insts_isGFX1250Plus_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_BitOp3, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24740 /* v_bitop3_b32 */, AMDGPU::V_BITOP3_B32_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasBitOp3Insts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_BitOp3, MCK_DPP8, MCK_DppFI }, },
  { 24740 /* v_bitop3_b32 */, AMDGPU::V_BITOP3_B32_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasBitOp3Insts_isGFX11Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_BitOp3, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24753 /* v_ceil_f16 */, AMDGPU::V_CEIL_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24764 /* v_ceil_f32 */, AMDGPU::V_CEIL_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24775 /* v_ceil_f64 */, AMDGPU::V_CEIL_F64_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX7Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24796 /* v_cls_i32 */, AMDGPU::V_CLS_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24796 /* v_cls_i32 */, AMDGPU::V_CLS_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24796 /* v_cls_i32 */, AMDGPU::V_CLS_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24796 /* v_cls_i32 */, AMDGPU::V_CLS_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24806 /* v_clz_i32_u32 */, AMDGPU::V_CLZ_I32_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24806 /* v_clz_i32_u32 */, AMDGPU::V_CLZ_I32_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 24806 /* v_clz_i32_u32 */, AMDGPU::V_CLZ_I32_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24806 /* v_clz_i32_u32 */, AMDGPU::V_CLZ_I32_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_DPP8, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_DPP8, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24820 /* v_cmp_class_f16 */, AMDGPU::V_CMP_CLASS_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24856 /* v_cmp_class_f32 */, AMDGPU::V_CMP_CLASS_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24928 /* v_cmp_eq_f16 */, AMDGPU::V_CMP_EQ_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 24958 /* v_cmp_eq_f32 */, AMDGPU::V_CMP_EQ_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25018 /* v_cmp_eq_i16 */, AMDGPU::V_CMP_EQ_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25048 /* v_cmp_eq_i32 */, AMDGPU::V_CMP_EQ_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25108 /* v_cmp_eq_u16 */, AMDGPU::V_CMP_EQ_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25138 /* v_cmp_eq_u32 */, AMDGPU::V_CMP_EQ_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25198 /* v_cmp_f_f16 */, AMDGPU::V_CMP_F_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25226 /* v_cmp_f_f32 */, AMDGPU::V_CMP_F_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 25226 /* v_cmp_f_f32 */, AMDGPU::V_CMP_F_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25310 /* v_cmp_f_i32 */, AMDGPU::V_CMP_F_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 25310 /* v_cmp_f_i32 */, AMDGPU::V_CMP_F_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25394 /* v_cmp_f_u32 */, AMDGPU::V_CMP_F_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 25394 /* v_cmp_f_u32 */, AMDGPU::V_CMP_F_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25450 /* v_cmp_ge_f16 */, AMDGPU::V_CMP_GE_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25480 /* v_cmp_ge_f32 */, AMDGPU::V_CMP_GE_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25540 /* v_cmp_ge_i16 */, AMDGPU::V_CMP_GE_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25570 /* v_cmp_ge_i32 */, AMDGPU::V_CMP_GE_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25630 /* v_cmp_ge_u16 */, AMDGPU::V_CMP_GE_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25660 /* v_cmp_ge_u32 */, AMDGPU::V_CMP_GE_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25720 /* v_cmp_gt_f16 */, AMDGPU::V_CMP_GT_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25750 /* v_cmp_gt_f32 */, AMDGPU::V_CMP_GT_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25810 /* v_cmp_gt_i16 */, AMDGPU::V_CMP_GT_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25840 /* v_cmp_gt_i32 */, AMDGPU::V_CMP_GT_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25900 /* v_cmp_gt_u16 */, AMDGPU::V_CMP_GT_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25930 /* v_cmp_gt_u32 */, AMDGPU::V_CMP_GT_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 25990 /* v_cmp_le_f16 */, AMDGPU::V_CMP_LE_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26020 /* v_cmp_le_f32 */, AMDGPU::V_CMP_LE_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26080 /* v_cmp_le_i16 */, AMDGPU::V_CMP_LE_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26110 /* v_cmp_le_i32 */, AMDGPU::V_CMP_LE_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26170 /* v_cmp_le_u16 */, AMDGPU::V_CMP_LE_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26200 /* v_cmp_le_u32 */, AMDGPU::V_CMP_LE_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26260 /* v_cmp_lg_f16 */, AMDGPU::V_CMP_LG_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26290 /* v_cmp_lg_f32 */, AMDGPU::V_CMP_LG_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26350 /* v_cmp_lt_f16 */, AMDGPU::V_CMP_LT_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26380 /* v_cmp_lt_f32 */, AMDGPU::V_CMP_LT_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26440 /* v_cmp_lt_i16 */, AMDGPU::V_CMP_LT_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26470 /* v_cmp_lt_i32 */, AMDGPU::V_CMP_LT_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26530 /* v_cmp_lt_u16 */, AMDGPU::V_CMP_LT_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26560 /* v_cmp_lt_u32 */, AMDGPU::V_CMP_LT_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26620 /* v_cmp_ne_i16 */, AMDGPU::V_CMP_NE_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26650 /* v_cmp_ne_i32 */, AMDGPU::V_CMP_NE_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26710 /* v_cmp_ne_u16 */, AMDGPU::V_CMP_NE_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26740 /* v_cmp_ne_u32 */, AMDGPU::V_CMP_NE_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26800 /* v_cmp_neq_f16 */, AMDGPU::V_CMP_NEQ_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26832 /* v_cmp_neq_f32 */, AMDGPU::V_CMP_NEQ_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26896 /* v_cmp_nge_f16 */, AMDGPU::V_CMP_NGE_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26928 /* v_cmp_nge_f32 */, AMDGPU::V_CMP_NGE_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 26992 /* v_cmp_ngt_f16 */, AMDGPU::V_CMP_NGT_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27024 /* v_cmp_ngt_f32 */, AMDGPU::V_CMP_NGT_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27088 /* v_cmp_nle_f16 */, AMDGPU::V_CMP_NLE_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27120 /* v_cmp_nle_f32 */, AMDGPU::V_CMP_NLE_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27184 /* v_cmp_nlg_f16 */, AMDGPU::V_CMP_NLG_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27216 /* v_cmp_nlg_f32 */, AMDGPU::V_CMP_NLG_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27280 /* v_cmp_nlt_f16 */, AMDGPU::V_CMP_NLT_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27312 /* v_cmp_nlt_f32 */, AMDGPU::V_CMP_NLT_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27376 /* v_cmp_o_f16 */, AMDGPU::V_CMP_O_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27404 /* v_cmp_o_f32 */, AMDGPU::V_CMP_O_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27460 /* v_cmp_t_f16 */, AMDGPU::V_CMP_T_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27488 /* v_cmp_t_f32 */, AMDGPU::V_CMP_T_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27488 /* v_cmp_t_f32 */, AMDGPU::V_CMP_T_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27572 /* v_cmp_t_i32 */, AMDGPU::V_CMP_T_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 27572 /* v_cmp_t_i32 */, AMDGPU::V_CMP_T_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27656 /* v_cmp_t_u32 */, AMDGPU::V_CMP_T_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 27656 /* v_cmp_t_u32 */, AMDGPU::V_CMP_T_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_BoolReg, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27808 /* v_cmp_u_f16 */, AMDGPU::V_CMP_U_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_BoolReg, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 27836 /* v_cmp_u_f32 */, AMDGPU::V_CMP_U_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_DPP8, MCK_DppFI }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_DPP8, MCK_DppFI }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30036 /* v_cmpx_class_f16 */, AMDGPU::V_CMPX_CLASS_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30074 /* v_cmpx_class_f32 */, AMDGPU::V_CMPX_CLASS_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 30074 /* v_cmpx_class_f32 */, AMDGPU::V_CMPX_CLASS_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 30074 /* v_cmpx_class_f32 */, AMDGPU::V_CMPX_CLASS_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30074 /* v_cmpx_class_f32 */, AMDGPU::V_CMPX_CLASS_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30150 /* v_cmpx_eq_f16 */, AMDGPU::V_CMPX_EQ_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30182 /* v_cmpx_eq_f32 */, AMDGPU::V_CMPX_EQ_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 30182 /* v_cmpx_eq_f32 */, AMDGPU::V_CMPX_EQ_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 30182 /* v_cmpx_eq_f32 */, AMDGPU::V_CMPX_EQ_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30182 /* v_cmpx_eq_f32 */, AMDGPU::V_CMPX_EQ_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30246 /* v_cmpx_eq_i16 */, AMDGPU::V_CMPX_EQ_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30278 /* v_cmpx_eq_i32 */, AMDGPU::V_CMPX_EQ_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 30278 /* v_cmpx_eq_i32 */, AMDGPU::V_CMPX_EQ_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 30278 /* v_cmpx_eq_i32 */, AMDGPU::V_CMPX_EQ_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30278 /* v_cmpx_eq_i32 */, AMDGPU::V_CMPX_EQ_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30342 /* v_cmpx_eq_u16 */, AMDGPU::V_CMPX_EQ_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30374 /* v_cmpx_eq_u32 */, AMDGPU::V_CMPX_EQ_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 30374 /* v_cmpx_eq_u32 */, AMDGPU::V_CMPX_EQ_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 30374 /* v_cmpx_eq_u32 */, AMDGPU::V_CMPX_EQ_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30374 /* v_cmpx_eq_u32 */, AMDGPU::V_CMPX_EQ_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30438 /* v_cmpx_f_f16 */, AMDGPU::V_CMPX_F_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 30438 /* v_cmpx_f_f16 */, AMDGPU::V_CMPX_F_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 30438 /* v_cmpx_f_f16 */, AMDGPU::V_CMPX_F_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30438 /* v_cmpx_f_f16 */, AMDGPU::V_CMPX_F_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30468 /* v_cmpx_f_f32 */, AMDGPU::V_CMPX_F_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 30468 /* v_cmpx_f_f32 */, AMDGPU::V_CMPX_F_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30558 /* v_cmpx_f_i32 */, AMDGPU::V_CMPX_F_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 30558 /* v_cmpx_f_i32 */, AMDGPU::V_CMPX_F_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30648 /* v_cmpx_f_u32 */, AMDGPU::V_CMPX_F_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 30648 /* v_cmpx_f_u32 */, AMDGPU::V_CMPX_F_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30708 /* v_cmpx_ge_f16 */, AMDGPU::V_CMPX_GE_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30740 /* v_cmpx_ge_f32 */, AMDGPU::V_CMPX_GE_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 30740 /* v_cmpx_ge_f32 */, AMDGPU::V_CMPX_GE_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 30740 /* v_cmpx_ge_f32 */, AMDGPU::V_CMPX_GE_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30740 /* v_cmpx_ge_f32 */, AMDGPU::V_CMPX_GE_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30804 /* v_cmpx_ge_i16 */, AMDGPU::V_CMPX_GE_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30836 /* v_cmpx_ge_i32 */, AMDGPU::V_CMPX_GE_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 30836 /* v_cmpx_ge_i32 */, AMDGPU::V_CMPX_GE_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 30836 /* v_cmpx_ge_i32 */, AMDGPU::V_CMPX_GE_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30836 /* v_cmpx_ge_i32 */, AMDGPU::V_CMPX_GE_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30900 /* v_cmpx_ge_u16 */, AMDGPU::V_CMPX_GE_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30932 /* v_cmpx_ge_u32 */, AMDGPU::V_CMPX_GE_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 30932 /* v_cmpx_ge_u32 */, AMDGPU::V_CMPX_GE_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 30932 /* v_cmpx_ge_u32 */, AMDGPU::V_CMPX_GE_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30932 /* v_cmpx_ge_u32 */, AMDGPU::V_CMPX_GE_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 30996 /* v_cmpx_gt_f16 */, AMDGPU::V_CMPX_GT_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31028 /* v_cmpx_gt_f32 */, AMDGPU::V_CMPX_GT_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 31028 /* v_cmpx_gt_f32 */, AMDGPU::V_CMPX_GT_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 31028 /* v_cmpx_gt_f32 */, AMDGPU::V_CMPX_GT_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31028 /* v_cmpx_gt_f32 */, AMDGPU::V_CMPX_GT_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31092 /* v_cmpx_gt_i16 */, AMDGPU::V_CMPX_GT_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31124 /* v_cmpx_gt_i32 */, AMDGPU::V_CMPX_GT_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 31124 /* v_cmpx_gt_i32 */, AMDGPU::V_CMPX_GT_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 31124 /* v_cmpx_gt_i32 */, AMDGPU::V_CMPX_GT_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31124 /* v_cmpx_gt_i32 */, AMDGPU::V_CMPX_GT_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31188 /* v_cmpx_gt_u16 */, AMDGPU::V_CMPX_GT_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31220 /* v_cmpx_gt_u32 */, AMDGPU::V_CMPX_GT_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 31220 /* v_cmpx_gt_u32 */, AMDGPU::V_CMPX_GT_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 31220 /* v_cmpx_gt_u32 */, AMDGPU::V_CMPX_GT_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31220 /* v_cmpx_gt_u32 */, AMDGPU::V_CMPX_GT_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31284 /* v_cmpx_le_f16 */, AMDGPU::V_CMPX_LE_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31316 /* v_cmpx_le_f32 */, AMDGPU::V_CMPX_LE_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 31316 /* v_cmpx_le_f32 */, AMDGPU::V_CMPX_LE_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 31316 /* v_cmpx_le_f32 */, AMDGPU::V_CMPX_LE_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31316 /* v_cmpx_le_f32 */, AMDGPU::V_CMPX_LE_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31380 /* v_cmpx_le_i16 */, AMDGPU::V_CMPX_LE_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31412 /* v_cmpx_le_i32 */, AMDGPU::V_CMPX_LE_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 31412 /* v_cmpx_le_i32 */, AMDGPU::V_CMPX_LE_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 31412 /* v_cmpx_le_i32 */, AMDGPU::V_CMPX_LE_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31412 /* v_cmpx_le_i32 */, AMDGPU::V_CMPX_LE_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31476 /* v_cmpx_le_u16 */, AMDGPU::V_CMPX_LE_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31508 /* v_cmpx_le_u32 */, AMDGPU::V_CMPX_LE_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 31508 /* v_cmpx_le_u32 */, AMDGPU::V_CMPX_LE_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 31508 /* v_cmpx_le_u32 */, AMDGPU::V_CMPX_LE_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31508 /* v_cmpx_le_u32 */, AMDGPU::V_CMPX_LE_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31572 /* v_cmpx_lg_f16 */, AMDGPU::V_CMPX_LG_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31604 /* v_cmpx_lg_f32 */, AMDGPU::V_CMPX_LG_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 31604 /* v_cmpx_lg_f32 */, AMDGPU::V_CMPX_LG_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 31604 /* v_cmpx_lg_f32 */, AMDGPU::V_CMPX_LG_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31604 /* v_cmpx_lg_f32 */, AMDGPU::V_CMPX_LG_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31668 /* v_cmpx_lt_f16 */, AMDGPU::V_CMPX_LT_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31700 /* v_cmpx_lt_f32 */, AMDGPU::V_CMPX_LT_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 31700 /* v_cmpx_lt_f32 */, AMDGPU::V_CMPX_LT_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 31700 /* v_cmpx_lt_f32 */, AMDGPU::V_CMPX_LT_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31700 /* v_cmpx_lt_f32 */, AMDGPU::V_CMPX_LT_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31764 /* v_cmpx_lt_i16 */, AMDGPU::V_CMPX_LT_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31796 /* v_cmpx_lt_i32 */, AMDGPU::V_CMPX_LT_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 31796 /* v_cmpx_lt_i32 */, AMDGPU::V_CMPX_LT_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 31796 /* v_cmpx_lt_i32 */, AMDGPU::V_CMPX_LT_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31796 /* v_cmpx_lt_i32 */, AMDGPU::V_CMPX_LT_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31860 /* v_cmpx_lt_u16 */, AMDGPU::V_CMPX_LT_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31892 /* v_cmpx_lt_u32 */, AMDGPU::V_CMPX_LT_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 31892 /* v_cmpx_lt_u32 */, AMDGPU::V_CMPX_LT_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 31892 /* v_cmpx_lt_u32 */, AMDGPU::V_CMPX_LT_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31892 /* v_cmpx_lt_u32 */, AMDGPU::V_CMPX_LT_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31956 /* v_cmpx_ne_i16 */, AMDGPU::V_CMPX_NE_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31988 /* v_cmpx_ne_i32 */, AMDGPU::V_CMPX_NE_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 31988 /* v_cmpx_ne_i32 */, AMDGPU::V_CMPX_NE_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 31988 /* v_cmpx_ne_i32 */, AMDGPU::V_CMPX_NE_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 31988 /* v_cmpx_ne_i32 */, AMDGPU::V_CMPX_NE_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32052 /* v_cmpx_ne_u16 */, AMDGPU::V_CMPX_NE_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32084 /* v_cmpx_ne_u32 */, AMDGPU::V_CMPX_NE_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 32084 /* v_cmpx_ne_u32 */, AMDGPU::V_CMPX_NE_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 32084 /* v_cmpx_ne_u32 */, AMDGPU::V_CMPX_NE_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32084 /* v_cmpx_ne_u32 */, AMDGPU::V_CMPX_NE_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32148 /* v_cmpx_neq_f16 */, AMDGPU::V_CMPX_NEQ_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32182 /* v_cmpx_neq_f32 */, AMDGPU::V_CMPX_NEQ_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32182 /* v_cmpx_neq_f32 */, AMDGPU::V_CMPX_NEQ_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32182 /* v_cmpx_neq_f32 */, AMDGPU::V_CMPX_NEQ_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32182 /* v_cmpx_neq_f32 */, AMDGPU::V_CMPX_NEQ_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32250 /* v_cmpx_nge_f16 */, AMDGPU::V_CMPX_NGE_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32284 /* v_cmpx_nge_f32 */, AMDGPU::V_CMPX_NGE_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32284 /* v_cmpx_nge_f32 */, AMDGPU::V_CMPX_NGE_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32284 /* v_cmpx_nge_f32 */, AMDGPU::V_CMPX_NGE_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32284 /* v_cmpx_nge_f32 */, AMDGPU::V_CMPX_NGE_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32352 /* v_cmpx_ngt_f16 */, AMDGPU::V_CMPX_NGT_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32386 /* v_cmpx_ngt_f32 */, AMDGPU::V_CMPX_NGT_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32386 /* v_cmpx_ngt_f32 */, AMDGPU::V_CMPX_NGT_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32386 /* v_cmpx_ngt_f32 */, AMDGPU::V_CMPX_NGT_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32386 /* v_cmpx_ngt_f32 */, AMDGPU::V_CMPX_NGT_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32454 /* v_cmpx_nle_f16 */, AMDGPU::V_CMPX_NLE_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32488 /* v_cmpx_nle_f32 */, AMDGPU::V_CMPX_NLE_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32488 /* v_cmpx_nle_f32 */, AMDGPU::V_CMPX_NLE_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32488 /* v_cmpx_nle_f32 */, AMDGPU::V_CMPX_NLE_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32488 /* v_cmpx_nle_f32 */, AMDGPU::V_CMPX_NLE_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32556 /* v_cmpx_nlg_f16 */, AMDGPU::V_CMPX_NLG_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32590 /* v_cmpx_nlg_f32 */, AMDGPU::V_CMPX_NLG_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32590 /* v_cmpx_nlg_f32 */, AMDGPU::V_CMPX_NLG_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32590 /* v_cmpx_nlg_f32 */, AMDGPU::V_CMPX_NLG_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32590 /* v_cmpx_nlg_f32 */, AMDGPU::V_CMPX_NLG_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32658 /* v_cmpx_nlt_f16 */, AMDGPU::V_CMPX_NLT_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32692 /* v_cmpx_nlt_f32 */, AMDGPU::V_CMPX_NLT_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32692 /* v_cmpx_nlt_f32 */, AMDGPU::V_CMPX_NLT_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32692 /* v_cmpx_nlt_f32 */, AMDGPU::V_CMPX_NLT_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32692 /* v_cmpx_nlt_f32 */, AMDGPU::V_CMPX_NLT_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32760 /* v_cmpx_o_f16 */, AMDGPU::V_CMPX_O_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32790 /* v_cmpx_o_f32 */, AMDGPU::V_CMPX_O_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32790 /* v_cmpx_o_f32 */, AMDGPU::V_CMPX_O_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32790 /* v_cmpx_o_f32 */, AMDGPU::V_CMPX_O_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32790 /* v_cmpx_o_f32 */, AMDGPU::V_CMPX_O_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32850 /* v_cmpx_t_f16 */, AMDGPU::V_CMPX_T_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32850 /* v_cmpx_t_f16 */, AMDGPU::V_CMPX_T_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32850 /* v_cmpx_t_f16 */, AMDGPU::V_CMPX_T_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32850 /* v_cmpx_t_f16 */, AMDGPU::V_CMPX_T_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32880 /* v_cmpx_t_f32 */, AMDGPU::V_CMPX_T_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 32880 /* v_cmpx_t_f32 */, AMDGPU::V_CMPX_T_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 32970 /* v_cmpx_t_i32 */, AMDGPU::V_CMPX_T_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 32970 /* v_cmpx_t_i32 */, AMDGPU::V_CMPX_T_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33060 /* v_cmpx_t_u32 */, AMDGPU::V_CMPX_T_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 33060 /* v_cmpx_t_u32 */, AMDGPU::V_CMPX_T_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseFakeTrue16Insts, { MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33222 /* v_cmpx_u_f16 */, AMDGPU::V_CMPX_U_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only_UseRealTrue16Insts, { MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33252 /* v_cmpx_u_f32 */, AMDGPU::V_CMPX_U_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 33252 /* v_cmpx_u_f32 */, AMDGPU::V_CMPX_U_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 33252 /* v_cmpx_u_f32 */, AMDGPU::V_CMPX_U_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX11Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33252 /* v_cmpx_u_f32 */, AMDGPU::V_CMPX_U_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPP16_isGFX12Only, { MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33312 /* v_cndmask_b16 */, AMDGPU::V_CNDMASK_B16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_BoolReg, MCK_DPP8, MCK_DppFI }, },
  { 33312 /* v_cndmask_b16 */, AMDGPU::V_CNDMASK_B16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_BoolReg, MCK_DPP8, MCK_DppFI }, },
  { 33312 /* v_cndmask_b16 */, AMDGPU::V_CNDMASK_B16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_BoolReg, MCK_DPP8, MCK_DppFI }, },
  { 33312 /* v_cndmask_b16 */, AMDGPU::V_CNDMASK_B16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_BoolReg, MCK_DPP8, MCK_DppFI }, },
  { 33312 /* v_cndmask_b16 */, AMDGPU::V_CNDMASK_B16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_BoolReg, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33312 /* v_cndmask_b16 */, AMDGPU::V_CNDMASK_B16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_BoolReg, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33312 /* v_cndmask_b16 */, AMDGPU::V_CNDMASK_B16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_BoolReg, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33312 /* v_cndmask_b16 */, AMDGPU::V_CNDMASK_B16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_BoolReg, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_BoolReg, MCK_DPP8, MCK_DppFI }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_BoolReg, MCK_DPP8, MCK_DppFI }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_BoolReg, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33326 /* v_cndmask_b32 */, AMDGPU::V_CNDMASK_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_BoolReg, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33340 /* v_cos_bf16 */, AMDGPU::V_COS_BF16V_COS_BF16_fake16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_DPP8, MCK_DppFI }, },
  { 33340 /* v_cos_bf16 */, AMDGPU::V_COS_BF16V_COS_BF16_t16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 33340 /* v_cos_bf16 */, AMDGPU::V_COS_BF16V_COS_BF16_fake16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33340 /* v_cos_bf16 */, AMDGPU::V_COS_BF16V_COS_BF16_t16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33351 /* v_cos_f16 */, AMDGPU::V_COS_F16V_COS_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33361 /* v_cos_f32 */, AMDGPU::V_COS_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33371 /* v_ctz_i32_b32 */, AMDGPU::V_CTZ_I32_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33371 /* v_ctz_i32_b32 */, AMDGPU::V_CTZ_I32_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33371 /* v_ctz_i32_b32 */, AMDGPU::V_CTZ_I32_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33371 /* v_ctz_i32_b32 */, AMDGPU::V_CTZ_I32_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33385 /* v_cubeid_f32 */, AMDGPU::V_CUBEID_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasCubeInsts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33385 /* v_cubeid_f32 */, AMDGPU::V_CUBEID_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasCubeInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33385 /* v_cubeid_f32 */, AMDGPU::V_CUBEID_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasCubeInsts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33385 /* v_cubeid_f32 */, AMDGPU::V_CUBEID_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasCubeInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33398 /* v_cubema_f32 */, AMDGPU::V_CUBEMA_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasCubeInsts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33398 /* v_cubema_f32 */, AMDGPU::V_CUBEMA_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasCubeInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33398 /* v_cubema_f32 */, AMDGPU::V_CUBEMA_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasCubeInsts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33398 /* v_cubema_f32 */, AMDGPU::V_CUBEMA_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasCubeInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33411 /* v_cubesc_f32 */, AMDGPU::V_CUBESC_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasCubeInsts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33411 /* v_cubesc_f32 */, AMDGPU::V_CUBESC_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasCubeInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33411 /* v_cubesc_f32 */, AMDGPU::V_CUBESC_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasCubeInsts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33411 /* v_cubesc_f32 */, AMDGPU::V_CUBESC_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasCubeInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33424 /* v_cubetc_f32 */, AMDGPU::V_CUBETC_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasCubeInsts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33424 /* v_cubetc_f32 */, AMDGPU::V_CUBETC_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasCubeInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33424 /* v_cubetc_f32 */, AMDGPU::V_CUBETC_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasCubeInsts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33424 /* v_cubetc_f32 */, AMDGPU::V_CUBETC_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasCubeInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33437 /* v_cvt_f16_bf8 */, AMDGPU::V_CVT_F16_BF8V_CVT_F16_BF8_fake16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_ByteSel, MCK_DPP8, MCK_DppFI }, },
  { 33437 /* v_cvt_f16_bf8 */, AMDGPU::V_CVT_F16_BF8V_CVT_F16_BF8_t16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16, MCK_VGPR_32, MCK_OpSel, MCK_ByteSel, MCK_DPP8, MCK_DppFI }, },
  { 33437 /* v_cvt_f16_bf8 */, AMDGPU::V_CVT_F16_BF8V_CVT_F16_BF8_fake16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_ByteSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33437 /* v_cvt_f16_bf8 */, AMDGPU::V_CVT_F16_BF8V_CVT_F16_BF8_t16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16, MCK_VGPR_32, MCK_OpSel, MCK_ByteSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33451 /* v_cvt_f16_f32 */, AMDGPU::V_CVT_F16_F32V_CVT_F16_F32_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33465 /* v_cvt_f16_fp8 */, AMDGPU::V_CVT_F16_FP8V_CVT_F16_FP8_fake16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_ByteSel, MCK_DPP8, MCK_DppFI }, },
  { 33465 /* v_cvt_f16_fp8 */, AMDGPU::V_CVT_F16_FP8V_CVT_F16_FP8_t16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16, MCK_VGPR_32, MCK_OpSel, MCK_ByteSel, MCK_DPP8, MCK_DppFI }, },
  { 33465 /* v_cvt_f16_fp8 */, AMDGPU::V_CVT_F16_FP8V_CVT_F16_FP8_fake16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_ByteSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33465 /* v_cvt_f16_fp8 */, AMDGPU::V_CVT_F16_FP8V_CVT_F16_FP8_t16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16, MCK_VGPR_32, MCK_OpSel, MCK_ByteSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33479 /* v_cvt_f16_i16 */, AMDGPU::V_CVT_F16_I16V_CVT_F16_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33493 /* v_cvt_f16_u16 */, AMDGPU::V_CVT_F16_U16V_CVT_F16_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33507 /* v_cvt_f32_bf16 */, AMDGPU::V_CVT_F32_BF16_gfx1250V_CVT_F32_BF16_gfx1250_fake16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasBF16ConversionInsts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 33507 /* v_cvt_f32_bf16 */, AMDGPU::V_CVT_F32_BF16_gfx1250V_CVT_F32_BF16_gfx1250_t16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasBF16ConversionInsts_isGFX1250Plus_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 33507 /* v_cvt_f32_bf16 */, AMDGPU::V_CVT_F32_BF16_gfx1250V_CVT_F32_BF16_gfx1250_fake16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasBF16ConversionInsts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33507 /* v_cvt_f32_bf16 */, AMDGPU::V_CVT_F32_BF16_gfx1250V_CVT_F32_BF16_gfx1250_t16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasBF16ConversionInsts_isGFX1250Plus_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33522 /* v_cvt_f32_bf8 */, AMDGPU::V_CVT_F32_BF8_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_ByteSel, MCK_DPP8, MCK_DppFI }, },
  { 33522 /* v_cvt_f32_bf8 */, AMDGPU::V_CVT_F32_BF8_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_ByteSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33536 /* v_cvt_f32_f16 */, AMDGPU::V_CVT_F32_F16V_CVT_F32_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33550 /* v_cvt_f32_f64 */, AMDGPU::V_CVT_F32_F64_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33564 /* v_cvt_f32_fp8 */, AMDGPU::V_CVT_F32_FP8_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFP8ConversionInsts_isGFX12PlusNot12_50_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_ByteSel, MCK_DPP8, MCK_DppFI }, },
  { 33564 /* v_cvt_f32_fp8 */, AMDGPU::V_CVT_F32_FP8_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFP8ConversionInsts_isGFX12PlusNot12_50_isGFX12Not12_50, { MCK_VGPR_32, MCK_VGPR_32, MCK_ByteSel, MCK_DPP8, MCK_DppFI }, },
  { 33564 /* v_cvt_f32_fp8 */, AMDGPU::V_CVT_F32_FP8_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFP8ConversionInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_ByteSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 33564 /* v_cvt_f32_fp8 */, AMDGPU::V_CVT_F32_FP8_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasFP8ConversionInsts_isGFX12PlusNot12_50_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_ByteSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33564 /* v_cvt_f32_fp8 */, AMDGPU::V_CVT_F32_FP8_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasFP8ConversionInsts_isGFX12PlusNot12_50_isGFX12Not12_50, { MCK_VGPR_32, MCK_VGPR_32, MCK_ByteSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33564 /* v_cvt_f32_fp8 */, AMDGPU::V_CVT_F32_FP8_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasFP8ConversionInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_ByteSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33578 /* v_cvt_f32_i32 */, AMDGPU::V_CVT_F32_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33592 /* v_cvt_f32_u32 */, AMDGPU::V_CVT_F32_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33606 /* v_cvt_f32_ubyte0 */, AMDGPU::V_CVT_F32_UBYTE0_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33623 /* v_cvt_f32_ubyte1 */, AMDGPU::V_CVT_F32_UBYTE1_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33640 /* v_cvt_f32_ubyte2 */, AMDGPU::V_CVT_F32_UBYTE2_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33657 /* v_cvt_f32_ubyte3 */, AMDGPU::V_CVT_F32_UBYTE3_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33674 /* v_cvt_f64_f32 */, AMDGPU::V_CVT_F64_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33688 /* v_cvt_f64_i32 */, AMDGPU::V_CVT_F64_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33702 /* v_cvt_f64_u32 */, AMDGPU::V_CVT_F64_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33716 /* v_cvt_floor_i32_f32 */, AMDGPU::V_CVT_FLOOR_I32_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 33716 /* v_cvt_floor_i32_f32 */, AMDGPU::V_CVT_FLOOR_I32_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 33716 /* v_cvt_floor_i32_f32 */, AMDGPU::V_CVT_FLOOR_I32_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33716 /* v_cvt_floor_i32_f32 */, AMDGPU::V_CVT_FLOOR_I32_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33754 /* v_cvt_i16_f16 */, AMDGPU::V_CVT_I16_F16V_CVT_I16_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33768 /* v_cvt_i32_f32 */, AMDGPU::V_CVT_I32_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33782 /* v_cvt_i32_f64 */, AMDGPU::V_CVT_I32_F64_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33796 /* v_cvt_i32_i16 */, AMDGPU::V_CVT_I32_I16V_CVT_I32_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33810 /* v_cvt_nearest_i32_f32 */, AMDGPU::V_CVT_NEAREST_I32_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 33810 /* v_cvt_nearest_i32_f32 */, AMDGPU::V_CVT_NEAREST_I32_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 33810 /* v_cvt_nearest_i32_f32 */, AMDGPU::V_CVT_NEAREST_I32_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33810 /* v_cvt_nearest_i32_f32 */, AMDGPU::V_CVT_NEAREST_I32_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33832 /* v_cvt_norm_i16_f16 */, AMDGPU::V_CVT_NORM_I16_F16V_CVT_NORM_I16_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33851 /* v_cvt_norm_u16_f16 */, AMDGPU::V_CVT_NORM_U16_F16V_CVT_NORM_U16_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_HasCvtNormInsts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33870 /* v_cvt_off_f32_i4 */, AMDGPU::V_CVT_OFF_F32_I4_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33887 /* v_cvt_pk_bf16_f32 */, AMDGPU::V_CVT_PK_BF16_F32_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasBF16ConversionInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33887 /* v_cvt_pk_bf16_f32 */, AMDGPU::V_CVT_PK_BF16_F32_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasBF16ConversionInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33905 /* v_cvt_pk_bf8_f16 */, AMDGPU::V_CVT_PK_BF8_F16_gfx1250_fake16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 33905 /* v_cvt_pk_bf8_f16 */, AMDGPU::V_CVT_PK_BF8_F16_gfx1250_t16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 33905 /* v_cvt_pk_bf8_f16 */, AMDGPU::V_CVT_PK_BF8_F16_gfx1250_fake16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33905 /* v_cvt_pk_bf8_f16 */, AMDGPU::V_CVT_PK_BF8_F16_gfx1250_t16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33922 /* v_cvt_pk_bf8_f32 */, AMDGPU::V_CVT_PK_BF8_F32_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFP8ConversionInsts_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 33922 /* v_cvt_pk_bf8_f32 */, AMDGPU::V_CVT_PK_BF8_F32_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFP8ConversionInsts_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 33922 /* v_cvt_pk_bf8_f32 */, AMDGPU::V_CVT_PK_BF8_F32_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFP8ConversionInsts_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 33922 /* v_cvt_pk_bf8_f32 */, AMDGPU::V_CVT_PK_BF8_F32_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFP8ConversionInsts_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 33922 /* v_cvt_pk_bf8_f32 */, AMDGPU::V_CVT_PK_BF8_F32_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasFP8ConversionInsts_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33922 /* v_cvt_pk_bf8_f32 */, AMDGPU::V_CVT_PK_BF8_F32_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasFP8ConversionInsts_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33922 /* v_cvt_pk_bf8_f32 */, AMDGPU::V_CVT_PK_BF8_F32_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasFP8ConversionInsts_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33922 /* v_cvt_pk_bf8_f32 */, AMDGPU::V_CVT_PK_BF8_F32_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasFP8ConversionInsts_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33939 /* v_cvt_pk_f16_bf8 */, AMDGPU::V_CVT_PK_F16_BF8V_CVT_PK_F16_BF8_fake16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 33939 /* v_cvt_pk_f16_bf8 */, AMDGPU::V_CVT_PK_F16_BF8V_CVT_PK_F16_BF8_t16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 33939 /* v_cvt_pk_f16_bf8 */, AMDGPU::V_CVT_PK_F16_BF8V_CVT_PK_F16_BF8_fake16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33939 /* v_cvt_pk_f16_bf8 */, AMDGPU::V_CVT_PK_F16_BF8V_CVT_PK_F16_BF8_t16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33956 /* v_cvt_pk_f16_f32 */, AMDGPU::V_CVT_PK_F16_F32_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasCvtPkF16F32Inst_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 33956 /* v_cvt_pk_f16_f32 */, AMDGPU::V_CVT_PK_F16_F32_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasCvtPkF16F32Inst_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33973 /* v_cvt_pk_f16_fp8 */, AMDGPU::V_CVT_PK_F16_FP8V_CVT_PK_F16_FP8_fake16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 33973 /* v_cvt_pk_f16_fp8 */, AMDGPU::V_CVT_PK_F16_FP8V_CVT_PK_F16_FP8_t16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 33973 /* v_cvt_pk_f16_fp8 */, AMDGPU::V_CVT_PK_F16_FP8V_CVT_PK_F16_FP8_fake16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 33973 /* v_cvt_pk_f16_fp8 */, AMDGPU::V_CVT_PK_F16_FP8V_CVT_PK_F16_FP8_t16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34024 /* v_cvt_pk_fp8_f16 */, AMDGPU::V_CVT_PK_FP8_F16_gfx1250_fake16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 34024 /* v_cvt_pk_fp8_f16 */, AMDGPU::V_CVT_PK_FP8_F16_gfx1250_t16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 34024 /* v_cvt_pk_fp8_f16 */, AMDGPU::V_CVT_PK_FP8_F16_gfx1250_fake16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34024 /* v_cvt_pk_fp8_f16 */, AMDGPU::V_CVT_PK_FP8_F16_gfx1250_t16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34041 /* v_cvt_pk_fp8_f32 */, AMDGPU::V_CVT_PK_FP8_F32_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 34041 /* v_cvt_pk_fp8_f32 */, AMDGPU::V_CVT_PK_FP8_F32_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX9Plus_isGFX12Not12_50, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 34041 /* v_cvt_pk_fp8_f32 */, AMDGPU::V_CVT_PK_FP8_F32_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 34041 /* v_cvt_pk_fp8_f32 */, AMDGPU::V_CVT_PK_FP8_F32_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX9Plus_isGFX12Not12_50_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 34041 /* v_cvt_pk_fp8_f32 */, AMDGPU::V_CVT_PK_FP8_F32_gfx1250_fake16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFP8ConversionInsts_HasFP8E5M3Insts_isGFX9Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 34041 /* v_cvt_pk_fp8_f32 */, AMDGPU::V_CVT_PK_FP8_F32_gfx1250_t16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFP8ConversionInsts_HasFP8E5M3Insts_isGFX9Plus_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 34041 /* v_cvt_pk_fp8_f32 */, AMDGPU::V_CVT_PK_FP8_F32_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34041 /* v_cvt_pk_fp8_f32 */, AMDGPU::V_CVT_PK_FP8_F32_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX9Plus_isGFX12Not12_50, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34041 /* v_cvt_pk_fp8_f32 */, AMDGPU::V_CVT_PK_FP8_F32_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34041 /* v_cvt_pk_fp8_f32 */, AMDGPU::V_CVT_PK_FP8_F32_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX9Plus_isGFX12Not12_50_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34041 /* v_cvt_pk_fp8_f32 */, AMDGPU::V_CVT_PK_FP8_F32_gfx1250_fake16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasFP8ConversionInsts_HasFP8E5M3Insts_isGFX9Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34041 /* v_cvt_pk_fp8_f32 */, AMDGPU::V_CVT_PK_FP8_F32_gfx1250_t16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasFP8ConversionInsts_HasFP8E5M3Insts_isGFX9Plus_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34058 /* v_cvt_pk_i16_f32 */, AMDGPU::V_CVT_PK_I16_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 34058 /* v_cvt_pk_i16_f32 */, AMDGPU::V_CVT_PK_I16_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 34058 /* v_cvt_pk_i16_f32 */, AMDGPU::V_CVT_PK_I16_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34058 /* v_cvt_pk_i16_f32 */, AMDGPU::V_CVT_PK_I16_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34075 /* v_cvt_pk_i16_i32 */, AMDGPU::V_CVT_PK_I16_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 34075 /* v_cvt_pk_i16_i32 */, AMDGPU::V_CVT_PK_I16_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 34075 /* v_cvt_pk_i16_i32 */, AMDGPU::V_CVT_PK_I16_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34075 /* v_cvt_pk_i16_i32 */, AMDGPU::V_CVT_PK_I16_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34092 /* v_cvt_pk_norm_i16_f16 */, AMDGPU::V_CVT_PK_NORM_I16_F16V_CVT_PKNORM_I16_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasCvtPkNormVOP3Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 34092 /* v_cvt_pk_norm_i16_f16 */, AMDGPU::V_CVT_PK_NORM_I16_F16V_CVT_PKNORM_I16_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasCvtPkNormVOP3Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 34092 /* v_cvt_pk_norm_i16_f16 */, AMDGPU::V_CVT_PK_NORM_I16_F16V_CVT_PKNORM_I16_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasCvtPkNormVOP3Insts_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 34092 /* v_cvt_pk_norm_i16_f16 */, AMDGPU::V_CVT_PK_NORM_I16_F16V_CVT_PKNORM_I16_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasCvtPkNormVOP3Insts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 34092 /* v_cvt_pk_norm_i16_f16 */, AMDGPU::V_CVT_PK_NORM_I16_F16V_CVT_PKNORM_I16_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasCvtPkNormVOP3Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34092 /* v_cvt_pk_norm_i16_f16 */, AMDGPU::V_CVT_PK_NORM_I16_F16V_CVT_PKNORM_I16_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasCvtPkNormVOP3Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34092 /* v_cvt_pk_norm_i16_f16 */, AMDGPU::V_CVT_PK_NORM_I16_F16V_CVT_PKNORM_I16_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasCvtPkNormVOP3Insts_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34092 /* v_cvt_pk_norm_i16_f16 */, AMDGPU::V_CVT_PK_NORM_I16_F16V_CVT_PKNORM_I16_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasCvtPkNormVOP3Insts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34114 /* v_cvt_pk_norm_i16_f32 */, AMDGPU::V_CVT_PK_NORM_I16_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasCvtPkNormVOP2Insts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 34114 /* v_cvt_pk_norm_i16_f32 */, AMDGPU::V_CVT_PK_NORM_I16_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasCvtPkNormVOP2Insts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 34114 /* v_cvt_pk_norm_i16_f32 */, AMDGPU::V_CVT_PK_NORM_I16_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasCvtPkNormVOP2Insts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34114 /* v_cvt_pk_norm_i16_f32 */, AMDGPU::V_CVT_PK_NORM_I16_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasCvtPkNormVOP2Insts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34136 /* v_cvt_pk_norm_u16_f16 */, AMDGPU::V_CVT_PK_NORM_U16_F16V_CVT_PKNORM_U16_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasCvtPkNormVOP3Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 34136 /* v_cvt_pk_norm_u16_f16 */, AMDGPU::V_CVT_PK_NORM_U16_F16V_CVT_PKNORM_U16_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasCvtPkNormVOP3Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 34136 /* v_cvt_pk_norm_u16_f16 */, AMDGPU::V_CVT_PK_NORM_U16_F16V_CVT_PKNORM_U16_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasCvtPkNormVOP3Insts_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 34136 /* v_cvt_pk_norm_u16_f16 */, AMDGPU::V_CVT_PK_NORM_U16_F16V_CVT_PKNORM_U16_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasCvtPkNormVOP3Insts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 34136 /* v_cvt_pk_norm_u16_f16 */, AMDGPU::V_CVT_PK_NORM_U16_F16V_CVT_PKNORM_U16_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasCvtPkNormVOP3Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34136 /* v_cvt_pk_norm_u16_f16 */, AMDGPU::V_CVT_PK_NORM_U16_F16V_CVT_PKNORM_U16_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasCvtPkNormVOP3Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34136 /* v_cvt_pk_norm_u16_f16 */, AMDGPU::V_CVT_PK_NORM_U16_F16V_CVT_PKNORM_U16_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasCvtPkNormVOP3Insts_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34136 /* v_cvt_pk_norm_u16_f16 */, AMDGPU::V_CVT_PK_NORM_U16_F16V_CVT_PKNORM_U16_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasCvtPkNormVOP3Insts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34158 /* v_cvt_pk_norm_u16_f32 */, AMDGPU::V_CVT_PK_NORM_U16_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasCvtPkNormVOP2Insts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 34158 /* v_cvt_pk_norm_u16_f32 */, AMDGPU::V_CVT_PK_NORM_U16_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasCvtPkNormVOP2Insts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 34158 /* v_cvt_pk_norm_u16_f32 */, AMDGPU::V_CVT_PK_NORM_U16_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasCvtPkNormVOP2Insts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34158 /* v_cvt_pk_norm_u16_f32 */, AMDGPU::V_CVT_PK_NORM_U16_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasCvtPkNormVOP2Insts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34180 /* v_cvt_pk_rtz_f16_f32 */, AMDGPU::V_CVT_PK_RTZ_F16_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 34180 /* v_cvt_pk_rtz_f16_f32 */, AMDGPU::V_CVT_PK_RTZ_F16_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 34180 /* v_cvt_pk_rtz_f16_f32 */, AMDGPU::V_CVT_PK_RTZ_F16_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34180 /* v_cvt_pk_rtz_f16_f32 */, AMDGPU::V_CVT_PK_RTZ_F16_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34201 /* v_cvt_pk_u16_f32 */, AMDGPU::V_CVT_PK_U16_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 34201 /* v_cvt_pk_u16_f32 */, AMDGPU::V_CVT_PK_U16_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 34201 /* v_cvt_pk_u16_f32 */, AMDGPU::V_CVT_PK_U16_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34201 /* v_cvt_pk_u16_f32 */, AMDGPU::V_CVT_PK_U16_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34218 /* v_cvt_pk_u16_u32 */, AMDGPU::V_CVT_PK_U16_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 34218 /* v_cvt_pk_u16_u32 */, AMDGPU::V_CVT_PK_U16_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 34218 /* v_cvt_pk_u16_u32 */, AMDGPU::V_CVT_PK_U16_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34218 /* v_cvt_pk_u16_u32 */, AMDGPU::V_CVT_PK_U16_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34235 /* v_cvt_pk_u8_f32 */, AMDGPU::V_CVT_PK_U8_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 34235 /* v_cvt_pk_u8_f32 */, AMDGPU::V_CVT_PK_U8_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 34235 /* v_cvt_pk_u8_f32 */, AMDGPU::V_CVT_PK_U8_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 34235 /* v_cvt_pk_u8_f32 */, AMDGPU::V_CVT_PK_U8_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37004 /* v_cvt_sr_bf8_f16 */, AMDGPU::V_CVT_SR_BF8_F16_fake16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_VCSrc_b32, MCK_OpSel, MCK_ByteSel, MCK_DPP8, MCK_DppFI }, },
  { 37004 /* v_cvt_sr_bf8_f16 */, AMDGPU::V_CVT_SR_BF8_F16_t16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX1250Plus_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_VCSrc_b32, MCK_OpSel, MCK_ByteSel, MCK_DPP8, MCK_DppFI }, },
  { 37004 /* v_cvt_sr_bf8_f16 */, AMDGPU::V_CVT_SR_BF8_F16_fake16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_VCSrc_b32, MCK_OpSel, MCK_ByteSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37004 /* v_cvt_sr_bf8_f16 */, AMDGPU::V_CVT_SR_BF8_F16_t16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX1250Plus_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_VCSrc_b32, MCK_OpSel, MCK_ByteSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37021 /* v_cvt_sr_bf8_f32 */, AMDGPU::V_CVT_SR_BF8_F32_gfx12_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_ByteSel, MCK_DPP8, MCK_DppFI }, },
  { 37021 /* v_cvt_sr_bf8_f32 */, AMDGPU::V_CVT_SR_BF8_F32_gfx12_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_ByteSel, MCK_DPP8, MCK_DppFI }, },
  { 37021 /* v_cvt_sr_bf8_f32 */, AMDGPU::V_CVT_SR_BF8_F32_gfx12_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_ByteSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37021 /* v_cvt_sr_bf8_f32 */, AMDGPU::V_CVT_SR_BF8_F32_gfx12_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasFP8ConversionInsts_isGFX12Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_ByteSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37055 /* v_cvt_sr_fp8_f16 */, AMDGPU::V_CVT_SR_FP8_F16_fake16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_VCSrc_b32, MCK_OpSel, MCK_ByteSel, MCK_DPP8, MCK_DppFI }, },
  { 37055 /* v_cvt_sr_fp8_f16 */, AMDGPU::V_CVT_SR_FP8_F16_t16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX1250Plus_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_VCSrc_b32, MCK_OpSel, MCK_ByteSel, MCK_DPP8, MCK_DppFI }, },
  { 37055 /* v_cvt_sr_fp8_f16 */, AMDGPU::V_CVT_SR_FP8_F16_fake16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_VCSrc_b32, MCK_OpSel, MCK_ByteSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37055 /* v_cvt_sr_fp8_f16 */, AMDGPU::V_CVT_SR_FP8_F16_t16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX1250Plus_isGFX125xOnly_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_VCSrc_b32, MCK_OpSel, MCK_ByteSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37072 /* v_cvt_sr_fp8_f32 */, AMDGPU::V_CVT_SR_FP8_F32_gfx12_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX12Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_ByteSel, MCK_DPP8, MCK_DppFI }, },
  { 37072 /* v_cvt_sr_fp8_f32 */, AMDGPU::V_CVT_SR_FP8_F32_gfx12_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX12Plus_isGFX12Not12_50, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_ByteSel, MCK_DPP8, MCK_DppFI }, },
  { 37072 /* v_cvt_sr_fp8_f32 */, AMDGPU::V_CVT_SR_FP8_F32_gfx1250_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFP8ConversionInsts_HasFP8E5M3Insts_isGFX12Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_ByteSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 37072 /* v_cvt_sr_fp8_f32 */, AMDGPU::V_CVT_SR_FP8_F32_gfx12_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX12Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_ByteSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37072 /* v_cvt_sr_fp8_f32 */, AMDGPU::V_CVT_SR_FP8_F32_gfx12_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasFP8ConversionInsts_NotHasFP8E5M3Insts_isGFX12Plus_isGFX12Not12_50, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_ByteSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37072 /* v_cvt_sr_fp8_f32 */, AMDGPU::V_CVT_SR_FP8_F32_gfx1250_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasFP8ConversionInsts_HasFP8E5M3Insts_isGFX12Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_ByteSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37089 /* v_cvt_sr_pk_bf16_f32 */, AMDGPU::V_CVT_SR_PK_BF16_F32_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasBF16ConversionInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_VCSrc_b32, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 37089 /* v_cvt_sr_pk_bf16_f32 */, AMDGPU::V_CVT_SR_PK_BF16_F32_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasBF16ConversionInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_VCSrc_b32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37110 /* v_cvt_sr_pk_f16_f32 */, AMDGPU::V_CVT_SR_PK_F16_F32_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_VCSrc_b32, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 37110 /* v_cvt_sr_pk_f16_f32 */, AMDGPU::V_CVT_SR_PK_F16_F32_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_VCSrc_b32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37130 /* v_cvt_u16_f16 */, AMDGPU::V_CVT_U16_F16V_CVT_U16_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37144 /* v_cvt_u32_f32 */, AMDGPU::V_CVT_U32_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37158 /* v_cvt_u32_f64 */, AMDGPU::V_CVT_U32_F64_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37172 /* v_cvt_u32_u16 */, AMDGPU::V_CVT_U32_U16V_CVT_U32_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37186 /* v_div_fixup_f16 */, AMDGPU::V_DIV_FIXUP_F16V_DIV_FIXUP_F16_gfx9_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 37186 /* v_div_fixup_f16 */, AMDGPU::V_DIV_FIXUP_F16V_DIV_FIXUP_F16_gfx9_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 37186 /* v_div_fixup_f16 */, AMDGPU::V_DIV_FIXUP_F16V_DIV_FIXUP_F16_gfx9_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 37186 /* v_div_fixup_f16 */, AMDGPU::V_DIV_FIXUP_F16V_DIV_FIXUP_F16_gfx9_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 37186 /* v_div_fixup_f16 */, AMDGPU::V_DIV_FIXUP_F16V_DIV_FIXUP_F16_gfx9_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37186 /* v_div_fixup_f16 */, AMDGPU::V_DIV_FIXUP_F16V_DIV_FIXUP_F16_gfx9_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37186 /* v_div_fixup_f16 */, AMDGPU::V_DIV_FIXUP_F16V_DIV_FIXUP_F16_gfx9_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37186 /* v_div_fixup_f16 */, AMDGPU::V_DIV_FIXUP_F16V_DIV_FIXUP_F16_gfx9_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37218 /* v_div_fixup_f64 */, AMDGPU::V_DIV_FIXUP_F64_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP64InputMods, MCK_RegOrInlineImmWithFP64InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37272 /* v_div_fmas_f64 */, AMDGPU::V_DIV_FMAS_F64_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP64InputMods, MCK_RegOrInlineImmWithFP64InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37303 /* v_div_scale_f64 */, AMDGPU::V_DIV_SCALE_F64_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_BoolReg, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP64InputMods, MCK_RegOrInlineImmWithFP64InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37319 /* v_dot2_bf16_bf16 */, AMDGPU::V_DOT2_BF16_BF16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasDot9Insts_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 37319 /* v_dot2_bf16_bf16 */, AMDGPU::V_DOT2_BF16_BF16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasDot9Insts_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 37319 /* v_dot2_bf16_bf16 */, AMDGPU::V_DOT2_BF16_BF16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasDot9Insts_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 37319 /* v_dot2_bf16_bf16 */, AMDGPU::V_DOT2_BF16_BF16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasDot9Insts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 37319 /* v_dot2_bf16_bf16 */, AMDGPU::V_DOT2_BF16_BF16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDot9Insts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37319 /* v_dot2_bf16_bf16 */, AMDGPU::V_DOT2_BF16_BF16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDot9Insts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37319 /* v_dot2_bf16_bf16 */, AMDGPU::V_DOT2_BF16_BF16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDot9Insts_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37319 /* v_dot2_bf16_bf16 */, AMDGPU::V_DOT2_BF16_BF16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDot9Insts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37336 /* v_dot2_f16_f16 */, AMDGPU::V_DOT2_F16_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasDot9Insts_isGFX11Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 37336 /* v_dot2_f16_f16 */, AMDGPU::V_DOT2_F16_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasDot9Insts_isGFX12Only_UseFakeTrue16Insts, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 37336 /* v_dot2_f16_f16 */, AMDGPU::V_DOT2_F16_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasDot9Insts_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 37336 /* v_dot2_f16_f16 */, AMDGPU::V_DOT2_F16_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasDot9Insts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 37336 /* v_dot2_f16_f16 */, AMDGPU::V_DOT2_F16_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDot9Insts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37336 /* v_dot2_f16_f16 */, AMDGPU::V_DOT2_F16_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDot9Insts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37336 /* v_dot2_f16_f16 */, AMDGPU::V_DOT2_F16_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDot9Insts_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37336 /* v_dot2_f16_f16 */, AMDGPU::V_DOT2_F16_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDot9Insts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37351 /* v_dot2_f32_bf16 */, AMDGPU::V_DOT2_F32_BF16_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasDot12Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_v2bf16, MCK_VCSrc_f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 37351 /* v_dot2_f32_bf16 */, AMDGPU::V_DOT2_F32_BF16_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasDot12Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_v2bf16, MCK_VCSrc_f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 37351 /* v_dot2_f32_bf16 */, AMDGPU::V_DOT2_F32_BF16_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDot12Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_v2bf16, MCK_VCSrc_f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37351 /* v_dot2_f32_bf16 */, AMDGPU::V_DOT2_F32_BF16_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDot12Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_v2bf16, MCK_VCSrc_f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37367 /* v_dot2_f32_f16 */, AMDGPU::V_DOT2_F32_F16_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasDot10Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_v2f16, MCK_VCSrc_f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 37367 /* v_dot2_f32_f16 */, AMDGPU::V_DOT2_F32_F16_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasDot10Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_v2f16, MCK_VCSrc_f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 37367 /* v_dot2_f32_f16 */, AMDGPU::V_DOT2_F32_F16_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDot10Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_v2f16, MCK_VCSrc_f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37367 /* v_dot2_f32_f16 */, AMDGPU::V_DOT2_F32_F16_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDot10Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_v2f16, MCK_VCSrc_f32, MCK_OpSel, MCK_OpSelHi, MCK_NegLo, MCK_NegHi, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37479 /* v_dot4_f32_bf8_bf8 */, AMDGPU::V_DOT4_F32_BF8_BF8_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasDot11Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_NegLo, MCK_NegHi, MCK_DPP8, MCK_DppFI }, },
  { 37479 /* v_dot4_f32_bf8_bf8 */, AMDGPU::V_DOT4_F32_BF8_BF8_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDot11Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_NegLo, MCK_NegHi, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37498 /* v_dot4_f32_bf8_fp8 */, AMDGPU::V_DOT4_F32_BF8_FP8_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasDot11Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_NegLo, MCK_NegHi, MCK_DPP8, MCK_DppFI }, },
  { 37498 /* v_dot4_f32_bf8_fp8 */, AMDGPU::V_DOT4_F32_BF8_FP8_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDot11Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_NegLo, MCK_NegHi, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37517 /* v_dot4_f32_fp8_bf8 */, AMDGPU::V_DOT4_F32_FP8_BF8_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasDot11Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_NegLo, MCK_NegHi, MCK_DPP8, MCK_DppFI }, },
  { 37517 /* v_dot4_f32_fp8_bf8 */, AMDGPU::V_DOT4_F32_FP8_BF8_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDot11Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_NegLo, MCK_NegHi, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 37536 /* v_dot4_f32_fp8_fp8 */, AMDGPU::V_DOT4_F32_FP8_FP8_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasDot11Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_NegLo, MCK_NegHi, MCK_DPP8, MCK_DppFI }, },
  { 37536 /* v_dot4_f32_fp8_fp8 */, AMDGPU::V_DOT4_F32_FP8_FP8_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDot11Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_VGPR_32, MCK_NegLo, MCK_NegHi, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38148 /* v_exp_bf16 */, AMDGPU::V_EXP_BF16V_EXP_BF16_fake16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_DPP8, MCK_DppFI }, },
  { 38148 /* v_exp_bf16 */, AMDGPU::V_EXP_BF16V_EXP_BF16_t16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 38148 /* v_exp_bf16 */, AMDGPU::V_EXP_BF16V_EXP_BF16_fake16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38148 /* v_exp_bf16 */, AMDGPU::V_EXP_BF16V_EXP_BF16_t16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38159 /* v_exp_f16 */, AMDGPU::V_EXP_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38169 /* v_exp_f32 */, AMDGPU::V_EXP_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38229 /* v_floor_f16 */, AMDGPU::V_FLOOR_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38241 /* v_floor_f32 */, AMDGPU::V_FLOOR_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38253 /* v_floor_f64 */, AMDGPU::V_FLOOR_F64_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX7Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38284 /* v_fma_f16 */, AMDGPU::V_FMA_F16V_FMA_F16_gfx9_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38284 /* v_fma_f16 */, AMDGPU::V_FMA_F16V_FMA_F16_gfx9_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38284 /* v_fma_f16 */, AMDGPU::V_FMA_F16V_FMA_F16_gfx9_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38284 /* v_fma_f16 */, AMDGPU::V_FMA_F16V_FMA_F16_gfx9_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38284 /* v_fma_f16 */, AMDGPU::V_FMA_F16V_FMA_F16_gfx9_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38284 /* v_fma_f16 */, AMDGPU::V_FMA_F16V_FMA_F16_gfx9_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38284 /* v_fma_f16 */, AMDGPU::V_FMA_F16V_FMA_F16_gfx9_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38284 /* v_fma_f16 */, AMDGPU::V_FMA_F16V_FMA_F16_gfx9_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38294 /* v_fma_f32 */, AMDGPU::V_FMA_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38294 /* v_fma_f32 */, AMDGPU::V_FMA_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38294 /* v_fma_f32 */, AMDGPU::V_FMA_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38294 /* v_fma_f32 */, AMDGPU::V_FMA_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38304 /* v_fma_f64 */, AMDGPU::V_FMA_F64_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP64InputMods, MCK_RegOrInlineImmWithFP64InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38348 /* v_fma_mix_f32 */, AMDGPU::V_FMA_MIX_F32_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFmaMixInsts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 38348 /* v_fma_mix_f32 */, AMDGPU::V_FMA_MIX_F32_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFmaMixInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 38348 /* v_fma_mix_f32 */, AMDGPU::V_FMA_MIX_F32_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasFmaMixInsts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38348 /* v_fma_mix_f32 */, AMDGPU::V_FMA_MIX_F32_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasFmaMixInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38362 /* v_fma_mix_f32_bf16 */, AMDGPU::V_FMA_MIX_F32_BF16_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFmaMixBF16Insts_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 38362 /* v_fma_mix_f32_bf16 */, AMDGPU::V_FMA_MIX_F32_BF16_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasFmaMixBF16Insts_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38381 /* v_fma_mixhi_bf16 */, AMDGPU::V_FMA_MIXHI_BF16_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFmaMixBF16Insts_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 38381 /* v_fma_mixhi_bf16 */, AMDGPU::V_FMA_MIXHI_BF16_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasFmaMixBF16Insts_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38398 /* v_fma_mixhi_f16 */, AMDGPU::V_FMA_MIXHI_F16_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFmaMixInsts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 38398 /* v_fma_mixhi_f16 */, AMDGPU::V_FMA_MIXHI_F16_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFmaMixInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 38398 /* v_fma_mixhi_f16 */, AMDGPU::V_FMA_MIXHI_F16_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasFmaMixInsts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38398 /* v_fma_mixhi_f16 */, AMDGPU::V_FMA_MIXHI_F16_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasFmaMixInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38414 /* v_fma_mixlo_bf16 */, AMDGPU::V_FMA_MIXLO_BF16_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFmaMixBF16Insts_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 38414 /* v_fma_mixlo_bf16 */, AMDGPU::V_FMA_MIXLO_BF16_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasFmaMixBF16Insts_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38431 /* v_fma_mixlo_f16 */, AMDGPU::V_FMA_MIXLO_F16_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFmaMixInsts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 38431 /* v_fma_mixlo_f16 */, AMDGPU::V_FMA_MIXLO_F16_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasFmaMixInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 38431 /* v_fma_mixlo_f16 */, AMDGPU::V_FMA_MIXLO_F16_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasFmaMixInsts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38431 /* v_fma_mixlo_f16 */, AMDGPU::V_FMA_MIXLO_F16_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasFmaMixInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VRegWithFPInputMods, MCK_RegOrImmWithFP16InputMods, MCK_OpSel, MCK_OpSelHi, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX10Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX10Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX10Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38503 /* v_fmac_f16 */, AMDGPU::V_FMAC_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX10Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38514 /* v_fmac_f32 */, AMDGPU::V_FMAC_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasDLInsts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38514 /* v_fmac_f32 */, AMDGPU::V_FMAC_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasDLInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38514 /* v_fmac_f32 */, AMDGPU::V_FMAC_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDLInsts_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38514 /* v_fmac_f32 */, AMDGPU::V_FMAC_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDLInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38525 /* v_fmac_f64 */, AMDGPU::V_FMAC_F64_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_HasFmacF64Inst_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP64InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38590 /* v_fract_f16 */, AMDGPU::V_FRACT_F16V_FRACT_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38602 /* v_fract_f32 */, AMDGPU::V_FRACT_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38614 /* v_fract_f64 */, AMDGPU::V_FRACT_F64_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38626 /* v_frexp_exp_i16_f16 */, AMDGPU::V_FREXP_EXP_I16_F16V_FREXP_EXP_I16_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38646 /* v_frexp_exp_i32_f32 */, AMDGPU::V_FREXP_EXP_I32_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38666 /* v_frexp_exp_i32_f64 */, AMDGPU::V_FREXP_EXP_I32_F64_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38686 /* v_frexp_mant_f16 */, AMDGPU::V_FREXP_MANT_F16V_FREXP_MANT_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38703 /* v_frexp_mant_f32 */, AMDGPU::V_FREXP_MANT_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38720 /* v_frexp_mant_f64 */, AMDGPU::V_FREXP_MANT_F64_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithIntFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithIntFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithIntT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithIntT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithIntFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithIntFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithIntT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38978 /* v_ldexp_f16 */, AMDGPU::V_LDEXP_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithIntT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38990 /* v_ldexp_f32 */, AMDGPU::V_LDEXP_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38990 /* v_ldexp_f32 */, AMDGPU::V_LDEXP_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 38990 /* v_ldexp_f32 */, AMDGPU::V_LDEXP_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 38990 /* v_ldexp_f32 */, AMDGPU::V_LDEXP_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39002 /* v_ldexp_f64 */, AMDGPU::V_LDEXP_F64_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_VCSrc_b32, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39014 /* v_lerp_u8 */, AMDGPU::V_LERP_U8_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasLerpInst_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 39014 /* v_lerp_u8 */, AMDGPU::V_LERP_U8_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasLerpInst_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 39014 /* v_lerp_u8 */, AMDGPU::V_LERP_U8_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasLerpInst_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39014 /* v_lerp_u8 */, AMDGPU::V_LERP_U8_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasLerpInst_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39024 /* v_log_bf16 */, AMDGPU::V_LOG_BF16V_LOG_BF16_fake16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_DPP8, MCK_DppFI }, },
  { 39024 /* v_log_bf16 */, AMDGPU::V_LOG_BF16V_LOG_BF16_t16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 39024 /* v_log_bf16 */, AMDGPU::V_LOG_BF16V_LOG_BF16_fake16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39024 /* v_log_bf16 */, AMDGPU::V_LOG_BF16V_LOG_BF16_t16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39051 /* v_log_f16 */, AMDGPU::V_LOG_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39061 /* v_log_f32 */, AMDGPU::V_LOG_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39088 /* v_lshl_add_u32 */, AMDGPU::V_LSHL_ADD_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 39088 /* v_lshl_add_u32 */, AMDGPU::V_LSHL_ADD_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 39088 /* v_lshl_add_u32 */, AMDGPU::V_LSHL_ADD_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39088 /* v_lshl_add_u32 */, AMDGPU::V_LSHL_ADD_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39103 /* v_lshl_add_u64 */, AMDGPU::V_LSHL_ADD_U64_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_HasLshlAddU64Inst_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VCSrc_b32, MCK_VCSrc_b64, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39140 /* v_lshl_or_b32 */, AMDGPU::V_LSHL_OR_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 39140 /* v_lshl_or_b32 */, AMDGPU::V_LSHL_OR_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 39140 /* v_lshl_or_b32 */, AMDGPU::V_LSHL_OR_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39140 /* v_lshl_or_b32 */, AMDGPU::V_LSHL_OR_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39154 /* v_lshlrev_b16 */, AMDGPU::V_LSHLREV_B16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 39154 /* v_lshlrev_b16 */, AMDGPU::V_LSHLREV_B16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 39154 /* v_lshlrev_b16 */, AMDGPU::V_LSHLREV_B16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 39154 /* v_lshlrev_b16 */, AMDGPU::V_LSHLREV_B16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 39154 /* v_lshlrev_b16 */, AMDGPU::V_LSHLREV_B16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39154 /* v_lshlrev_b16 */, AMDGPU::V_LSHLREV_B16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39154 /* v_lshlrev_b16 */, AMDGPU::V_LSHLREV_B16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39154 /* v_lshlrev_b16 */, AMDGPU::V_LSHLREV_B16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39168 /* v_lshlrev_b32 */, AMDGPU::V_LSHLREV_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39182 /* v_lshlrev_b64 */, AMDGPU::V_LSHLREV_B64_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_VCSrc_b64, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39218 /* v_lshrrev_b16 */, AMDGPU::V_LSHRREV_B16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 39218 /* v_lshrrev_b16 */, AMDGPU::V_LSHRREV_B16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 39218 /* v_lshrrev_b16 */, AMDGPU::V_LSHRREV_B16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 39218 /* v_lshrrev_b16 */, AMDGPU::V_LSHRREV_B16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 39218 /* v_lshrrev_b16 */, AMDGPU::V_LSHRREV_B16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39218 /* v_lshrrev_b16 */, AMDGPU::V_LSHRREV_B16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39218 /* v_lshrrev_b16 */, AMDGPU::V_LSHRREV_B16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39218 /* v_lshrrev_b16 */, AMDGPU::V_LSHRREV_B16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39232 /* v_lshrrev_b32 */, AMDGPU::V_LSHRREV_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39246 /* v_lshrrev_b64 */, AMDGPU::V_LSHRREV_B64_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX8Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_VCSrc_b64, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39297 /* v_mad_co_i64_i32 */, AMDGPU::V_MAD_CO_I64_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX7Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b64, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39314 /* v_mad_co_u64_u32 */, AMDGPU::V_MAD_CO_U64_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX7Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b64, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39351 /* v_mad_i16 */, AMDGPU::V_MAD_I16V_MAD_I16_gfx9_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39351 /* v_mad_i16 */, AMDGPU::V_MAD_I16V_MAD_I16_gfx9_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39351 /* v_mad_i16 */, AMDGPU::V_MAD_I16V_MAD_I16_gfx9_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39351 /* v_mad_i16 */, AMDGPU::V_MAD_I16V_MAD_I16_gfx9_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39351 /* v_mad_i16 */, AMDGPU::V_MAD_I16V_MAD_I16_gfx9_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39351 /* v_mad_i16 */, AMDGPU::V_MAD_I16V_MAD_I16_gfx9_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39351 /* v_mad_i16 */, AMDGPU::V_MAD_I16V_MAD_I16_gfx9_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39351 /* v_mad_i16 */, AMDGPU::V_MAD_I16V_MAD_I16_gfx9_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39361 /* v_mad_i32_i16 */, AMDGPU::V_MAD_I32_I16V_MAD_I32_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b32, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39361 /* v_mad_i32_i16 */, AMDGPU::V_MAD_I32_I16V_MAD_I32_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b32, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39361 /* v_mad_i32_i16 */, AMDGPU::V_MAD_I32_I16V_MAD_I32_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrc_b32, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39361 /* v_mad_i32_i16 */, AMDGPU::V_MAD_I32_I16V_MAD_I32_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrc_b32, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39361 /* v_mad_i32_i16 */, AMDGPU::V_MAD_I32_I16V_MAD_I32_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b32, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39361 /* v_mad_i32_i16 */, AMDGPU::V_MAD_I32_I16V_MAD_I32_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b32, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39361 /* v_mad_i32_i16 */, AMDGPU::V_MAD_I32_I16V_MAD_I32_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrc_b32, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39361 /* v_mad_i32_i16 */, AMDGPU::V_MAD_I32_I16V_MAD_I32_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrc_b32, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39375 /* v_mad_i32_i24 */, AMDGPU::V_MAD_I32_I24_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39375 /* v_mad_i32_i24 */, AMDGPU::V_MAD_I32_I24_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39375 /* v_mad_i32_i24 */, AMDGPU::V_MAD_I32_I24_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39375 /* v_mad_i32_i24 */, AMDGPU::V_MAD_I32_I24_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39517 /* v_mad_nc_i64_i32 */, AMDGPU::V_MAD_NC_I64_I32_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b64, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39534 /* v_mad_nc_u64_u32 */, AMDGPU::V_MAD_NC_U64_U32_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b64, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39551 /* v_mad_u16 */, AMDGPU::V_MAD_U16V_MAD_U16_gfx9_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39551 /* v_mad_u16 */, AMDGPU::V_MAD_U16V_MAD_U16_gfx9_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39551 /* v_mad_u16 */, AMDGPU::V_MAD_U16V_MAD_U16_gfx9_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39551 /* v_mad_u16 */, AMDGPU::V_MAD_U16V_MAD_U16_gfx9_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39551 /* v_mad_u16 */, AMDGPU::V_MAD_U16V_MAD_U16_gfx9_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39551 /* v_mad_u16 */, AMDGPU::V_MAD_U16V_MAD_U16_gfx9_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39551 /* v_mad_u16 */, AMDGPU::V_MAD_U16V_MAD_U16_gfx9_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39551 /* v_mad_u16 */, AMDGPU::V_MAD_U16V_MAD_U16_gfx9_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39561 /* v_mad_u32 */, AMDGPU::V_MAD_U32_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_HasMadU32Inst_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39571 /* v_mad_u32_u16 */, AMDGPU::V_MAD_U32_U16V_MAD_U32_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b32, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39571 /* v_mad_u32_u16 */, AMDGPU::V_MAD_U32_U16V_MAD_U32_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b32, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39571 /* v_mad_u32_u16 */, AMDGPU::V_MAD_U32_U16V_MAD_U32_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrc_b32, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39571 /* v_mad_u32_u16 */, AMDGPU::V_MAD_U32_U16V_MAD_U32_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrc_b32, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39571 /* v_mad_u32_u16 */, AMDGPU::V_MAD_U32_U16V_MAD_U32_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b32, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39571 /* v_mad_u32_u16 */, AMDGPU::V_MAD_U32_U16V_MAD_U32_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b32, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39571 /* v_mad_u32_u16 */, AMDGPU::V_MAD_U32_U16V_MAD_U32_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrc_b32, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39571 /* v_mad_u32_u16 */, AMDGPU::V_MAD_U32_U16V_MAD_U32_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrc_b32, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39585 /* v_mad_u32_u24 */, AMDGPU::V_MAD_U32_U24_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39585 /* v_mad_u32_u24 */, AMDGPU::V_MAD_U32_U24_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39585 /* v_mad_u32_u24 */, AMDGPU::V_MAD_U32_U24_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39585 /* v_mad_u32_u24 */, AMDGPU::V_MAD_U32_U24_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39661 /* v_max3_f16 */, AMDGPU::V_MAX3_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39661 /* v_max3_f16 */, AMDGPU::V_MAX3_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39661 /* v_max3_f16 */, AMDGPU::V_MAX3_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39661 /* v_max3_f16 */, AMDGPU::V_MAX3_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39672 /* v_max3_f32 */, AMDGPU::V_MAX3_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39672 /* v_max3_f32 */, AMDGPU::V_MAX3_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39683 /* v_max3_i16 */, AMDGPU::V_MAX3_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39683 /* v_max3_i16 */, AMDGPU::V_MAX3_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39683 /* v_max3_i16 */, AMDGPU::V_MAX3_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39683 /* v_max3_i16 */, AMDGPU::V_MAX3_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39683 /* v_max3_i16 */, AMDGPU::V_MAX3_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39683 /* v_max3_i16 */, AMDGPU::V_MAX3_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39683 /* v_max3_i16 */, AMDGPU::V_MAX3_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39683 /* v_max3_i16 */, AMDGPU::V_MAX3_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39694 /* v_max3_i32 */, AMDGPU::V_MAX3_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 39694 /* v_max3_i32 */, AMDGPU::V_MAX3_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 39694 /* v_max3_i32 */, AMDGPU::V_MAX3_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39694 /* v_max3_i32 */, AMDGPU::V_MAX3_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39705 /* v_max3_num_f16 */, AMDGPU::V_MAX3_NUM_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39705 /* v_max3_num_f16 */, AMDGPU::V_MAX3_NUM_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39705 /* v_max3_num_f16 */, AMDGPU::V_MAX3_NUM_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39705 /* v_max3_num_f16 */, AMDGPU::V_MAX3_NUM_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39720 /* v_max3_num_f32 */, AMDGPU::V_MAX3_NUM_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39720 /* v_max3_num_f32 */, AMDGPU::V_MAX3_NUM_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39735 /* v_max3_u16 */, AMDGPU::V_MAX3_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39735 /* v_max3_u16 */, AMDGPU::V_MAX3_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39735 /* v_max3_u16 */, AMDGPU::V_MAX3_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39735 /* v_max3_u16 */, AMDGPU::V_MAX3_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 39735 /* v_max3_u16 */, AMDGPU::V_MAX3_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39735 /* v_max3_u16 */, AMDGPU::V_MAX3_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39735 /* v_max3_u16 */, AMDGPU::V_MAX3_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39735 /* v_max3_u16 */, AMDGPU::V_MAX3_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39746 /* v_max3_u32 */, AMDGPU::V_MAX3_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 39746 /* v_max3_u32 */, AMDGPU::V_MAX3_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 39746 /* v_max3_u32 */, AMDGPU::V_MAX3_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39746 /* v_max3_u32 */, AMDGPU::V_MAX3_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39757 /* v_max_f16 */, AMDGPU::V_MAX_F16V_MAX_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39757 /* v_max_f16 */, AMDGPU::V_MAX_F16V_MAX_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39757 /* v_max_f16 */, AMDGPU::V_MAX_F16V_MAX_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39757 /* v_max_f16 */, AMDGPU::V_MAX_F16V_MAX_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39767 /* v_max_f32 */, AMDGPU::V_MAX_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39767 /* v_max_f32 */, AMDGPU::V_MAX_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39787 /* v_max_i16 */, AMDGPU::V_MAX_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 39787 /* v_max_i16 */, AMDGPU::V_MAX_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 39787 /* v_max_i16 */, AMDGPU::V_MAX_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 39787 /* v_max_i16 */, AMDGPU::V_MAX_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 39787 /* v_max_i16 */, AMDGPU::V_MAX_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39787 /* v_max_i16 */, AMDGPU::V_MAX_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39787 /* v_max_i16 */, AMDGPU::V_MAX_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39787 /* v_max_i16 */, AMDGPU::V_MAX_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39797 /* v_max_i32 */, AMDGPU::V_MAX_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39807 /* v_max_i64 */, AMDGPU::V_MAX_I64_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VCSrc_b64, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39834 /* v_max_num_f16 */, AMDGPU::V_MAX_NUM_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39834 /* v_max_num_f16 */, AMDGPU::V_MAX_NUM_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39834 /* v_max_num_f16 */, AMDGPU::V_MAX_NUM_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39834 /* v_max_num_f16 */, AMDGPU::V_MAX_NUM_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39848 /* v_max_num_f32 */, AMDGPU::V_MAX_NUM_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39848 /* v_max_num_f32 */, AMDGPU::V_MAX_NUM_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39862 /* v_max_num_f64 */, AMDGPU::V_MAX_NUM_F64_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP64InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39876 /* v_max_u16 */, AMDGPU::V_MAX_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 39876 /* v_max_u16 */, AMDGPU::V_MAX_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 39876 /* v_max_u16 */, AMDGPU::V_MAX_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 39876 /* v_max_u16 */, AMDGPU::V_MAX_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 39876 /* v_max_u16 */, AMDGPU::V_MAX_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39876 /* v_max_u16 */, AMDGPU::V_MAX_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39876 /* v_max_u16 */, AMDGPU::V_MAX_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39876 /* v_max_u16 */, AMDGPU::V_MAX_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39886 /* v_max_u32 */, AMDGPU::V_MAX_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39896 /* v_max_u64 */, AMDGPU::V_MAX_U64_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VCSrc_b64, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39906 /* v_maximum3_f16 */, AMDGPU::V_MAXIMUM3_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasMinimum3Maximum3F16_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39906 /* v_maximum3_f16 */, AMDGPU::V_MAXIMUM3_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasMinimum3Maximum3F16_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39906 /* v_maximum3_f16 */, AMDGPU::V_MAXIMUM3_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasMinimum3Maximum3F16_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39906 /* v_maximum3_f16 */, AMDGPU::V_MAXIMUM3_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasMinimum3Maximum3F16_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39921 /* v_maximum3_f32 */, AMDGPU::V_MAXIMUM3_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasMinimum3Maximum3F32_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39921 /* v_maximum3_f32 */, AMDGPU::V_MAXIMUM3_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasMinimum3Maximum3F32_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39936 /* v_maximum_f16 */, AMDGPU::V_MAXIMUM_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39936 /* v_maximum_f16 */, AMDGPU::V_MAXIMUM_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39936 /* v_maximum_f16 */, AMDGPU::V_MAXIMUM_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39936 /* v_maximum_f16 */, AMDGPU::V_MAXIMUM_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39950 /* v_maximum_f32 */, AMDGPU::V_MAXIMUM_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39950 /* v_maximum_f32 */, AMDGPU::V_MAXIMUM_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39964 /* v_maximum_f64 */, AMDGPU::V_MAXIMUM_F64_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_HasIEEEMinimumMaximumInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP64InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39964 /* v_maximum_f64 */, AMDGPU::V_MAXIMUM_F64_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP64InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39978 /* v_maximumminimum_f16 */, AMDGPU::V_MAXIMUMMINIMUM_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39978 /* v_maximumminimum_f16 */, AMDGPU::V_MAXIMUMMINIMUM_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39978 /* v_maximumminimum_f16 */, AMDGPU::V_MAXIMUMMINIMUM_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39978 /* v_maximumminimum_f16 */, AMDGPU::V_MAXIMUMMINIMUM_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 39999 /* v_maximumminimum_f32 */, AMDGPU::V_MAXIMUMMINIMUM_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 39999 /* v_maximumminimum_f32 */, AMDGPU::V_MAXIMUMMINIMUM_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40020 /* v_maxmin_f16 */, AMDGPU::V_MAXMIN_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 40020 /* v_maxmin_f16 */, AMDGPU::V_MAXMIN_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 40020 /* v_maxmin_f16 */, AMDGPU::V_MAXMIN_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40020 /* v_maxmin_f16 */, AMDGPU::V_MAXMIN_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40033 /* v_maxmin_f32 */, AMDGPU::V_MAXMIN_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 40033 /* v_maxmin_f32 */, AMDGPU::V_MAXMIN_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40046 /* v_maxmin_i32 */, AMDGPU::V_MAXMIN_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 40046 /* v_maxmin_i32 */, AMDGPU::V_MAXMIN_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 40046 /* v_maxmin_i32 */, AMDGPU::V_MAXMIN_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40046 /* v_maxmin_i32 */, AMDGPU::V_MAXMIN_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40059 /* v_maxmin_num_f16 */, AMDGPU::V_MAXMIN_NUM_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 40059 /* v_maxmin_num_f16 */, AMDGPU::V_MAXMIN_NUM_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 40059 /* v_maxmin_num_f16 */, AMDGPU::V_MAXMIN_NUM_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40059 /* v_maxmin_num_f16 */, AMDGPU::V_MAXMIN_NUM_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40076 /* v_maxmin_num_f32 */, AMDGPU::V_MAXMIN_NUM_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 40076 /* v_maxmin_num_f32 */, AMDGPU::V_MAXMIN_NUM_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40093 /* v_maxmin_u32 */, AMDGPU::V_MAXMIN_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 40093 /* v_maxmin_u32 */, AMDGPU::V_MAXMIN_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 40093 /* v_maxmin_u32 */, AMDGPU::V_MAXMIN_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40093 /* v_maxmin_u32 */, AMDGPU::V_MAXMIN_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40106 /* v_mbcnt_hi_u32_b32 */, AMDGPU::V_MBCNT_HI_U32_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 40106 /* v_mbcnt_hi_u32_b32 */, AMDGPU::V_MBCNT_HI_U32_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 40106 /* v_mbcnt_hi_u32_b32 */, AMDGPU::V_MBCNT_HI_U32_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40106 /* v_mbcnt_hi_u32_b32 */, AMDGPU::V_MBCNT_HI_U32_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40125 /* v_mbcnt_lo_u32_b32 */, AMDGPU::V_MBCNT_LO_U32_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 40125 /* v_mbcnt_lo_u32_b32 */, AMDGPU::V_MBCNT_LO_U32_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 40125 /* v_mbcnt_lo_u32_b32 */, AMDGPU::V_MBCNT_LO_U32_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40125 /* v_mbcnt_lo_u32_b32 */, AMDGPU::V_MBCNT_LO_U32_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40144 /* v_med3_f16 */, AMDGPU::V_MED3_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 40144 /* v_med3_f16 */, AMDGPU::V_MED3_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 40144 /* v_med3_f16 */, AMDGPU::V_MED3_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40144 /* v_med3_f16 */, AMDGPU::V_MED3_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40155 /* v_med3_f32 */, AMDGPU::V_MED3_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 40155 /* v_med3_f32 */, AMDGPU::V_MED3_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40166 /* v_med3_i16 */, AMDGPU::V_MED3_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 40166 /* v_med3_i16 */, AMDGPU::V_MED3_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 40166 /* v_med3_i16 */, AMDGPU::V_MED3_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 40166 /* v_med3_i16 */, AMDGPU::V_MED3_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 40166 /* v_med3_i16 */, AMDGPU::V_MED3_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40166 /* v_med3_i16 */, AMDGPU::V_MED3_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40166 /* v_med3_i16 */, AMDGPU::V_MED3_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40166 /* v_med3_i16 */, AMDGPU::V_MED3_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40177 /* v_med3_i32 */, AMDGPU::V_MED3_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 40177 /* v_med3_i32 */, AMDGPU::V_MED3_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 40177 /* v_med3_i32 */, AMDGPU::V_MED3_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40177 /* v_med3_i32 */, AMDGPU::V_MED3_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40188 /* v_med3_num_f16 */, AMDGPU::V_MED3_NUM_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 40188 /* v_med3_num_f16 */, AMDGPU::V_MED3_NUM_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 40188 /* v_med3_num_f16 */, AMDGPU::V_MED3_NUM_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40188 /* v_med3_num_f16 */, AMDGPU::V_MED3_NUM_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40203 /* v_med3_num_f32 */, AMDGPU::V_MED3_NUM_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 40203 /* v_med3_num_f32 */, AMDGPU::V_MED3_NUM_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40218 /* v_med3_u16 */, AMDGPU::V_MED3_U16V_MED3_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 40218 /* v_med3_u16 */, AMDGPU::V_MED3_U16V_MED3_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 40218 /* v_med3_u16 */, AMDGPU::V_MED3_U16V_MED3_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 40218 /* v_med3_u16 */, AMDGPU::V_MED3_U16V_MED3_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 40218 /* v_med3_u16 */, AMDGPU::V_MED3_U16V_MED3_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40218 /* v_med3_u16 */, AMDGPU::V_MED3_U16V_MED3_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40218 /* v_med3_u16 */, AMDGPU::V_MED3_U16V_MED3_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40218 /* v_med3_u16 */, AMDGPU::V_MED3_U16V_MED3_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40229 /* v_med3_u32 */, AMDGPU::V_MED3_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 40229 /* v_med3_u32 */, AMDGPU::V_MED3_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 40229 /* v_med3_u32 */, AMDGPU::V_MED3_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40229 /* v_med3_u32 */, AMDGPU::V_MED3_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 40317 /* v_mfma_f32_16x16x16bf16 */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40317 /* v_mfma_f32_16x16x16bf16 */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40341 /* v_mfma_f32_16x16x16bf16_1k */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40341 /* v_mfma_f32_16x16x16bf16_1k */, AMDGPU::V_MFMA_F32_16X16X16BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40368 /* v_mfma_f32_16x16x16f16 */, AMDGPU::V_MFMA_F32_16X16X16F16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40368 /* v_mfma_f32_16x16x16f16 */, AMDGPU::V_MFMA_F32_16X16X16F16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40417 /* v_mfma_f32_16x16x1f32 */, AMDGPU::V_MFMA_F32_16X16X1F32_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40417 /* v_mfma_f32_16x16x1f32 */, AMDGPU::V_MFMA_F32_16X16X1F32_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40623 /* v_mfma_f32_16x16x32bf16 */, AMDGPU::V_MFMA_F32_16X16X32_BF16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40623 /* v_mfma_f32_16x16x32bf16 */, AMDGPU::V_MFMA_F32_16X16X32_BF16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40647 /* v_mfma_f32_16x16x32f16 */, AMDGPU::V_MFMA_F32_16X16X32_F16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40647 /* v_mfma_f32_16x16x32f16 */, AMDGPU::V_MFMA_F32_16X16X32_F16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40746 /* v_mfma_f32_16x16x4bf16 */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40746 /* v_mfma_f32_16x16x4bf16 */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40769 /* v_mfma_f32_16x16x4bf16_1k */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40769 /* v_mfma_f32_16x16x4bf16_1k */, AMDGPU::V_MFMA_F32_16X16X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40795 /* v_mfma_f32_16x16x4f16 */, AMDGPU::V_MFMA_F32_16X16X4F16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40795 /* v_mfma_f32_16x16x4f16 */, AMDGPU::V_MFMA_F32_16X16X4F16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40817 /* v_mfma_f32_16x16x4f32 */, AMDGPU::V_MFMA_F32_16X16X4F32_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40817 /* v_mfma_f32_16x16x4f32 */, AMDGPU::V_MFMA_F32_16X16X4F32_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40886 /* v_mfma_f32_16x16x8xf32 */, AMDGPU::V_MFMA_F32_16X16X8XF32_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 40886 /* v_mfma_f32_16x16x8xf32 */, AMDGPU::V_MFMA_F32_16X16X8XF32_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41070 /* v_mfma_f32_32x32x16bf16 */, AMDGPU::V_MFMA_F32_32X32X16_BF16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41070 /* v_mfma_f32_32x32x16bf16 */, AMDGPU::V_MFMA_F32_32X32X16_BF16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41094 /* v_mfma_f32_32x32x16f16 */, AMDGPU::V_MFMA_F32_32X32X16_F16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41094 /* v_mfma_f32_32x32x16f16 */, AMDGPU::V_MFMA_F32_32X32X16_F16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41143 /* v_mfma_f32_32x32x1f32 */, AMDGPU::V_MFMA_F32_32X32X1F32_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_1024_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41143 /* v_mfma_f32_32x32x1f32 */, AMDGPU::V_MFMA_F32_32X32X1F32_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_1024_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_1024_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41211 /* v_mfma_f32_32x32x2f32 */, AMDGPU::V_MFMA_F32_32X32X2F32_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41211 /* v_mfma_f32_32x32x2f32 */, AMDGPU::V_MFMA_F32_32X32X2F32_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41310 /* v_mfma_f32_32x32x4bf16 */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41310 /* v_mfma_f32_32x32x4bf16 */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41333 /* v_mfma_f32_32x32x4bf16_1k */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41333 /* v_mfma_f32_32x32x4bf16_1k */, AMDGPU::V_MFMA_F32_32X32X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41359 /* v_mfma_f32_32x32x4f16 */, AMDGPU::V_MFMA_F32_32X32X4F16_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41359 /* v_mfma_f32_32x32x4f16 */, AMDGPU::V_MFMA_F32_32X32X4F16_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41381 /* v_mfma_f32_32x32x4xf32 */, AMDGPU::V_MFMA_F32_32X32X4XF32_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41381 /* v_mfma_f32_32x32x4xf32 */, AMDGPU::V_MFMA_F32_32X32X4XF32_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasXF32Insts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41478 /* v_mfma_f32_32x32x8bf16 */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41478 /* v_mfma_f32_32x32x8bf16 */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41501 /* v_mfma_f32_32x32x8bf16_1k */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41501 /* v_mfma_f32_32x32x8bf16_1k */, AMDGPU::V_MFMA_F32_32X32X8BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41527 /* v_mfma_f32_32x32x8f16 */, AMDGPU::V_MFMA_F32_32X32X8F16_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41527 /* v_mfma_f32_32x32x8f16 */, AMDGPU::V_MFMA_F32_32X32X8F16_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41574 /* v_mfma_f32_4x4x1f32 */, AMDGPU::V_MFMA_F32_4X4X1F32_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41574 /* v_mfma_f32_4x4x1f32 */, AMDGPU::V_MFMA_F32_4X4X1F32_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41666 /* v_mfma_f32_4x4x4bf16 */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41666 /* v_mfma_f32_4x4x4bf16 */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41687 /* v_mfma_f32_4x4x4bf16_1k */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41687 /* v_mfma_f32_4x4x4bf16_1k */, AMDGPU::V_MFMA_F32_4X4X4BF16_1K_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41711 /* v_mfma_f32_4x4x4f16 */, AMDGPU::V_MFMA_F32_4X4X4F16_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41711 /* v_mfma_f32_4x4x4f16 */, AMDGPU::V_MFMA_F32_4X4X4F16_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41754 /* v_mfma_f64_16x16x4f64 */, AMDGPU::V_MFMA_F64_16X16X4F64_gfx940_acd, Convert__RegByHwMode_AReg_256_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_256_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_256_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_256_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41754 /* v_mfma_f64_16x16x4f64 */, AMDGPU::V_MFMA_F64_16X16X4F64_gfx940_vcd, Convert__RegByHwMode_VReg_256_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_256_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_256_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_256_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41800 /* v_mfma_f64_4x4x4f64 */, AMDGPU::V_MFMA_F64_4X4X4F64_gfx940_acd, Convert__RegByHwMode_AReg_64_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_64_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_AReg_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_64_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41800 /* v_mfma_f64_4x4x4f64 */, AMDGPU::V_MFMA_F64_4X4X4F64_gfx940_vcd, Convert__RegByHwMode_VReg_64_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_64_f641_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX90APlus_isGFX940Plus, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_64_f64, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41865 /* v_mfma_i32_16x16x32i8 */, AMDGPU::V_MFMA_I32_16X16X32I8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41865 /* v_mfma_i32_16x16x32i8 */, AMDGPU::V_MFMA_I32_16X16X32I8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41912 /* v_mfma_i32_16x16x4i8 */, AMDGPU::V_MFMA_I32_16X16X4I8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41912 /* v_mfma_i32_16x16x4i8 */, AMDGPU::V_MFMA_I32_16X16X4I8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41956 /* v_mfma_i32_16x16x64i8 */, AMDGPU::V_MFMA_I32_16X16X64_I8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 41956 /* v_mfma_i32_16x16x64i8 */, AMDGPU::V_MFMA_I32_16X16X64_I8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_128_f321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_128_f32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42001 /* v_mfma_i32_32x32x16i8 */, AMDGPU::V_MFMA_I32_32X32X16I8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42001 /* v_mfma_i32_32x32x16i8 */, AMDGPU::V_MFMA_I32_32X32X16I8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_64_AlignTarget1_1__RegByHwMode_AV_64_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_isGFX940Plus, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_RegByHwMode_AV_64_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42046 /* v_mfma_i32_32x32x32i8 */, AMDGPU::V_MFMA_I32_32X32X32_I8_gfx940_acd, Convert__RegByHwMode_AReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__AISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_AReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_AISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42046 /* v_mfma_i32_32x32x32i8 */, AMDGPU::V_MFMA_I32_32X32X32_I8_gfx940_vcd, Convert__RegByHwMode_VReg_512_AlignTarget1_0__RegByHwMode_AV_128_AlignTarget1_1__RegByHwMode_AV_128_AlignTarget1_2__VISrc_512_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasGFX950Insts, { MCK_RegByHwMode_VReg_512_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_RegByHwMode_AV_128_AlignTarget, MCK_VISrc_512_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42093 /* v_mfma_i32_32x32x4i8 */, AMDGPU::V_MFMA_I32_32X32X4I8_gfx940_acd, Convert__RegByHwMode_AReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42093 /* v_mfma_i32_32x32x4i8 */, AMDGPU::V_MFMA_I32_32X32X4I8_gfx940_vcd, Convert__RegByHwMode_VReg_1024_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_1024_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_1024_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_1024_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42159 /* v_mfma_i32_4x4x4i8 */, AMDGPU::V_MFMA_I32_4X4X4I8_gfx940_acd, Convert__RegByHwMode_AReg_128_AlignTarget1_0__Reg1_1__Reg1_2__AISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_AReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_AISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42159 /* v_mfma_i32_4x4x4i8 */, AMDGPU::V_MFMA_I32_4X4X4I8_gfx940_vcd, Convert__RegByHwMode_VReg_128_AlignTarget1_0__Reg1_1__Reg1_2__VISrc_128_b321_3__CBSZ1_4__ABID1_5__BLGP1_6, AMFBS_HasMAIInsts_isGFX940Plus, { MCK_RegByHwMode_VReg_128_AlignTarget, MCK_AV_32, MCK_AV_32, MCK_VISrc_128_b32, MCK_CBSZ, MCK_ABID, MCK_BLGP }, },
  { 42265 /* v_min3_f16 */, AMDGPU::V_MIN3_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42265 /* v_min3_f16 */, AMDGPU::V_MIN3_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42265 /* v_min3_f16 */, AMDGPU::V_MIN3_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42265 /* v_min3_f16 */, AMDGPU::V_MIN3_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42276 /* v_min3_f32 */, AMDGPU::V_MIN3_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42276 /* v_min3_f32 */, AMDGPU::V_MIN3_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42287 /* v_min3_i16 */, AMDGPU::V_MIN3_I16V_MIN3_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 42287 /* v_min3_i16 */, AMDGPU::V_MIN3_I16V_MIN3_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 42287 /* v_min3_i16 */, AMDGPU::V_MIN3_I16V_MIN3_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 42287 /* v_min3_i16 */, AMDGPU::V_MIN3_I16V_MIN3_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 42287 /* v_min3_i16 */, AMDGPU::V_MIN3_I16V_MIN3_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42287 /* v_min3_i16 */, AMDGPU::V_MIN3_I16V_MIN3_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42287 /* v_min3_i16 */, AMDGPU::V_MIN3_I16V_MIN3_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42287 /* v_min3_i16 */, AMDGPU::V_MIN3_I16V_MIN3_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42298 /* v_min3_i32 */, AMDGPU::V_MIN3_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 42298 /* v_min3_i32 */, AMDGPU::V_MIN3_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 42298 /* v_min3_i32 */, AMDGPU::V_MIN3_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42298 /* v_min3_i32 */, AMDGPU::V_MIN3_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42309 /* v_min3_num_f16 */, AMDGPU::V_MIN3_NUM_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42309 /* v_min3_num_f16 */, AMDGPU::V_MIN3_NUM_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42309 /* v_min3_num_f16 */, AMDGPU::V_MIN3_NUM_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42309 /* v_min3_num_f16 */, AMDGPU::V_MIN3_NUM_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42324 /* v_min3_num_f32 */, AMDGPU::V_MIN3_NUM_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42324 /* v_min3_num_f32 */, AMDGPU::V_MIN3_NUM_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42339 /* v_min3_u16 */, AMDGPU::V_MIN3_U16V_MIN3_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 42339 /* v_min3_u16 */, AMDGPU::V_MIN3_U16V_MIN3_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 42339 /* v_min3_u16 */, AMDGPU::V_MIN3_U16V_MIN3_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 42339 /* v_min3_u16 */, AMDGPU::V_MIN3_U16V_MIN3_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 42339 /* v_min3_u16 */, AMDGPU::V_MIN3_U16V_MIN3_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42339 /* v_min3_u16 */, AMDGPU::V_MIN3_U16V_MIN3_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42339 /* v_min3_u16 */, AMDGPU::V_MIN3_U16V_MIN3_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42339 /* v_min3_u16 */, AMDGPU::V_MIN3_U16V_MIN3_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42350 /* v_min3_u32 */, AMDGPU::V_MIN3_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 42350 /* v_min3_u32 */, AMDGPU::V_MIN3_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 42350 /* v_min3_u32 */, AMDGPU::V_MIN3_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42350 /* v_min3_u32 */, AMDGPU::V_MIN3_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42361 /* v_min_f16 */, AMDGPU::V_MIN_F16V_MIN_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42361 /* v_min_f16 */, AMDGPU::V_MIN_F16V_MIN_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42361 /* v_min_f16 */, AMDGPU::V_MIN_F16V_MIN_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42361 /* v_min_f16 */, AMDGPU::V_MIN_F16V_MIN_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42371 /* v_min_f32 */, AMDGPU::V_MIN_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42371 /* v_min_f32 */, AMDGPU::V_MIN_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42391 /* v_min_i16 */, AMDGPU::V_MIN_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 42391 /* v_min_i16 */, AMDGPU::V_MIN_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 42391 /* v_min_i16 */, AMDGPU::V_MIN_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 42391 /* v_min_i16 */, AMDGPU::V_MIN_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 42391 /* v_min_i16 */, AMDGPU::V_MIN_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42391 /* v_min_i16 */, AMDGPU::V_MIN_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42391 /* v_min_i16 */, AMDGPU::V_MIN_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42391 /* v_min_i16 */, AMDGPU::V_MIN_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42401 /* v_min_i32 */, AMDGPU::V_MIN_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42411 /* v_min_i64 */, AMDGPU::V_MIN_I64_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VCSrc_b64, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42438 /* v_min_num_f16 */, AMDGPU::V_MIN_NUM_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42438 /* v_min_num_f16 */, AMDGPU::V_MIN_NUM_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42438 /* v_min_num_f16 */, AMDGPU::V_MIN_NUM_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42438 /* v_min_num_f16 */, AMDGPU::V_MIN_NUM_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42452 /* v_min_num_f32 */, AMDGPU::V_MIN_NUM_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42452 /* v_min_num_f32 */, AMDGPU::V_MIN_NUM_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42466 /* v_min_num_f64 */, AMDGPU::V_MIN_NUM_F64_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP64InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42480 /* v_min_u16 */, AMDGPU::V_MIN_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 42480 /* v_min_u16 */, AMDGPU::V_MIN_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 42480 /* v_min_u16 */, AMDGPU::V_MIN_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 42480 /* v_min_u16 */, AMDGPU::V_MIN_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 42480 /* v_min_u16 */, AMDGPU::V_MIN_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42480 /* v_min_u16 */, AMDGPU::V_MIN_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42480 /* v_min_u16 */, AMDGPU::V_MIN_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42480 /* v_min_u16 */, AMDGPU::V_MIN_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42490 /* v_min_u32 */, AMDGPU::V_MIN_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42500 /* v_min_u64 */, AMDGPU::V_MIN_U64_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX1250Plus_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VCSrc_b64, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42510 /* v_minimum3_f16 */, AMDGPU::V_MINIMUM3_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasMinimum3Maximum3F16_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42510 /* v_minimum3_f16 */, AMDGPU::V_MINIMUM3_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasMinimum3Maximum3F16_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42510 /* v_minimum3_f16 */, AMDGPU::V_MINIMUM3_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasMinimum3Maximum3F16_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42510 /* v_minimum3_f16 */, AMDGPU::V_MINIMUM3_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasMinimum3Maximum3F16_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42525 /* v_minimum3_f32 */, AMDGPU::V_MINIMUM3_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasMinimum3Maximum3F32_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42525 /* v_minimum3_f32 */, AMDGPU::V_MINIMUM3_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasMinimum3Maximum3F32_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42540 /* v_minimum_f16 */, AMDGPU::V_MINIMUM_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42540 /* v_minimum_f16 */, AMDGPU::V_MINIMUM_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42540 /* v_minimum_f16 */, AMDGPU::V_MINIMUM_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42540 /* v_minimum_f16 */, AMDGPU::V_MINIMUM_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42554 /* v_minimum_f32 */, AMDGPU::V_MINIMUM_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42554 /* v_minimum_f32 */, AMDGPU::V_MINIMUM_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42568 /* v_minimum_f64 */, AMDGPU::V_MINIMUM_F64_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_HasIEEEMinimumMaximumInsts_isGFX11Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP64InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42568 /* v_minimum_f64 */, AMDGPU::V_MINIMUM_F64_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP64InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42582 /* v_minimummaximum_f16 */, AMDGPU::V_MINIMUMMAXIMUM_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42582 /* v_minimummaximum_f16 */, AMDGPU::V_MINIMUMMAXIMUM_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42582 /* v_minimummaximum_f16 */, AMDGPU::V_MINIMUMMAXIMUM_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42582 /* v_minimummaximum_f16 */, AMDGPU::V_MINIMUMMAXIMUM_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42603 /* v_minimummaximum_f32 */, AMDGPU::V_MINIMUMMAXIMUM_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42603 /* v_minimummaximum_f32 */, AMDGPU::V_MINIMUMMAXIMUM_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasIEEEMinimumMaximumInsts_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42624 /* v_minmax_f16 */, AMDGPU::V_MINMAX_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42624 /* v_minmax_f16 */, AMDGPU::V_MINMAX_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42624 /* v_minmax_f16 */, AMDGPU::V_MINMAX_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42624 /* v_minmax_f16 */, AMDGPU::V_MINMAX_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42637 /* v_minmax_f32 */, AMDGPU::V_MINMAX_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42637 /* v_minmax_f32 */, AMDGPU::V_MINMAX_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42650 /* v_minmax_i32 */, AMDGPU::V_MINMAX_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 42650 /* v_minmax_i32 */, AMDGPU::V_MINMAX_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 42650 /* v_minmax_i32 */, AMDGPU::V_MINMAX_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42650 /* v_minmax_i32 */, AMDGPU::V_MINMAX_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42663 /* v_minmax_num_f16 */, AMDGPU::V_MINMAX_NUM_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42663 /* v_minmax_num_f16 */, AMDGPU::V_MINMAX_NUM_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42663 /* v_minmax_num_f16 */, AMDGPU::V_MINMAX_NUM_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42663 /* v_minmax_num_f16 */, AMDGPU::V_MINMAX_NUM_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42680 /* v_minmax_num_f32 */, AMDGPU::V_MINMAX_NUM_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42680 /* v_minmax_num_f32 */, AMDGPU::V_MINMAX_NUM_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42697 /* v_minmax_u32 */, AMDGPU::V_MINMAX_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 42697 /* v_minmax_u32 */, AMDGPU::V_MINMAX_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 42697 /* v_minmax_u32 */, AMDGPU::V_MINMAX_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42697 /* v_minmax_u32 */, AMDGPU::V_MINMAX_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42710 /* v_mov_b16 */, AMDGPU::V_MOV_B16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 42710 /* v_mov_b16 */, AMDGPU::V_MOV_B16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 42710 /* v_mov_b16 */, AMDGPU::V_MOV_B16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42710 /* v_mov_b16 */, AMDGPU::V_MOV_B16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42720 /* v_mov_b32 */, AMDGPU::V_MOV_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42730 /* v_mov_b64 */, AMDGPU::V_MOV_B64_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX940orGFX1250_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42740 /* v_movreld_b32 */, AMDGPU::V_MOVRELD_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasMovrel_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42740 /* v_movreld_b32 */, AMDGPU::V_MOVRELD_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasMovrel_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42740 /* v_movreld_b32 */, AMDGPU::V_MOVRELD_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasMovrel_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42740 /* v_movreld_b32 */, AMDGPU::V_MOVRELD_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasMovrel_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42754 /* v_movrels_b32 */, AMDGPU::V_MOVRELS_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasMovrel_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42754 /* v_movrels_b32 */, AMDGPU::V_MOVRELS_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasMovrel_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42754 /* v_movrels_b32 */, AMDGPU::V_MOVRELS_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasMovrel_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42754 /* v_movrels_b32 */, AMDGPU::V_MOVRELS_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasMovrel_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42768 /* v_movrelsd_2_b32 */, AMDGPU::V_MOVRELSD_2_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42768 /* v_movrelsd_2_b32 */, AMDGPU::V_MOVRELSD_2_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42768 /* v_movrelsd_2_b32 */, AMDGPU::V_MOVRELSD_2_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42768 /* v_movrelsd_2_b32 */, AMDGPU::V_MOVRELSD_2_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42785 /* v_movrelsd_b32 */, AMDGPU::V_MOVRELSD_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasMovrel_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42785 /* v_movrelsd_b32 */, AMDGPU::V_MOVRELSD_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasMovrel_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 42785 /* v_movrelsd_b32 */, AMDGPU::V_MOVRELSD_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasMovrel_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42785 /* v_movrelsd_b32 */, AMDGPU::V_MOVRELSD_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasMovrel_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42833 /* v_msad_u8 */, AMDGPU::V_MSAD_U8_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 42833 /* v_msad_u8 */, AMDGPU::V_MSAD_U8_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 42833 /* v_msad_u8 */, AMDGPU::V_MSAD_U8_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42833 /* v_msad_u8 */, AMDGPU::V_MSAD_U8_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42843 /* v_mul_dx9_zero_f32 */, AMDGPU::V_MUL_DX9_ZERO_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42843 /* v_mul_dx9_zero_f32 */, AMDGPU::V_MUL_DX9_ZERO_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42843 /* v_mul_dx9_zero_f32 */, AMDGPU::V_MUL_DX9_ZERO_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42843 /* v_mul_dx9_zero_f32 */, AMDGPU::V_MUL_DX9_ZERO_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42862 /* v_mul_f16 */, AMDGPU::V_MUL_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42872 /* v_mul_f32 */, AMDGPU::V_MUL_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42882 /* v_mul_f64 */, AMDGPU::V_MUL_F64_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX12Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP64InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42892 /* v_mul_hi_i32 */, AMDGPU::V_MUL_HI_I32_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42905 /* v_mul_hi_i32_i24 */, AMDGPU::V_MUL_HI_I32_I24_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42922 /* v_mul_hi_u32 */, AMDGPU::V_MUL_HI_U32_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42935 /* v_mul_hi_u32_u24 */, AMDGPU::V_MUL_HI_U32_U24_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42952 /* v_mul_i32_i24 */, AMDGPU::V_MUL_I32_I24_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42996 /* v_mul_lo_u16 */, AMDGPU::V_MUL_LO_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 42996 /* v_mul_lo_u16 */, AMDGPU::V_MUL_LO_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 42996 /* v_mul_lo_u16 */, AMDGPU::V_MUL_LO_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 42996 /* v_mul_lo_u16 */, AMDGPU::V_MUL_LO_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 42996 /* v_mul_lo_u16 */, AMDGPU::V_MUL_LO_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42996 /* v_mul_lo_u16 */, AMDGPU::V_MUL_LO_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42996 /* v_mul_lo_u16 */, AMDGPU::V_MUL_LO_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 42996 /* v_mul_lo_u16 */, AMDGPU::V_MUL_LO_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43009 /* v_mul_lo_u32 */, AMDGPU::V_MUL_LO_U32_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43022 /* v_mul_u32_u24 */, AMDGPU::V_MUL_U32_U24_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43046 /* v_mullit_f32 */, AMDGPU::V_MULLIT_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 43046 /* v_mullit_f32 */, AMDGPU::V_MULLIT_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX6GFX7GFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 43046 /* v_mullit_f32 */, AMDGPU::V_MULLIT_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43046 /* v_mullit_f32 */, AMDGPU::V_MULLIT_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX6GFX7GFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43065 /* v_not_b16 */, AMDGPU::V_NOT_B16V_NOT_B16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43075 /* v_not_b32 */, AMDGPU::V_NOT_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43085 /* v_or3_b32 */, AMDGPU::V_OR3_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 43085 /* v_or3_b32 */, AMDGPU::V_OR3_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 43085 /* v_or3_b32 */, AMDGPU::V_OR3_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43085 /* v_or3_b32 */, AMDGPU::V_OR3_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43095 /* v_or_b16 */, AMDGPU::V_OR_B16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 43095 /* v_or_b16 */, AMDGPU::V_OR_B16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 43095 /* v_or_b16 */, AMDGPU::V_OR_B16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 43095 /* v_or_b16 */, AMDGPU::V_OR_B16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 43095 /* v_or_b16 */, AMDGPU::V_OR_B16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43095 /* v_or_b16 */, AMDGPU::V_OR_B16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43095 /* v_or_b16 */, AMDGPU::V_OR_B16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43095 /* v_or_b16 */, AMDGPU::V_OR_B16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43104 /* v_or_b32 */, AMDGPU::V_OR_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43113 /* v_pack_b32_f16 */, AMDGPU::V_PACK_B32_F16V_PACK_B32_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 43113 /* v_pack_b32_f16 */, AMDGPU::V_PACK_B32_F16V_PACK_B32_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 43113 /* v_pack_b32_f16 */, AMDGPU::V_PACK_B32_F16V_PACK_B32_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 43113 /* v_pack_b32_f16 */, AMDGPU::V_PACK_B32_F16V_PACK_B32_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 43113 /* v_pack_b32_f16 */, AMDGPU::V_PACK_B32_F16V_PACK_B32_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43113 /* v_pack_b32_f16 */, AMDGPU::V_PACK_B32_F16V_PACK_B32_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43113 /* v_pack_b32_f16 */, AMDGPU::V_PACK_B32_F16V_PACK_B32_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43113 /* v_pack_b32_f16 */, AMDGPU::V_PACK_B32_F16V_PACK_B32_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_32, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43128 /* v_perm_b32 */, AMDGPU::V_PERM_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX8Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 43128 /* v_perm_b32 */, AMDGPU::V_PERM_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX8Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 43128 /* v_perm_b32 */, AMDGPU::V_PERM_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX8Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 43128 /* v_perm_b32 */, AMDGPU::V_PERM_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX8Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44115 /* v_prng_b32 */, AMDGPU::V_PRNG_B32_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasPrngInst_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44115 /* v_prng_b32 */, AMDGPU::V_PRNG_B32_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasPrngInst_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44143 /* v_rcp_bf16 */, AMDGPU::V_RCP_BF16V_RCP_BF16_fake16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_DPP8, MCK_DppFI }, },
  { 44143 /* v_rcp_bf16 */, AMDGPU::V_RCP_BF16V_RCP_BF16_t16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 44143 /* v_rcp_bf16 */, AMDGPU::V_RCP_BF16V_RCP_BF16_fake16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44143 /* v_rcp_bf16 */, AMDGPU::V_RCP_BF16V_RCP_BF16_t16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44186 /* v_rcp_f16 */, AMDGPU::V_RCP_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44196 /* v_rcp_f32 */, AMDGPU::V_RCP_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44216 /* v_rcp_iflag_f32 */, AMDGPU::V_RCP_IFLAG_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44284 /* v_rndne_f16 */, AMDGPU::V_RNDNE_F16V_RNDNE_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44296 /* v_rndne_f32 */, AMDGPU::V_RNDNE_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44308 /* v_rndne_f64 */, AMDGPU::V_RNDNE_F64_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX7Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44320 /* v_rsq_bf16 */, AMDGPU::V_RSQ_BF16V_RSQ_BF16_fake16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_DPP8, MCK_DppFI }, },
  { 44320 /* v_rsq_bf16 */, AMDGPU::V_RSQ_BF16V_RSQ_BF16_t16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 44320 /* v_rsq_bf16 */, AMDGPU::V_RSQ_BF16V_RSQ_BF16_fake16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44320 /* v_rsq_bf16 */, AMDGPU::V_RSQ_BF16V_RSQ_BF16_t16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44363 /* v_rsq_f16 */, AMDGPU::V_RSQ_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44373 /* v_rsq_f32 */, AMDGPU::V_RSQ_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44532 /* v_sad_hi_u8 */, AMDGPU::V_SAD_HI_U8_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasSadInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 44532 /* v_sad_hi_u8 */, AMDGPU::V_SAD_HI_U8_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasSadInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 44532 /* v_sad_hi_u8 */, AMDGPU::V_SAD_HI_U8_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasSadInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44532 /* v_sad_hi_u8 */, AMDGPU::V_SAD_HI_U8_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasSadInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44544 /* v_sad_u16 */, AMDGPU::V_SAD_U16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasSadInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 44544 /* v_sad_u16 */, AMDGPU::V_SAD_U16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasSadInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 44544 /* v_sad_u16 */, AMDGPU::V_SAD_U16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasSadInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44544 /* v_sad_u16 */, AMDGPU::V_SAD_U16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasSadInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44554 /* v_sad_u32 */, AMDGPU::V_SAD_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasSadInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 44554 /* v_sad_u32 */, AMDGPU::V_SAD_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasSadInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 44554 /* v_sad_u32 */, AMDGPU::V_SAD_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasSadInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44554 /* v_sad_u32 */, AMDGPU::V_SAD_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasSadInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44564 /* v_sad_u8 */, AMDGPU::V_SAD_U8_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasSadInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 44564 /* v_sad_u8 */, AMDGPU::V_SAD_U8_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasSadInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 44564 /* v_sad_u8 */, AMDGPU::V_SAD_U8_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasSadInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44564 /* v_sad_u8 */, AMDGPU::V_SAD_U8_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasSadInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44573 /* v_sat_pk4_i4_i8 */, AMDGPU::V_SAT_PK4_I4_I8V_SAT_PK4_I4_I8_fake16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44573 /* v_sat_pk4_i4_i8 */, AMDGPU::V_SAT_PK4_I4_I8V_SAT_PK4_I4_I8_t16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16, MCK_VGPR_32, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 44573 /* v_sat_pk4_i4_i8 */, AMDGPU::V_SAT_PK4_I4_I8V_SAT_PK4_I4_I8_fake16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44573 /* v_sat_pk4_i4_i8 */, AMDGPU::V_SAT_PK4_I4_I8V_SAT_PK4_I4_I8_t16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16, MCK_VGPR_32, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44589 /* v_sat_pk4_u4_u8 */, AMDGPU::V_SAT_PK4_U4_U8V_SAT_PK4_U4_U8_fake16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44589 /* v_sat_pk4_u4_u8 */, AMDGPU::V_SAT_PK4_U4_U8V_SAT_PK4_U4_U8_t16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16, MCK_VGPR_32, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 44589 /* v_sat_pk4_u4_u8 */, AMDGPU::V_SAT_PK4_U4_U8V_SAT_PK4_U4_U8_fake16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44589 /* v_sat_pk4_u4_u8 */, AMDGPU::V_SAT_PK4_U4_U8V_SAT_PK4_U4_U8_t16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX1250Plus_isGFX125xOnly, { MCK_VGPR_16, MCK_VGPR_32, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPP8, MCK_DppFI }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX9Plus_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_32, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX9Plus_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_32, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX9Plus_isGFX11Only, { MCK_VGPR_16, MCK_VGPR_32, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44605 /* v_sat_pk_u8_i16 */, AMDGPU::V_SAT_PK_U8_I16V_SAT_PK_U8_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX9Plus_isGFX12Only, { MCK_VGPR_16, MCK_VGPR_32, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44648 /* v_sin_bf16 */, AMDGPU::V_SIN_BF16V_SIN_BF16_fake16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_DPP8, MCK_DppFI }, },
  { 44648 /* v_sin_bf16 */, AMDGPU::V_SIN_BF16V_SIN_BF16_t16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 44648 /* v_sin_bf16 */, AMDGPU::V_SIN_BF16V_SIN_BF16_fake16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44648 /* v_sin_bf16 */, AMDGPU::V_SIN_BF16V_SIN_BF16_t16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44659 /* v_sin_f16 */, AMDGPU::V_SIN_F16V_SIN_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 44669 /* v_sin_f32 */, AMDGPU::V_SIN_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45476 /* v_sqrt_bf16 */, AMDGPU::V_SQRT_BF16V_SQRT_BF16_fake16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_DPP8, MCK_DppFI }, },
  { 45476 /* v_sqrt_bf16 */, AMDGPU::V_SQRT_BF16V_SQRT_BF16_t16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 45476 /* v_sqrt_bf16 */, AMDGPU::V_SQRT_BF16V_SQRT_BF16_fake16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45476 /* v_sqrt_bf16 */, AMDGPU::V_SQRT_BF16V_SQRT_BF16_t16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45488 /* v_sqrt_f16 */, AMDGPU::V_SQRT_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45499 /* v_sqrt_f32 */, AMDGPU::V_SQRT_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_BoolReg, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_BoolReg, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_BoolReg, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45521 /* v_sub_co_ci_u32 */, AMDGPU::V_SUB_CO_CI_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_BoolReg, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45537 /* v_sub_co_u32 */, AMDGPU::V_SUB_CO_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 45537 /* v_sub_co_u32 */, AMDGPU::V_SUB_CO_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 45537 /* v_sub_co_u32 */, AMDGPU::V_SUB_CO_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45537 /* v_sub_co_u32 */, AMDGPU::V_SUB_CO_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45550 /* v_sub_f16 */, AMDGPU::V_SUB_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45560 /* v_sub_f32 */, AMDGPU::V_SUB_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45590 /* v_sub_nc_i16 */, AMDGPU::V_SUB_NC_I16V_SUB_I16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 45590 /* v_sub_nc_i16 */, AMDGPU::V_SUB_NC_I16V_SUB_I16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 45590 /* v_sub_nc_i16 */, AMDGPU::V_SUB_NC_I16V_SUB_I16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 45590 /* v_sub_nc_i16 */, AMDGPU::V_SUB_NC_I16V_SUB_I16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 45590 /* v_sub_nc_i16 */, AMDGPU::V_SUB_NC_I16V_SUB_I16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45590 /* v_sub_nc_i16 */, AMDGPU::V_SUB_NC_I16V_SUB_I16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45590 /* v_sub_nc_i16 */, AMDGPU::V_SUB_NC_I16V_SUB_I16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45590 /* v_sub_nc_i16 */, AMDGPU::V_SUB_NC_I16V_SUB_I16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45603 /* v_sub_nc_i32 */, AMDGPU::V_SUB_NC_I32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 45603 /* v_sub_nc_i32 */, AMDGPU::V_SUB_NC_I32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 45603 /* v_sub_nc_i32 */, AMDGPU::V_SUB_NC_I32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45603 /* v_sub_nc_i32 */, AMDGPU::V_SUB_NC_I32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45616 /* v_sub_nc_u16 */, AMDGPU::V_SUB_NC_U16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 45616 /* v_sub_nc_u16 */, AMDGPU::V_SUB_NC_U16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 45616 /* v_sub_nc_u16 */, AMDGPU::V_SUB_NC_U16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX10Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 45616 /* v_sub_nc_u16 */, AMDGPU::V_SUB_NC_U16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX10Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 45616 /* v_sub_nc_u16 */, AMDGPU::V_SUB_NC_U16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45616 /* v_sub_nc_u16 */, AMDGPU::V_SUB_NC_U16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45616 /* v_sub_nc_u16 */, AMDGPU::V_SUB_NC_U16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX10Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45616 /* v_sub_nc_u16 */, AMDGPU::V_SUB_NC_U16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX10Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45629 /* v_sub_nc_u32 */, AMDGPU::V_SUB_NC_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasAddNoCarryInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 45629 /* v_sub_nc_u32 */, AMDGPU::V_SUB_NC_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasAddNoCarryInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 45629 /* v_sub_nc_u32 */, AMDGPU::V_SUB_NC_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasAddNoCarryInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45629 /* v_sub_nc_u32 */, AMDGPU::V_SUB_NC_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasAddNoCarryInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45642 /* v_sub_nc_u64 */, AMDGPU::V_SUB_U64_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_HasAddSubU64Insts_isGFX125xOnly, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VCSrc_b64, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_BoolReg, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_BoolReg, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_BoolReg, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45731 /* v_subrev_co_ci_u32 */, AMDGPU::V_SUBREV_CO_CI_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_BoolReg, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45750 /* v_subrev_co_u32 */, AMDGPU::V_SUBREV_CO_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 45750 /* v_subrev_co_u32 */, AMDGPU::V_SUBREV_CO_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 45750 /* v_subrev_co_u32 */, AMDGPU::V_SUBREV_CO_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45750 /* v_subrev_co_u32 */, AMDGPU::V_SUBREV_CO_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_BoolReg, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPFake16InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45766 /* v_subrev_f16 */, AMDGPU::V_SUBREV_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_RegOrInlineImmWithFPT16InputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45779 /* v_subrev_f32 */, AMDGPU::V_SUBREV_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_RegOrInlineImmWithFP32InputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45805 /* v_subrev_nc_u32 */, AMDGPU::V_SUBREV_NC_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasAddNoCarryInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 45805 /* v_subrev_nc_u32 */, AMDGPU::V_SUBREV_NC_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasAddNoCarryInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPP8, MCK_DppFI }, },
  { 45805 /* v_subrev_nc_u32 */, AMDGPU::V_SUBREV_NC_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasAddNoCarryInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 45805 /* v_subrev_nc_u32 */, AMDGPU::V_SUBREV_NC_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasAddNoCarryInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_Clamp, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46601 /* v_tanh_bf16 */, AMDGPU::V_TANH_BF16V_TANH_BF16_fake16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_DPP8, MCK_DppFI }, },
  { 46601 /* v_tanh_bf16 */, AMDGPU::V_TANH_BF16V_TANH_BF16_t16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 46601 /* v_tanh_bf16 */, AMDGPU::V_TANH_BF16V_TANH_BF16_fake16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46601 /* v_tanh_bf16 */, AMDGPU::V_TANH_BF16V_TANH_BF16_t16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_HasBF16TransInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46613 /* v_tanh_f16 */, AMDGPU::V_TANH_F16V_TANH_F16_fake16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_HasTanhInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 46613 /* v_tanh_f16 */, AMDGPU::V_TANH_F16V_TANH_F16_t16_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_HasTanhInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 46613 /* v_tanh_f16 */, AMDGPU::V_TANH_F16V_TANH_F16_fake16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_HasTanhInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46613 /* v_tanh_f16 */, AMDGPU::V_TANH_F16V_TANH_F16_t16_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_HasTanhInsts_isGFX125xOnly, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46624 /* v_tanh_f32 */, AMDGPU::V_TANH_F32_e64_dpp8_gfx1250, ConvertCustom_cvtVOP3DPP8, AMFBS_HasTanhInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 46624 /* v_tanh_f32 */, AMDGPU::V_TANH_F32_e64_dpp_gfx1250, ConvertCustom_cvtVOP3DPP, AMFBS_HasTanhInsts_isGFX125xOnly, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseFakeTrue16Insts_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_UseRealTrue16Insts_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseFakeTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_Fake16VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX11Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46652 /* v_trunc_f16 */, AMDGPU::V_TRUNC_F16V_TRUNC_F16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_UseRealTrue16Insts_isGFX11Plus_isGFX12Only, { MCK_VGPR_16, MCK_T16VRegWithFPInputMods, MCK_OpSel, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPP8, MCK_DppFI }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46664 /* v_trunc_f32 */, AMDGPU::V_TRUNC_F32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 46676 /* v_trunc_f64 */, AMDGPU::V_TRUNC_F64_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDPALU_DPP_isGFX7Plus_isGFX12Only, { MCK_RegByHwMode_VReg_64_AlignTarget, MCK_VRegWithFPInputMods, MCK_Clamp, MCK_OModSI, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 47858 /* v_xad_u32 */, AMDGPU::V_XAD_U32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 47858 /* v_xad_u32 */, AMDGPU::V_XAD_U32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 47858 /* v_xad_u32 */, AMDGPU::V_XAD_U32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 47858 /* v_xad_u32 */, AMDGPU::V_XAD_U32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX9Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 47868 /* v_xnor_b32 */, AMDGPU::V_XNOR_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_HasDLInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 47868 /* v_xnor_b32 */, AMDGPU::V_XNOR_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_HasDLInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 47868 /* v_xnor_b32 */, AMDGPU::V_XNOR_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_HasDLInsts_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 47868 /* v_xnor_b32 */, AMDGPU::V_XNOR_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_HasDLInsts_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 47879 /* v_xor3_b32 */, AMDGPU::V_XOR3_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 47879 /* v_xor3_b32 */, AMDGPU::V_XOR3_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 47879 /* v_xor3_b32 */, AMDGPU::V_XOR3_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX10Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 47879 /* v_xor3_b32 */, AMDGPU::V_XOR3_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX10Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 47890 /* v_xor_b16 */, AMDGPU::V_XOR_B16_fake16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 47890 /* v_xor_b16 */, AMDGPU::V_XOR_B16_fake16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPP8, MCK_DppFI }, },
  { 47890 /* v_xor_b16 */, AMDGPU::V_XOR_B16_t16_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 47890 /* v_xor_b16 */, AMDGPU::V_XOR_B16_t16_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPP8, MCK_DppFI }, },
  { 47890 /* v_xor_b16 */, AMDGPU::V_XOR_B16_fake16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 47890 /* v_xor_b16 */, AMDGPU::V_XOR_B16_fake16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b16, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 47890 /* v_xor_b16 */, AMDGPU::V_XOR_B16_t16_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 47890 /* v_xor_b16 */, AMDGPU::V_XOR_B16_t16_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only_UseRealTrue16Insts, { MCK_VGPR_16, MCK_VGPR_16, MCK_VCSrcT_b16, MCK_OpSel, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_e64_dpp8_gfx11, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_e64_dpp8_gfx12, ConvertCustom_cvtVOP3DPP8, AMFBS_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPP8, MCK_DppFI }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_e64_dpp_gfx11, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX11Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
  { 47900 /* v_xor_b32 */, AMDGPU::V_XOR_B32_e64_dpp_gfx12, ConvertCustom_cvtVOP3DPP, AMFBS_isGFX11Plus_isGFX12Only, { MCK_VGPR_32, MCK_VGPR_32, MCK_VCSrc_b32, MCK_DPPCtrl, MCK_DppRowMask, MCK_DppBankMask, MCK_DppBoundCtrl, MCK_DppFI }, },
};

#include "llvm/Support/Debug.h"
#include "llvm/Support/Format.h"

unsigned AMDGPUAsmParser::
MatchInstructionImpl(const OperandVector &Operands,
                     MCInst &Inst,
                     uint64_t &ErrorInfo,
                     FeatureBitset &MissingFeatures,
                     bool matchingInlineAsm, unsigned VariantID) {
  // Eliminate obvious mismatches.
  if (Operands.size() > 27) {
    ErrorInfo = 27;
    return Match_InvalidOperand;
  }

  // Get the current feature set.
  const FeatureBitset &AvailableFeatures = getAvailableFeatures();

  // Get the instruction mnemonic, which is the first token.
  StringRef Mnemonic = ((AMDGPUOperand &)*Operands[0]).getToken();

  // Process all MnemonicAliases to remap the mnemonic.
  applyMnemonicAliases(Mnemonic, AvailableFeatures, VariantID);

  // Some state to try to produce better error messages.
  bool HadMatchOtherThanFeatures = false;
  bool HadMatchOtherThanPredicate = false;
  unsigned RetCode = Match_InvalidOperand;
  MissingFeatures.set();
  // Set ErrorInfo to the operand that mismatches if it is
  // wrong for all instances of the instruction.
  ErrorInfo = ~0ULL;
  SmallBitVector OptionalOperandsMask(26);
  // Find the appropriate table for this asm variant.
  const MatchEntry *Start, *End;
  switch (VariantID) {
  default: llvm_unreachable("invalid variant!");
  case 0: Start = std::begin(MatchTable0); End = std::end(MatchTable0); break;
  case 1: Start = std::begin(MatchTable1); End = std::end(MatchTable1); break;
  case 2: Start = std::begin(MatchTable2); End = std::end(MatchTable2); break;
  case 3: Start = std::begin(MatchTable3); End = std::end(MatchTable3); break;
  case 4: Start = std::begin(MatchTable4); End = std::end(MatchTable4); break;
  case 5: Start = std::begin(MatchTable5); End = std::end(MatchTable5); break;
  }
  // Search the table.
  auto MnemonicRange = std::equal_range(Start, End, Mnemonic, LessOpcode());

  DEBUG_WITH_TYPE("asm-matcher", dbgs() << "AsmMatcher: found " <<
  std::distance(MnemonicRange.first, MnemonicRange.second) <<
  " encodings with mnemonic '" << Mnemonic << "'\n");

  // Return a more specific error code if no mnemonics match.
  if (MnemonicRange.first == MnemonicRange.second)
    return Match_MnemonicFail;

  for (const MatchEntry *it = MnemonicRange.first, *ie = MnemonicRange.second;
       it != ie; ++it) {
    const FeatureBitset &RequiredFeatures = FeatureBitsets[it->RequiredFeaturesIdx];
    bool HasRequiredFeatures =
      (AvailableFeatures & RequiredFeatures) == RequiredFeatures;
    DEBUG_WITH_TYPE("asm-matcher", dbgs() << "Trying to match opcode "
                                          << MII.getName(it->Opcode) << "\n");
    // equal_range guarantees that instruction mnemonic matches.
    assert(Mnemonic == it->getMnemonic());
    bool OperandsValid = true;
    OptionalOperandsMask.reset(0, 26);
    for (unsigned FormalIdx = 0, ActualIdx = 1; FormalIdx != 26; ++FormalIdx) {
      auto Formal = static_cast<MatchClassKind>(it->Classes[FormalIdx]);
      DEBUG_WITH_TYPE("asm-matcher",
                      dbgs() << "  Matching formal operand class " << getMatchClassName(Formal)
                             << " against actual operand at index " << ActualIdx);
      if (ActualIdx < Operands.size())
        DEBUG_WITH_TYPE("asm-matcher", dbgs() << " (";
                        Operands[ActualIdx]->print(dbgs(), *getContext().getAsmInfo()); dbgs() << "): ");
      else
        DEBUG_WITH_TYPE("asm-matcher", dbgs() << ": ");
      if (ActualIdx >= Operands.size()) {
        DEBUG_WITH_TYPE("asm-matcher", dbgs() << "actual operand index out of range\n");
        if (Formal == InvalidMatchClass) {
          OptionalOperandsMask.set(FormalIdx, 26);
          break;
        }
        if (isSubclass(Formal, OptionalMatchClass)) {
          OptionalOperandsMask.set(FormalIdx);
          continue;
        }
        OperandsValid = false;
        ErrorInfo = ActualIdx;
        break;
      }
      MCParsedAsmOperand &Actual = *Operands[ActualIdx];
      unsigned Diag = validateOperandClass(Actual, Formal, *STI);
      if (Diag == Match_Success) {
        DEBUG_WITH_TYPE("asm-matcher",
                        dbgs() << "match success using generic matcher\n");
        ++ActualIdx;
        continue;
      }
      // If the generic handler indicates an invalid operand
      // failure, check for a special case.
      if (Diag != Match_Success) {
        unsigned TargetDiag = validateTargetOperandClass(Actual, Formal);
        if (TargetDiag == Match_Success) {
          DEBUG_WITH_TYPE("asm-matcher",
                          dbgs() << "match success using target matcher\n");
          ++ActualIdx;
          continue;
        }
        // If the target matcher returned a specific error code use
        // that, else use the one from the generic matcher.
        if (TargetDiag != Match_InvalidOperand && HasRequiredFeatures)
          Diag = TargetDiag;
      }
      // If current formal operand wasn't matched and it is optional
      // then try to match next formal operand
      if (Diag == Match_InvalidOperand && isSubclass(Formal, OptionalMatchClass)) {
        OptionalOperandsMask.set(FormalIdx);
        DEBUG_WITH_TYPE("asm-matcher", dbgs() << "ignoring optional operand\n");
        continue;
      }
      // If this operand is broken for all of the instances of this
      // mnemonic, keep track of it so we can report loc info.
      // If we already had a match that only failed due to a
      // target predicate, that diagnostic is preferred.
      if (!HadMatchOtherThanPredicate &&
          (it == MnemonicRange.first || ErrorInfo <= ActualIdx)) {
        if (HasRequiredFeatures && (ErrorInfo != ActualIdx || Diag != Match_InvalidOperand))
          RetCode = Diag;
        ErrorInfo = ActualIdx;
      }
      // Otherwise, just reject this instance of the mnemonic.
      OperandsValid = false;
      break;
    }

    if (!OperandsValid) {
      DEBUG_WITH_TYPE("asm-matcher", dbgs() << "Opcode result: multiple "
                                               "operand mismatches, ignoring "
                                               "this opcode\n");
      continue;
    }
    if (!HasRequiredFeatures) {
      HadMatchOtherThanFeatures = true;
      FeatureBitset NewMissingFeatures = RequiredFeatures & ~AvailableFeatures;
      DEBUG_WITH_TYPE("asm-matcher", dbgs() << "Missing target features:";
                      for (unsigned I = 0, E = NewMissingFeatures.size(); I != E; ++I)
                        if (NewMissingFeatures[I])
                          dbgs() << ' ' << I;
                      dbgs() << "\n");
      if (NewMissingFeatures.count() <=
          MissingFeatures.count())
        MissingFeatures = NewMissingFeatures;
      continue;
    }

    Inst.clear();

    Inst.setOpcode(it->Opcode);
    // We have a potential match but have not rendered the operands.
    // Check the target predicate to handle any context sensitive
    // constraints.
    // For example, Ties that are referenced multiple times must be
    // checked here to ensure the input is the same for each match
    // constraints. If we leave it any later the ties will have been
    // canonicalized
    unsigned MatchResult;
    if ((MatchResult = checkEarlyTargetMatchPredicate(Inst, Operands)) != Match_Success) {
      Inst.clear();
      DEBUG_WITH_TYPE(
          "asm-matcher",
          dbgs() << "Early target match predicate failed with diag code "
                 << MatchResult << "\n");
      RetCode = MatchResult;
      HadMatchOtherThanPredicate = true;
      continue;
    }

    unsigned DefaultsOffset[27] = { 0 };
    assert(OptionalOperandsMask.size() == 26);
    for (unsigned i = 0, NumDefaults = 0; i < 26; ++i) {
      DefaultsOffset[i + 1] = NumDefaults;
      NumDefaults += (OptionalOperandsMask[i] ? 1 : 0);
    }

    if (matchingInlineAsm) {
      convertToMapAndConstraints(it->ConvertFn, Operands);
      if (!checkAsmTiedOperandConstraints(*this, it->ConvertFn, Operands,
                                          DefaultsOffset, ErrorInfo))
        return Match_InvalidTiedOperand;

      return Match_Success;
    }

    // We have selected a definite instruction, convert the parsed
    // operands into the appropriate MCInst.
    convertToMCInst(it->ConvertFn, Inst, it->Opcode, Operands,
                    OptionalOperandsMask, DefaultsOffset);

    // We have a potential match. Check the target predicate to
    // handle any context sensitive constraints.
    if ((MatchResult = checkTargetMatchPredicate(Inst)) != Match_Success) {
      DEBUG_WITH_TYPE("asm-matcher",
                      dbgs() << "Target match predicate failed with diag code "
                             << MatchResult << "\n");
      Inst.clear();
      RetCode = MatchResult;
      HadMatchOtherThanPredicate = true;
      continue;
    }

    if (!checkAsmTiedOperandConstraints(*this, it->ConvertFn, Operands,
                                         DefaultsOffset, ErrorInfo))
      return Match_InvalidTiedOperand;

    DEBUG_WITH_TYPE(
        "asm-matcher",
        dbgs() << "Opcode result: complete match, selecting this opcode\n");
    return Match_Success;
  }

  // Okay, we had no match.  Try to return a useful error code.
  if (HadMatchOtherThanPredicate || !HadMatchOtherThanFeatures)
    return RetCode;

  ErrorInfo = 0;
  return Match_MissingFeature;
}

namespace {
  struct OperandMatchEntry {
    uint16_t Mnemonic;
    uint32_t OperandMask;
    uint16_t Class;
    uint16_t RequiredFeaturesIdx;

    StringRef getMnemonic() const {
      return StringRef(MnemonicTable + Mnemonic + 1,
                       MnemonicTable[Mnemonic]);
    }
  };

  // Predicate for searching for an opcode.
  struct LessOpcodeOperand {
    bool operator()(const OperandMatchEntry &LHS, StringRef RHS) {
      return LHS.getMnemonic()  < RHS;
    }
    bool operator()(StringRef LHS, const OperandMatchEntry &RHS) {
      return LHS < RHS.getMnemonic();
    }
    bool operator()(const OperandMatchEntry &LHS, const OperandMatchEntry &RHS) {
      return LHS.getMnemonic() < RHS.getMnemonic();
    }
  };
} // end anonymous namespace

static const OperandMatchEntry OperandMatchTable[291413] = {
  /* Operand List Mnemonic, Mask, Operand Class, Features */
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 0 /* buffer_atomic_add */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 0 /* buffer_atomic_add */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicFaddRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFaddNoRtnInsts_isGFX90AOnly },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 18 /* buffer_atomic_add_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 18 /* buffer_atomic_add_f32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_off, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_off, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_offen, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_offen, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_offen, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_offen, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX12Only },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 40 /* buffer_atomic_add_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 40 /* buffer_atomic_add_f64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 62 /* buffer_atomic_add_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 62 /* buffer_atomic_add_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 62 /* buffer_atomic_add_u32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 84 /* buffer_atomic_add_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 84 /* buffer_atomic_add_u64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 106 /* buffer_atomic_add_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 106 /* buffer_atomic_add_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 127 /* buffer_atomic_and */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 127 /* buffer_atomic_and */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 145 /* buffer_atomic_and_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 145 /* buffer_atomic_and_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 145 /* buffer_atomic_and_b32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 167 /* buffer_atomic_and_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 167 /* buffer_atomic_and_b64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 189 /* buffer_atomic_and_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 189 /* buffer_atomic_and_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 210 /* buffer_atomic_cmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 210 /* buffer_atomic_cmpswap */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 232 /* buffer_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 232 /* buffer_atomic_cmpswap_b32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 258 /* buffer_atomic_cmpswap_b64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 284 /* buffer_atomic_cmpswap_f32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX11Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 310 /* buffer_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 310 /* buffer_atomic_cmpswap_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 335 /* buffer_atomic_cond_sub_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Plus_isGFX12Only },
  { 335 /* buffer_atomic_cond_sub_u32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Plus_isGFX12Only },
  { 362 /* buffer_atomic_csub */, 2 /* 1 */, MCK_off, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 16 /* 4 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 2 /* 1 */, MCK_off, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 16 /* 4 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 16 /* 4 */, MCK_idxen, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 32 /* 5 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 16 /* 4 */, MCK_idxen, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 32 /* 5 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 16 /* 4 */, MCK_offen, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 32 /* 5 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 16 /* 4 */, MCK_offen, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 32 /* 5 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 16 /* 4 */, MCK_idxen, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 32 /* 5 */, MCK_offen, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 64 /* 6 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 16 /* 4 */, MCK_idxen, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 32 /* 5 */, MCK_offen, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 64 /* 6 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 362 /* buffer_atomic_csub */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 381 /* buffer_atomic_csub_u32 */, 2 /* 1 */, MCK_off, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 2 /* 1 */, MCK_off, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 16 /* 4 */, MCK_offen, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 16 /* 4 */, MCK_offen, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 32 /* 5 */, MCK_offen, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 32 /* 5 */, MCK_offen, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 381 /* buffer_atomic_csub_u32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 404 /* buffer_atomic_dec */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 404 /* buffer_atomic_dec */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 422 /* buffer_atomic_dec_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 422 /* buffer_atomic_dec_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 422 /* buffer_atomic_dec_u32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 444 /* buffer_atomic_dec_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 444 /* buffer_atomic_dec_u64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 466 /* buffer_atomic_dec_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 466 /* buffer_atomic_dec_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 487 /* buffer_atomic_fcmpswap */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX10Only },
  { 487 /* buffer_atomic_fcmpswap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 487 /* buffer_atomic_fcmpswap */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7GFX10Plus_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7GFX10_isGFX10Only },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 510 /* buffer_atomic_fcmpswap_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7GFX10_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 16 /* 4 */, MCK_addr64, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 16 /* 4 */, MCK_addr64, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 536 /* buffer_atomic_fmax */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 536 /* buffer_atomic_fmax */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 555 /* buffer_atomic_fmax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 555 /* buffer_atomic_fmax_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 16 /* 4 */, MCK_addr64, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 16 /* 4 */, MCK_addr64, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX10Only },
  { 577 /* buffer_atomic_fmin */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 577 /* buffer_atomic_fmin */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 596 /* buffer_atomic_fmin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 596 /* buffer_atomic_fmin_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 618 /* buffer_atomic_inc */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 618 /* buffer_atomic_inc */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 636 /* buffer_atomic_inc_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 636 /* buffer_atomic_inc_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 636 /* buffer_atomic_inc_u32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 658 /* buffer_atomic_inc_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 658 /* buffer_atomic_inc_u64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 680 /* buffer_atomic_inc_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 680 /* buffer_atomic_inc_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 701 /* buffer_atomic_max_f32 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 701 /* buffer_atomic_max_f32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 723 /* buffer_atomic_max_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 723 /* buffer_atomic_max_f64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 745 /* buffer_atomic_max_i32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 745 /* buffer_atomic_max_i32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 745 /* buffer_atomic_max_i32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 767 /* buffer_atomic_max_i64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 767 /* buffer_atomic_max_i64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 789 /* buffer_atomic_max_num_f32 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 789 /* buffer_atomic_max_num_f32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 815 /* buffer_atomic_max_num_f64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 841 /* buffer_atomic_max_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 841 /* buffer_atomic_max_u32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 863 /* buffer_atomic_max_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 863 /* buffer_atomic_max_u64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 885 /* buffer_atomic_min_f32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX11Only },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX90AOnly },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX940Plus },
  { 907 /* buffer_atomic_min_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 907 /* buffer_atomic_min_f64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus_isGFX8GFX9NotGFX90A },
  { 929 /* buffer_atomic_min_i32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 929 /* buffer_atomic_min_i32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 929 /* buffer_atomic_min_i32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 951 /* buffer_atomic_min_i64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 951 /* buffer_atomic_min_i64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 973 /* buffer_atomic_min_num_f32 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 973 /* buffer_atomic_min_num_f32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF32GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 999 /* buffer_atomic_min_num_f64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1025 /* buffer_atomic_min_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1025 /* buffer_atomic_min_u32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1047 /* buffer_atomic_min_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1047 /* buffer_atomic_min_u64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1069 /* buffer_atomic_or */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1069 /* buffer_atomic_or */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1086 /* buffer_atomic_or_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1086 /* buffer_atomic_or_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1086 /* buffer_atomic_or_b32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1107 /* buffer_atomic_or_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1107 /* buffer_atomic_or_b64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1128 /* buffer_atomic_or_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1128 /* buffer_atomic_or_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX12Only },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX90AOnly },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX940Plus },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1148 /* buffer_atomic_pk_add_bf16 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferPkAddBF16Inst_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_off, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_offen, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX90AOnly },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 1174 /* buffer_atomic_pk_add_f16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 32 /* 5 */, MCK_offen, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1174 /* buffer_atomic_pk_add_f16 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1199 /* buffer_atomic_smax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1199 /* buffer_atomic_smax */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1218 /* buffer_atomic_smax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1218 /* buffer_atomic_smax_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1240 /* buffer_atomic_smin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1240 /* buffer_atomic_smin */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1259 /* buffer_atomic_smin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1259 /* buffer_atomic_smin_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1281 /* buffer_atomic_sub */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1281 /* buffer_atomic_sub */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 2 /* 1 */, MCK_off, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 2 /* 1 */, MCK_off, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 16 /* 4 */, MCK_offen, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 16 /* 4 */, MCK_offen, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 32 /* 5 */, MCK_offen, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 32 /* 5 */, MCK_offen, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1299 /* buffer_atomic_sub_clamp_u32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1327 /* buffer_atomic_sub_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1327 /* buffer_atomic_sub_u32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1349 /* buffer_atomic_sub_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1349 /* buffer_atomic_sub_u64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1371 /* buffer_atomic_sub_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1371 /* buffer_atomic_sub_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1392 /* buffer_atomic_swap */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1392 /* buffer_atomic_swap */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1411 /* buffer_atomic_swap_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1411 /* buffer_atomic_swap_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1411 /* buffer_atomic_swap_b32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1434 /* buffer_atomic_swap_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1434 /* buffer_atomic_swap_b64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1457 /* buffer_atomic_swap_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1457 /* buffer_atomic_swap_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1479 /* buffer_atomic_umax */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1479 /* buffer_atomic_umax */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1498 /* buffer_atomic_umax_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1498 /* buffer_atomic_umax_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1520 /* buffer_atomic_umin */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1520 /* buffer_atomic_umin */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1539 /* buffer_atomic_umin_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1539 /* buffer_atomic_umin_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1561 /* buffer_atomic_xor */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1561 /* buffer_atomic_xor */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1579 /* buffer_atomic_xor_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1579 /* buffer_atomic_xor_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1579 /* buffer_atomic_xor_b32 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX12Only },
  { 1601 /* buffer_atomic_xor_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1601 /* buffer_atomic_xor_b64 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX11Only },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 48 /* 4, 5 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 48 /* 4, 5 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 96 /* 5, 6 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 96 /* 5, 6 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 192 /* 6, 7 */, MCK_CPol_GLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX10Only },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX6GFX7 },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX90APlus },
  { 1623 /* buffer_atomic_xor_x2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 1623 /* buffer_atomic_xor_x2 */, 192 /* 6, 7 */, MCK_CPol_NonGLC, AMFBS_isGFX8GFX9NotGFX90A },
  { 1674 /* buffer_inv */, 1 /* 0 */, MCK_CPol, AMFBS_isGFX940Plus },
  { 1698 /* buffer_load_b128 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1698 /* buffer_load_b128 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1698 /* buffer_load_b128 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1715 /* buffer_load_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1715 /* buffer_load_b32 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1731 /* buffer_load_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1731 /* buffer_load_b64 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 1747 /* buffer_load_b96 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 1747 /* buffer_load_b96 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1763 /* buffer_load_d16_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1763 /* buffer_load_d16_b16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1783 /* buffer_load_d16_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1783 /* buffer_load_d16_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1808 /* buffer_load_d16_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1808 /* buffer_load_d16_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1834 /* buffer_load_d16_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1834 /* buffer_load_d16_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1861 /* buffer_load_d16_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1889 /* buffer_load_d16_hi_b16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1912 /* buffer_load_d16_hi_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1940 /* buffer_load_d16_hi_i8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1962 /* buffer_load_d16_hi_u8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 1984 /* buffer_load_d16_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 1984 /* buffer_load_d16_i8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2003 /* buffer_load_d16_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2003 /* buffer_load_d16_u8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2022 /* buffer_load_dword */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_off, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_off, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_offen, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2022 /* buffer_load_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2022 /* buffer_load_dword */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2040 /* buffer_load_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2040 /* buffer_load_dwordx2 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_off, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_Offset, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_off, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_Offset, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_idxen, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_Offset, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_idxen, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_Offset, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_offen, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_Offset, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_offen, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_Offset, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_idxen, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_offen, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_idxen, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_offen, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2060 /* buffer_load_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2060 /* buffer_load_dwordx3 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_off, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_Offset, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_off, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_Offset, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_idxen, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_Offset, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_idxen, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_Offset, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_offen, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_Offset, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_offen, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_Offset, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_idxen, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_offen, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasGFX950Insts_isGFX90APlus },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_idxen, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_offen, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasGFX950Insts_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2080 /* buffer_load_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2080 /* buffer_load_dwordx4 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 2100 /* buffer_load_format_d16_hi_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 2100 /* buffer_load_format_d16_hi_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2100 /* buffer_load_format_d16_hi_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_off, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_off, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 32 /* 5 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2128 /* buffer_load_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 32 /* 5 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2128 /* buffer_load_format_d16_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_off, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_off, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2153 /* buffer_load_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2153 /* buffer_load_format_d16_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2179 /* buffer_load_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2179 /* buffer_load_format_d16_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 2206 /* buffer_load_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 2206 /* buffer_load_format_d16_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 2234 /* buffer_load_format_x */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_addr64, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_addr64, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_addr64, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2234 /* buffer_load_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2234 /* buffer_load_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_addr64, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_addr64, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2255 /* buffer_load_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2255 /* buffer_load_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_addr64, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_addr64, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2277 /* buffer_load_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2277 /* buffer_load_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_addr64, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_addr64, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 2300 /* buffer_load_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2300 /* buffer_load_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 2324 /* buffer_load_i16 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2324 /* buffer_load_i16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2324 /* buffer_load_i16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2340 /* buffer_load_i8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2340 /* buffer_load_i8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2355 /* buffer_load_sbyte */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_off, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_off, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_offen, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2355 /* buffer_load_sbyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2355 /* buffer_load_sbyte */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2373 /* buffer_load_sbyte_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2373 /* buffer_load_sbyte_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2373 /* buffer_load_sbyte_d16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2395 /* buffer_load_sbyte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2395 /* buffer_load_sbyte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2395 /* buffer_load_sbyte_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2420 /* buffer_load_short_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2420 /* buffer_load_short_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2420 /* buffer_load_short_d16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2442 /* buffer_load_short_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2442 /* buffer_load_short_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2442 /* buffer_load_short_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_off, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_off, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_offen, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2467 /* buffer_load_sshort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2467 /* buffer_load_sshort */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2486 /* buffer_load_u16 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2486 /* buffer_load_u16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2486 /* buffer_load_u16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2502 /* buffer_load_u8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2502 /* buffer_load_u8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2517 /* buffer_load_ubyte */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_off, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_off, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_offen, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2517 /* buffer_load_ubyte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2517 /* buffer_load_ubyte */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2535 /* buffer_load_ubyte_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2535 /* buffer_load_ubyte_d16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2535 /* buffer_load_ubyte_d16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2557 /* buffer_load_ubyte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2557 /* buffer_load_ubyte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2557 /* buffer_load_ubyte_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_off, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_off, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 56 /* 3, 4, 5 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_offen, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 112 /* 4, 5, 6 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 224 /* 5, 6, 7 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2582 /* buffer_load_ushort */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2582 /* buffer_load_ushort */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2601 /* buffer_store_b128 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2601 /* buffer_store_b128 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2601 /* buffer_store_b128 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2619 /* buffer_store_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2619 /* buffer_store_b16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2636 /* buffer_store_b32 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2636 /* buffer_store_b32 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2653 /* buffer_store_b64 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2653 /* buffer_store_b64 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2670 /* buffer_store_b8 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2670 /* buffer_store_b8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 2 /* 1 */, MCK_off, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 2 /* 1 */, MCK_off, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 8 /* 3 */, MCK_SReg_32, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX12Only },
  { 2686 /* buffer_store_b96 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX11Only },
  { 2686 /* buffer_store_b96 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX11Only },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2703 /* buffer_store_byte */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2703 /* buffer_store_byte */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 2721 /* buffer_store_byte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 2721 /* buffer_store_byte_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2721 /* buffer_store_byte_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 2746 /* buffer_store_d16_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2746 /* buffer_store_d16_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2746 /* buffer_store_d16_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2772 /* buffer_store_d16_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2772 /* buffer_store_d16_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2799 /* buffer_store_d16_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2799 /* buffer_store_d16_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX12Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2827 /* buffer_store_d16_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2856 /* buffer_store_d16_hi_b16 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2880 /* buffer_store_d16_hi_b8 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX12Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2903 /* buffer_store_d16_hi_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX11Only },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2932 /* buffer_store_dword */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2932 /* buffer_store_dword */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2951 /* buffer_store_dwordx2 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2951 /* buffer_store_dwordx2 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2972 /* buffer_store_dwordx3 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2972 /* buffer_store_dwordx3 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 2993 /* buffer_store_dwordx4 */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 2993 /* buffer_store_dwordx4 */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX90APlus },
  { 3014 /* buffer_store_format_d16_hi_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX10Only },
  { 3014 /* buffer_store_format_d16_hi_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3014 /* buffer_store_format_d16_hi_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_off, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_off, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 32 /* 5 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3043 /* buffer_store_format_d16_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 32 /* 5 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3043 /* buffer_store_format_d16_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_off, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_off, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3069 /* buffer_store_format_d16_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3069 /* buffer_store_format_d16_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3096 /* buffer_store_format_d16_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3096 /* buffer_store_format_d16_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX90APlus },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_HasFormattedMUBUFInsts_isGFX10Only },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasPackedD16VMem_isGFX8GFX9NotGFX90A },
  { 3124 /* buffer_store_format_d16_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasUnpackedD16VMem },
  { 3124 /* buffer_store_format_d16_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasUnpackedD16VMem },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_addr64, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_addr64, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3153 /* buffer_store_format_x */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3153 /* buffer_store_format_x */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_addr64, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_addr64, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3175 /* buffer_store_format_xy */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3175 /* buffer_store_format_xy */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_addr64, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_addr64, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3198 /* buffer_store_format_xyz */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3198 /* buffer_store_format_xyz */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_addr64, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_off, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX90APlus },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_addr64, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SReg_32, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX12Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX10Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX11Only },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX6GFX7 },
  { 3222 /* buffer_store_format_xyzw */, 16 /* 4 */, MCK_idxen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 32 /* 5 */, MCK_offen, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 64 /* 6 */, MCK_Offset, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3222 /* buffer_store_format_xyzw */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasFormattedMUBUFInsts_isGFX8GFX9NotGFX90A },
  { 3247 /* buffer_store_lds_dword */, 12 /* 2, 3 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX940_isGFX90APlus },
  { 3247 /* buffer_store_lds_dword */, 1 /* 0 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX940_isGFX90APlus },
  { 3247 /* buffer_store_lds_dword */, 2 /* 1 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX940_isGFX90APlus },
  { 3247 /* buffer_store_lds_dword */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX940_isGFX90APlus },
  { 3247 /* buffer_store_lds_dword */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX940_isGFX90APlus },
  { 3247 /* buffer_store_lds_dword */, 12 /* 2, 3 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX940_isGFX8GFX9NotGFX90A },
  { 3247 /* buffer_store_lds_dword */, 1 /* 0 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX940_isGFX8GFX9NotGFX90A },
  { 3247 /* buffer_store_lds_dword */, 2 /* 1 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX940_isGFX8GFX9NotGFX90A },
  { 3247 /* buffer_store_lds_dword */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX940_isGFX8GFX9NotGFX90A },
  { 3247 /* buffer_store_lds_dword */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX940_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_off, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_offen, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_off, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_off, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_offen, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX90APlus },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_offen, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_addr64, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 96 /* 5, 6 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_offen, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX10Only },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_offen, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX6GFX7 },
  { 3270 /* buffer_store_short */, 16 /* 4 */, MCK_idxen, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 32 /* 5 */, MCK_offen, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 64 /* 6 */, MCK_Offset, AMFBS_isGFX8GFX9NotGFX90A },
  { 3270 /* buffer_store_short */, 192 /* 6, 7 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 2 /* 1 */, MCK_off, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 112 /* 4, 5, 6 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 16 /* 4 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX90APlus },
  { 3289 /* buffer_store_short_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 16 /* 4 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 224 /* 5, 6, 7 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 32 /* 5 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 96 /* 5, 6 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 3289 /* buffer_store_short_d16_hi */, 16 /* 4 */, MCK_idxen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 32 /* 5 */, MCK_offen, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 448 /* 6, 7, 8 */, MCK_tfe, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 8 /* 3 */, MCK_SCSrc_b32, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 64 /* 6 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3289 /* buffer_store_short_d16_hi */, 192 /* 6, 7 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9NotGFX90A },
  { 3367 /* buffer_wbl2 */, 1 /* 0 */, MCK_CPol, AMFBS_isGFX940Plus },
  { 3379 /* cluster_load_async_to_lds_b128 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3379 /* cluster_load_async_to_lds_b128 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3379 /* cluster_load_async_to_lds_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3379 /* cluster_load_async_to_lds_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3379 /* cluster_load_async_to_lds_b128 */, 4 /* 2 */, MCK_off, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3379 /* cluster_load_async_to_lds_b128 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3379 /* cluster_load_async_to_lds_b128 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3379 /* cluster_load_async_to_lds_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3379 /* cluster_load_async_to_lds_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3410 /* cluster_load_async_to_lds_b32 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3410 /* cluster_load_async_to_lds_b32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3410 /* cluster_load_async_to_lds_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3410 /* cluster_load_async_to_lds_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3410 /* cluster_load_async_to_lds_b32 */, 4 /* 2 */, MCK_off, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3410 /* cluster_load_async_to_lds_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3410 /* cluster_load_async_to_lds_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3410 /* cluster_load_async_to_lds_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3410 /* cluster_load_async_to_lds_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3440 /* cluster_load_async_to_lds_b64 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3440 /* cluster_load_async_to_lds_b64 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3440 /* cluster_load_async_to_lds_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3440 /* cluster_load_async_to_lds_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3440 /* cluster_load_async_to_lds_b64 */, 4 /* 2 */, MCK_off, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3440 /* cluster_load_async_to_lds_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3440 /* cluster_load_async_to_lds_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3440 /* cluster_load_async_to_lds_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3440 /* cluster_load_async_to_lds_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3470 /* cluster_load_async_to_lds_b8 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3470 /* cluster_load_async_to_lds_b8 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3470 /* cluster_load_async_to_lds_b8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3470 /* cluster_load_async_to_lds_b8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3470 /* cluster_load_async_to_lds_b8 */, 4 /* 2 */, MCK_off, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3470 /* cluster_load_async_to_lds_b8 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3470 /* cluster_load_async_to_lds_b8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3470 /* cluster_load_async_to_lds_b8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3470 /* cluster_load_async_to_lds_b8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly_isWave32 },
  { 3499 /* cluster_load_b128 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3499 /* cluster_load_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3499 /* cluster_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3499 /* cluster_load_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3499 /* cluster_load_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3499 /* cluster_load_b128 */, 4 /* 2 */, MCK_off, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3499 /* cluster_load_b128 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3499 /* cluster_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3499 /* cluster_load_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3499 /* cluster_load_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3517 /* cluster_load_b32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3517 /* cluster_load_b32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3517 /* cluster_load_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3517 /* cluster_load_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3517 /* cluster_load_b32 */, 4 /* 2 */, MCK_off, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3517 /* cluster_load_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3517 /* cluster_load_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3517 /* cluster_load_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3517 /* cluster_load_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3534 /* cluster_load_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3534 /* cluster_load_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3534 /* cluster_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3534 /* cluster_load_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3534 /* cluster_load_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3534 /* cluster_load_b64 */, 4 /* 2 */, MCK_off, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3534 /* cluster_load_b64 */, 3 /* 0, 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3534 /* cluster_load_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3534 /* cluster_load_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX1250Plus_isGFX125xOnly_isWave32 },
  { 3551 /* ds_add_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasLDSFPAtomicAddF32_isGFX10Only },
  { 3551 /* ds_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasLDSFPAtomicAddF32_isGFX10Only },
  { 3551 /* ds_add_f32 */, 4 /* 2 */, MCK_Offset, AMFBS_HasLDSFPAtomicAddF32_isGFX10Only },
  { 3551 /* ds_add_f32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasLDSFPAtomicAddF32_isGFX10Only },
  { 3551 /* ds_add_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasLDSFPAtomicAddF32_isGFX11Only },
  { 3551 /* ds_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasLDSFPAtomicAddF32_isGFX11Only },
  { 3551 /* ds_add_f32 */, 4 /* 2 */, MCK_Offset, AMFBS_HasLDSFPAtomicAddF32_isGFX11Only },
  { 3551 /* ds_add_f32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasLDSFPAtomicAddF32_isGFX11Only },
  { 3551 /* ds_add_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasLDSFPAtomicAddF32_isGFX12Plus },
  { 3551 /* ds_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasLDSFPAtomicAddF32_isGFX12Plus },
  { 3551 /* ds_add_f32 */, 4 /* 2 */, MCK_Offset, AMFBS_HasLDSFPAtomicAddF32_isGFX12Plus },
  { 3551 /* ds_add_f32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasLDSFPAtomicAddF32_isGFX12Plus },
  { 3551 /* ds_add_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasLDSFPAtomicAddF32_isGFX8GFX9 },
  { 3551 /* ds_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasLDSFPAtomicAddF32_isGFX8GFX9 },
  { 3551 /* ds_add_f32 */, 4 /* 2 */, MCK_Offset, AMFBS_HasLDSFPAtomicAddF32_isGFX8GFX9 },
  { 3551 /* ds_add_f32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasLDSFPAtomicAddF32_isGFX8GFX9 },
  { 3551 /* ds_add_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasLDSFPAtomicAddF32_isGFX8GFX9 },
  { 3551 /* ds_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasLDSFPAtomicAddF32_isGFX8GFX9 },
  { 3551 /* ds_add_f32 */, 4 /* 2 */, MCK_Offset, AMFBS_HasLDSFPAtomicAddF32_isGFX8GFX9 },
  { 3551 /* ds_add_f32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasLDSFPAtomicAddF32_isGFX8GFX9 },
  { 3562 /* ds_add_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasLdsAtomicAddF64_isGFX12Plus },
  { 3562 /* ds_add_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasLdsAtomicAddF64_isGFX12Plus },
  { 3562 /* ds_add_f64 */, 4 /* 2 */, MCK_Offset, AMFBS_HasLdsAtomicAddF64_isGFX12Plus },
  { 3562 /* ds_add_f64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasLdsAtomicAddF64_isGFX12Plus },
  { 3562 /* ds_add_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasLdsAtomicAddF64_isGFX8GFX9 },
  { 3562 /* ds_add_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasLdsAtomicAddF64_isGFX8GFX9 },
  { 3562 /* ds_add_f64 */, 4 /* 2 */, MCK_Offset, AMFBS_HasLdsAtomicAddF64_isGFX8GFX9 },
  { 3562 /* ds_add_f64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasLdsAtomicAddF64_isGFX8GFX9 },
  { 3573 /* ds_add_gs_reg_rtn */, 12 /* 2, 3 */, MCK_gds, AMFBS_isGFX11Only },
  { 3573 /* ds_add_gs_reg_rtn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 3573 /* ds_add_gs_reg_rtn */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 3573 /* ds_add_gs_reg_rtn */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 3591 /* ds_add_rtn_f32 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasLDSFPAtomicAddF32_isGFX90APlus },
  { 3591 /* ds_add_rtn_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasLDSFPAtomicAddF32_isGFX90APlus },
  { 3591 /* ds_add_rtn_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_HasLDSFPAtomicAddF32_isGFX90APlus },
  { 3591 /* ds_add_rtn_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_HasLDSFPAtomicAddF32_isGFX90APlus },
  { 3591 /* ds_add_rtn_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasLDSFPAtomicAddF32_isGFX10Only },
  { 3591 /* ds_add_rtn_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_HasLDSFPAtomicAddF32_isGFX10Only },
  { 3591 /* ds_add_rtn_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_HasLDSFPAtomicAddF32_isGFX10Only },
  { 3591 /* ds_add_rtn_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasLDSFPAtomicAddF32_isGFX11Only },
  { 3591 /* ds_add_rtn_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_HasLDSFPAtomicAddF32_isGFX11Only },
  { 3591 /* ds_add_rtn_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_HasLDSFPAtomicAddF32_isGFX11Only },
  { 3591 /* ds_add_rtn_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasLDSFPAtomicAddF32_isGFX12Plus },
  { 3591 /* ds_add_rtn_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_HasLDSFPAtomicAddF32_isGFX12Plus },
  { 3591 /* ds_add_rtn_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_HasLDSFPAtomicAddF32_isGFX12Plus },
  { 3591 /* ds_add_rtn_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasLDSFPAtomicAddF32_isGFX8GFX9 },
  { 3591 /* ds_add_rtn_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_HasLDSFPAtomicAddF32_isGFX8GFX9 },
  { 3591 /* ds_add_rtn_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_HasLDSFPAtomicAddF32_isGFX8GFX9 },
  { 3591 /* ds_add_rtn_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasLDSFPAtomicAddF32_isGFX8GFX9 },
  { 3591 /* ds_add_rtn_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_HasLDSFPAtomicAddF32_isGFX8GFX9 },
  { 3591 /* ds_add_rtn_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_HasLDSFPAtomicAddF32_isGFX8GFX9 },
  { 3606 /* ds_add_rtn_f64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_HasLdsAtomicAddF64_isGFX90APlus },
  { 3606 /* ds_add_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasLdsAtomicAddF64_isGFX90APlus },
  { 3606 /* ds_add_rtn_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_HasLdsAtomicAddF64_isGFX90APlus },
  { 3606 /* ds_add_rtn_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_HasLdsAtomicAddF64_isGFX90APlus },
  { 3606 /* ds_add_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasLdsAtomicAddF64_isGFX12Plus },
  { 3606 /* ds_add_rtn_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasLdsAtomicAddF64_isGFX12Plus },
  { 3606 /* ds_add_rtn_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_HasLdsAtomicAddF64_isGFX12Plus },
  { 3606 /* ds_add_rtn_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_HasLdsAtomicAddF64_isGFX12Plus },
  { 3606 /* ds_add_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasLdsAtomicAddF64_isGFX8GFX9 },
  { 3606 /* ds_add_rtn_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasLdsAtomicAddF64_isGFX8GFX9 },
  { 3606 /* ds_add_rtn_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_HasLdsAtomicAddF64_isGFX8GFX9 },
  { 3606 /* ds_add_rtn_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_HasLdsAtomicAddF64_isGFX8GFX9 },
  { 3621 /* ds_add_rtn_u32 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 3621 /* ds_add_rtn_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 3621 /* ds_add_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 3621 /* ds_add_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 3621 /* ds_add_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 3621 /* ds_add_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 3621 /* ds_add_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 3621 /* ds_add_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 3621 /* ds_add_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 3621 /* ds_add_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 3621 /* ds_add_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 3621 /* ds_add_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 3621 /* ds_add_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 3621 /* ds_add_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 3621 /* ds_add_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 3621 /* ds_add_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 3621 /* ds_add_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 3621 /* ds_add_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 3621 /* ds_add_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 3621 /* ds_add_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 3621 /* ds_add_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 3621 /* ds_add_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 3636 /* ds_add_rtn_u64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 3636 /* ds_add_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 3636 /* ds_add_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 3636 /* ds_add_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 3636 /* ds_add_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 3636 /* ds_add_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 3636 /* ds_add_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 3636 /* ds_add_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 3636 /* ds_add_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 3636 /* ds_add_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 3636 /* ds_add_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 3636 /* ds_add_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 3636 /* ds_add_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 3636 /* ds_add_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 3636 /* ds_add_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 3636 /* ds_add_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 3636 /* ds_add_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 3636 /* ds_add_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 3636 /* ds_add_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 3636 /* ds_add_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 3636 /* ds_add_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 3636 /* ds_add_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 3636 /* ds_add_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 3636 /* ds_add_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 3636 /* ds_add_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 3636 /* ds_add_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 3636 /* ds_add_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 3636 /* ds_add_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 3651 /* ds_add_src2_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_HasLDSFPAtomicAddF32_isGFX10Only },
  { 3651 /* ds_add_src2_f32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_HasLDSFPAtomicAddF32_isGFX10Only },
  { 3651 /* ds_add_src2_f32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_HasLDSFPAtomicAddF32_isGFX10Only },
  { 3651 /* ds_add_src2_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_HasLDSFPAtomicAddF32_isGFX8GFX9 },
  { 3651 /* ds_add_src2_f32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_HasLDSFPAtomicAddF32_isGFX8GFX9 },
  { 3651 /* ds_add_src2_f32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_HasLDSFPAtomicAddF32_isGFX8GFX9 },
  { 3667 /* ds_add_src2_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 3667 /* ds_add_src2_u32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 3667 /* ds_add_src2_u32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 3667 /* ds_add_src2_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 3667 /* ds_add_src2_u32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 3667 /* ds_add_src2_u32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 3667 /* ds_add_src2_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 3667 /* ds_add_src2_u32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 3667 /* ds_add_src2_u32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 3683 /* ds_add_src2_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 3683 /* ds_add_src2_u64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 3683 /* ds_add_src2_u64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 3683 /* ds_add_src2_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 3683 /* ds_add_src2_u64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 3683 /* ds_add_src2_u64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 3683 /* ds_add_src2_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 3683 /* ds_add_src2_u64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 3683 /* ds_add_src2_u64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 3699 /* ds_add_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 3699 /* ds_add_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 3699 /* ds_add_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 3699 /* ds_add_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 3699 /* ds_add_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 3699 /* ds_add_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 3699 /* ds_add_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 3699 /* ds_add_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 3699 /* ds_add_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 3699 /* ds_add_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 3699 /* ds_add_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 3699 /* ds_add_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 3699 /* ds_add_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 3699 /* ds_add_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 3699 /* ds_add_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 3699 /* ds_add_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 3699 /* ds_add_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 3699 /* ds_add_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 3699 /* ds_add_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 3699 /* ds_add_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 3699 /* ds_add_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 3699 /* ds_add_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 3699 /* ds_add_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 3699 /* ds_add_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 3710 /* ds_add_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 3710 /* ds_add_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 3710 /* ds_add_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 3710 /* ds_add_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 3710 /* ds_add_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 3710 /* ds_add_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 3710 /* ds_add_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 3710 /* ds_add_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 3710 /* ds_add_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 3710 /* ds_add_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Plus },
  { 3710 /* ds_add_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 3710 /* ds_add_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 3710 /* ds_add_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 3710 /* ds_add_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 3710 /* ds_add_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 3710 /* ds_add_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 3710 /* ds_add_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 3710 /* ds_add_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 3710 /* ds_add_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 3710 /* ds_add_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 3710 /* ds_add_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 3710 /* ds_add_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 3710 /* ds_add_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 3710 /* ds_add_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 3721 /* ds_and_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 3721 /* ds_and_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 3721 /* ds_and_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 3721 /* ds_and_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 3721 /* ds_and_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 3721 /* ds_and_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 3721 /* ds_and_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 3721 /* ds_and_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 3721 /* ds_and_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 3721 /* ds_and_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 3721 /* ds_and_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 3721 /* ds_and_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 3721 /* ds_and_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 3721 /* ds_and_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 3721 /* ds_and_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 3721 /* ds_and_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 3721 /* ds_and_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 3721 /* ds_and_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 3721 /* ds_and_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 3721 /* ds_and_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 3721 /* ds_and_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 3721 /* ds_and_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 3721 /* ds_and_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 3721 /* ds_and_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 3732 /* ds_and_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 3732 /* ds_and_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 3732 /* ds_and_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 3732 /* ds_and_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 3732 /* ds_and_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 3732 /* ds_and_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 3732 /* ds_and_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 3732 /* ds_and_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 3732 /* ds_and_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 3732 /* ds_and_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Plus },
  { 3732 /* ds_and_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 3732 /* ds_and_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 3732 /* ds_and_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 3732 /* ds_and_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 3732 /* ds_and_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 3732 /* ds_and_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 3732 /* ds_and_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 3732 /* ds_and_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 3732 /* ds_and_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 3732 /* ds_and_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 3732 /* ds_and_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 3732 /* ds_and_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 3732 /* ds_and_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 3732 /* ds_and_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 3743 /* ds_and_rtn_b32 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 3743 /* ds_and_rtn_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 3743 /* ds_and_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 3743 /* ds_and_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 3743 /* ds_and_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 3743 /* ds_and_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 3743 /* ds_and_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 3743 /* ds_and_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 3743 /* ds_and_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 3743 /* ds_and_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 3743 /* ds_and_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 3743 /* ds_and_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 3743 /* ds_and_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 3743 /* ds_and_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 3743 /* ds_and_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 3743 /* ds_and_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 3743 /* ds_and_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 3743 /* ds_and_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 3743 /* ds_and_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 3743 /* ds_and_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 3743 /* ds_and_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 3743 /* ds_and_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 3758 /* ds_and_rtn_b64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 3758 /* ds_and_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 3758 /* ds_and_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 3758 /* ds_and_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 3758 /* ds_and_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 3758 /* ds_and_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 3758 /* ds_and_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 3758 /* ds_and_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 3758 /* ds_and_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 3758 /* ds_and_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 3758 /* ds_and_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 3758 /* ds_and_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 3758 /* ds_and_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 3758 /* ds_and_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 3758 /* ds_and_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 3758 /* ds_and_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 3758 /* ds_and_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 3758 /* ds_and_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 3758 /* ds_and_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 3758 /* ds_and_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 3758 /* ds_and_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 3758 /* ds_and_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 3758 /* ds_and_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 3758 /* ds_and_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 3758 /* ds_and_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 3758 /* ds_and_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 3758 /* ds_and_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 3758 /* ds_and_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 3773 /* ds_and_src2_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 3773 /* ds_and_src2_b32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 3773 /* ds_and_src2_b32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 3773 /* ds_and_src2_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 3773 /* ds_and_src2_b32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 3773 /* ds_and_src2_b32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 3773 /* ds_and_src2_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 3773 /* ds_and_src2_b32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 3773 /* ds_and_src2_b32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 3789 /* ds_and_src2_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 3789 /* ds_and_src2_b64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 3789 /* ds_and_src2_b64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 3789 /* ds_and_src2_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 3789 /* ds_and_src2_b64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 3789 /* ds_and_src2_b64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 3789 /* ds_and_src2_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 3789 /* ds_and_src2_b64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 3789 /* ds_and_src2_b64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 3805 /* ds_append */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 3805 /* ds_append */, 2 /* 1 */, MCK_Offset, AMFBS_isGFX10Only },
  { 3805 /* ds_append */, 6 /* 1, 2 */, MCK_GDS, AMFBS_isGFX10Only },
  { 3805 /* ds_append */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 3805 /* ds_append */, 2 /* 1 */, MCK_Offset, AMFBS_isGFX11Only },
  { 3805 /* ds_append */, 6 /* 1, 2 */, MCK_GDS, AMFBS_isGFX11Only },
  { 3805 /* ds_append */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 3805 /* ds_append */, 2 /* 1 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 3805 /* ds_append */, 6 /* 1, 2 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 3805 /* ds_append */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 3805 /* ds_append */, 2 /* 1 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 3805 /* ds_append */, 6 /* 1, 2 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 3805 /* ds_append */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 3805 /* ds_append */, 2 /* 1 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 3805 /* ds_append */, 6 /* 1, 2 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 3815 /* ds_atomic_async_barrier_arrive_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasLdsBarrierArriveAtomic_isGFX1250Plus },
  { 3815 /* ds_atomic_async_barrier_arrive_b64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasLdsBarrierArriveAtomic_isGFX1250Plus },
  { 3815 /* ds_atomic_async_barrier_arrive_b64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasLdsBarrierArriveAtomic_isGFX1250Plus },
  { 3850 /* ds_atomic_barrier_arrive_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasLdsBarrierArriveAtomic_isGFX1250Plus },
  { 3850 /* ds_atomic_barrier_arrive_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasLdsBarrierArriveAtomic_isGFX1250Plus },
  { 3850 /* ds_atomic_barrier_arrive_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_HasLdsBarrierArriveAtomic_isGFX1250Plus },
  { 3850 /* ds_atomic_barrier_arrive_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_HasLdsBarrierArriveAtomic_isGFX1250Plus },
  { 3883 /* ds_bpermute_b32 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX8Plus_isGFX90APlus },
  { 3883 /* ds_bpermute_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8Plus_isGFX90APlus },
  { 3883 /* ds_bpermute_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8Plus_isGFX90APlus },
  { 3883 /* ds_bpermute_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8Plus_isGFX10Only },
  { 3883 /* ds_bpermute_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8Plus_isGFX10Only },
  { 3883 /* ds_bpermute_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8Plus_isGFX11Only },
  { 3883 /* ds_bpermute_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8Plus_isGFX11Only },
  { 3883 /* ds_bpermute_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8Plus_isGFX12Plus },
  { 3883 /* ds_bpermute_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8Plus_isGFX12Plus },
  { 3883 /* ds_bpermute_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8Plus_isGFX8GFX9 },
  { 3883 /* ds_bpermute_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8Plus_isGFX8GFX9 },
  { 3899 /* ds_bpermute_fi_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 3899 /* ds_bpermute_fi_b32 */, 5 /* 0, 2 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 3899 /* ds_bpermute_fi_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 3918 /* ds_bvh_stack_push4_pop1_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Plus_isGFX12Plus },
  { 3918 /* ds_bvh_stack_push4_pop1_rtn_b32 */, 8 /* 3 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Plus_isGFX12Plus },
  { 3918 /* ds_bvh_stack_push4_pop1_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasImageInsts_isGFX11Plus_isGFX12Plus },
  { 3950 /* ds_bvh_stack_push8_pop1_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 3950 /* ds_bvh_stack_push8_pop1_rtn_b32 */, 8 /* 3 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 3950 /* ds_bvh_stack_push8_pop1_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasImageInsts_isGFX12Plus },
  { 3982 /* ds_bvh_stack_push8_pop2_rtn_b64 */, 6 /* 1, 2 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 3982 /* ds_bvh_stack_push8_pop2_rtn_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 3982 /* ds_bvh_stack_push8_pop2_rtn_b64 */, 8 /* 3 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 3982 /* ds_bvh_stack_push8_pop2_rtn_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_HasImageInsts_isGFX12Plus },
  { 4014 /* ds_bvh_stack_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Plus_isGFX11Only },
  { 4014 /* ds_bvh_stack_rtn_b32 */, 8 /* 3 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Plus_isGFX11Only },
  { 4014 /* ds_bvh_stack_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_HasImageInsts_isGFX11Plus_isGFX11Only },
  { 4035 /* ds_cmpst_b32 */, 6 /* 1, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 4035 /* ds_cmpst_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 4035 /* ds_cmpst_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 4035 /* ds_cmpst_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 4035 /* ds_cmpst_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 4035 /* ds_cmpst_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 4035 /* ds_cmpst_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 4035 /* ds_cmpst_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 4035 /* ds_cmpst_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 4035 /* ds_cmpst_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 4035 /* ds_cmpst_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4035 /* ds_cmpst_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4035 /* ds_cmpst_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4035 /* ds_cmpst_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4035 /* ds_cmpst_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4035 /* ds_cmpst_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4048 /* ds_cmpst_b64 */, 6 /* 1, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 4048 /* ds_cmpst_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 4048 /* ds_cmpst_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 4048 /* ds_cmpst_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 4048 /* ds_cmpst_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 4048 /* ds_cmpst_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 4048 /* ds_cmpst_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 4048 /* ds_cmpst_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 4048 /* ds_cmpst_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 4048 /* ds_cmpst_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 4048 /* ds_cmpst_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 4048 /* ds_cmpst_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 4048 /* ds_cmpst_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4048 /* ds_cmpst_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 4048 /* ds_cmpst_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4048 /* ds_cmpst_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4048 /* ds_cmpst_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4048 /* ds_cmpst_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 4048 /* ds_cmpst_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4048 /* ds_cmpst_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4061 /* ds_cmpst_f32 */, 6 /* 1, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 4061 /* ds_cmpst_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 4061 /* ds_cmpst_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 4061 /* ds_cmpst_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 4061 /* ds_cmpst_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 4061 /* ds_cmpst_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 4061 /* ds_cmpst_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 4061 /* ds_cmpst_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 4061 /* ds_cmpst_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 4061 /* ds_cmpst_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 4061 /* ds_cmpst_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4061 /* ds_cmpst_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4061 /* ds_cmpst_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4061 /* ds_cmpst_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4061 /* ds_cmpst_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4061 /* ds_cmpst_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4074 /* ds_cmpst_f64 */, 6 /* 1, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 4074 /* ds_cmpst_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 4074 /* ds_cmpst_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 4074 /* ds_cmpst_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 4074 /* ds_cmpst_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 4074 /* ds_cmpst_f64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 4074 /* ds_cmpst_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 4074 /* ds_cmpst_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 4074 /* ds_cmpst_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 4074 /* ds_cmpst_f64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 4074 /* ds_cmpst_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 4074 /* ds_cmpst_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 4074 /* ds_cmpst_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4074 /* ds_cmpst_f64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 4074 /* ds_cmpst_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4074 /* ds_cmpst_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4074 /* ds_cmpst_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4074 /* ds_cmpst_f64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 4074 /* ds_cmpst_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4074 /* ds_cmpst_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4087 /* ds_cmpst_rtn_b32 */, 13 /* 0, 2, 3 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 4087 /* ds_cmpst_rtn_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 4087 /* ds_cmpst_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 4087 /* ds_cmpst_rtn_b32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 4087 /* ds_cmpst_rtn_b32 */, 15 /* 0, 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 4087 /* ds_cmpst_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 4087 /* ds_cmpst_rtn_b32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX10Only },
  { 4087 /* ds_cmpst_rtn_b32 */, 15 /* 0, 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 4087 /* ds_cmpst_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 4087 /* ds_cmpst_rtn_b32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 4087 /* ds_cmpst_rtn_b32 */, 15 /* 0, 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4087 /* ds_cmpst_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4087 /* ds_cmpst_rtn_b32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4087 /* ds_cmpst_rtn_b32 */, 15 /* 0, 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4087 /* ds_cmpst_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4087 /* ds_cmpst_rtn_b32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4104 /* ds_cmpst_rtn_b64 */, 13 /* 0, 2, 3 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 4104 /* ds_cmpst_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 4104 /* ds_cmpst_rtn_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 4104 /* ds_cmpst_rtn_b64 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 4104 /* ds_cmpst_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 4104 /* ds_cmpst_rtn_b64 */, 13 /* 0, 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 4104 /* ds_cmpst_rtn_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 4104 /* ds_cmpst_rtn_b64 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX10Only },
  { 4104 /* ds_cmpst_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 4104 /* ds_cmpst_rtn_b64 */, 13 /* 0, 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 4104 /* ds_cmpst_rtn_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 4104 /* ds_cmpst_rtn_b64 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 4104 /* ds_cmpst_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4104 /* ds_cmpst_rtn_b64 */, 13 /* 0, 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 4104 /* ds_cmpst_rtn_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4104 /* ds_cmpst_rtn_b64 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4104 /* ds_cmpst_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4104 /* ds_cmpst_rtn_b64 */, 13 /* 0, 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 4104 /* ds_cmpst_rtn_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4104 /* ds_cmpst_rtn_b64 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4121 /* ds_cmpst_rtn_f32 */, 13 /* 0, 2, 3 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 4121 /* ds_cmpst_rtn_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 4121 /* ds_cmpst_rtn_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 4121 /* ds_cmpst_rtn_f32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 4121 /* ds_cmpst_rtn_f32 */, 15 /* 0, 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 4121 /* ds_cmpst_rtn_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 4121 /* ds_cmpst_rtn_f32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX10Only },
  { 4121 /* ds_cmpst_rtn_f32 */, 15 /* 0, 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 4121 /* ds_cmpst_rtn_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 4121 /* ds_cmpst_rtn_f32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 4121 /* ds_cmpst_rtn_f32 */, 15 /* 0, 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4121 /* ds_cmpst_rtn_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4121 /* ds_cmpst_rtn_f32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4121 /* ds_cmpst_rtn_f32 */, 15 /* 0, 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4121 /* ds_cmpst_rtn_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4121 /* ds_cmpst_rtn_f32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4138 /* ds_cmpst_rtn_f64 */, 13 /* 0, 2, 3 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 4138 /* ds_cmpst_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 4138 /* ds_cmpst_rtn_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 4138 /* ds_cmpst_rtn_f64 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 4138 /* ds_cmpst_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 4138 /* ds_cmpst_rtn_f64 */, 13 /* 0, 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 4138 /* ds_cmpst_rtn_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 4138 /* ds_cmpst_rtn_f64 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX10Only },
  { 4138 /* ds_cmpst_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 4138 /* ds_cmpst_rtn_f64 */, 13 /* 0, 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 4138 /* ds_cmpst_rtn_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 4138 /* ds_cmpst_rtn_f64 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 4138 /* ds_cmpst_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4138 /* ds_cmpst_rtn_f64 */, 13 /* 0, 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 4138 /* ds_cmpst_rtn_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4138 /* ds_cmpst_rtn_f64 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4138 /* ds_cmpst_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4138 /* ds_cmpst_rtn_f64 */, 13 /* 0, 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 4138 /* ds_cmpst_rtn_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4138 /* ds_cmpst_rtn_f64 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4155 /* ds_cmpstore_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4155 /* ds_cmpstore_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4155 /* ds_cmpstore_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4155 /* ds_cmpstore_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4155 /* ds_cmpstore_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 4155 /* ds_cmpstore_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4171 /* ds_cmpstore_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4171 /* ds_cmpstore_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 4171 /* ds_cmpstore_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4171 /* ds_cmpstore_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4171 /* ds_cmpstore_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4171 /* ds_cmpstore_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 4171 /* ds_cmpstore_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 4171 /* ds_cmpstore_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4187 /* ds_cmpstore_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4187 /* ds_cmpstore_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4187 /* ds_cmpstore_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4203 /* ds_cmpstore_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4203 /* ds_cmpstore_f64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 4203 /* ds_cmpstore_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4203 /* ds_cmpstore_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4219 /* ds_cmpstore_rtn_b32 */, 15 /* 0, 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4219 /* ds_cmpstore_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4219 /* ds_cmpstore_rtn_b32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4219 /* ds_cmpstore_rtn_b32 */, 15 /* 0, 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4219 /* ds_cmpstore_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 4219 /* ds_cmpstore_rtn_b32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4239 /* ds_cmpstore_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4239 /* ds_cmpstore_rtn_b64 */, 13 /* 0, 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 4239 /* ds_cmpstore_rtn_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4239 /* ds_cmpstore_rtn_b64 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4239 /* ds_cmpstore_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4239 /* ds_cmpstore_rtn_b64 */, 13 /* 0, 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 4239 /* ds_cmpstore_rtn_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 4239 /* ds_cmpstore_rtn_b64 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4259 /* ds_cmpstore_rtn_f32 */, 15 /* 0, 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4259 /* ds_cmpstore_rtn_f32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4259 /* ds_cmpstore_rtn_f32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4279 /* ds_cmpstore_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4279 /* ds_cmpstore_rtn_f64 */, 13 /* 0, 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 4279 /* ds_cmpstore_rtn_f64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4279 /* ds_cmpstore_rtn_f64 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4299 /* ds_cond_sub_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4299 /* ds_cond_sub_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 4299 /* ds_cond_sub_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4319 /* ds_cond_sub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4319 /* ds_cond_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 4319 /* ds_cond_sub_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 4319 /* ds_cond_sub_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4335 /* ds_condxchg32_rtn_b64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX7Plus_isGFX90APlus },
  { 4335 /* ds_condxchg32_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX90APlus },
  { 4335 /* ds_condxchg32_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX90APlus },
  { 4335 /* ds_condxchg32_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX90APlus },
  { 4335 /* ds_condxchg32_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX10Only },
  { 4335 /* ds_condxchg32_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7Plus_isGFX10Only },
  { 4335 /* ds_condxchg32_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX10Only },
  { 4335 /* ds_condxchg32_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX10Only },
  { 4335 /* ds_condxchg32_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX11Only },
  { 4335 /* ds_condxchg32_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7Plus_isGFX11Only },
  { 4335 /* ds_condxchg32_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX11Only },
  { 4335 /* ds_condxchg32_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX11Only },
  { 4335 /* ds_condxchg32_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX12Plus },
  { 4335 /* ds_condxchg32_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7Plus_isGFX12Plus },
  { 4335 /* ds_condxchg32_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX12Plus },
  { 4335 /* ds_condxchg32_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX12Plus },
  { 4335 /* ds_condxchg32_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX7Only },
  { 4335 /* ds_condxchg32_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7Plus_isGFX7Only },
  { 4335 /* ds_condxchg32_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX7Only },
  { 4335 /* ds_condxchg32_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX7Only },
  { 4335 /* ds_condxchg32_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 4335 /* ds_condxchg32_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 4335 /* ds_condxchg32_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 4335 /* ds_condxchg32_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 4335 /* ds_condxchg32_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 4335 /* ds_condxchg32_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 4335 /* ds_condxchg32_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 4335 /* ds_condxchg32_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 4357 /* ds_consume */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 4357 /* ds_consume */, 2 /* 1 */, MCK_Offset, AMFBS_isGFX10Only },
  { 4357 /* ds_consume */, 6 /* 1, 2 */, MCK_GDS, AMFBS_isGFX10Only },
  { 4357 /* ds_consume */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 4357 /* ds_consume */, 2 /* 1 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4357 /* ds_consume */, 6 /* 1, 2 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4357 /* ds_consume */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 4357 /* ds_consume */, 2 /* 1 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 4357 /* ds_consume */, 6 /* 1, 2 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4357 /* ds_consume */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 4357 /* ds_consume */, 2 /* 1 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 4357 /* ds_consume */, 6 /* 1, 2 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 4357 /* ds_consume */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 4357 /* ds_consume */, 2 /* 1 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4357 /* ds_consume */, 6 /* 1, 2 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4368 /* ds_dec_rtn_u32 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 4368 /* ds_dec_rtn_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 4368 /* ds_dec_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 4368 /* ds_dec_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 4368 /* ds_dec_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 4368 /* ds_dec_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 4368 /* ds_dec_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 4368 /* ds_dec_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4368 /* ds_dec_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4368 /* ds_dec_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4368 /* ds_dec_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4368 /* ds_dec_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 4368 /* ds_dec_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4368 /* ds_dec_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 4368 /* ds_dec_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 4368 /* ds_dec_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 4368 /* ds_dec_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4368 /* ds_dec_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4368 /* ds_dec_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4368 /* ds_dec_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4368 /* ds_dec_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4368 /* ds_dec_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4383 /* ds_dec_rtn_u64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 4383 /* ds_dec_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 4383 /* ds_dec_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 4383 /* ds_dec_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 4383 /* ds_dec_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 4383 /* ds_dec_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 4383 /* ds_dec_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 4383 /* ds_dec_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 4383 /* ds_dec_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4383 /* ds_dec_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 4383 /* ds_dec_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4383 /* ds_dec_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4383 /* ds_dec_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4383 /* ds_dec_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 4383 /* ds_dec_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 4383 /* ds_dec_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4383 /* ds_dec_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 4383 /* ds_dec_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 4383 /* ds_dec_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 4383 /* ds_dec_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 4383 /* ds_dec_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4383 /* ds_dec_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 4383 /* ds_dec_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4383 /* ds_dec_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4383 /* ds_dec_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4383 /* ds_dec_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 4383 /* ds_dec_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4383 /* ds_dec_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4398 /* ds_dec_src2_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 4398 /* ds_dec_src2_u32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 4398 /* ds_dec_src2_u32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 4398 /* ds_dec_src2_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 4398 /* ds_dec_src2_u32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 4398 /* ds_dec_src2_u32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 4398 /* ds_dec_src2_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 4398 /* ds_dec_src2_u32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 4398 /* ds_dec_src2_u32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 4414 /* ds_dec_src2_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 4414 /* ds_dec_src2_u64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 4414 /* ds_dec_src2_u64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 4414 /* ds_dec_src2_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 4414 /* ds_dec_src2_u64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 4414 /* ds_dec_src2_u64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 4414 /* ds_dec_src2_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 4414 /* ds_dec_src2_u64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 4414 /* ds_dec_src2_u64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 4430 /* ds_dec_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 4430 /* ds_dec_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 4430 /* ds_dec_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 4430 /* ds_dec_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 4430 /* ds_dec_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4430 /* ds_dec_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 4430 /* ds_dec_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4430 /* ds_dec_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4430 /* ds_dec_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4430 /* ds_dec_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 4430 /* ds_dec_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 4430 /* ds_dec_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4430 /* ds_dec_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 4430 /* ds_dec_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 4430 /* ds_dec_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 4430 /* ds_dec_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 4430 /* ds_dec_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4430 /* ds_dec_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 4430 /* ds_dec_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4430 /* ds_dec_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4430 /* ds_dec_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4430 /* ds_dec_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 4430 /* ds_dec_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4430 /* ds_dec_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4441 /* ds_dec_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 4441 /* ds_dec_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 4441 /* ds_dec_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 4441 /* ds_dec_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 4441 /* ds_dec_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4441 /* ds_dec_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 4441 /* ds_dec_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4441 /* ds_dec_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4441 /* ds_dec_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4441 /* ds_dec_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Plus },
  { 4441 /* ds_dec_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 4441 /* ds_dec_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4441 /* ds_dec_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 4441 /* ds_dec_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 4441 /* ds_dec_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 4441 /* ds_dec_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 4441 /* ds_dec_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4441 /* ds_dec_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 4441 /* ds_dec_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4441 /* ds_dec_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4441 /* ds_dec_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4441 /* ds_dec_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 4441 /* ds_dec_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4441 /* ds_dec_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4452 /* ds_direct_load */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12PlusNot12_50_isGFX12Plus },
  { 4452 /* ds_direct_load */, 2 /* 1 */, MCK_WaitVAVDst, AMFBS_isGFX12PlusNot12_50_isGFX12Plus },
  { 4452 /* ds_direct_load */, 6 /* 1, 2 */, MCK_WaitVMVSrc, AMFBS_isGFX12PlusNot12_50_isGFX12Plus },
  { 4467 /* ds_gws_barrier */, 6 /* 1, 2 */, MCK_gds, AMFBS_isGFX10Only },
  { 4467 /* ds_gws_barrier */, 1 /* 0 */, MCK_AV_LdSt_32_Align2_RegOp, AMFBS_isGFX10Only },
  { 4467 /* ds_gws_barrier */, 2 /* 1 */, MCK_Offset, AMFBS_isGFX10Only },
  { 4467 /* ds_gws_barrier */, 6 /* 1, 2 */, MCK_gds, AMFBS_isGFX11Only },
  { 4467 /* ds_gws_barrier */, 1 /* 0 */, MCK_AV_LdSt_32_Align2_RegOp, AMFBS_isGFX11Only },
  { 4467 /* ds_gws_barrier */, 2 /* 1 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4467 /* ds_gws_barrier */, 6 /* 1, 2 */, MCK_gds, AMFBS_isGFX6GFX7 },
  { 4467 /* ds_gws_barrier */, 1 /* 0 */, MCK_AV_LdSt_32_Align2_RegOp, AMFBS_isGFX6GFX7 },
  { 4467 /* ds_gws_barrier */, 2 /* 1 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 4467 /* ds_gws_barrier */, 6 /* 1, 2 */, MCK_gds, AMFBS_isGFX8GFX9 },
  { 4467 /* ds_gws_barrier */, 1 /* 0 */, MCK_AV_LdSt_32_Align2_RegOp, AMFBS_isGFX8GFX9 },
  { 4467 /* ds_gws_barrier */, 2 /* 1 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4482 /* ds_gws_init */, 6 /* 1, 2 */, MCK_gds, AMFBS_isGFX10Only },
  { 4482 /* ds_gws_init */, 1 /* 0 */, MCK_AV_LdSt_32_Align2_RegOp, AMFBS_isGFX10Only },
  { 4482 /* ds_gws_init */, 2 /* 1 */, MCK_Offset, AMFBS_isGFX10Only },
  { 4482 /* ds_gws_init */, 6 /* 1, 2 */, MCK_gds, AMFBS_isGFX11Only },
  { 4482 /* ds_gws_init */, 1 /* 0 */, MCK_AV_LdSt_32_Align2_RegOp, AMFBS_isGFX11Only },
  { 4482 /* ds_gws_init */, 2 /* 1 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4482 /* ds_gws_init */, 6 /* 1, 2 */, MCK_gds, AMFBS_isGFX6GFX7 },
  { 4482 /* ds_gws_init */, 1 /* 0 */, MCK_AV_LdSt_32_Align2_RegOp, AMFBS_isGFX6GFX7 },
  { 4482 /* ds_gws_init */, 2 /* 1 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 4482 /* ds_gws_init */, 6 /* 1, 2 */, MCK_gds, AMFBS_isGFX8GFX9 },
  { 4482 /* ds_gws_init */, 1 /* 0 */, MCK_AV_LdSt_32_Align2_RegOp, AMFBS_isGFX8GFX9 },
  { 4482 /* ds_gws_init */, 2 /* 1 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4494 /* ds_gws_sema_br */, 6 /* 1, 2 */, MCK_gds, AMFBS_isGFX10Only },
  { 4494 /* ds_gws_sema_br */, 1 /* 0 */, MCK_AV_LdSt_32_Align2_RegOp, AMFBS_isGFX10Only },
  { 4494 /* ds_gws_sema_br */, 2 /* 1 */, MCK_Offset, AMFBS_isGFX10Only },
  { 4494 /* ds_gws_sema_br */, 6 /* 1, 2 */, MCK_gds, AMFBS_isGFX11Only },
  { 4494 /* ds_gws_sema_br */, 1 /* 0 */, MCK_AV_LdSt_32_Align2_RegOp, AMFBS_isGFX11Only },
  { 4494 /* ds_gws_sema_br */, 2 /* 1 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4494 /* ds_gws_sema_br */, 6 /* 1, 2 */, MCK_gds, AMFBS_isGFX6GFX7 },
  { 4494 /* ds_gws_sema_br */, 1 /* 0 */, MCK_AV_LdSt_32_Align2_RegOp, AMFBS_isGFX6GFX7 },
  { 4494 /* ds_gws_sema_br */, 2 /* 1 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 4494 /* ds_gws_sema_br */, 6 /* 1, 2 */, MCK_gds, AMFBS_isGFX8GFX9 },
  { 4494 /* ds_gws_sema_br */, 1 /* 0 */, MCK_AV_LdSt_32_Align2_RegOp, AMFBS_isGFX8GFX9 },
  { 4494 /* ds_gws_sema_br */, 2 /* 1 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4509 /* ds_gws_sema_p */, 3 /* 0, 1 */, MCK_gds, AMFBS_isGFX10Only },
  { 4509 /* ds_gws_sema_p */, 1 /* 0 */, MCK_Offset, AMFBS_isGFX10Only },
  { 4509 /* ds_gws_sema_p */, 3 /* 0, 1 */, MCK_gds, AMFBS_isGFX11Only },
  { 4509 /* ds_gws_sema_p */, 1 /* 0 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4509 /* ds_gws_sema_p */, 3 /* 0, 1 */, MCK_gds, AMFBS_isGFX6GFX7 },
  { 4509 /* ds_gws_sema_p */, 1 /* 0 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 4509 /* ds_gws_sema_p */, 3 /* 0, 1 */, MCK_gds, AMFBS_isGFX8GFX9 },
  { 4509 /* ds_gws_sema_p */, 1 /* 0 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4523 /* ds_gws_sema_release_all */, 3 /* 0, 1 */, MCK_gds, AMFBS_isGFX7Plus_isGFX10Only },
  { 4523 /* ds_gws_sema_release_all */, 1 /* 0 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX10Only },
  { 4523 /* ds_gws_sema_release_all */, 3 /* 0, 1 */, MCK_gds, AMFBS_isGFX7Plus_isGFX11Only },
  { 4523 /* ds_gws_sema_release_all */, 1 /* 0 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX11Only },
  { 4523 /* ds_gws_sema_release_all */, 3 /* 0, 1 */, MCK_gds, AMFBS_isGFX7Plus_isGFX7Only },
  { 4523 /* ds_gws_sema_release_all */, 1 /* 0 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX7Only },
  { 4523 /* ds_gws_sema_release_all */, 3 /* 0, 1 */, MCK_gds, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 4523 /* ds_gws_sema_release_all */, 1 /* 0 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 4547 /* ds_gws_sema_v */, 3 /* 0, 1 */, MCK_gds, AMFBS_isGFX10Only },
  { 4547 /* ds_gws_sema_v */, 1 /* 0 */, MCK_Offset, AMFBS_isGFX10Only },
  { 4547 /* ds_gws_sema_v */, 3 /* 0, 1 */, MCK_gds, AMFBS_isGFX11Only },
  { 4547 /* ds_gws_sema_v */, 1 /* 0 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4547 /* ds_gws_sema_v */, 3 /* 0, 1 */, MCK_gds, AMFBS_isGFX6GFX7 },
  { 4547 /* ds_gws_sema_v */, 1 /* 0 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 4547 /* ds_gws_sema_v */, 3 /* 0, 1 */, MCK_gds, AMFBS_isGFX8GFX9 },
  { 4547 /* ds_gws_sema_v */, 1 /* 0 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4561 /* ds_inc_rtn_u32 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 4561 /* ds_inc_rtn_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 4561 /* ds_inc_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 4561 /* ds_inc_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 4561 /* ds_inc_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 4561 /* ds_inc_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 4561 /* ds_inc_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 4561 /* ds_inc_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4561 /* ds_inc_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4561 /* ds_inc_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4561 /* ds_inc_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4561 /* ds_inc_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 4561 /* ds_inc_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4561 /* ds_inc_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 4561 /* ds_inc_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 4561 /* ds_inc_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 4561 /* ds_inc_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4561 /* ds_inc_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4561 /* ds_inc_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4561 /* ds_inc_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4561 /* ds_inc_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4561 /* ds_inc_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4576 /* ds_inc_rtn_u64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 4576 /* ds_inc_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 4576 /* ds_inc_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 4576 /* ds_inc_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 4576 /* ds_inc_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 4576 /* ds_inc_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 4576 /* ds_inc_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 4576 /* ds_inc_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 4576 /* ds_inc_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4576 /* ds_inc_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 4576 /* ds_inc_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4576 /* ds_inc_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4576 /* ds_inc_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4576 /* ds_inc_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 4576 /* ds_inc_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 4576 /* ds_inc_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4576 /* ds_inc_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 4576 /* ds_inc_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 4576 /* ds_inc_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 4576 /* ds_inc_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 4576 /* ds_inc_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4576 /* ds_inc_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 4576 /* ds_inc_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4576 /* ds_inc_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4576 /* ds_inc_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4576 /* ds_inc_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 4576 /* ds_inc_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4576 /* ds_inc_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4591 /* ds_inc_src2_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 4591 /* ds_inc_src2_u32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 4591 /* ds_inc_src2_u32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 4591 /* ds_inc_src2_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 4591 /* ds_inc_src2_u32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 4591 /* ds_inc_src2_u32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 4591 /* ds_inc_src2_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 4591 /* ds_inc_src2_u32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 4591 /* ds_inc_src2_u32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 4607 /* ds_inc_src2_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 4607 /* ds_inc_src2_u64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 4607 /* ds_inc_src2_u64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 4607 /* ds_inc_src2_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 4607 /* ds_inc_src2_u64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 4607 /* ds_inc_src2_u64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 4607 /* ds_inc_src2_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 4607 /* ds_inc_src2_u64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 4607 /* ds_inc_src2_u64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 4623 /* ds_inc_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 4623 /* ds_inc_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 4623 /* ds_inc_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 4623 /* ds_inc_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 4623 /* ds_inc_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4623 /* ds_inc_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 4623 /* ds_inc_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4623 /* ds_inc_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4623 /* ds_inc_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4623 /* ds_inc_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 4623 /* ds_inc_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 4623 /* ds_inc_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4623 /* ds_inc_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 4623 /* ds_inc_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 4623 /* ds_inc_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 4623 /* ds_inc_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 4623 /* ds_inc_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4623 /* ds_inc_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 4623 /* ds_inc_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4623 /* ds_inc_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4623 /* ds_inc_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4623 /* ds_inc_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 4623 /* ds_inc_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4623 /* ds_inc_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4634 /* ds_inc_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 4634 /* ds_inc_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 4634 /* ds_inc_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 4634 /* ds_inc_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 4634 /* ds_inc_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4634 /* ds_inc_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 4634 /* ds_inc_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4634 /* ds_inc_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4634 /* ds_inc_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4634 /* ds_inc_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Plus },
  { 4634 /* ds_inc_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 4634 /* ds_inc_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4634 /* ds_inc_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 4634 /* ds_inc_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 4634 /* ds_inc_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 4634 /* ds_inc_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 4634 /* ds_inc_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4634 /* ds_inc_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 4634 /* ds_inc_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4634 /* ds_inc_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4634 /* ds_inc_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 4634 /* ds_inc_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 4634 /* ds_inc_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 4634 /* ds_inc_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 4645 /* ds_load_2addr_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4645 /* ds_load_2addr_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 4645 /* ds_load_2addr_b32 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX11Only },
  { 4645 /* ds_load_2addr_b32 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX11Only },
  { 4645 /* ds_load_2addr_b32 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4645 /* ds_load_2addr_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4645 /* ds_load_2addr_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Plus },
  { 4645 /* ds_load_2addr_b32 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX12Plus },
  { 4645 /* ds_load_2addr_b32 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX12Plus },
  { 4645 /* ds_load_2addr_b32 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4663 /* ds_load_2addr_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4663 /* ds_load_2addr_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 4663 /* ds_load_2addr_b64 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX11Only },
  { 4663 /* ds_load_2addr_b64 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX11Only },
  { 4663 /* ds_load_2addr_b64 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4663 /* ds_load_2addr_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4663 /* ds_load_2addr_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Plus },
  { 4663 /* ds_load_2addr_b64 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX12Plus },
  { 4663 /* ds_load_2addr_b64 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX12Plus },
  { 4663 /* ds_load_2addr_b64 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4681 /* ds_load_2addr_stride64_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4681 /* ds_load_2addr_stride64_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 4681 /* ds_load_2addr_stride64_b32 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX11Only },
  { 4681 /* ds_load_2addr_stride64_b32 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX11Only },
  { 4681 /* ds_load_2addr_stride64_b32 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4681 /* ds_load_2addr_stride64_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4681 /* ds_load_2addr_stride64_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Plus },
  { 4681 /* ds_load_2addr_stride64_b32 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX12Plus },
  { 4681 /* ds_load_2addr_stride64_b32 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX12Plus },
  { 4681 /* ds_load_2addr_stride64_b32 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4708 /* ds_load_2addr_stride64_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4708 /* ds_load_2addr_stride64_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX11Only },
  { 4708 /* ds_load_2addr_stride64_b64 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX11Only },
  { 4708 /* ds_load_2addr_stride64_b64 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX11Only },
  { 4708 /* ds_load_2addr_stride64_b64 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4708 /* ds_load_2addr_stride64_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4708 /* ds_load_2addr_stride64_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX12Plus },
  { 4708 /* ds_load_2addr_stride64_b64 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX12Plus },
  { 4708 /* ds_load_2addr_stride64_b64 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX12Plus },
  { 4708 /* ds_load_2addr_stride64_b64 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4735 /* ds_load_addtid_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasDSAddTid_isGFX11Only },
  { 4735 /* ds_load_addtid_b32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDSAddTid_isGFX11Only },
  { 4735 /* ds_load_addtid_b32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDSAddTid_isGFX11Only },
  { 4735 /* ds_load_addtid_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasDSAddTid_isGFX12Plus },
  { 4735 /* ds_load_addtid_b32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDSAddTid_isGFX12Plus },
  { 4735 /* ds_load_addtid_b32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDSAddTid_isGFX12Plus },
  { 4754 /* ds_load_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX11Only },
  { 4754 /* ds_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX7Plus_isGFX11Only },
  { 4754 /* ds_load_b128 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX11Only },
  { 4754 /* ds_load_b128 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX11Only },
  { 4754 /* ds_load_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX12Plus },
  { 4754 /* ds_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX7Plus_isGFX12Plus },
  { 4754 /* ds_load_b128 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX12Plus },
  { 4754 /* ds_load_b128 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX12Plus },
  { 4767 /* ds_load_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4767 /* ds_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 4767 /* ds_load_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4767 /* ds_load_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4767 /* ds_load_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4767 /* ds_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 4767 /* ds_load_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 4767 /* ds_load_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4779 /* ds_load_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4779 /* ds_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 4779 /* ds_load_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4779 /* ds_load_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4779 /* ds_load_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4779 /* ds_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Plus },
  { 4779 /* ds_load_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 4779 /* ds_load_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4791 /* ds_load_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX11Only },
  { 4791 /* ds_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX7Plus_isGFX11Only },
  { 4791 /* ds_load_b96 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX11Only },
  { 4791 /* ds_load_b96 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX11Only },
  { 4791 /* ds_load_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX12Plus },
  { 4791 /* ds_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX7Plus_isGFX12Plus },
  { 4791 /* ds_load_b96 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX12Plus },
  { 4791 /* ds_load_b96 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX12Plus },
  { 4803 /* ds_load_i16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4803 /* ds_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 4803 /* ds_load_i16 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4803 /* ds_load_i16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4803 /* ds_load_i16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4803 /* ds_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 4803 /* ds_load_i16 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 4803 /* ds_load_i16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4815 /* ds_load_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4815 /* ds_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 4815 /* ds_load_i8 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4815 /* ds_load_i8 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4815 /* ds_load_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4815 /* ds_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 4815 /* ds_load_i8 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 4815 /* ds_load_i8 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4826 /* ds_load_i8_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4826 /* ds_load_i8_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4826 /* ds_load_i8_d16 */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4826 /* ds_load_i8_d16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4826 /* ds_load_i8_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4826 /* ds_load_i8_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4826 /* ds_load_i8_d16 */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4826 /* ds_load_i8_d16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4841 /* ds_load_i8_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4841 /* ds_load_i8_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4841 /* ds_load_i8_d16_hi */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4841 /* ds_load_i8_d16_hi */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4841 /* ds_load_i8_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4841 /* ds_load_i8_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4841 /* ds_load_i8_d16_hi */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4841 /* ds_load_i8_d16_hi */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4859 /* ds_load_tr16_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX1250Plus_isGFX12Plus_isWave32 },
  { 4859 /* ds_load_tr16_b128 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX1250Plus_isGFX12Plus_isWave32 },
  { 4859 /* ds_load_tr16_b128 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX1250Plus_isGFX12Plus_isWave32 },
  { 4859 /* ds_load_tr16_b128 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX1250Plus_isGFX12Plus_isWave32 },
  { 4877 /* ds_load_tr4_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasTransposeLoadF4F6Insts_isGFX1250Plus_isGFX12Plus_isWave32 },
  { 4877 /* ds_load_tr4_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasTransposeLoadF4F6Insts_isGFX1250Plus_isGFX12Plus_isWave32 },
  { 4877 /* ds_load_tr4_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_HasTransposeLoadF4F6Insts_isGFX1250Plus_isGFX12Plus_isWave32 },
  { 4877 /* ds_load_tr4_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasTransposeLoadF4F6Insts_isGFX1250Plus_isGFX12Plus_isWave32 },
  { 4893 /* ds_load_tr6_b96 */, 1 /* 0 */, MCK_VReg_96, AMFBS_HasTransposeLoadF4F6Insts_isGFX1250Plus_isGFX12Plus_isWave32 },
  { 4893 /* ds_load_tr6_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasTransposeLoadF4F6Insts_isGFX1250Plus_isGFX12Plus_isWave32 },
  { 4893 /* ds_load_tr6_b96 */, 4 /* 2 */, MCK_Offset, AMFBS_HasTransposeLoadF4F6Insts_isGFX1250Plus_isGFX12Plus_isWave32 },
  { 4893 /* ds_load_tr6_b96 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasTransposeLoadF4F6Insts_isGFX1250Plus_isGFX12Plus_isWave32 },
  { 4909 /* ds_load_tr8_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX1250Plus_isGFX12Plus_isWave32 },
  { 4909 /* ds_load_tr8_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX1250Plus_isGFX12Plus_isWave32 },
  { 4909 /* ds_load_tr8_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX1250Plus_isGFX12Plus_isWave32 },
  { 4909 /* ds_load_tr8_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX1250Plus_isGFX12Plus_isWave32 },
  { 4925 /* ds_load_u16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4925 /* ds_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 4925 /* ds_load_u16 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4925 /* ds_load_u16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4925 /* ds_load_u16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4925 /* ds_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 4925 /* ds_load_u16 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 4925 /* ds_load_u16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4937 /* ds_load_u16_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4937 /* ds_load_u16_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4937 /* ds_load_u16_d16 */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4937 /* ds_load_u16_d16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4937 /* ds_load_u16_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4937 /* ds_load_u16_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4937 /* ds_load_u16_d16 */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4937 /* ds_load_u16_d16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4953 /* ds_load_u16_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4953 /* ds_load_u16_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4953 /* ds_load_u16_d16_hi */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4953 /* ds_load_u16_d16_hi */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4953 /* ds_load_u16_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4953 /* ds_load_u16_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4953 /* ds_load_u16_d16_hi */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4953 /* ds_load_u16_d16_hi */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4972 /* ds_load_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 4972 /* ds_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 4972 /* ds_load_u8 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 4972 /* ds_load_u8 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 4972 /* ds_load_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 4972 /* ds_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 4972 /* ds_load_u8 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 4972 /* ds_load_u8 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 4983 /* ds_load_u8_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4983 /* ds_load_u8_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4983 /* ds_load_u8_d16 */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4983 /* ds_load_u8_d16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4983 /* ds_load_u8_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4983 /* ds_load_u8_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4983 /* ds_load_u8_d16 */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4983 /* ds_load_u8_d16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4998 /* ds_load_u8_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4998 /* ds_load_u8_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4998 /* ds_load_u8_d16_hi */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4998 /* ds_load_u8_d16_hi */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX11Only },
  { 4998 /* ds_load_u8_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4998 /* ds_load_u8_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4998 /* ds_load_u8_d16_hi */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 4998 /* ds_load_u8_d16_hi */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 5016 /* ds_max_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5016 /* ds_max_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 5016 /* ds_max_f32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5016 /* ds_max_f32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5016 /* ds_max_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5016 /* ds_max_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 5016 /* ds_max_f32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5016 /* ds_max_f32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5016 /* ds_max_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5016 /* ds_max_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 5016 /* ds_max_f32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5016 /* ds_max_f32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5016 /* ds_max_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5016 /* ds_max_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 5016 /* ds_max_f32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5016 /* ds_max_f32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5016 /* ds_max_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5016 /* ds_max_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 5016 /* ds_max_f32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5016 /* ds_max_f32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5027 /* ds_max_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5027 /* ds_max_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 5027 /* ds_max_f64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5027 /* ds_max_f64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5027 /* ds_max_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5027 /* ds_max_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 5027 /* ds_max_f64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5027 /* ds_max_f64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5027 /* ds_max_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5027 /* ds_max_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 5027 /* ds_max_f64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5027 /* ds_max_f64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5027 /* ds_max_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5027 /* ds_max_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5027 /* ds_max_f64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5027 /* ds_max_f64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5027 /* ds_max_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5027 /* ds_max_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5027 /* ds_max_f64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5027 /* ds_max_f64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5038 /* ds_max_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5038 /* ds_max_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 5038 /* ds_max_i32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5038 /* ds_max_i32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5038 /* ds_max_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5038 /* ds_max_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 5038 /* ds_max_i32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5038 /* ds_max_i32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5038 /* ds_max_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5038 /* ds_max_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 5038 /* ds_max_i32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5038 /* ds_max_i32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5038 /* ds_max_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5038 /* ds_max_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 5038 /* ds_max_i32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5038 /* ds_max_i32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5038 /* ds_max_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5038 /* ds_max_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 5038 /* ds_max_i32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5038 /* ds_max_i32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5038 /* ds_max_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5038 /* ds_max_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 5038 /* ds_max_i32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5038 /* ds_max_i32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5049 /* ds_max_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5049 /* ds_max_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 5049 /* ds_max_i64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5049 /* ds_max_i64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5049 /* ds_max_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5049 /* ds_max_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 5049 /* ds_max_i64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5049 /* ds_max_i64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5049 /* ds_max_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5049 /* ds_max_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Plus },
  { 5049 /* ds_max_i64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5049 /* ds_max_i64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5049 /* ds_max_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5049 /* ds_max_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 5049 /* ds_max_i64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5049 /* ds_max_i64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5049 /* ds_max_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5049 /* ds_max_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5049 /* ds_max_i64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5049 /* ds_max_i64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5049 /* ds_max_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5049 /* ds_max_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5049 /* ds_max_i64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5049 /* ds_max_i64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5060 /* ds_max_num_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5060 /* ds_max_num_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 5060 /* ds_max_num_f32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5060 /* ds_max_num_f32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5075 /* ds_max_num_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5075 /* ds_max_num_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Plus },
  { 5075 /* ds_max_num_f64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5075 /* ds_max_num_f64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5090 /* ds_max_num_rtn_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5090 /* ds_max_num_rtn_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5090 /* ds_max_num_rtn_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5109 /* ds_max_num_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5109 /* ds_max_num_rtn_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 5109 /* ds_max_num_rtn_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5109 /* ds_max_num_rtn_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5128 /* ds_max_rtn_f32 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 5128 /* ds_max_rtn_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 5128 /* ds_max_rtn_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 5128 /* ds_max_rtn_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 5128 /* ds_max_rtn_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5128 /* ds_max_rtn_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5128 /* ds_max_rtn_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5128 /* ds_max_rtn_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5128 /* ds_max_rtn_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5128 /* ds_max_rtn_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5128 /* ds_max_rtn_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5128 /* ds_max_rtn_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5128 /* ds_max_rtn_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5128 /* ds_max_rtn_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5128 /* ds_max_rtn_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5128 /* ds_max_rtn_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5128 /* ds_max_rtn_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5128 /* ds_max_rtn_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5128 /* ds_max_rtn_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5143 /* ds_max_rtn_f64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 5143 /* ds_max_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 5143 /* ds_max_rtn_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 5143 /* ds_max_rtn_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 5143 /* ds_max_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5143 /* ds_max_rtn_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 5143 /* ds_max_rtn_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5143 /* ds_max_rtn_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5143 /* ds_max_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5143 /* ds_max_rtn_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 5143 /* ds_max_rtn_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5143 /* ds_max_rtn_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5143 /* ds_max_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5143 /* ds_max_rtn_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 5143 /* ds_max_rtn_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5143 /* ds_max_rtn_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5143 /* ds_max_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5143 /* ds_max_rtn_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5143 /* ds_max_rtn_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5143 /* ds_max_rtn_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5143 /* ds_max_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5143 /* ds_max_rtn_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5143 /* ds_max_rtn_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5143 /* ds_max_rtn_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5158 /* ds_max_rtn_i32 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 5158 /* ds_max_rtn_i32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 5158 /* ds_max_rtn_i32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 5158 /* ds_max_rtn_i32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 5158 /* ds_max_rtn_i32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5158 /* ds_max_rtn_i32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5158 /* ds_max_rtn_i32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5158 /* ds_max_rtn_i32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5158 /* ds_max_rtn_i32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5158 /* ds_max_rtn_i32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5158 /* ds_max_rtn_i32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5158 /* ds_max_rtn_i32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5158 /* ds_max_rtn_i32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5158 /* ds_max_rtn_i32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5158 /* ds_max_rtn_i32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5158 /* ds_max_rtn_i32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5158 /* ds_max_rtn_i32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5158 /* ds_max_rtn_i32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5158 /* ds_max_rtn_i32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5158 /* ds_max_rtn_i32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5158 /* ds_max_rtn_i32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5158 /* ds_max_rtn_i32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5173 /* ds_max_rtn_i64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 5173 /* ds_max_rtn_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 5173 /* ds_max_rtn_i64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 5173 /* ds_max_rtn_i64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 5173 /* ds_max_rtn_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5173 /* ds_max_rtn_i64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 5173 /* ds_max_rtn_i64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5173 /* ds_max_rtn_i64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5173 /* ds_max_rtn_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5173 /* ds_max_rtn_i64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 5173 /* ds_max_rtn_i64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5173 /* ds_max_rtn_i64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5173 /* ds_max_rtn_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5173 /* ds_max_rtn_i64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 5173 /* ds_max_rtn_i64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5173 /* ds_max_rtn_i64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5173 /* ds_max_rtn_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5173 /* ds_max_rtn_i64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 5173 /* ds_max_rtn_i64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5173 /* ds_max_rtn_i64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5173 /* ds_max_rtn_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5173 /* ds_max_rtn_i64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5173 /* ds_max_rtn_i64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5173 /* ds_max_rtn_i64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5173 /* ds_max_rtn_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5173 /* ds_max_rtn_i64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5173 /* ds_max_rtn_i64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5173 /* ds_max_rtn_i64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5188 /* ds_max_rtn_u32 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 5188 /* ds_max_rtn_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 5188 /* ds_max_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 5188 /* ds_max_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 5188 /* ds_max_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5188 /* ds_max_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5188 /* ds_max_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5188 /* ds_max_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5188 /* ds_max_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5188 /* ds_max_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5188 /* ds_max_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5188 /* ds_max_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5188 /* ds_max_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5188 /* ds_max_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5188 /* ds_max_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5188 /* ds_max_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5188 /* ds_max_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5188 /* ds_max_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5188 /* ds_max_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5188 /* ds_max_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5188 /* ds_max_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5188 /* ds_max_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5203 /* ds_max_rtn_u64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 5203 /* ds_max_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 5203 /* ds_max_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 5203 /* ds_max_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 5203 /* ds_max_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5203 /* ds_max_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 5203 /* ds_max_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5203 /* ds_max_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5203 /* ds_max_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5203 /* ds_max_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 5203 /* ds_max_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5203 /* ds_max_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5203 /* ds_max_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5203 /* ds_max_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 5203 /* ds_max_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5203 /* ds_max_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5203 /* ds_max_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5203 /* ds_max_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 5203 /* ds_max_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5203 /* ds_max_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5203 /* ds_max_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5203 /* ds_max_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5203 /* ds_max_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5203 /* ds_max_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5203 /* ds_max_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5203 /* ds_max_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5203 /* ds_max_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5203 /* ds_max_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5218 /* ds_max_src2_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5218 /* ds_max_src2_f32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5218 /* ds_max_src2_f32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5218 /* ds_max_src2_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5218 /* ds_max_src2_f32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5218 /* ds_max_src2_f32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5218 /* ds_max_src2_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5218 /* ds_max_src2_f32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5218 /* ds_max_src2_f32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5234 /* ds_max_src2_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5234 /* ds_max_src2_f64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5234 /* ds_max_src2_f64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5234 /* ds_max_src2_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5234 /* ds_max_src2_f64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5234 /* ds_max_src2_f64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5234 /* ds_max_src2_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5234 /* ds_max_src2_f64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5234 /* ds_max_src2_f64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5250 /* ds_max_src2_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5250 /* ds_max_src2_i32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5250 /* ds_max_src2_i32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5250 /* ds_max_src2_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5250 /* ds_max_src2_i32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5250 /* ds_max_src2_i32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5250 /* ds_max_src2_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5250 /* ds_max_src2_i32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5250 /* ds_max_src2_i32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5266 /* ds_max_src2_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5266 /* ds_max_src2_i64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5266 /* ds_max_src2_i64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5266 /* ds_max_src2_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5266 /* ds_max_src2_i64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5266 /* ds_max_src2_i64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5266 /* ds_max_src2_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5266 /* ds_max_src2_i64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5266 /* ds_max_src2_i64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5282 /* ds_max_src2_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5282 /* ds_max_src2_u32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5282 /* ds_max_src2_u32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5282 /* ds_max_src2_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5282 /* ds_max_src2_u32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5282 /* ds_max_src2_u32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5282 /* ds_max_src2_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5282 /* ds_max_src2_u32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5282 /* ds_max_src2_u32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5298 /* ds_max_src2_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5298 /* ds_max_src2_u64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5298 /* ds_max_src2_u64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5298 /* ds_max_src2_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5298 /* ds_max_src2_u64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5298 /* ds_max_src2_u64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5298 /* ds_max_src2_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5298 /* ds_max_src2_u64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5298 /* ds_max_src2_u64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5314 /* ds_max_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5314 /* ds_max_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 5314 /* ds_max_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5314 /* ds_max_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5314 /* ds_max_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5314 /* ds_max_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 5314 /* ds_max_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5314 /* ds_max_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5314 /* ds_max_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5314 /* ds_max_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 5314 /* ds_max_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5314 /* ds_max_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5314 /* ds_max_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5314 /* ds_max_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 5314 /* ds_max_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5314 /* ds_max_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5314 /* ds_max_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5314 /* ds_max_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 5314 /* ds_max_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5314 /* ds_max_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5314 /* ds_max_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5314 /* ds_max_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 5314 /* ds_max_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5314 /* ds_max_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5325 /* ds_max_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5325 /* ds_max_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 5325 /* ds_max_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5325 /* ds_max_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5325 /* ds_max_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5325 /* ds_max_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 5325 /* ds_max_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5325 /* ds_max_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5325 /* ds_max_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5325 /* ds_max_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Plus },
  { 5325 /* ds_max_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5325 /* ds_max_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5325 /* ds_max_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5325 /* ds_max_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 5325 /* ds_max_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5325 /* ds_max_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5325 /* ds_max_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5325 /* ds_max_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5325 /* ds_max_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5325 /* ds_max_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5325 /* ds_max_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5325 /* ds_max_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5325 /* ds_max_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5325 /* ds_max_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5336 /* ds_min_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5336 /* ds_min_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 5336 /* ds_min_f32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5336 /* ds_min_f32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5336 /* ds_min_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5336 /* ds_min_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 5336 /* ds_min_f32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5336 /* ds_min_f32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5336 /* ds_min_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5336 /* ds_min_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 5336 /* ds_min_f32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5336 /* ds_min_f32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5336 /* ds_min_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5336 /* ds_min_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 5336 /* ds_min_f32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5336 /* ds_min_f32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5336 /* ds_min_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5336 /* ds_min_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 5336 /* ds_min_f32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5336 /* ds_min_f32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5347 /* ds_min_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5347 /* ds_min_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 5347 /* ds_min_f64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5347 /* ds_min_f64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5347 /* ds_min_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5347 /* ds_min_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 5347 /* ds_min_f64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5347 /* ds_min_f64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5347 /* ds_min_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5347 /* ds_min_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 5347 /* ds_min_f64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5347 /* ds_min_f64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5347 /* ds_min_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5347 /* ds_min_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5347 /* ds_min_f64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5347 /* ds_min_f64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5347 /* ds_min_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5347 /* ds_min_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5347 /* ds_min_f64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5347 /* ds_min_f64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5358 /* ds_min_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5358 /* ds_min_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 5358 /* ds_min_i32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5358 /* ds_min_i32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5358 /* ds_min_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5358 /* ds_min_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 5358 /* ds_min_i32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5358 /* ds_min_i32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5358 /* ds_min_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5358 /* ds_min_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 5358 /* ds_min_i32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5358 /* ds_min_i32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5358 /* ds_min_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5358 /* ds_min_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 5358 /* ds_min_i32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5358 /* ds_min_i32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5358 /* ds_min_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5358 /* ds_min_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 5358 /* ds_min_i32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5358 /* ds_min_i32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5358 /* ds_min_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5358 /* ds_min_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 5358 /* ds_min_i32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5358 /* ds_min_i32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5369 /* ds_min_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5369 /* ds_min_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 5369 /* ds_min_i64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5369 /* ds_min_i64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5369 /* ds_min_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5369 /* ds_min_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 5369 /* ds_min_i64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5369 /* ds_min_i64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5369 /* ds_min_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5369 /* ds_min_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Plus },
  { 5369 /* ds_min_i64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5369 /* ds_min_i64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5369 /* ds_min_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5369 /* ds_min_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 5369 /* ds_min_i64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5369 /* ds_min_i64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5369 /* ds_min_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5369 /* ds_min_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5369 /* ds_min_i64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5369 /* ds_min_i64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5369 /* ds_min_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5369 /* ds_min_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5369 /* ds_min_i64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5369 /* ds_min_i64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5380 /* ds_min_num_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5380 /* ds_min_num_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 5380 /* ds_min_num_f32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5380 /* ds_min_num_f32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5395 /* ds_min_num_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5395 /* ds_min_num_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Plus },
  { 5395 /* ds_min_num_f64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5395 /* ds_min_num_f64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5410 /* ds_min_num_rtn_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5410 /* ds_min_num_rtn_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5410 /* ds_min_num_rtn_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5429 /* ds_min_num_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5429 /* ds_min_num_rtn_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 5429 /* ds_min_num_rtn_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5429 /* ds_min_num_rtn_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5448 /* ds_min_rtn_f32 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 5448 /* ds_min_rtn_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 5448 /* ds_min_rtn_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 5448 /* ds_min_rtn_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 5448 /* ds_min_rtn_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5448 /* ds_min_rtn_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5448 /* ds_min_rtn_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5448 /* ds_min_rtn_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5448 /* ds_min_rtn_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5448 /* ds_min_rtn_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5448 /* ds_min_rtn_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5448 /* ds_min_rtn_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5448 /* ds_min_rtn_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5448 /* ds_min_rtn_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5448 /* ds_min_rtn_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5448 /* ds_min_rtn_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5448 /* ds_min_rtn_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5448 /* ds_min_rtn_f32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5448 /* ds_min_rtn_f32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5463 /* ds_min_rtn_f64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 5463 /* ds_min_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 5463 /* ds_min_rtn_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 5463 /* ds_min_rtn_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 5463 /* ds_min_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5463 /* ds_min_rtn_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 5463 /* ds_min_rtn_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5463 /* ds_min_rtn_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5463 /* ds_min_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5463 /* ds_min_rtn_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 5463 /* ds_min_rtn_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5463 /* ds_min_rtn_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5463 /* ds_min_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5463 /* ds_min_rtn_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 5463 /* ds_min_rtn_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5463 /* ds_min_rtn_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5463 /* ds_min_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5463 /* ds_min_rtn_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5463 /* ds_min_rtn_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5463 /* ds_min_rtn_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5463 /* ds_min_rtn_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5463 /* ds_min_rtn_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5463 /* ds_min_rtn_f64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5463 /* ds_min_rtn_f64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5478 /* ds_min_rtn_i32 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 5478 /* ds_min_rtn_i32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 5478 /* ds_min_rtn_i32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 5478 /* ds_min_rtn_i32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 5478 /* ds_min_rtn_i32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5478 /* ds_min_rtn_i32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5478 /* ds_min_rtn_i32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5478 /* ds_min_rtn_i32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5478 /* ds_min_rtn_i32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5478 /* ds_min_rtn_i32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5478 /* ds_min_rtn_i32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5478 /* ds_min_rtn_i32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5478 /* ds_min_rtn_i32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5478 /* ds_min_rtn_i32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5478 /* ds_min_rtn_i32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5478 /* ds_min_rtn_i32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5478 /* ds_min_rtn_i32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5478 /* ds_min_rtn_i32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5478 /* ds_min_rtn_i32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5478 /* ds_min_rtn_i32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5478 /* ds_min_rtn_i32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5478 /* ds_min_rtn_i32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5493 /* ds_min_rtn_i64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 5493 /* ds_min_rtn_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 5493 /* ds_min_rtn_i64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 5493 /* ds_min_rtn_i64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 5493 /* ds_min_rtn_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5493 /* ds_min_rtn_i64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 5493 /* ds_min_rtn_i64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5493 /* ds_min_rtn_i64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5493 /* ds_min_rtn_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5493 /* ds_min_rtn_i64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 5493 /* ds_min_rtn_i64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5493 /* ds_min_rtn_i64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5493 /* ds_min_rtn_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5493 /* ds_min_rtn_i64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 5493 /* ds_min_rtn_i64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5493 /* ds_min_rtn_i64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5493 /* ds_min_rtn_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5493 /* ds_min_rtn_i64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 5493 /* ds_min_rtn_i64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5493 /* ds_min_rtn_i64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5493 /* ds_min_rtn_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5493 /* ds_min_rtn_i64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5493 /* ds_min_rtn_i64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5493 /* ds_min_rtn_i64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5493 /* ds_min_rtn_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5493 /* ds_min_rtn_i64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5493 /* ds_min_rtn_i64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5493 /* ds_min_rtn_i64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5508 /* ds_min_rtn_u32 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 5508 /* ds_min_rtn_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 5508 /* ds_min_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 5508 /* ds_min_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 5508 /* ds_min_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5508 /* ds_min_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5508 /* ds_min_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5508 /* ds_min_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5508 /* ds_min_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5508 /* ds_min_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5508 /* ds_min_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5508 /* ds_min_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5508 /* ds_min_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5508 /* ds_min_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5508 /* ds_min_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5508 /* ds_min_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5508 /* ds_min_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5508 /* ds_min_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5508 /* ds_min_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5508 /* ds_min_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5508 /* ds_min_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5508 /* ds_min_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5523 /* ds_min_rtn_u64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 5523 /* ds_min_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 5523 /* ds_min_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 5523 /* ds_min_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 5523 /* ds_min_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5523 /* ds_min_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 5523 /* ds_min_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5523 /* ds_min_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5523 /* ds_min_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5523 /* ds_min_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 5523 /* ds_min_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5523 /* ds_min_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5523 /* ds_min_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5523 /* ds_min_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 5523 /* ds_min_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5523 /* ds_min_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5523 /* ds_min_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5523 /* ds_min_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 5523 /* ds_min_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5523 /* ds_min_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5523 /* ds_min_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5523 /* ds_min_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5523 /* ds_min_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5523 /* ds_min_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5523 /* ds_min_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5523 /* ds_min_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5523 /* ds_min_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5523 /* ds_min_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5538 /* ds_min_src2_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5538 /* ds_min_src2_f32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5538 /* ds_min_src2_f32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5538 /* ds_min_src2_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5538 /* ds_min_src2_f32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5538 /* ds_min_src2_f32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5538 /* ds_min_src2_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5538 /* ds_min_src2_f32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5538 /* ds_min_src2_f32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5554 /* ds_min_src2_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5554 /* ds_min_src2_f64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5554 /* ds_min_src2_f64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5554 /* ds_min_src2_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5554 /* ds_min_src2_f64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5554 /* ds_min_src2_f64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5554 /* ds_min_src2_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5554 /* ds_min_src2_f64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5554 /* ds_min_src2_f64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5570 /* ds_min_src2_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5570 /* ds_min_src2_i32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5570 /* ds_min_src2_i32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5570 /* ds_min_src2_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5570 /* ds_min_src2_i32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5570 /* ds_min_src2_i32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5570 /* ds_min_src2_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5570 /* ds_min_src2_i32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5570 /* ds_min_src2_i32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5586 /* ds_min_src2_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5586 /* ds_min_src2_i64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5586 /* ds_min_src2_i64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5586 /* ds_min_src2_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5586 /* ds_min_src2_i64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5586 /* ds_min_src2_i64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5586 /* ds_min_src2_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5586 /* ds_min_src2_i64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5586 /* ds_min_src2_i64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5602 /* ds_min_src2_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5602 /* ds_min_src2_u32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5602 /* ds_min_src2_u32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5602 /* ds_min_src2_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5602 /* ds_min_src2_u32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5602 /* ds_min_src2_u32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5602 /* ds_min_src2_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5602 /* ds_min_src2_u32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5602 /* ds_min_src2_u32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5618 /* ds_min_src2_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5618 /* ds_min_src2_u64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5618 /* ds_min_src2_u64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5618 /* ds_min_src2_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5618 /* ds_min_src2_u64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5618 /* ds_min_src2_u64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5618 /* ds_min_src2_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5618 /* ds_min_src2_u64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5618 /* ds_min_src2_u64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5634 /* ds_min_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5634 /* ds_min_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 5634 /* ds_min_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5634 /* ds_min_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5634 /* ds_min_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5634 /* ds_min_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 5634 /* ds_min_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5634 /* ds_min_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5634 /* ds_min_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5634 /* ds_min_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 5634 /* ds_min_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5634 /* ds_min_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5634 /* ds_min_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5634 /* ds_min_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 5634 /* ds_min_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5634 /* ds_min_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5634 /* ds_min_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5634 /* ds_min_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 5634 /* ds_min_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5634 /* ds_min_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5634 /* ds_min_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5634 /* ds_min_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 5634 /* ds_min_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5634 /* ds_min_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5645 /* ds_min_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5645 /* ds_min_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 5645 /* ds_min_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5645 /* ds_min_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5645 /* ds_min_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5645 /* ds_min_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 5645 /* ds_min_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5645 /* ds_min_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5645 /* ds_min_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5645 /* ds_min_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Plus },
  { 5645 /* ds_min_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5645 /* ds_min_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5645 /* ds_min_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5645 /* ds_min_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 5645 /* ds_min_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5645 /* ds_min_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5645 /* ds_min_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5645 /* ds_min_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5645 /* ds_min_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5645 /* ds_min_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5645 /* ds_min_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5645 /* ds_min_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5645 /* ds_min_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5645 /* ds_min_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5656 /* ds_mskor_b32 */, 6 /* 1, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 5656 /* ds_mskor_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 5656 /* ds_mskor_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 5656 /* ds_mskor_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 5656 /* ds_mskor_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5656 /* ds_mskor_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5656 /* ds_mskor_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5656 /* ds_mskor_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5656 /* ds_mskor_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5656 /* ds_mskor_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5656 /* ds_mskor_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5656 /* ds_mskor_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5656 /* ds_mskor_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5656 /* ds_mskor_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5656 /* ds_mskor_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5656 /* ds_mskor_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5656 /* ds_mskor_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5656 /* ds_mskor_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5656 /* ds_mskor_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5656 /* ds_mskor_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5656 /* ds_mskor_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5656 /* ds_mskor_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5669 /* ds_mskor_b64 */, 6 /* 1, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 5669 /* ds_mskor_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 5669 /* ds_mskor_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 5669 /* ds_mskor_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 5669 /* ds_mskor_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5669 /* ds_mskor_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 5669 /* ds_mskor_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5669 /* ds_mskor_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5669 /* ds_mskor_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5669 /* ds_mskor_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 5669 /* ds_mskor_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5669 /* ds_mskor_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5669 /* ds_mskor_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5669 /* ds_mskor_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 5669 /* ds_mskor_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5669 /* ds_mskor_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5669 /* ds_mskor_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5669 /* ds_mskor_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 5669 /* ds_mskor_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5669 /* ds_mskor_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5669 /* ds_mskor_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5669 /* ds_mskor_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5669 /* ds_mskor_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5669 /* ds_mskor_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5669 /* ds_mskor_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5669 /* ds_mskor_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5669 /* ds_mskor_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5669 /* ds_mskor_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5682 /* ds_mskor_rtn_b32 */, 13 /* 0, 2, 3 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 5682 /* ds_mskor_rtn_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 5682 /* ds_mskor_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 5682 /* ds_mskor_rtn_b32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 5682 /* ds_mskor_rtn_b32 */, 15 /* 0, 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5682 /* ds_mskor_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5682 /* ds_mskor_rtn_b32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5682 /* ds_mskor_rtn_b32 */, 15 /* 0, 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5682 /* ds_mskor_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5682 /* ds_mskor_rtn_b32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5682 /* ds_mskor_rtn_b32 */, 15 /* 0, 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5682 /* ds_mskor_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5682 /* ds_mskor_rtn_b32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5682 /* ds_mskor_rtn_b32 */, 15 /* 0, 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5682 /* ds_mskor_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5682 /* ds_mskor_rtn_b32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5682 /* ds_mskor_rtn_b32 */, 15 /* 0, 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5682 /* ds_mskor_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5682 /* ds_mskor_rtn_b32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5682 /* ds_mskor_rtn_b32 */, 15 /* 0, 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5682 /* ds_mskor_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5682 /* ds_mskor_rtn_b32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5699 /* ds_mskor_rtn_b64 */, 13 /* 0, 2, 3 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 5699 /* ds_mskor_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 5699 /* ds_mskor_rtn_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 5699 /* ds_mskor_rtn_b64 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 5699 /* ds_mskor_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5699 /* ds_mskor_rtn_b64 */, 13 /* 0, 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 5699 /* ds_mskor_rtn_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5699 /* ds_mskor_rtn_b64 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5699 /* ds_mskor_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5699 /* ds_mskor_rtn_b64 */, 13 /* 0, 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 5699 /* ds_mskor_rtn_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5699 /* ds_mskor_rtn_b64 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5699 /* ds_mskor_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5699 /* ds_mskor_rtn_b64 */, 13 /* 0, 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 5699 /* ds_mskor_rtn_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5699 /* ds_mskor_rtn_b64 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5699 /* ds_mskor_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5699 /* ds_mskor_rtn_b64 */, 13 /* 0, 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 5699 /* ds_mskor_rtn_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5699 /* ds_mskor_rtn_b64 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5699 /* ds_mskor_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5699 /* ds_mskor_rtn_b64 */, 13 /* 0, 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5699 /* ds_mskor_rtn_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5699 /* ds_mskor_rtn_b64 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5699 /* ds_mskor_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5699 /* ds_mskor_rtn_b64 */, 13 /* 0, 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5699 /* ds_mskor_rtn_b64 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5699 /* ds_mskor_rtn_b64 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5723 /* ds_or_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5723 /* ds_or_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 5723 /* ds_or_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5723 /* ds_or_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5723 /* ds_or_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5723 /* ds_or_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 5723 /* ds_or_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5723 /* ds_or_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5723 /* ds_or_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5723 /* ds_or_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 5723 /* ds_or_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5723 /* ds_or_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5723 /* ds_or_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5723 /* ds_or_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 5723 /* ds_or_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5723 /* ds_or_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5723 /* ds_or_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5723 /* ds_or_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 5723 /* ds_or_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5723 /* ds_or_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5723 /* ds_or_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5723 /* ds_or_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 5723 /* ds_or_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5723 /* ds_or_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5733 /* ds_or_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5733 /* ds_or_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 5733 /* ds_or_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5733 /* ds_or_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5733 /* ds_or_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5733 /* ds_or_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 5733 /* ds_or_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5733 /* ds_or_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5733 /* ds_or_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5733 /* ds_or_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Plus },
  { 5733 /* ds_or_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5733 /* ds_or_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5733 /* ds_or_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5733 /* ds_or_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 5733 /* ds_or_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5733 /* ds_or_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5733 /* ds_or_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5733 /* ds_or_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5733 /* ds_or_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5733 /* ds_or_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5733 /* ds_or_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5733 /* ds_or_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5733 /* ds_or_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5733 /* ds_or_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5743 /* ds_or_rtn_b32 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 5743 /* ds_or_rtn_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 5743 /* ds_or_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 5743 /* ds_or_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 5743 /* ds_or_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5743 /* ds_or_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5743 /* ds_or_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5743 /* ds_or_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5743 /* ds_or_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5743 /* ds_or_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5743 /* ds_or_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5743 /* ds_or_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5743 /* ds_or_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5743 /* ds_or_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5743 /* ds_or_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5743 /* ds_or_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5743 /* ds_or_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5743 /* ds_or_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5743 /* ds_or_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5743 /* ds_or_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5743 /* ds_or_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5743 /* ds_or_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5757 /* ds_or_rtn_b64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 5757 /* ds_or_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 5757 /* ds_or_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 5757 /* ds_or_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 5757 /* ds_or_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5757 /* ds_or_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 5757 /* ds_or_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 5757 /* ds_or_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5757 /* ds_or_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 5757 /* ds_or_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 5757 /* ds_or_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 5757 /* ds_or_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 5757 /* ds_or_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 5757 /* ds_or_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 5757 /* ds_or_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 5757 /* ds_or_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 5757 /* ds_or_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5757 /* ds_or_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 5757 /* ds_or_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 5757 /* ds_or_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5757 /* ds_or_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5757 /* ds_or_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5757 /* ds_or_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5757 /* ds_or_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5757 /* ds_or_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5757 /* ds_or_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5757 /* ds_or_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 5757 /* ds_or_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5771 /* ds_or_src2_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5771 /* ds_or_src2_b32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5771 /* ds_or_src2_b32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5771 /* ds_or_src2_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5771 /* ds_or_src2_b32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5771 /* ds_or_src2_b32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5771 /* ds_or_src2_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5771 /* ds_or_src2_b32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5771 /* ds_or_src2_b32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5786 /* ds_or_src2_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5786 /* ds_or_src2_b64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5786 /* ds_or_src2_b64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 5786 /* ds_or_src2_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5786 /* ds_or_src2_b64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5786 /* ds_or_src2_b64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 5786 /* ds_or_src2_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5786 /* ds_or_src2_b64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5786 /* ds_or_src2_b64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 5801 /* ds_ordered_count */, 12 /* 2, 3 */, MCK_gds, AMFBS_isNotGFX90APlus_isGFX10Only },
  { 5801 /* ds_ordered_count */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isNotGFX90APlus_isGFX10Only },
  { 5801 /* ds_ordered_count */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isNotGFX90APlus_isGFX10Only },
  { 5801 /* ds_ordered_count */, 4 /* 2 */, MCK_Offset, AMFBS_isNotGFX90APlus_isGFX10Only },
  { 5801 /* ds_ordered_count */, 12 /* 2, 3 */, MCK_gds, AMFBS_isNotGFX90APlus_isGFX11Only },
  { 5801 /* ds_ordered_count */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isNotGFX90APlus_isGFX11Only },
  { 5801 /* ds_ordered_count */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isNotGFX90APlus_isGFX11Only },
  { 5801 /* ds_ordered_count */, 4 /* 2 */, MCK_Offset, AMFBS_isNotGFX90APlus_isGFX11Only },
  { 5801 /* ds_ordered_count */, 12 /* 2, 3 */, MCK_gds, AMFBS_isNotGFX90APlus_isGFX6GFX7 },
  { 5801 /* ds_ordered_count */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isNotGFX90APlus_isGFX6GFX7 },
  { 5801 /* ds_ordered_count */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isNotGFX90APlus_isGFX6GFX7 },
  { 5801 /* ds_ordered_count */, 4 /* 2 */, MCK_Offset, AMFBS_isNotGFX90APlus_isGFX6GFX7 },
  { 5801 /* ds_ordered_count */, 12 /* 2, 3 */, MCK_gds, AMFBS_isNotGFX90APlus_isGFX8GFX9 },
  { 5801 /* ds_ordered_count */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isNotGFX90APlus_isGFX8GFX9 },
  { 5801 /* ds_ordered_count */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isNotGFX90APlus_isGFX8GFX9 },
  { 5801 /* ds_ordered_count */, 4 /* 2 */, MCK_Offset, AMFBS_isNotGFX90APlus_isGFX8GFX9 },
  { 5818 /* ds_param_load */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12PlusNot12_50_isGFX12Plus },
  { 5818 /* ds_param_load */, 2 /* 1 */, MCK_InterpAttr, AMFBS_isGFX12PlusNot12_50_isGFX12Plus },
  { 5818 /* ds_param_load */, 4 /* 2 */, MCK_InterpAttrChan, AMFBS_isGFX12PlusNot12_50_isGFX12Plus },
  { 5818 /* ds_param_load */, 8 /* 3 */, MCK_WaitVAVDst, AMFBS_isGFX12PlusNot12_50_isGFX12Plus },
  { 5818 /* ds_param_load */, 24 /* 3, 4 */, MCK_WaitVMVSrc, AMFBS_isGFX12PlusNot12_50_isGFX12Plus },
  { 5832 /* ds_permute_b32 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX8Plus_isGFX90APlus },
  { 5832 /* ds_permute_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8Plus_isGFX90APlus },
  { 5832 /* ds_permute_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8Plus_isGFX90APlus },
  { 5832 /* ds_permute_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8Plus_isGFX10Only },
  { 5832 /* ds_permute_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8Plus_isGFX10Only },
  { 5832 /* ds_permute_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8Plus_isGFX11Only },
  { 5832 /* ds_permute_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8Plus_isGFX11Only },
  { 5832 /* ds_permute_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8Plus_isGFX12Plus },
  { 5832 /* ds_permute_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8Plus_isGFX12Plus },
  { 5832 /* ds_permute_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8Plus_isGFX8GFX9 },
  { 5832 /* ds_permute_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8Plus_isGFX8GFX9 },
  { 5847 /* ds_pk_add_bf16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasAtomicDsPkAdd16Insts_isGFX12Plus },
  { 5847 /* ds_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicDsPkAdd16Insts_isGFX12Plus },
  { 5847 /* ds_pk_add_bf16 */, 4 /* 2 */, MCK_Offset, AMFBS_HasAtomicDsPkAdd16Insts_isGFX12Plus },
  { 5847 /* ds_pk_add_bf16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasAtomicDsPkAdd16Insts_isGFX12Plus },
  { 5847 /* ds_pk_add_bf16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasAtomicDsPkAdd16Insts_isGFX8GFX9 },
  { 5847 /* ds_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicDsPkAdd16Insts_isGFX8GFX9 },
  { 5847 /* ds_pk_add_bf16 */, 4 /* 2 */, MCK_Offset, AMFBS_HasAtomicDsPkAdd16Insts_isGFX8GFX9 },
  { 5847 /* ds_pk_add_bf16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasAtomicDsPkAdd16Insts_isGFX8GFX9 },
  { 5862 /* ds_pk_add_f16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasAtomicDsPkAdd16Insts_isGFX12Plus },
  { 5862 /* ds_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicDsPkAdd16Insts_isGFX12Plus },
  { 5862 /* ds_pk_add_f16 */, 4 /* 2 */, MCK_Offset, AMFBS_HasAtomicDsPkAdd16Insts_isGFX12Plus },
  { 5862 /* ds_pk_add_f16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasAtomicDsPkAdd16Insts_isGFX12Plus },
  { 5862 /* ds_pk_add_f16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasAtomicDsPkAdd16Insts_isGFX8GFX9 },
  { 5862 /* ds_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicDsPkAdd16Insts_isGFX8GFX9 },
  { 5862 /* ds_pk_add_f16 */, 4 /* 2 */, MCK_Offset, AMFBS_HasAtomicDsPkAdd16Insts_isGFX8GFX9 },
  { 5862 /* ds_pk_add_f16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasAtomicDsPkAdd16Insts_isGFX8GFX9 },
  { 5876 /* ds_pk_add_rtn_bf16 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasAtomicDsPkAdd16Insts_isGFX90APlus },
  { 5876 /* ds_pk_add_rtn_bf16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicDsPkAdd16Insts_isGFX90APlus },
  { 5876 /* ds_pk_add_rtn_bf16 */, 8 /* 3 */, MCK_Offset, AMFBS_HasAtomicDsPkAdd16Insts_isGFX90APlus },
  { 5876 /* ds_pk_add_rtn_bf16 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_HasAtomicDsPkAdd16Insts_isGFX90APlus },
  { 5876 /* ds_pk_add_rtn_bf16 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasAtomicDsPkAdd16Insts_isGFX12Plus },
  { 5876 /* ds_pk_add_rtn_bf16 */, 8 /* 3 */, MCK_Offset, AMFBS_HasAtomicDsPkAdd16Insts_isGFX12Plus },
  { 5876 /* ds_pk_add_rtn_bf16 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_HasAtomicDsPkAdd16Insts_isGFX12Plus },
  { 5876 /* ds_pk_add_rtn_bf16 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasAtomicDsPkAdd16Insts_isGFX8GFX9 },
  { 5876 /* ds_pk_add_rtn_bf16 */, 8 /* 3 */, MCK_Offset, AMFBS_HasAtomicDsPkAdd16Insts_isGFX8GFX9 },
  { 5876 /* ds_pk_add_rtn_bf16 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_HasAtomicDsPkAdd16Insts_isGFX8GFX9 },
  { 5895 /* ds_pk_add_rtn_f16 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasAtomicDsPkAdd16Insts_isGFX90APlus },
  { 5895 /* ds_pk_add_rtn_f16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicDsPkAdd16Insts_isGFX90APlus },
  { 5895 /* ds_pk_add_rtn_f16 */, 8 /* 3 */, MCK_Offset, AMFBS_HasAtomicDsPkAdd16Insts_isGFX90APlus },
  { 5895 /* ds_pk_add_rtn_f16 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_HasAtomicDsPkAdd16Insts_isGFX90APlus },
  { 5895 /* ds_pk_add_rtn_f16 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasAtomicDsPkAdd16Insts_isGFX12Plus },
  { 5895 /* ds_pk_add_rtn_f16 */, 8 /* 3 */, MCK_Offset, AMFBS_HasAtomicDsPkAdd16Insts_isGFX12Plus },
  { 5895 /* ds_pk_add_rtn_f16 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_HasAtomicDsPkAdd16Insts_isGFX12Plus },
  { 5895 /* ds_pk_add_rtn_f16 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasAtomicDsPkAdd16Insts_isGFX8GFX9 },
  { 5895 /* ds_pk_add_rtn_f16 */, 8 /* 3 */, MCK_Offset, AMFBS_HasAtomicDsPkAdd16Insts_isGFX8GFX9 },
  { 5895 /* ds_pk_add_rtn_f16 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_HasAtomicDsPkAdd16Insts_isGFX8GFX9 },
  { 5913 /* ds_read2_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5913 /* ds_read2_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 5913 /* ds_read2_b32 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX10Only },
  { 5913 /* ds_read2_b32 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX10Only },
  { 5913 /* ds_read2_b32 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5913 /* ds_read2_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5913 /* ds_read2_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 5913 /* ds_read2_b32 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX6GFX7 },
  { 5913 /* ds_read2_b32 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX6GFX7 },
  { 5913 /* ds_read2_b32 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5913 /* ds_read2_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5913 /* ds_read2_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5913 /* ds_read2_b32 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 5913 /* ds_read2_b32 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 5913 /* ds_read2_b32 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5913 /* ds_read2_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5913 /* ds_read2_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5913 /* ds_read2_b32 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 5913 /* ds_read2_b32 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 5913 /* ds_read2_b32 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5926 /* ds_read2_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5926 /* ds_read2_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 5926 /* ds_read2_b64 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX10Only },
  { 5926 /* ds_read2_b64 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX10Only },
  { 5926 /* ds_read2_b64 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5926 /* ds_read2_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5926 /* ds_read2_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 5926 /* ds_read2_b64 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX6GFX7 },
  { 5926 /* ds_read2_b64 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX6GFX7 },
  { 5926 /* ds_read2_b64 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5926 /* ds_read2_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5926 /* ds_read2_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5926 /* ds_read2_b64 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 5926 /* ds_read2_b64 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 5926 /* ds_read2_b64 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5926 /* ds_read2_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5926 /* ds_read2_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5926 /* ds_read2_b64 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 5926 /* ds_read2_b64 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 5926 /* ds_read2_b64 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5939 /* ds_read2st64_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5939 /* ds_read2st64_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 5939 /* ds_read2st64_b32 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX10Only },
  { 5939 /* ds_read2st64_b32 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX10Only },
  { 5939 /* ds_read2st64_b32 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5939 /* ds_read2st64_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5939 /* ds_read2st64_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 5939 /* ds_read2st64_b32 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX6GFX7 },
  { 5939 /* ds_read2st64_b32 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX6GFX7 },
  { 5939 /* ds_read2st64_b32 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5939 /* ds_read2st64_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5939 /* ds_read2st64_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5939 /* ds_read2st64_b32 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 5939 /* ds_read2st64_b32 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 5939 /* ds_read2st64_b32 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5939 /* ds_read2st64_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5939 /* ds_read2st64_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5939 /* ds_read2st64_b32 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 5939 /* ds_read2st64_b32 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 5939 /* ds_read2st64_b32 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5956 /* ds_read2st64_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 5956 /* ds_read2st64_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Only },
  { 5956 /* ds_read2st64_b64 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX10Only },
  { 5956 /* ds_read2st64_b64 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX10Only },
  { 5956 /* ds_read2st64_b64 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 5956 /* ds_read2st64_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 5956 /* ds_read2st64_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 5956 /* ds_read2st64_b64 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX6GFX7 },
  { 5956 /* ds_read2st64_b64 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX6GFX7 },
  { 5956 /* ds_read2st64_b64 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 5956 /* ds_read2st64_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5956 /* ds_read2st64_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5956 /* ds_read2st64_b64 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 5956 /* ds_read2st64_b64 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 5956 /* ds_read2st64_b64 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5956 /* ds_read2st64_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 5956 /* ds_read2st64_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX8GFX9 },
  { 5956 /* ds_read2st64_b64 */, 4 /* 2 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 5956 /* ds_read2st64_b64 */, 12 /* 2, 3 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 5956 /* ds_read2st64_b64 */, 28 /* 2, 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 5973 /* ds_read_addtid_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasDSAddTid_isGFX10Only },
  { 5973 /* ds_read_addtid_b32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDSAddTid_isGFX10Only },
  { 5973 /* ds_read_addtid_b32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDSAddTid_isGFX10Only },
  { 5973 /* ds_read_addtid_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasDSAddTid_isGFX8GFX9 },
  { 5973 /* ds_read_addtid_b32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDSAddTid_isGFX8GFX9 },
  { 5973 /* ds_read_addtid_b32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDSAddTid_isGFX8GFX9 },
  { 5992 /* ds_read_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX10Only },
  { 5992 /* ds_read_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX7Plus_isGFX10Only },
  { 5992 /* ds_read_b128 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX10Only },
  { 5992 /* ds_read_b128 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX10Only },
  { 5992 /* ds_read_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX7Only },
  { 5992 /* ds_read_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX7Plus_isGFX7Only },
  { 5992 /* ds_read_b128 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX7Only },
  { 5992 /* ds_read_b128 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX7Only },
  { 5992 /* ds_read_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 5992 /* ds_read_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 5992 /* ds_read_b128 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 5992 /* ds_read_b128 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 5992 /* ds_read_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 5992 /* ds_read_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 5992 /* ds_read_b128 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 5992 /* ds_read_b128 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 6005 /* ds_read_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 6005 /* ds_read_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 6005 /* ds_read_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 6005 /* ds_read_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 6005 /* ds_read_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 6005 /* ds_read_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 6005 /* ds_read_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 6005 /* ds_read_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 6005 /* ds_read_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6005 /* ds_read_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 6005 /* ds_read_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6005 /* ds_read_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6005 /* ds_read_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6005 /* ds_read_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 6005 /* ds_read_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6005 /* ds_read_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6017 /* ds_read_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 6017 /* ds_read_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 6017 /* ds_read_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 6017 /* ds_read_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 6017 /* ds_read_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 6017 /* ds_read_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 6017 /* ds_read_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 6017 /* ds_read_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 6017 /* ds_read_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6017 /* ds_read_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 6017 /* ds_read_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6017 /* ds_read_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6017 /* ds_read_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6017 /* ds_read_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 6017 /* ds_read_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6017 /* ds_read_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6029 /* ds_read_b64_tr_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasGFX950Insts_isGFX8GFX9_isWave64 },
  { 6029 /* ds_read_b64_tr_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasGFX950Insts_isGFX8GFX9_isWave64 },
  { 6029 /* ds_read_b64_tr_b16 */, 4 /* 2 */, MCK_Offset, AMFBS_HasGFX950Insts_isGFX8GFX9_isWave64 },
  { 6029 /* ds_read_b64_tr_b16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasGFX950Insts_isGFX8GFX9_isWave64 },
  { 6048 /* ds_read_b64_tr_b4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasGFX950Insts_isGFX8GFX9_isWave64 },
  { 6048 /* ds_read_b64_tr_b4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasGFX950Insts_isGFX8GFX9_isWave64 },
  { 6048 /* ds_read_b64_tr_b4 */, 4 /* 2 */, MCK_Offset, AMFBS_HasGFX950Insts_isGFX8GFX9_isWave64 },
  { 6048 /* ds_read_b64_tr_b4 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasGFX950Insts_isGFX8GFX9_isWave64 },
  { 6066 /* ds_read_b64_tr_b8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasGFX950Insts_isGFX8GFX9_isWave64 },
  { 6066 /* ds_read_b64_tr_b8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasGFX950Insts_isGFX8GFX9_isWave64 },
  { 6066 /* ds_read_b64_tr_b8 */, 4 /* 2 */, MCK_Offset, AMFBS_HasGFX950Insts_isGFX8GFX9_isWave64 },
  { 6066 /* ds_read_b64_tr_b8 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasGFX950Insts_isGFX8GFX9_isWave64 },
  { 6084 /* ds_read_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX10Only },
  { 6084 /* ds_read_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX7Plus_isGFX10Only },
  { 6084 /* ds_read_b96 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX10Only },
  { 6084 /* ds_read_b96 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX10Only },
  { 6084 /* ds_read_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX7Only },
  { 6084 /* ds_read_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX7Plus_isGFX7Only },
  { 6084 /* ds_read_b96 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX7Only },
  { 6084 /* ds_read_b96 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX7Only },
  { 6084 /* ds_read_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 6084 /* ds_read_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 6084 /* ds_read_b96 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 6084 /* ds_read_b96 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 6084 /* ds_read_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 6084 /* ds_read_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 6084 /* ds_read_b96 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 6084 /* ds_read_b96 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 6096 /* ds_read_b96_tr_b6 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasGFX950Insts_isGFX8GFX9_isWave64 },
  { 6096 /* ds_read_b96_tr_b6 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align1, AMFBS_HasGFX950Insts_isGFX8GFX9_isWave64 },
  { 6096 /* ds_read_b96_tr_b6 */, 4 /* 2 */, MCK_Offset, AMFBS_HasGFX950Insts_isGFX8GFX9_isWave64 },
  { 6096 /* ds_read_b96_tr_b6 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasGFX950Insts_isGFX8GFX9_isWave64 },
  { 6114 /* ds_read_i16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 6114 /* ds_read_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 6114 /* ds_read_i16 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 6114 /* ds_read_i16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 6114 /* ds_read_i16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 6114 /* ds_read_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 6114 /* ds_read_i16 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 6114 /* ds_read_i16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 6114 /* ds_read_i16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6114 /* ds_read_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 6114 /* ds_read_i16 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6114 /* ds_read_i16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6114 /* ds_read_i16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6114 /* ds_read_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 6114 /* ds_read_i16 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6114 /* ds_read_i16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6126 /* ds_read_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 6126 /* ds_read_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 6126 /* ds_read_i8 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 6126 /* ds_read_i8 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 6126 /* ds_read_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 6126 /* ds_read_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 6126 /* ds_read_i8 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 6126 /* ds_read_i8 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 6126 /* ds_read_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6126 /* ds_read_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 6126 /* ds_read_i8 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6126 /* ds_read_i8 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6126 /* ds_read_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6126 /* ds_read_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 6126 /* ds_read_i8 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6126 /* ds_read_i8 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6137 /* ds_read_i8_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6137 /* ds_read_i8_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6137 /* ds_read_i8_d16 */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6137 /* ds_read_i8_d16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6137 /* ds_read_i8_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6137 /* ds_read_i8_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6137 /* ds_read_i8_d16 */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6137 /* ds_read_i8_d16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6152 /* ds_read_i8_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6152 /* ds_read_i8_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6152 /* ds_read_i8_d16_hi */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6152 /* ds_read_i8_d16_hi */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6152 /* ds_read_i8_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6152 /* ds_read_i8_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6152 /* ds_read_i8_d16_hi */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6152 /* ds_read_i8_d16_hi */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6170 /* ds_read_u16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 6170 /* ds_read_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 6170 /* ds_read_u16 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 6170 /* ds_read_u16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 6170 /* ds_read_u16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 6170 /* ds_read_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 6170 /* ds_read_u16 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 6170 /* ds_read_u16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 6170 /* ds_read_u16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6170 /* ds_read_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 6170 /* ds_read_u16 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6170 /* ds_read_u16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6170 /* ds_read_u16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6170 /* ds_read_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 6170 /* ds_read_u16 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6170 /* ds_read_u16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6182 /* ds_read_u16_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6182 /* ds_read_u16_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6182 /* ds_read_u16_d16 */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6182 /* ds_read_u16_d16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6182 /* ds_read_u16_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6182 /* ds_read_u16_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6182 /* ds_read_u16_d16 */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6182 /* ds_read_u16_d16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6198 /* ds_read_u16_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6198 /* ds_read_u16_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6198 /* ds_read_u16_d16_hi */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6198 /* ds_read_u16_d16_hi */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6198 /* ds_read_u16_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6198 /* ds_read_u16_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6198 /* ds_read_u16_d16_hi */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6198 /* ds_read_u16_d16_hi */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6217 /* ds_read_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 6217 /* ds_read_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 6217 /* ds_read_u8 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 6217 /* ds_read_u8 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 6217 /* ds_read_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 6217 /* ds_read_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 6217 /* ds_read_u8 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 6217 /* ds_read_u8 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 6217 /* ds_read_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6217 /* ds_read_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 6217 /* ds_read_u8 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6217 /* ds_read_u8 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6217 /* ds_read_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6217 /* ds_read_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 6217 /* ds_read_u8 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6217 /* ds_read_u8 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6228 /* ds_read_u8_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6228 /* ds_read_u8_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6228 /* ds_read_u8_d16 */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6228 /* ds_read_u8_d16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6228 /* ds_read_u8_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6228 /* ds_read_u8_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6228 /* ds_read_u8_d16 */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6228 /* ds_read_u8_d16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6243 /* ds_read_u8_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6243 /* ds_read_u8_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6243 /* ds_read_u8_d16_hi */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6243 /* ds_read_u8_d16_hi */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX10Only },
  { 6243 /* ds_read_u8_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6243 /* ds_read_u8_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6243 /* ds_read_u8_d16_hi */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6243 /* ds_read_u8_d16_hi */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 6261 /* ds_rsub_rtn_u32 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 6261 /* ds_rsub_rtn_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 6261 /* ds_rsub_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 6261 /* ds_rsub_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 6261 /* ds_rsub_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 6261 /* ds_rsub_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 6261 /* ds_rsub_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 6261 /* ds_rsub_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6261 /* ds_rsub_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 6261 /* ds_rsub_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6261 /* ds_rsub_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6261 /* ds_rsub_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 6261 /* ds_rsub_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6261 /* ds_rsub_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 6261 /* ds_rsub_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 6261 /* ds_rsub_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 6261 /* ds_rsub_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6261 /* ds_rsub_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6261 /* ds_rsub_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6261 /* ds_rsub_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6261 /* ds_rsub_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6261 /* ds_rsub_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6277 /* ds_rsub_rtn_u64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 6277 /* ds_rsub_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 6277 /* ds_rsub_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 6277 /* ds_rsub_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 6277 /* ds_rsub_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 6277 /* ds_rsub_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 6277 /* ds_rsub_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 6277 /* ds_rsub_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 6277 /* ds_rsub_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6277 /* ds_rsub_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 6277 /* ds_rsub_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 6277 /* ds_rsub_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6277 /* ds_rsub_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6277 /* ds_rsub_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 6277 /* ds_rsub_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 6277 /* ds_rsub_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6277 /* ds_rsub_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 6277 /* ds_rsub_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 6277 /* ds_rsub_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 6277 /* ds_rsub_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 6277 /* ds_rsub_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6277 /* ds_rsub_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 6277 /* ds_rsub_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6277 /* ds_rsub_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6277 /* ds_rsub_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6277 /* ds_rsub_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 6277 /* ds_rsub_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6277 /* ds_rsub_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6293 /* ds_rsub_src2_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 6293 /* ds_rsub_src2_u32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 6293 /* ds_rsub_src2_u32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 6293 /* ds_rsub_src2_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 6293 /* ds_rsub_src2_u32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 6293 /* ds_rsub_src2_u32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 6293 /* ds_rsub_src2_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 6293 /* ds_rsub_src2_u32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 6293 /* ds_rsub_src2_u32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 6310 /* ds_rsub_src2_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 6310 /* ds_rsub_src2_u64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 6310 /* ds_rsub_src2_u64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 6310 /* ds_rsub_src2_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 6310 /* ds_rsub_src2_u64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 6310 /* ds_rsub_src2_u64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 6310 /* ds_rsub_src2_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 6310 /* ds_rsub_src2_u64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 6310 /* ds_rsub_src2_u64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 6327 /* ds_rsub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 6327 /* ds_rsub_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 6327 /* ds_rsub_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 6327 /* ds_rsub_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 6327 /* ds_rsub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6327 /* ds_rsub_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 6327 /* ds_rsub_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 6327 /* ds_rsub_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6327 /* ds_rsub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6327 /* ds_rsub_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 6327 /* ds_rsub_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 6327 /* ds_rsub_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6327 /* ds_rsub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 6327 /* ds_rsub_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 6327 /* ds_rsub_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 6327 /* ds_rsub_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 6327 /* ds_rsub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6327 /* ds_rsub_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 6327 /* ds_rsub_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6327 /* ds_rsub_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6327 /* ds_rsub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6327 /* ds_rsub_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 6327 /* ds_rsub_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6327 /* ds_rsub_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6339 /* ds_rsub_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 6339 /* ds_rsub_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 6339 /* ds_rsub_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 6339 /* ds_rsub_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 6339 /* ds_rsub_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6339 /* ds_rsub_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 6339 /* ds_rsub_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 6339 /* ds_rsub_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6339 /* ds_rsub_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6339 /* ds_rsub_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Plus },
  { 6339 /* ds_rsub_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 6339 /* ds_rsub_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6339 /* ds_rsub_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 6339 /* ds_rsub_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 6339 /* ds_rsub_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 6339 /* ds_rsub_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 6339 /* ds_rsub_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6339 /* ds_rsub_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 6339 /* ds_rsub_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6339 /* ds_rsub_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6339 /* ds_rsub_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6339 /* ds_rsub_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 6339 /* ds_rsub_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6339 /* ds_rsub_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6351 /* ds_store_2addr_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6351 /* ds_store_2addr_b32 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX11Only },
  { 6351 /* ds_store_2addr_b32 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX11Only },
  { 6351 /* ds_store_2addr_b32 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6351 /* ds_store_2addr_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6351 /* ds_store_2addr_b32 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX12Plus },
  { 6351 /* ds_store_2addr_b32 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX12Plus },
  { 6351 /* ds_store_2addr_b32 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6370 /* ds_store_2addr_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6370 /* ds_store_2addr_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 6370 /* ds_store_2addr_b64 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX11Only },
  { 6370 /* ds_store_2addr_b64 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX11Only },
  { 6370 /* ds_store_2addr_b64 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6370 /* ds_store_2addr_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6370 /* ds_store_2addr_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 6370 /* ds_store_2addr_b64 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX12Plus },
  { 6370 /* ds_store_2addr_b64 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX12Plus },
  { 6370 /* ds_store_2addr_b64 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6389 /* ds_store_2addr_stride64_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6389 /* ds_store_2addr_stride64_b32 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX11Only },
  { 6389 /* ds_store_2addr_stride64_b32 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX11Only },
  { 6389 /* ds_store_2addr_stride64_b32 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6389 /* ds_store_2addr_stride64_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6389 /* ds_store_2addr_stride64_b32 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX12Plus },
  { 6389 /* ds_store_2addr_stride64_b32 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX12Plus },
  { 6389 /* ds_store_2addr_stride64_b32 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6417 /* ds_store_2addr_stride64_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6417 /* ds_store_2addr_stride64_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 6417 /* ds_store_2addr_stride64_b64 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX11Only },
  { 6417 /* ds_store_2addr_stride64_b64 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX11Only },
  { 6417 /* ds_store_2addr_stride64_b64 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6417 /* ds_store_2addr_stride64_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6417 /* ds_store_2addr_stride64_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 6417 /* ds_store_2addr_stride64_b64 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX12Plus },
  { 6417 /* ds_store_2addr_stride64_b64 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX12Plus },
  { 6417 /* ds_store_2addr_stride64_b64 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6445 /* ds_store_addtid_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasDSAddTid_isGFX11Only },
  { 6445 /* ds_store_addtid_b32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDSAddTid_isGFX11Only },
  { 6445 /* ds_store_addtid_b32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDSAddTid_isGFX11Only },
  { 6445 /* ds_store_addtid_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasDSAddTid_isGFX12Plus },
  { 6445 /* ds_store_addtid_b32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDSAddTid_isGFX12Plus },
  { 6445 /* ds_store_addtid_b32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDSAddTid_isGFX12Plus },
  { 6465 /* ds_store_b128 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX11Only },
  { 6465 /* ds_store_b128 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX7Plus_isGFX11Only },
  { 6465 /* ds_store_b128 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX11Only },
  { 6465 /* ds_store_b128 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX11Only },
  { 6465 /* ds_store_b128 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX12Plus },
  { 6465 /* ds_store_b128 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX7Plus_isGFX12Plus },
  { 6465 /* ds_store_b128 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX12Plus },
  { 6465 /* ds_store_b128 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX12Plus },
  { 6479 /* ds_store_b16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6479 /* ds_store_b16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 6479 /* ds_store_b16 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 6479 /* ds_store_b16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6479 /* ds_store_b16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6479 /* ds_store_b16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 6479 /* ds_store_b16 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 6479 /* ds_store_b16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6492 /* ds_store_b16_d16_hi */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 6492 /* ds_store_b16_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 6492 /* ds_store_b16_d16_hi */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 6492 /* ds_store_b16_d16_hi */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX11Only },
  { 6492 /* ds_store_b16_d16_hi */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 6492 /* ds_store_b16_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 6492 /* ds_store_b16_d16_hi */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 6492 /* ds_store_b16_d16_hi */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 6512 /* ds_store_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6512 /* ds_store_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 6512 /* ds_store_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 6512 /* ds_store_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6512 /* ds_store_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6512 /* ds_store_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 6512 /* ds_store_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 6512 /* ds_store_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6525 /* ds_store_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6525 /* ds_store_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 6525 /* ds_store_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 6525 /* ds_store_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6525 /* ds_store_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6525 /* ds_store_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Plus },
  { 6525 /* ds_store_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 6525 /* ds_store_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6538 /* ds_store_b8 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6538 /* ds_store_b8 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 6538 /* ds_store_b8 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 6538 /* ds_store_b8 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6538 /* ds_store_b8 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6538 /* ds_store_b8 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 6538 /* ds_store_b8 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 6538 /* ds_store_b8 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6550 /* ds_store_b8_d16_hi */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX11Only },
  { 6550 /* ds_store_b8_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 6550 /* ds_store_b8_d16_hi */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 6550 /* ds_store_b8_d16_hi */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX11Only },
  { 6550 /* ds_store_b8_d16_hi */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 6550 /* ds_store_b8_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 6550 /* ds_store_b8_d16_hi */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 6550 /* ds_store_b8_d16_hi */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX12Plus },
  { 6569 /* ds_store_b96 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX11Only },
  { 6569 /* ds_store_b96 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX7Plus_isGFX11Only },
  { 6569 /* ds_store_b96 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX11Only },
  { 6569 /* ds_store_b96 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX11Only },
  { 6569 /* ds_store_b96 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX12Plus },
  { 6569 /* ds_store_b96 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX7Plus_isGFX12Plus },
  { 6569 /* ds_store_b96 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX12Plus },
  { 6569 /* ds_store_b96 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX12Plus },
  { 6582 /* ds_storexchg_2addr_rtn_b32 */, 14 /* 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6582 /* ds_storexchg_2addr_rtn_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 6582 /* ds_storexchg_2addr_rtn_b32 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX11Only },
  { 6582 /* ds_storexchg_2addr_rtn_b32 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX11Only },
  { 6582 /* ds_storexchg_2addr_rtn_b32 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6582 /* ds_storexchg_2addr_rtn_b32 */, 14 /* 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6582 /* ds_storexchg_2addr_rtn_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 6582 /* ds_storexchg_2addr_rtn_b32 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX12Plus },
  { 6582 /* ds_storexchg_2addr_rtn_b32 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX12Plus },
  { 6582 /* ds_storexchg_2addr_rtn_b32 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6609 /* ds_storexchg_2addr_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6609 /* ds_storexchg_2addr_rtn_b64 */, 12 /* 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 6609 /* ds_storexchg_2addr_rtn_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX11Only },
  { 6609 /* ds_storexchg_2addr_rtn_b64 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX11Only },
  { 6609 /* ds_storexchg_2addr_rtn_b64 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX11Only },
  { 6609 /* ds_storexchg_2addr_rtn_b64 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6609 /* ds_storexchg_2addr_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6609 /* ds_storexchg_2addr_rtn_b64 */, 12 /* 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 6609 /* ds_storexchg_2addr_rtn_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX12Plus },
  { 6609 /* ds_storexchg_2addr_rtn_b64 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX12Plus },
  { 6609 /* ds_storexchg_2addr_rtn_b64 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX12Plus },
  { 6609 /* ds_storexchg_2addr_rtn_b64 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6636 /* ds_storexchg_2addr_stride64_rtn_b32 */, 14 /* 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6636 /* ds_storexchg_2addr_stride64_rtn_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 6636 /* ds_storexchg_2addr_stride64_rtn_b32 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX11Only },
  { 6636 /* ds_storexchg_2addr_stride64_rtn_b32 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX11Only },
  { 6636 /* ds_storexchg_2addr_stride64_rtn_b32 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6636 /* ds_storexchg_2addr_stride64_rtn_b32 */, 14 /* 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6636 /* ds_storexchg_2addr_stride64_rtn_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 6636 /* ds_storexchg_2addr_stride64_rtn_b32 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX12Plus },
  { 6636 /* ds_storexchg_2addr_stride64_rtn_b32 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX12Plus },
  { 6636 /* ds_storexchg_2addr_stride64_rtn_b32 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6672 /* ds_storexchg_2addr_stride64_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6672 /* ds_storexchg_2addr_stride64_rtn_b64 */, 12 /* 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 6672 /* ds_storexchg_2addr_stride64_rtn_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX11Only },
  { 6672 /* ds_storexchg_2addr_stride64_rtn_b64 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX11Only },
  { 6672 /* ds_storexchg_2addr_stride64_rtn_b64 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX11Only },
  { 6672 /* ds_storexchg_2addr_stride64_rtn_b64 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6672 /* ds_storexchg_2addr_stride64_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6672 /* ds_storexchg_2addr_stride64_rtn_b64 */, 12 /* 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 6672 /* ds_storexchg_2addr_stride64_rtn_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX12Plus },
  { 6672 /* ds_storexchg_2addr_stride64_rtn_b64 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX12Plus },
  { 6672 /* ds_storexchg_2addr_stride64_rtn_b64 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX12Plus },
  { 6672 /* ds_storexchg_2addr_stride64_rtn_b64 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6708 /* ds_storexchg_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6708 /* ds_storexchg_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 6708 /* ds_storexchg_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6708 /* ds_storexchg_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6708 /* ds_storexchg_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 6708 /* ds_storexchg_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6729 /* ds_storexchg_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6729 /* ds_storexchg_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 6729 /* ds_storexchg_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 6729 /* ds_storexchg_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6729 /* ds_storexchg_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6729 /* ds_storexchg_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 6729 /* ds_storexchg_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 6729 /* ds_storexchg_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6750 /* ds_sub_clamp_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6750 /* ds_sub_clamp_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 6750 /* ds_sub_clamp_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6771 /* ds_sub_clamp_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6771 /* ds_sub_clamp_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 6771 /* ds_sub_clamp_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 6771 /* ds_sub_clamp_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6788 /* ds_sub_gs_reg_rtn */, 12 /* 2, 3 */, MCK_gds, AMFBS_isGFX11Only },
  { 6788 /* ds_sub_gs_reg_rtn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6788 /* ds_sub_gs_reg_rtn */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 6788 /* ds_sub_gs_reg_rtn */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 6806 /* ds_sub_rtn_u32 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 6806 /* ds_sub_rtn_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 6806 /* ds_sub_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 6806 /* ds_sub_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 6806 /* ds_sub_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 6806 /* ds_sub_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 6806 /* ds_sub_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 6806 /* ds_sub_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6806 /* ds_sub_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 6806 /* ds_sub_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6806 /* ds_sub_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6806 /* ds_sub_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 6806 /* ds_sub_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6806 /* ds_sub_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 6806 /* ds_sub_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 6806 /* ds_sub_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 6806 /* ds_sub_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6806 /* ds_sub_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6806 /* ds_sub_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6806 /* ds_sub_rtn_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6806 /* ds_sub_rtn_u32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6806 /* ds_sub_rtn_u32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6821 /* ds_sub_rtn_u64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 6821 /* ds_sub_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 6821 /* ds_sub_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 6821 /* ds_sub_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 6821 /* ds_sub_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 6821 /* ds_sub_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 6821 /* ds_sub_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 6821 /* ds_sub_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 6821 /* ds_sub_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6821 /* ds_sub_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 6821 /* ds_sub_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 6821 /* ds_sub_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6821 /* ds_sub_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6821 /* ds_sub_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 6821 /* ds_sub_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 6821 /* ds_sub_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6821 /* ds_sub_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 6821 /* ds_sub_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 6821 /* ds_sub_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 6821 /* ds_sub_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 6821 /* ds_sub_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6821 /* ds_sub_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 6821 /* ds_sub_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6821 /* ds_sub_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6821 /* ds_sub_rtn_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6821 /* ds_sub_rtn_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 6821 /* ds_sub_rtn_u64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6821 /* ds_sub_rtn_u64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6836 /* ds_sub_src2_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 6836 /* ds_sub_src2_u32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 6836 /* ds_sub_src2_u32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 6836 /* ds_sub_src2_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 6836 /* ds_sub_src2_u32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 6836 /* ds_sub_src2_u32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 6836 /* ds_sub_src2_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 6836 /* ds_sub_src2_u32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 6836 /* ds_sub_src2_u32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 6852 /* ds_sub_src2_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 6852 /* ds_sub_src2_u64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 6852 /* ds_sub_src2_u64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 6852 /* ds_sub_src2_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 6852 /* ds_sub_src2_u64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 6852 /* ds_sub_src2_u64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 6852 /* ds_sub_src2_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 6852 /* ds_sub_src2_u64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 6852 /* ds_sub_src2_u64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 6868 /* ds_sub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 6868 /* ds_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 6868 /* ds_sub_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 6868 /* ds_sub_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 6868 /* ds_sub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6868 /* ds_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 6868 /* ds_sub_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 6868 /* ds_sub_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6868 /* ds_sub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6868 /* ds_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 6868 /* ds_sub_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 6868 /* ds_sub_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6868 /* ds_sub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 6868 /* ds_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 6868 /* ds_sub_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 6868 /* ds_sub_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 6868 /* ds_sub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6868 /* ds_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 6868 /* ds_sub_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6868 /* ds_sub_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6868 /* ds_sub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6868 /* ds_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 6868 /* ds_sub_u32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6868 /* ds_sub_u32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6879 /* ds_sub_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 6879 /* ds_sub_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 6879 /* ds_sub_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 6879 /* ds_sub_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 6879 /* ds_sub_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6879 /* ds_sub_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 6879 /* ds_sub_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 6879 /* ds_sub_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6879 /* ds_sub_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6879 /* ds_sub_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Plus },
  { 6879 /* ds_sub_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 6879 /* ds_sub_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6879 /* ds_sub_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 6879 /* ds_sub_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 6879 /* ds_sub_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 6879 /* ds_sub_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 6879 /* ds_sub_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6879 /* ds_sub_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 6879 /* ds_sub_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6879 /* ds_sub_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6879 /* ds_sub_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6879 /* ds_sub_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 6879 /* ds_sub_u64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 6879 /* ds_sub_u64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6890 /* ds_swizzle_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 6890 /* ds_swizzle_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 6890 /* ds_swizzle_b32 */, 4 /* 2 */, MCK_Swizzle, AMFBS_isGFX10Only },
  { 6890 /* ds_swizzle_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 6890 /* ds_swizzle_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 6890 /* ds_swizzle_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 6890 /* ds_swizzle_b32 */, 4 /* 2 */, MCK_Swizzle, AMFBS_isGFX11Only },
  { 6890 /* ds_swizzle_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 6890 /* ds_swizzle_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 6890 /* ds_swizzle_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 6890 /* ds_swizzle_b32 */, 4 /* 2 */, MCK_Swizzle, AMFBS_isGFX12Plus },
  { 6890 /* ds_swizzle_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 6890 /* ds_swizzle_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 6890 /* ds_swizzle_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 6890 /* ds_swizzle_b32 */, 4 /* 2 */, MCK_Swizzle, AMFBS_isGFX6GFX7 },
  { 6890 /* ds_swizzle_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 6890 /* ds_swizzle_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6890 /* ds_swizzle_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 6890 /* ds_swizzle_b32 */, 4 /* 2 */, MCK_Swizzle, AMFBS_isGFX8GFX9 },
  { 6890 /* ds_swizzle_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6905 /* ds_wrap_rtn_b32 */, 13 /* 0, 2, 3 */, MCK_AGPR_32, AMFBS_isGFX7Plus_isGFX90APlus },
  { 6905 /* ds_wrap_rtn_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX90APlus },
  { 6905 /* ds_wrap_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX90APlus },
  { 6905 /* ds_wrap_rtn_b32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX90APlus },
  { 6905 /* ds_wrap_rtn_b32 */, 15 /* 0, 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX10Only },
  { 6905 /* ds_wrap_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX10Only },
  { 6905 /* ds_wrap_rtn_b32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX10Only },
  { 6905 /* ds_wrap_rtn_b32 */, 15 /* 0, 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX11Only },
  { 6905 /* ds_wrap_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX11Only },
  { 6905 /* ds_wrap_rtn_b32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX11Only },
  { 6905 /* ds_wrap_rtn_b32 */, 15 /* 0, 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX7Only },
  { 6905 /* ds_wrap_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX7Only },
  { 6905 /* ds_wrap_rtn_b32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX7Only },
  { 6905 /* ds_wrap_rtn_b32 */, 15 /* 0, 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 6905 /* ds_wrap_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 6905 /* ds_wrap_rtn_b32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 6905 /* ds_wrap_rtn_b32 */, 15 /* 0, 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 6905 /* ds_wrap_rtn_b32 */, 16 /* 4 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 6905 /* ds_wrap_rtn_b32 */, 48 /* 4, 5 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 6921 /* ds_write2_b32 */, 6 /* 1, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 6921 /* ds_write2_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 6921 /* ds_write2_b32 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX90APlus },
  { 6921 /* ds_write2_b32 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX90APlus },
  { 6921 /* ds_write2_b32 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 6921 /* ds_write2_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 6921 /* ds_write2_b32 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX10Only },
  { 6921 /* ds_write2_b32 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX10Only },
  { 6921 /* ds_write2_b32 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX10Only },
  { 6921 /* ds_write2_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 6921 /* ds_write2_b32 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX6GFX7 },
  { 6921 /* ds_write2_b32 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX6GFX7 },
  { 6921 /* ds_write2_b32 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 6921 /* ds_write2_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6921 /* ds_write2_b32 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 6921 /* ds_write2_b32 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 6921 /* ds_write2_b32 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6921 /* ds_write2_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6921 /* ds_write2_b32 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 6921 /* ds_write2_b32 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 6921 /* ds_write2_b32 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6935 /* ds_write2_b64 */, 6 /* 1, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 6935 /* ds_write2_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 6935 /* ds_write2_b64 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX90APlus },
  { 6935 /* ds_write2_b64 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX90APlus },
  { 6935 /* ds_write2_b64 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 6935 /* ds_write2_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 6935 /* ds_write2_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 6935 /* ds_write2_b64 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX10Only },
  { 6935 /* ds_write2_b64 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX10Only },
  { 6935 /* ds_write2_b64 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX10Only },
  { 6935 /* ds_write2_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 6935 /* ds_write2_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 6935 /* ds_write2_b64 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX6GFX7 },
  { 6935 /* ds_write2_b64 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX6GFX7 },
  { 6935 /* ds_write2_b64 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 6935 /* ds_write2_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6935 /* ds_write2_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 6935 /* ds_write2_b64 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 6935 /* ds_write2_b64 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 6935 /* ds_write2_b64 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6935 /* ds_write2_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6935 /* ds_write2_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 6935 /* ds_write2_b64 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 6935 /* ds_write2_b64 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 6935 /* ds_write2_b64 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6949 /* ds_write2st64_b32 */, 6 /* 1, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 6949 /* ds_write2st64_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 6949 /* ds_write2st64_b32 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX90APlus },
  { 6949 /* ds_write2st64_b32 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX90APlus },
  { 6949 /* ds_write2st64_b32 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 6949 /* ds_write2st64_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 6949 /* ds_write2st64_b32 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX10Only },
  { 6949 /* ds_write2st64_b32 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX10Only },
  { 6949 /* ds_write2st64_b32 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX10Only },
  { 6949 /* ds_write2st64_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 6949 /* ds_write2st64_b32 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX6GFX7 },
  { 6949 /* ds_write2st64_b32 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX6GFX7 },
  { 6949 /* ds_write2st64_b32 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 6949 /* ds_write2st64_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6949 /* ds_write2st64_b32 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 6949 /* ds_write2st64_b32 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 6949 /* ds_write2st64_b32 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6949 /* ds_write2st64_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6949 /* ds_write2st64_b32 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 6949 /* ds_write2st64_b32 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 6949 /* ds_write2st64_b32 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6967 /* ds_write2st64_b64 */, 6 /* 1, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 6967 /* ds_write2st64_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 6967 /* ds_write2st64_b64 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX90APlus },
  { 6967 /* ds_write2st64_b64 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX90APlus },
  { 6967 /* ds_write2st64_b64 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 6967 /* ds_write2st64_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 6967 /* ds_write2st64_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 6967 /* ds_write2st64_b64 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX10Only },
  { 6967 /* ds_write2st64_b64 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX10Only },
  { 6967 /* ds_write2st64_b64 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX10Only },
  { 6967 /* ds_write2st64_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 6967 /* ds_write2st64_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 6967 /* ds_write2st64_b64 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX6GFX7 },
  { 6967 /* ds_write2st64_b64 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX6GFX7 },
  { 6967 /* ds_write2st64_b64 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 6967 /* ds_write2st64_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6967 /* ds_write2st64_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 6967 /* ds_write2st64_b64 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 6967 /* ds_write2st64_b64 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 6967 /* ds_write2st64_b64 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6967 /* ds_write2st64_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 6967 /* ds_write2st64_b64 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 6967 /* ds_write2st64_b64 */, 8 /* 3 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 6967 /* ds_write2st64_b64 */, 24 /* 3, 4 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 6967 /* ds_write2st64_b64 */, 56 /* 3, 4, 5 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 6985 /* ds_write_addtid_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasDSAddTid_isGFX10Only },
  { 6985 /* ds_write_addtid_b32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDSAddTid_isGFX10Only },
  { 6985 /* ds_write_addtid_b32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDSAddTid_isGFX10Only },
  { 6985 /* ds_write_addtid_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasDSAddTid_isGFX8GFX9 },
  { 6985 /* ds_write_addtid_b32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDSAddTid_isGFX8GFX9 },
  { 6985 /* ds_write_addtid_b32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDSAddTid_isGFX8GFX9 },
  { 7005 /* ds_write_b128 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX10Only },
  { 7005 /* ds_write_b128 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX7Plus_isGFX10Only },
  { 7005 /* ds_write_b128 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX10Only },
  { 7005 /* ds_write_b128 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX10Only },
  { 7005 /* ds_write_b128 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX7Only },
  { 7005 /* ds_write_b128 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX7Plus_isGFX7Only },
  { 7005 /* ds_write_b128 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX7Only },
  { 7005 /* ds_write_b128 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX7Only },
  { 7005 /* ds_write_b128 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 7005 /* ds_write_b128 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 7005 /* ds_write_b128 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 7005 /* ds_write_b128 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 7005 /* ds_write_b128 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 7005 /* ds_write_b128 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 7005 /* ds_write_b128 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 7005 /* ds_write_b128 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 7019 /* ds_write_b16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 7019 /* ds_write_b16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 7019 /* ds_write_b16 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 7019 /* ds_write_b16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 7019 /* ds_write_b16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 7019 /* ds_write_b16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 7019 /* ds_write_b16 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 7019 /* ds_write_b16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 7019 /* ds_write_b16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7019 /* ds_write_b16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 7019 /* ds_write_b16 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 7019 /* ds_write_b16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7019 /* ds_write_b16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7019 /* ds_write_b16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 7019 /* ds_write_b16 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 7019 /* ds_write_b16 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7032 /* ds_write_b16_d16_hi */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 7032 /* ds_write_b16_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 7032 /* ds_write_b16_d16_hi */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 7032 /* ds_write_b16_d16_hi */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX10Only },
  { 7032 /* ds_write_b16_d16_hi */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 7032 /* ds_write_b16_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 7032 /* ds_write_b16_d16_hi */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 7032 /* ds_write_b16_d16_hi */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 7052 /* ds_write_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 7052 /* ds_write_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 7052 /* ds_write_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 7052 /* ds_write_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 7052 /* ds_write_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 7052 /* ds_write_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 7052 /* ds_write_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 7052 /* ds_write_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 7052 /* ds_write_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7052 /* ds_write_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 7052 /* ds_write_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 7052 /* ds_write_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7052 /* ds_write_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7052 /* ds_write_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 7052 /* ds_write_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 7052 /* ds_write_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7065 /* ds_write_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 7065 /* ds_write_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 7065 /* ds_write_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 7065 /* ds_write_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 7065 /* ds_write_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 7065 /* ds_write_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 7065 /* ds_write_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 7065 /* ds_write_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 7065 /* ds_write_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7065 /* ds_write_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 7065 /* ds_write_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 7065 /* ds_write_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7065 /* ds_write_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7065 /* ds_write_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 7065 /* ds_write_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 7065 /* ds_write_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7078 /* ds_write_b8 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 7078 /* ds_write_b8 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 7078 /* ds_write_b8 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 7078 /* ds_write_b8 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 7078 /* ds_write_b8 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 7078 /* ds_write_b8 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 7078 /* ds_write_b8 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 7078 /* ds_write_b8 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 7078 /* ds_write_b8 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7078 /* ds_write_b8 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 7078 /* ds_write_b8 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 7078 /* ds_write_b8 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7078 /* ds_write_b8 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7078 /* ds_write_b8 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 7078 /* ds_write_b8 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 7078 /* ds_write_b8 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7090 /* ds_write_b8_d16_hi */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX10Only },
  { 7090 /* ds_write_b8_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 7090 /* ds_write_b8_d16_hi */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 7090 /* ds_write_b8_d16_hi */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX10Only },
  { 7090 /* ds_write_b8_d16_hi */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 7090 /* ds_write_b8_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 7090 /* ds_write_b8_d16_hi */, 4 /* 2 */, MCK_Offset, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 7090 /* ds_write_b8_d16_hi */, 12 /* 2, 3 */, MCK_GDS, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 7109 /* ds_write_b96 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX10Only },
  { 7109 /* ds_write_b96 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX7Plus_isGFX10Only },
  { 7109 /* ds_write_b96 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX10Only },
  { 7109 /* ds_write_b96 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX10Only },
  { 7109 /* ds_write_b96 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX7Only },
  { 7109 /* ds_write_b96 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX7Plus_isGFX7Only },
  { 7109 /* ds_write_b96 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX7Only },
  { 7109 /* ds_write_b96 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX7Only },
  { 7109 /* ds_write_b96 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 7109 /* ds_write_b96 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 7109 /* ds_write_b96 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 7109 /* ds_write_b96 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 7109 /* ds_write_b96 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 7109 /* ds_write_b96 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 7109 /* ds_write_b96 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 7109 /* ds_write_b96 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX7Plus_isGFX8GFX9 },
  { 7122 /* ds_write_src2_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 7122 /* ds_write_src2_b32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 7122 /* ds_write_src2_b32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 7122 /* ds_write_src2_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 7122 /* ds_write_src2_b32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 7122 /* ds_write_src2_b32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 7122 /* ds_write_src2_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 7122 /* ds_write_src2_b32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 7122 /* ds_write_src2_b32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 7140 /* ds_write_src2_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 7140 /* ds_write_src2_b64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 7140 /* ds_write_src2_b64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 7140 /* ds_write_src2_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 7140 /* ds_write_src2_b64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 7140 /* ds_write_src2_b64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 7140 /* ds_write_src2_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 7140 /* ds_write_src2_b64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 7140 /* ds_write_src2_b64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 1 /* 0 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 12 /* 2, 3 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX90APlus },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX90APlus },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 14 /* 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX10Only },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX10Only },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX10Only },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 14 /* 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX6GFX7 },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX6GFX7 },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 14 /* 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 14 /* 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 7158 /* ds_wrxchg2_rtn_b32 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 1 /* 0 */, MCK_AReg_128, AMFBS_isGFX90APlus },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 12 /* 2, 3 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX90APlus },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX90APlus },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 12 /* 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX10Only },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX10Only },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX10Only },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX10Only },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 12 /* 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX6GFX7 },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX6GFX7 },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 12 /* 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX8GFX9 },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 12 /* 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX8GFX9 },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 7177 /* ds_wrxchg2_rtn_b64 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 1 /* 0 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 12 /* 2, 3 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX90APlus },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX90APlus },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 14 /* 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX10Only },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX10Only },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX10Only },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 14 /* 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX6GFX7 },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX6GFX7 },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 14 /* 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 14 /* 1, 2, 3 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 7196 /* ds_wrxchg2st64_rtn_b32 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 1 /* 0 */, MCK_AReg_128, AMFBS_isGFX90APlus },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 12 /* 2, 3 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX90APlus },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX90APlus },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 12 /* 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX10Only },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX10Only },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX10Only },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX10Only },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 12 /* 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX6GFX7 },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX6GFX7 },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX6GFX7 },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 12 /* 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX8GFX9 },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 12 /* 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX8GFX9 },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 16 /* 4 */, MCK_Offset0, AMFBS_isGFX8GFX9 },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 48 /* 4, 5 */, MCK_Offset1, AMFBS_isGFX8GFX9 },
  { 7219 /* ds_wrxchg2st64_rtn_b64 */, 112 /* 4, 5, 6 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7242 /* ds_wrxchg_rtn_b32 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 7242 /* ds_wrxchg_rtn_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 7242 /* ds_wrxchg_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 7242 /* ds_wrxchg_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 7242 /* ds_wrxchg_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 7242 /* ds_wrxchg_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 7242 /* ds_wrxchg_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 7242 /* ds_wrxchg_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 7242 /* ds_wrxchg_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 7242 /* ds_wrxchg_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 7242 /* ds_wrxchg_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7242 /* ds_wrxchg_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 7242 /* ds_wrxchg_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7242 /* ds_wrxchg_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7242 /* ds_wrxchg_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 7242 /* ds_wrxchg_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7260 /* ds_wrxchg_rtn_b64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 7260 /* ds_wrxchg_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 7260 /* ds_wrxchg_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 7260 /* ds_wrxchg_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 7260 /* ds_wrxchg_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 7260 /* ds_wrxchg_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 7260 /* ds_wrxchg_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 7260 /* ds_wrxchg_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 7260 /* ds_wrxchg_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 7260 /* ds_wrxchg_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 7260 /* ds_wrxchg_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 7260 /* ds_wrxchg_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 7260 /* ds_wrxchg_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7260 /* ds_wrxchg_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 7260 /* ds_wrxchg_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 7260 /* ds_wrxchg_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7260 /* ds_wrxchg_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7260 /* ds_wrxchg_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 7260 /* ds_wrxchg_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 7260 /* ds_wrxchg_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7278 /* ds_xor_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 7278 /* ds_xor_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Only },
  { 7278 /* ds_xor_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 7278 /* ds_xor_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 7278 /* ds_xor_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 7278 /* ds_xor_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX11Only },
  { 7278 /* ds_xor_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 7278 /* ds_xor_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 7278 /* ds_xor_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 7278 /* ds_xor_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX12Plus },
  { 7278 /* ds_xor_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 7278 /* ds_xor_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 7278 /* ds_xor_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 7278 /* ds_xor_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX6GFX7 },
  { 7278 /* ds_xor_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 7278 /* ds_xor_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 7278 /* ds_xor_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7278 /* ds_xor_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 7278 /* ds_xor_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 7278 /* ds_xor_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7278 /* ds_xor_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7278 /* ds_xor_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX8GFX9 },
  { 7278 /* ds_xor_b32 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 7278 /* ds_xor_b32 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7289 /* ds_xor_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 7289 /* ds_xor_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Only },
  { 7289 /* ds_xor_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX10Only },
  { 7289 /* ds_xor_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX10Only },
  { 7289 /* ds_xor_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 7289 /* ds_xor_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX11Only },
  { 7289 /* ds_xor_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX11Only },
  { 7289 /* ds_xor_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX11Only },
  { 7289 /* ds_xor_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 7289 /* ds_xor_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX12Plus },
  { 7289 /* ds_xor_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 7289 /* ds_xor_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 7289 /* ds_xor_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 7289 /* ds_xor_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 7289 /* ds_xor_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 7289 /* ds_xor_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 7289 /* ds_xor_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7289 /* ds_xor_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 7289 /* ds_xor_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 7289 /* ds_xor_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7289 /* ds_xor_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7289 /* ds_xor_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 7289 /* ds_xor_b64 */, 4 /* 2 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 7289 /* ds_xor_b64 */, 12 /* 2, 3 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7300 /* ds_xor_rtn_b32 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus },
  { 7300 /* ds_xor_rtn_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 7300 /* ds_xor_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 7300 /* ds_xor_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 7300 /* ds_xor_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 7300 /* ds_xor_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 7300 /* ds_xor_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 7300 /* ds_xor_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 7300 /* ds_xor_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 7300 /* ds_xor_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 7300 /* ds_xor_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 7300 /* ds_xor_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 7300 /* ds_xor_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 7300 /* ds_xor_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 7300 /* ds_xor_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 7300 /* ds_xor_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 7300 /* ds_xor_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7300 /* ds_xor_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 7300 /* ds_xor_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7300 /* ds_xor_rtn_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7300 /* ds_xor_rtn_b32 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 7300 /* ds_xor_rtn_b32 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7315 /* ds_xor_rtn_b64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus },
  { 7315 /* ds_xor_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus },
  { 7315 /* ds_xor_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX90APlus },
  { 7315 /* ds_xor_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX90APlus },
  { 7315 /* ds_xor_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Only },
  { 7315 /* ds_xor_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Only },
  { 7315 /* ds_xor_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX10Only },
  { 7315 /* ds_xor_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX10Only },
  { 7315 /* ds_xor_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX11Only },
  { 7315 /* ds_xor_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX11Only },
  { 7315 /* ds_xor_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX11Only },
  { 7315 /* ds_xor_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX11Only },
  { 7315 /* ds_xor_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus },
  { 7315 /* ds_xor_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus },
  { 7315 /* ds_xor_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX12Plus },
  { 7315 /* ds_xor_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX12Plus },
  { 7315 /* ds_xor_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX6GFX7 },
  { 7315 /* ds_xor_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX6GFX7 },
  { 7315 /* ds_xor_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX6GFX7 },
  { 7315 /* ds_xor_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX6GFX7 },
  { 7315 /* ds_xor_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7315 /* ds_xor_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 7315 /* ds_xor_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 7315 /* ds_xor_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7315 /* ds_xor_rtn_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX8GFX9 },
  { 7315 /* ds_xor_rtn_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9 },
  { 7315 /* ds_xor_rtn_b64 */, 8 /* 3 */, MCK_Offset, AMFBS_isGFX8GFX9 },
  { 7315 /* ds_xor_rtn_b64 */, 24 /* 3, 4 */, MCK_GDS, AMFBS_isGFX8GFX9 },
  { 7330 /* ds_xor_src2_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 7330 /* ds_xor_src2_b32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 7330 /* ds_xor_src2_b32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 7330 /* ds_xor_src2_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 7330 /* ds_xor_src2_b32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 7330 /* ds_xor_src2_b32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 7330 /* ds_xor_src2_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 7330 /* ds_xor_src2_b32 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 7330 /* ds_xor_src2_b32 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 7346 /* ds_xor_src2_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 7346 /* ds_xor_src2_b64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 7346 /* ds_xor_src2_b64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX10Only },
  { 7346 /* ds_xor_src2_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 7346 /* ds_xor_src2_b64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 7346 /* ds_xor_src2_b64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX6GFX7 },
  { 7346 /* ds_xor_src2_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 7346 /* ds_xor_src2_b64 */, 2 /* 1 */, MCK_Offset, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 7346 /* ds_xor_src2_b64 */, 6 /* 1, 2 */, MCK_GDS, AMFBS_HasDsSrc2Insts_isGFX8GFX9 },
  { 7362 /* exp */, 30 /* 1, 2, 3, 4 */, MCK_VReg32OrOff, AMFBS_isGFX11Only },
  { 7362 /* exp */, 1 /* 0 */, MCK_ExpTgt, AMFBS_isGFX11Only },
  { 7362 /* exp */, 32 /* 5 */, MCK_done, AMFBS_isGFX11Only },
  { 7362 /* exp */, 30 /* 1, 2, 3, 4 */, MCK_VReg32OrOff, AMFBS_isGFX11Only },
  { 7362 /* exp */, 1 /* 0 */, MCK_ExpTgt, AMFBS_isGFX11Only },
  { 7362 /* exp */, 32 /* 5 */, MCK_row_95_en, AMFBS_isGFX11Only },
  { 7362 /* exp */, 30 /* 1, 2, 3, 4 */, MCK_VReg32OrOff, AMFBS_isGFX11Only },
  { 7362 /* exp */, 1 /* 0 */, MCK_ExpTgt, AMFBS_isGFX11Only },
  { 7362 /* exp */, 32 /* 5 */, MCK_done, AMFBS_isGFX11Only },
  { 7362 /* exp */, 64 /* 6 */, MCK_row_95_en, AMFBS_isGFX11Only },
  { 7362 /* exp */, 30 /* 1, 2, 3, 4 */, MCK_VReg32OrOff, AMFBS_isGFX11Only },
  { 7362 /* exp */, 1 /* 0 */, MCK_ExpTgt, AMFBS_isGFX11Only },
  { 7362 /* exp */, 30 /* 1, 2, 3, 4 */, MCK_VReg32OrOff, AMFBS_isNotGFX90APlus_isGFX8GFX9 },
  { 7362 /* exp */, 32 /* 5 */, MCK_ExpCompr, AMFBS_isNotGFX90APlus_isGFX8GFX9 },
  { 7362 /* exp */, 96 /* 5, 6 */, MCK_ExpVM, AMFBS_isNotGFX90APlus_isGFX8GFX9 },
  { 7362 /* exp */, 1 /* 0 */, MCK_ExpTgt, AMFBS_isNotGFX90APlus_isGFX8GFX9 },
  { 7362 /* exp */, 30 /* 1, 2, 3, 4 */, MCK_VReg32OrOff, AMFBS_isGFX10Only },
  { 7362 /* exp */, 32 /* 5 */, MCK_ExpCompr, AMFBS_isGFX10Only },
  { 7362 /* exp */, 96 /* 5, 6 */, MCK_ExpVM, AMFBS_isGFX10Only },
  { 7362 /* exp */, 1 /* 0 */, MCK_ExpTgt, AMFBS_isGFX10Only },
  { 7362 /* exp */, 30 /* 1, 2, 3, 4 */, MCK_VReg32OrOff, AMFBS_isGFX6GFX7 },
  { 7362 /* exp */, 32 /* 5 */, MCK_ExpCompr, AMFBS_isGFX6GFX7 },
  { 7362 /* exp */, 96 /* 5, 6 */, MCK_ExpVM, AMFBS_isGFX6GFX7 },
  { 7362 /* exp */, 1 /* 0 */, MCK_ExpTgt, AMFBS_isGFX6GFX7 },
  { 7362 /* exp */, 32 /* 5 */, MCK_done, AMFBS_isNotGFX90APlus_isGFX8GFX9 },
  { 7362 /* exp */, 30 /* 1, 2, 3, 4 */, MCK_VReg32OrOff, AMFBS_isNotGFX90APlus_isGFX8GFX9 },
  { 7362 /* exp */, 64 /* 6 */, MCK_ExpCompr, AMFBS_isNotGFX90APlus_isGFX8GFX9 },
  { 7362 /* exp */, 192 /* 6, 7 */, MCK_ExpVM, AMFBS_isNotGFX90APlus_isGFX8GFX9 },
  { 7362 /* exp */, 1 /* 0 */, MCK_ExpTgt, AMFBS_isNotGFX90APlus_isGFX8GFX9 },
  { 7362 /* exp */, 32 /* 5 */, MCK_done, AMFBS_isGFX10Only },
  { 7362 /* exp */, 30 /* 1, 2, 3, 4 */, MCK_VReg32OrOff, AMFBS_isGFX10Only },
  { 7362 /* exp */, 64 /* 6 */, MCK_ExpCompr, AMFBS_isGFX10Only },
  { 7362 /* exp */, 192 /* 6, 7 */, MCK_ExpVM, AMFBS_isGFX10Only },
  { 7362 /* exp */, 1 /* 0 */, MCK_ExpTgt, AMFBS_isGFX10Only },
  { 7362 /* exp */, 32 /* 5 */, MCK_done, AMFBS_isGFX6GFX7 },
  { 7362 /* exp */, 30 /* 1, 2, 3, 4 */, MCK_VReg32OrOff, AMFBS_isGFX6GFX7 },
  { 7362 /* exp */, 64 /* 6 */, MCK_ExpCompr, AMFBS_isGFX6GFX7 },
  { 7362 /* exp */, 192 /* 6, 7 */, MCK_ExpVM, AMFBS_isGFX6GFX7 },
  { 7362 /* exp */, 1 /* 0 */, MCK_ExpTgt, AMFBS_isGFX6GFX7 },
  { 7366 /* export */, 30 /* 1, 2, 3, 4 */, MCK_VReg32OrOff, AMFBS_HasExportInsts_isGFX12Only },
  { 7366 /* export */, 1 /* 0 */, MCK_ExpTgt, AMFBS_HasExportInsts_isGFX12Only },
  { 7366 /* export */, 32 /* 5 */, MCK_done, AMFBS_HasExportInsts_isGFX12Only },
  { 7366 /* export */, 30 /* 1, 2, 3, 4 */, MCK_VReg32OrOff, AMFBS_HasExportInsts_isGFX12Only },
  { 7366 /* export */, 1 /* 0 */, MCK_ExpTgt, AMFBS_HasExportInsts_isGFX12Only },
  { 7366 /* export */, 32 /* 5 */, MCK_row_95_en, AMFBS_HasExportInsts_isGFX12Only },
  { 7366 /* export */, 30 /* 1, 2, 3, 4 */, MCK_VReg32OrOff, AMFBS_HasExportInsts_isGFX12Only },
  { 7366 /* export */, 1 /* 0 */, MCK_ExpTgt, AMFBS_HasExportInsts_isGFX12Only },
  { 7366 /* export */, 32 /* 5 */, MCK_done, AMFBS_HasExportInsts_isGFX12Only },
  { 7366 /* export */, 64 /* 6 */, MCK_row_95_en, AMFBS_HasExportInsts_isGFX12Only },
  { 7366 /* export */, 30 /* 1, 2, 3, 4 */, MCK_VReg32OrOff, AMFBS_HasExportInsts_isGFX12Only },
  { 7366 /* export */, 1 /* 0 */, MCK_ExpTgt, AMFBS_HasExportInsts_isGFX12Only },
  { 7373 /* flat_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7373 /* flat_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7373 /* flat_atomic_add */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7373 /* flat_atomic_add */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7373 /* flat_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7373 /* flat_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7373 /* flat_atomic_add */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7373 /* flat_atomic_add */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7373 /* flat_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7373 /* flat_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7373 /* flat_atomic_add */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7373 /* flat_atomic_add */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7373 /* flat_atomic_add */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7373 /* flat_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7373 /* flat_atomic_add */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7373 /* flat_atomic_add */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7373 /* flat_atomic_add */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7373 /* flat_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7373 /* flat_atomic_add */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7373 /* flat_atomic_add */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7373 /* flat_atomic_add */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7373 /* flat_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7373 /* flat_atomic_add */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7373 /* flat_atomic_add */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7373 /* flat_atomic_add */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7373 /* flat_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7373 /* flat_atomic_add */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7373 /* flat_atomic_add */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7389 /* flat_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAtomicFaddF32Inst_isGFX11Only },
  { 7389 /* flat_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAtomicFaddF32Inst_isGFX11Only },
  { 7389 /* flat_atomic_add_f32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAtomicFaddF32Inst_isGFX11Only },
  { 7389 /* flat_atomic_add_f32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAtomicFaddF32Inst_isGFX11Only },
  { 7389 /* flat_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAtomicFaddF32Inst_isGFX12Only },
  { 7389 /* flat_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAtomicFaddF32Inst_isGFX12Only },
  { 7389 /* flat_atomic_add_f32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAtomicFaddF32Inst_isGFX12Only },
  { 7389 /* flat_atomic_add_f32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAtomicFaddF32Inst_isGFX12Only },
  { 7389 /* flat_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAtomicFaddF32Inst_isGFX940Plus },
  { 7389 /* flat_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAtomicFaddF32Inst_isGFX940Plus },
  { 7389 /* flat_atomic_add_f32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAtomicFaddF32Inst_isGFX940Plus },
  { 7389 /* flat_atomic_add_f32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAtomicFaddF32Inst_isGFX940Plus },
  { 7389 /* flat_atomic_add_f32 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasFlatAtomicFaddF32Inst_isGFX940Plus },
  { 7389 /* flat_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAtomicFaddF32Inst_isGFX940Plus },
  { 7389 /* flat_atomic_add_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAtomicFaddF32Inst_isGFX940Plus },
  { 7389 /* flat_atomic_add_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAtomicFaddF32Inst_isGFX940Plus },
  { 7389 /* flat_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAtomicFaddF32Inst_isGFX12Only },
  { 7389 /* flat_atomic_add_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAtomicFaddF32Inst_isGFX12Only },
  { 7389 /* flat_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasFlatAtomicFaddF32Inst_isGFX12Only },
  { 7389 /* flat_atomic_add_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAtomicFaddF32Inst_isGFX12Only },
  { 7389 /* flat_atomic_add_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAtomicFaddF32Inst_isGFX12Only },
  { 7389 /* flat_atomic_add_f32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAtomicFaddF32Inst_isGFX11Only },
  { 7389 /* flat_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAtomicFaddF32Inst_isGFX11Only },
  { 7389 /* flat_atomic_add_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAtomicFaddF32Inst_isGFX11Only },
  { 7389 /* flat_atomic_add_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAtomicFaddF32Inst_isGFX11Only },
  { 7389 /* flat_atomic_add_f32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAtomicFaddF32Inst_isGFX12Only },
  { 7389 /* flat_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAtomicFaddF32Inst_isGFX12Only },
  { 7389 /* flat_atomic_add_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAtomicFaddF32Inst_isGFX12Only },
  { 7389 /* flat_atomic_add_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAtomicFaddF32Inst_isGFX12Only },
  { 7389 /* flat_atomic_add_f32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAtomicFaddF32Inst_isGFX940Plus },
  { 7389 /* flat_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAtomicFaddF32Inst_isGFX940Plus },
  { 7389 /* flat_atomic_add_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAtomicFaddF32Inst_isGFX940Plus },
  { 7389 /* flat_atomic_add_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAtomicFaddF32Inst_isGFX940Plus },
  { 7389 /* flat_atomic_add_f32 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAtomicFaddF32Inst_isGFX12Only },
  { 7389 /* flat_atomic_add_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAtomicFaddF32Inst_isGFX12Only },
  { 7389 /* flat_atomic_add_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAtomicFaddF32Inst_isGFX12Only },
  { 7389 /* flat_atomic_add_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAtomicFaddF32Inst_isGFX12Only },
  { 7409 /* flat_atomic_add_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 7409 /* flat_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 7409 /* flat_atomic_add_f64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 7409 /* flat_atomic_add_f64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 7409 /* flat_atomic_add_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 7409 /* flat_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 7409 /* flat_atomic_add_f64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 7409 /* flat_atomic_add_f64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 7409 /* flat_atomic_add_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 7409 /* flat_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 7409 /* flat_atomic_add_f64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 7409 /* flat_atomic_add_f64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 7409 /* flat_atomic_add_f64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 7409 /* flat_atomic_add_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 7409 /* flat_atomic_add_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 7409 /* flat_atomic_add_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 7409 /* flat_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 7409 /* flat_atomic_add_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 7409 /* flat_atomic_add_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 7409 /* flat_atomic_add_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 7409 /* flat_atomic_add_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 7409 /* flat_atomic_add_f64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 7409 /* flat_atomic_add_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 7409 /* flat_atomic_add_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 7409 /* flat_atomic_add_f64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 7409 /* flat_atomic_add_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 7409 /* flat_atomic_add_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 7409 /* flat_atomic_add_f64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 7409 /* flat_atomic_add_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 7409 /* flat_atomic_add_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 7409 /* flat_atomic_add_f64 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 7409 /* flat_atomic_add_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 7409 /* flat_atomic_add_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 7409 /* flat_atomic_add_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 7409 /* flat_atomic_add_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 7429 /* flat_atomic_add_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7429 /* flat_atomic_add_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7429 /* flat_atomic_add_u32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7429 /* flat_atomic_add_u32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7429 /* flat_atomic_add_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7429 /* flat_atomic_add_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7429 /* flat_atomic_add_u32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7429 /* flat_atomic_add_u32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7429 /* flat_atomic_add_u32 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7429 /* flat_atomic_add_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7429 /* flat_atomic_add_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7429 /* flat_atomic_add_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7429 /* flat_atomic_add_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7429 /* flat_atomic_add_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7429 /* flat_atomic_add_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7429 /* flat_atomic_add_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7429 /* flat_atomic_add_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7429 /* flat_atomic_add_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7429 /* flat_atomic_add_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7429 /* flat_atomic_add_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7429 /* flat_atomic_add_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7429 /* flat_atomic_add_u32 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7429 /* flat_atomic_add_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7429 /* flat_atomic_add_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7429 /* flat_atomic_add_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7449 /* flat_atomic_add_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7449 /* flat_atomic_add_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7449 /* flat_atomic_add_u64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7449 /* flat_atomic_add_u64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7449 /* flat_atomic_add_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7449 /* flat_atomic_add_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7449 /* flat_atomic_add_u64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7449 /* flat_atomic_add_u64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7449 /* flat_atomic_add_u64 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7449 /* flat_atomic_add_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7449 /* flat_atomic_add_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7449 /* flat_atomic_add_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7449 /* flat_atomic_add_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7449 /* flat_atomic_add_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7449 /* flat_atomic_add_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7449 /* flat_atomic_add_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7449 /* flat_atomic_add_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7449 /* flat_atomic_add_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7449 /* flat_atomic_add_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7449 /* flat_atomic_add_u64 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7449 /* flat_atomic_add_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7449 /* flat_atomic_add_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7449 /* flat_atomic_add_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7449 /* flat_atomic_add_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7469 /* flat_atomic_add_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7469 /* flat_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7469 /* flat_atomic_add_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7469 /* flat_atomic_add_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7469 /* flat_atomic_add_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7469 /* flat_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7469 /* flat_atomic_add_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7469 /* flat_atomic_add_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7469 /* flat_atomic_add_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7469 /* flat_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7469 /* flat_atomic_add_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7469 /* flat_atomic_add_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7469 /* flat_atomic_add_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7469 /* flat_atomic_add_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7469 /* flat_atomic_add_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7469 /* flat_atomic_add_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7469 /* flat_atomic_add_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7469 /* flat_atomic_add_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7469 /* flat_atomic_add_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7469 /* flat_atomic_add_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7469 /* flat_atomic_add_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7469 /* flat_atomic_add_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7469 /* flat_atomic_add_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7469 /* flat_atomic_add_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7469 /* flat_atomic_add_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7488 /* flat_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7488 /* flat_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7488 /* flat_atomic_and */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7488 /* flat_atomic_and */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7488 /* flat_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7488 /* flat_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7488 /* flat_atomic_and */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7488 /* flat_atomic_and */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7488 /* flat_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7488 /* flat_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7488 /* flat_atomic_and */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7488 /* flat_atomic_and */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7488 /* flat_atomic_and */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7488 /* flat_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7488 /* flat_atomic_and */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7488 /* flat_atomic_and */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7488 /* flat_atomic_and */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7488 /* flat_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7488 /* flat_atomic_and */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7488 /* flat_atomic_and */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7488 /* flat_atomic_and */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7488 /* flat_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7488 /* flat_atomic_and */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7488 /* flat_atomic_and */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7488 /* flat_atomic_and */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7488 /* flat_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7488 /* flat_atomic_and */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7488 /* flat_atomic_and */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7504 /* flat_atomic_and_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7504 /* flat_atomic_and_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7504 /* flat_atomic_and_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7504 /* flat_atomic_and_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7504 /* flat_atomic_and_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7504 /* flat_atomic_and_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7504 /* flat_atomic_and_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7504 /* flat_atomic_and_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7504 /* flat_atomic_and_b32 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7504 /* flat_atomic_and_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7504 /* flat_atomic_and_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7504 /* flat_atomic_and_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7504 /* flat_atomic_and_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7504 /* flat_atomic_and_b32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7504 /* flat_atomic_and_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7504 /* flat_atomic_and_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7504 /* flat_atomic_and_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7504 /* flat_atomic_and_b32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7504 /* flat_atomic_and_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7504 /* flat_atomic_and_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7504 /* flat_atomic_and_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7504 /* flat_atomic_and_b32 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7504 /* flat_atomic_and_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7504 /* flat_atomic_and_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7504 /* flat_atomic_and_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7524 /* flat_atomic_and_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7524 /* flat_atomic_and_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7524 /* flat_atomic_and_b64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7524 /* flat_atomic_and_b64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7524 /* flat_atomic_and_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7524 /* flat_atomic_and_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7524 /* flat_atomic_and_b64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7524 /* flat_atomic_and_b64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7524 /* flat_atomic_and_b64 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7524 /* flat_atomic_and_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7524 /* flat_atomic_and_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7524 /* flat_atomic_and_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7524 /* flat_atomic_and_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7524 /* flat_atomic_and_b64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7524 /* flat_atomic_and_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7524 /* flat_atomic_and_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7524 /* flat_atomic_and_b64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7524 /* flat_atomic_and_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7524 /* flat_atomic_and_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7524 /* flat_atomic_and_b64 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7524 /* flat_atomic_and_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7524 /* flat_atomic_and_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7524 /* flat_atomic_and_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7524 /* flat_atomic_and_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7544 /* flat_atomic_and_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7544 /* flat_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7544 /* flat_atomic_and_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7544 /* flat_atomic_and_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7544 /* flat_atomic_and_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7544 /* flat_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7544 /* flat_atomic_and_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7544 /* flat_atomic_and_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7544 /* flat_atomic_and_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7544 /* flat_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7544 /* flat_atomic_and_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7544 /* flat_atomic_and_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7544 /* flat_atomic_and_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7544 /* flat_atomic_and_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7544 /* flat_atomic_and_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7544 /* flat_atomic_and_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7544 /* flat_atomic_and_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7544 /* flat_atomic_and_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7544 /* flat_atomic_and_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7544 /* flat_atomic_and_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7544 /* flat_atomic_and_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7544 /* flat_atomic_and_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7544 /* flat_atomic_and_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7544 /* flat_atomic_and_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7544 /* flat_atomic_and_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7563 /* flat_atomic_cmpswap */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7563 /* flat_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7563 /* flat_atomic_cmpswap */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7563 /* flat_atomic_cmpswap */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7563 /* flat_atomic_cmpswap */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7563 /* flat_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7563 /* flat_atomic_cmpswap */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7563 /* flat_atomic_cmpswap */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7563 /* flat_atomic_cmpswap */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7563 /* flat_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7563 /* flat_atomic_cmpswap */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7563 /* flat_atomic_cmpswap */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7563 /* flat_atomic_cmpswap */, 4 /* 2 */, MCK_AReg_64, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7563 /* flat_atomic_cmpswap */, 1 /* 0 */, MCK_AGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7563 /* flat_atomic_cmpswap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7563 /* flat_atomic_cmpswap */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7563 /* flat_atomic_cmpswap */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7563 /* flat_atomic_cmpswap */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7563 /* flat_atomic_cmpswap */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7563 /* flat_atomic_cmpswap */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7563 /* flat_atomic_cmpswap */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7563 /* flat_atomic_cmpswap */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7563 /* flat_atomic_cmpswap */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7563 /* flat_atomic_cmpswap */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7563 /* flat_atomic_cmpswap */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7563 /* flat_atomic_cmpswap */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7563 /* flat_atomic_cmpswap */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7563 /* flat_atomic_cmpswap */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7563 /* flat_atomic_cmpswap */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7583 /* flat_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7583 /* flat_atomic_cmpswap_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 3 /* 0, 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 3 /* 0, 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7607 /* flat_atomic_cmpswap_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7631 /* flat_atomic_cmpswap_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 7631 /* flat_atomic_cmpswap_f32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 7631 /* flat_atomic_cmpswap_f32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 7631 /* flat_atomic_cmpswap_f32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 7631 /* flat_atomic_cmpswap_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 7631 /* flat_atomic_cmpswap_f32 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 7631 /* flat_atomic_cmpswap_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 7631 /* flat_atomic_cmpswap_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 7655 /* flat_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7655 /* flat_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7655 /* flat_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7655 /* flat_atomic_cmpswap_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7655 /* flat_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7655 /* flat_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7655 /* flat_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7655 /* flat_atomic_cmpswap_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7655 /* flat_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7655 /* flat_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7655 /* flat_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7655 /* flat_atomic_cmpswap_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7655 /* flat_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_AReg_128, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7655 /* flat_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_AReg_64, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7655 /* flat_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7655 /* flat_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7655 /* flat_atomic_cmpswap_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7655 /* flat_atomic_cmpswap_x2 */, 3 /* 0, 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7655 /* flat_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7655 /* flat_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7655 /* flat_atomic_cmpswap_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7655 /* flat_atomic_cmpswap_x2 */, 3 /* 0, 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7655 /* flat_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7655 /* flat_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7655 /* flat_atomic_cmpswap_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7655 /* flat_atomic_cmpswap_x2 */, 3 /* 0, 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7655 /* flat_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7655 /* flat_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7655 /* flat_atomic_cmpswap_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7678 /* flat_atomic_cond_sub_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Only },
  { 7678 /* flat_atomic_cond_sub_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Only },
  { 7678 /* flat_atomic_cond_sub_u32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX12Only },
  { 7678 /* flat_atomic_cond_sub_u32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX12Only },
  { 7678 /* flat_atomic_cond_sub_u32 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_isGFX12Only },
  { 7678 /* flat_atomic_cond_sub_u32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_isGFX12Only },
  { 7678 /* flat_atomic_cond_sub_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_isGFX12Only },
  { 7678 /* flat_atomic_cond_sub_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_isGFX12Only },
  { 7678 /* flat_atomic_cond_sub_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 7678 /* flat_atomic_cond_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus_isGFX12Only },
  { 7678 /* flat_atomic_cond_sub_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX12Plus_isGFX12Only },
  { 7678 /* flat_atomic_cond_sub_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX12Plus_isGFX12Only },
  { 7678 /* flat_atomic_cond_sub_u32 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_isGFX12Plus_isGFX12Only },
  { 7678 /* flat_atomic_cond_sub_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_isGFX12Plus_isGFX12Only },
  { 7678 /* flat_atomic_cond_sub_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_isGFX12Plus_isGFX12Only },
  { 7678 /* flat_atomic_cond_sub_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_isGFX12Plus_isGFX12Only },
  { 7703 /* flat_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7703 /* flat_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7703 /* flat_atomic_dec */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7703 /* flat_atomic_dec */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7703 /* flat_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7703 /* flat_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7703 /* flat_atomic_dec */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7703 /* flat_atomic_dec */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7703 /* flat_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7703 /* flat_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7703 /* flat_atomic_dec */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7703 /* flat_atomic_dec */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7703 /* flat_atomic_dec */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7703 /* flat_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7703 /* flat_atomic_dec */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7703 /* flat_atomic_dec */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7703 /* flat_atomic_dec */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7703 /* flat_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7703 /* flat_atomic_dec */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7703 /* flat_atomic_dec */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7703 /* flat_atomic_dec */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7703 /* flat_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7703 /* flat_atomic_dec */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7703 /* flat_atomic_dec */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7703 /* flat_atomic_dec */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7703 /* flat_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7703 /* flat_atomic_dec */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7703 /* flat_atomic_dec */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7719 /* flat_atomic_dec_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7719 /* flat_atomic_dec_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7719 /* flat_atomic_dec_u32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7719 /* flat_atomic_dec_u32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7719 /* flat_atomic_dec_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7719 /* flat_atomic_dec_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7719 /* flat_atomic_dec_u32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7719 /* flat_atomic_dec_u32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7719 /* flat_atomic_dec_u32 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7719 /* flat_atomic_dec_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7719 /* flat_atomic_dec_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7719 /* flat_atomic_dec_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7719 /* flat_atomic_dec_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7719 /* flat_atomic_dec_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7719 /* flat_atomic_dec_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7719 /* flat_atomic_dec_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7719 /* flat_atomic_dec_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7719 /* flat_atomic_dec_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7719 /* flat_atomic_dec_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7719 /* flat_atomic_dec_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7719 /* flat_atomic_dec_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7719 /* flat_atomic_dec_u32 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7719 /* flat_atomic_dec_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7719 /* flat_atomic_dec_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7719 /* flat_atomic_dec_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7739 /* flat_atomic_dec_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7739 /* flat_atomic_dec_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7739 /* flat_atomic_dec_u64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7739 /* flat_atomic_dec_u64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7739 /* flat_atomic_dec_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7739 /* flat_atomic_dec_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7739 /* flat_atomic_dec_u64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7739 /* flat_atomic_dec_u64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7739 /* flat_atomic_dec_u64 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7739 /* flat_atomic_dec_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7739 /* flat_atomic_dec_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7739 /* flat_atomic_dec_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7739 /* flat_atomic_dec_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7739 /* flat_atomic_dec_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7739 /* flat_atomic_dec_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7739 /* flat_atomic_dec_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7739 /* flat_atomic_dec_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7739 /* flat_atomic_dec_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7739 /* flat_atomic_dec_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7739 /* flat_atomic_dec_u64 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7739 /* flat_atomic_dec_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7739 /* flat_atomic_dec_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7739 /* flat_atomic_dec_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7739 /* flat_atomic_dec_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7759 /* flat_atomic_dec_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7759 /* flat_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7759 /* flat_atomic_dec_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7759 /* flat_atomic_dec_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7759 /* flat_atomic_dec_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7759 /* flat_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7759 /* flat_atomic_dec_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7759 /* flat_atomic_dec_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7759 /* flat_atomic_dec_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7759 /* flat_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7759 /* flat_atomic_dec_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7759 /* flat_atomic_dec_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7759 /* flat_atomic_dec_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7759 /* flat_atomic_dec_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7759 /* flat_atomic_dec_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7759 /* flat_atomic_dec_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7759 /* flat_atomic_dec_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7759 /* flat_atomic_dec_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7759 /* flat_atomic_dec_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7759 /* flat_atomic_dec_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7759 /* flat_atomic_dec_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7759 /* flat_atomic_dec_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7759 /* flat_atomic_dec_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7759 /* flat_atomic_dec_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7759 /* flat_atomic_dec_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7778 /* flat_atomic_fcmpswap */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7778 /* flat_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7778 /* flat_atomic_fcmpswap */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7778 /* flat_atomic_fcmpswap */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7778 /* flat_atomic_fcmpswap */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7778 /* flat_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7778 /* flat_atomic_fcmpswap */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7778 /* flat_atomic_fcmpswap */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7778 /* flat_atomic_fcmpswap */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7778 /* flat_atomic_fcmpswap */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7778 /* flat_atomic_fcmpswap */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7778 /* flat_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7778 /* flat_atomic_fcmpswap */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7778 /* flat_atomic_fcmpswap */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7778 /* flat_atomic_fcmpswap */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7778 /* flat_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7799 /* flat_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX7GFX10_isGFX7Only },
  { 7799 /* flat_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10_isGFX7Only },
  { 7799 /* flat_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX7GFX10_isGFX7Only },
  { 7799 /* flat_atomic_fcmpswap_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX7GFX10_isGFX7Only },
  { 7799 /* flat_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX7GFX10_isGFX10Only },
  { 7799 /* flat_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10_isGFX10Only },
  { 7799 /* flat_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX7GFX10_isGFX10Only },
  { 7799 /* flat_atomic_fcmpswap_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX7GFX10_isGFX10Only },
  { 7799 /* flat_atomic_fcmpswap_x2 */, 3 /* 0, 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10_isGFX7Only },
  { 7799 /* flat_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX7GFX10_isGFX7Only },
  { 7799 /* flat_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX7GFX10_isGFX7Only },
  { 7799 /* flat_atomic_fcmpswap_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX7GFX10_isGFX7Only },
  { 7799 /* flat_atomic_fcmpswap_x2 */, 3 /* 0, 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10_isGFX10Only },
  { 7799 /* flat_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX7GFX10_isGFX10Only },
  { 7799 /* flat_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX7GFX10_isGFX10Only },
  { 7799 /* flat_atomic_fcmpswap_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX7GFX10_isGFX10Only },
  { 7823 /* flat_atomic_fmax */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7823 /* flat_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7823 /* flat_atomic_fmax */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7823 /* flat_atomic_fmax */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7823 /* flat_atomic_fmax */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7823 /* flat_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7823 /* flat_atomic_fmax */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7823 /* flat_atomic_fmax */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7823 /* flat_atomic_fmax */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7823 /* flat_atomic_fmax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7823 /* flat_atomic_fmax */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7823 /* flat_atomic_fmax */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7823 /* flat_atomic_fmax */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7823 /* flat_atomic_fmax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7823 /* flat_atomic_fmax */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7823 /* flat_atomic_fmax */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7840 /* flat_atomic_fmax_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX7Only },
  { 7840 /* flat_atomic_fmax_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX7Only },
  { 7840 /* flat_atomic_fmax_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX7Only },
  { 7840 /* flat_atomic_fmax_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX7Only },
  { 7840 /* flat_atomic_fmax_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX10Only },
  { 7840 /* flat_atomic_fmax_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX10Only },
  { 7840 /* flat_atomic_fmax_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX10Only },
  { 7840 /* flat_atomic_fmax_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX10Only },
  { 7840 /* flat_atomic_fmax_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX7Only },
  { 7840 /* flat_atomic_fmax_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX7Only },
  { 7840 /* flat_atomic_fmax_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX7Only },
  { 7840 /* flat_atomic_fmax_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX10Only },
  { 7840 /* flat_atomic_fmax_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX10Only },
  { 7840 /* flat_atomic_fmax_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX10Only },
  { 7860 /* flat_atomic_fmin */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7860 /* flat_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7860 /* flat_atomic_fmin */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7860 /* flat_atomic_fmin */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7860 /* flat_atomic_fmin */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7860 /* flat_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7860 /* flat_atomic_fmin */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7860 /* flat_atomic_fmin */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7860 /* flat_atomic_fmin */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7860 /* flat_atomic_fmin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7860 /* flat_atomic_fmin */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7860 /* flat_atomic_fmin */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX7GFX10GFX11_isGFX7Only },
  { 7860 /* flat_atomic_fmin */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7860 /* flat_atomic_fmin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7860 /* flat_atomic_fmin */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7860 /* flat_atomic_fmin */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX7GFX10GFX11_isGFX10Only },
  { 7877 /* flat_atomic_fmin_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX7Only },
  { 7877 /* flat_atomic_fmin_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX7Only },
  { 7877 /* flat_atomic_fmin_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX7Only },
  { 7877 /* flat_atomic_fmin_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX7Only },
  { 7877 /* flat_atomic_fmin_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX10Only },
  { 7877 /* flat_atomic_fmin_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX10Only },
  { 7877 /* flat_atomic_fmin_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX10Only },
  { 7877 /* flat_atomic_fmin_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX10Only },
  { 7877 /* flat_atomic_fmin_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX7Only },
  { 7877 /* flat_atomic_fmin_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX7Only },
  { 7877 /* flat_atomic_fmin_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX7Only },
  { 7877 /* flat_atomic_fmin_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX10Only },
  { 7877 /* flat_atomic_fmin_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX10Only },
  { 7877 /* flat_atomic_fmin_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX10Only },
  { 7897 /* flat_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7897 /* flat_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7897 /* flat_atomic_inc */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7897 /* flat_atomic_inc */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7897 /* flat_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7897 /* flat_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7897 /* flat_atomic_inc */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7897 /* flat_atomic_inc */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7897 /* flat_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7897 /* flat_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7897 /* flat_atomic_inc */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7897 /* flat_atomic_inc */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7897 /* flat_atomic_inc */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7897 /* flat_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7897 /* flat_atomic_inc */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7897 /* flat_atomic_inc */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7897 /* flat_atomic_inc */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7897 /* flat_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7897 /* flat_atomic_inc */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7897 /* flat_atomic_inc */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7897 /* flat_atomic_inc */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7897 /* flat_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7897 /* flat_atomic_inc */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7897 /* flat_atomic_inc */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7897 /* flat_atomic_inc */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7897 /* flat_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7897 /* flat_atomic_inc */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7897 /* flat_atomic_inc */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7913 /* flat_atomic_inc_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7913 /* flat_atomic_inc_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7913 /* flat_atomic_inc_u32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7913 /* flat_atomic_inc_u32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7913 /* flat_atomic_inc_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7913 /* flat_atomic_inc_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7913 /* flat_atomic_inc_u32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7913 /* flat_atomic_inc_u32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7913 /* flat_atomic_inc_u32 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7913 /* flat_atomic_inc_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7913 /* flat_atomic_inc_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7913 /* flat_atomic_inc_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7913 /* flat_atomic_inc_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7913 /* flat_atomic_inc_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7913 /* flat_atomic_inc_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7913 /* flat_atomic_inc_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7913 /* flat_atomic_inc_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7913 /* flat_atomic_inc_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7913 /* flat_atomic_inc_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7913 /* flat_atomic_inc_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7913 /* flat_atomic_inc_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7913 /* flat_atomic_inc_u32 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7913 /* flat_atomic_inc_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7913 /* flat_atomic_inc_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7913 /* flat_atomic_inc_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7933 /* flat_atomic_inc_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7933 /* flat_atomic_inc_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7933 /* flat_atomic_inc_u64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7933 /* flat_atomic_inc_u64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7933 /* flat_atomic_inc_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7933 /* flat_atomic_inc_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7933 /* flat_atomic_inc_u64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7933 /* flat_atomic_inc_u64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7933 /* flat_atomic_inc_u64 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7933 /* flat_atomic_inc_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7933 /* flat_atomic_inc_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7933 /* flat_atomic_inc_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7933 /* flat_atomic_inc_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7933 /* flat_atomic_inc_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7933 /* flat_atomic_inc_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7933 /* flat_atomic_inc_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 7933 /* flat_atomic_inc_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7933 /* flat_atomic_inc_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7933 /* flat_atomic_inc_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 7933 /* flat_atomic_inc_u64 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7933 /* flat_atomic_inc_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7933 /* flat_atomic_inc_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7933 /* flat_atomic_inc_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7933 /* flat_atomic_inc_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 7953 /* flat_atomic_inc_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7953 /* flat_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7953 /* flat_atomic_inc_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7953 /* flat_atomic_inc_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7953 /* flat_atomic_inc_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7953 /* flat_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7953 /* flat_atomic_inc_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7953 /* flat_atomic_inc_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7953 /* flat_atomic_inc_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7953 /* flat_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7953 /* flat_atomic_inc_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7953 /* flat_atomic_inc_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7953 /* flat_atomic_inc_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7953 /* flat_atomic_inc_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7953 /* flat_atomic_inc_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7953 /* flat_atomic_inc_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7953 /* flat_atomic_inc_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7953 /* flat_atomic_inc_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7953 /* flat_atomic_inc_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 7953 /* flat_atomic_inc_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7953 /* flat_atomic_inc_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7953 /* flat_atomic_inc_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 7953 /* flat_atomic_inc_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7953 /* flat_atomic_inc_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7953 /* flat_atomic_inc_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 7972 /* flat_atomic_max_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 7972 /* flat_atomic_max_f32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 7972 /* flat_atomic_max_f32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 7972 /* flat_atomic_max_f32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 7972 /* flat_atomic_max_f32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 7972 /* flat_atomic_max_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 7972 /* flat_atomic_max_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 7972 /* flat_atomic_max_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 7992 /* flat_atomic_max_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX940Plus },
  { 7992 /* flat_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX940Plus },
  { 7992 /* flat_atomic_max_f64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX940Plus },
  { 7992 /* flat_atomic_max_f64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX940Plus },
  { 7992 /* flat_atomic_max_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9 },
  { 7992 /* flat_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9 },
  { 7992 /* flat_atomic_max_f64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9 },
  { 7992 /* flat_atomic_max_f64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9 },
  { 7992 /* flat_atomic_max_f64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9 },
  { 7992 /* flat_atomic_max_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9 },
  { 7992 /* flat_atomic_max_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9 },
  { 7992 /* flat_atomic_max_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9 },
  { 7992 /* flat_atomic_max_f64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX940Plus },
  { 7992 /* flat_atomic_max_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX940Plus },
  { 7992 /* flat_atomic_max_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX940Plus },
  { 7992 /* flat_atomic_max_f64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9 },
  { 7992 /* flat_atomic_max_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9 },
  { 7992 /* flat_atomic_max_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9 },
  { 8012 /* flat_atomic_max_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8012 /* flat_atomic_max_i32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8012 /* flat_atomic_max_i32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8012 /* flat_atomic_max_i32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8012 /* flat_atomic_max_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8012 /* flat_atomic_max_i32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8012 /* flat_atomic_max_i32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8012 /* flat_atomic_max_i32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8012 /* flat_atomic_max_i32 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8012 /* flat_atomic_max_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8012 /* flat_atomic_max_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8012 /* flat_atomic_max_i32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8012 /* flat_atomic_max_i32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8012 /* flat_atomic_max_i32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8012 /* flat_atomic_max_i32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8012 /* flat_atomic_max_i32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8012 /* flat_atomic_max_i32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8012 /* flat_atomic_max_i32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8012 /* flat_atomic_max_i32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8012 /* flat_atomic_max_i32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8012 /* flat_atomic_max_i32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8012 /* flat_atomic_max_i32 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8012 /* flat_atomic_max_i32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8012 /* flat_atomic_max_i32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8012 /* flat_atomic_max_i32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8032 /* flat_atomic_max_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8032 /* flat_atomic_max_i64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8032 /* flat_atomic_max_i64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8032 /* flat_atomic_max_i64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8032 /* flat_atomic_max_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8032 /* flat_atomic_max_i64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8032 /* flat_atomic_max_i64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8032 /* flat_atomic_max_i64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8032 /* flat_atomic_max_i64 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8032 /* flat_atomic_max_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8032 /* flat_atomic_max_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8032 /* flat_atomic_max_i64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8032 /* flat_atomic_max_i64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8032 /* flat_atomic_max_i64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8032 /* flat_atomic_max_i64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8032 /* flat_atomic_max_i64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8032 /* flat_atomic_max_i64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8032 /* flat_atomic_max_i64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8032 /* flat_atomic_max_i64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8032 /* flat_atomic_max_i64 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8032 /* flat_atomic_max_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8032 /* flat_atomic_max_i64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8032 /* flat_atomic_max_i64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8032 /* flat_atomic_max_i64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8052 /* flat_atomic_max_num_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX7GFX10GFX11_isGFX12Only },
  { 8052 /* flat_atomic_max_num_f32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX12Only },
  { 8052 /* flat_atomic_max_num_f32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX7GFX10GFX11_isGFX12Only },
  { 8052 /* flat_atomic_max_num_f32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX7GFX10GFX11_isGFX12Only },
  { 8052 /* flat_atomic_max_num_f32 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only },
  { 8052 /* flat_atomic_max_num_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only },
  { 8052 /* flat_atomic_max_num_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only },
  { 8052 /* flat_atomic_max_num_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only },
  { 8052 /* flat_atomic_max_num_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only },
  { 8052 /* flat_atomic_max_num_f32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_isGFX7GFX10GFX11_isGFX12Only },
  { 8052 /* flat_atomic_max_num_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX12Only },
  { 8052 /* flat_atomic_max_num_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX7GFX10GFX11_isGFX12Only },
  { 8052 /* flat_atomic_max_num_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX7GFX10GFX11_isGFX12Only },
  { 8052 /* flat_atomic_max_num_f32 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only },
  { 8052 /* flat_atomic_max_num_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only },
  { 8052 /* flat_atomic_max_num_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only },
  { 8052 /* flat_atomic_max_num_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only },
  { 8076 /* flat_atomic_max_num_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8076 /* flat_atomic_max_num_f64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8076 /* flat_atomic_max_num_f64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8076 /* flat_atomic_max_num_f64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8076 /* flat_atomic_max_num_f64 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8076 /* flat_atomic_max_num_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8076 /* flat_atomic_max_num_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8076 /* flat_atomic_max_num_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8076 /* flat_atomic_max_num_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8076 /* flat_atomic_max_num_f64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8076 /* flat_atomic_max_num_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8076 /* flat_atomic_max_num_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8076 /* flat_atomic_max_num_f64 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8076 /* flat_atomic_max_num_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8076 /* flat_atomic_max_num_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8076 /* flat_atomic_max_num_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8076 /* flat_atomic_max_num_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8100 /* flat_atomic_max_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8100 /* flat_atomic_max_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8100 /* flat_atomic_max_u32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8100 /* flat_atomic_max_u32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8100 /* flat_atomic_max_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8100 /* flat_atomic_max_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8100 /* flat_atomic_max_u32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8100 /* flat_atomic_max_u32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8100 /* flat_atomic_max_u32 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8100 /* flat_atomic_max_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8100 /* flat_atomic_max_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8100 /* flat_atomic_max_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8100 /* flat_atomic_max_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8100 /* flat_atomic_max_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8100 /* flat_atomic_max_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8100 /* flat_atomic_max_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8100 /* flat_atomic_max_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8100 /* flat_atomic_max_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8100 /* flat_atomic_max_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8100 /* flat_atomic_max_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8100 /* flat_atomic_max_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8100 /* flat_atomic_max_u32 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8100 /* flat_atomic_max_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8100 /* flat_atomic_max_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8100 /* flat_atomic_max_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8120 /* flat_atomic_max_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8120 /* flat_atomic_max_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8120 /* flat_atomic_max_u64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8120 /* flat_atomic_max_u64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8120 /* flat_atomic_max_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8120 /* flat_atomic_max_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8120 /* flat_atomic_max_u64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8120 /* flat_atomic_max_u64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8120 /* flat_atomic_max_u64 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8120 /* flat_atomic_max_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8120 /* flat_atomic_max_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8120 /* flat_atomic_max_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8120 /* flat_atomic_max_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8120 /* flat_atomic_max_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8120 /* flat_atomic_max_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8120 /* flat_atomic_max_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8120 /* flat_atomic_max_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8120 /* flat_atomic_max_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8120 /* flat_atomic_max_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8120 /* flat_atomic_max_u64 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8120 /* flat_atomic_max_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8120 /* flat_atomic_max_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8120 /* flat_atomic_max_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8120 /* flat_atomic_max_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8140 /* flat_atomic_min_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 8140 /* flat_atomic_min_f32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 8140 /* flat_atomic_min_f32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 8140 /* flat_atomic_min_f32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 8140 /* flat_atomic_min_f32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 8140 /* flat_atomic_min_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 8140 /* flat_atomic_min_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 8140 /* flat_atomic_min_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX7GFX10GFX11_isGFX11Only },
  { 8160 /* flat_atomic_min_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX940Plus },
  { 8160 /* flat_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX940Plus },
  { 8160 /* flat_atomic_min_f64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX940Plus },
  { 8160 /* flat_atomic_min_f64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX940Plus },
  { 8160 /* flat_atomic_min_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9 },
  { 8160 /* flat_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9 },
  { 8160 /* flat_atomic_min_f64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9 },
  { 8160 /* flat_atomic_min_f64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9 },
  { 8160 /* flat_atomic_min_f64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9 },
  { 8160 /* flat_atomic_min_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9 },
  { 8160 /* flat_atomic_min_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9 },
  { 8160 /* flat_atomic_min_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9 },
  { 8160 /* flat_atomic_min_f64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX940Plus },
  { 8160 /* flat_atomic_min_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX940Plus },
  { 8160 /* flat_atomic_min_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX940Plus },
  { 8160 /* flat_atomic_min_f64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9 },
  { 8160 /* flat_atomic_min_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9 },
  { 8160 /* flat_atomic_min_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX8GFX9 },
  { 8180 /* flat_atomic_min_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8180 /* flat_atomic_min_i32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8180 /* flat_atomic_min_i32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8180 /* flat_atomic_min_i32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8180 /* flat_atomic_min_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8180 /* flat_atomic_min_i32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8180 /* flat_atomic_min_i32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8180 /* flat_atomic_min_i32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8180 /* flat_atomic_min_i32 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8180 /* flat_atomic_min_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8180 /* flat_atomic_min_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8180 /* flat_atomic_min_i32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8180 /* flat_atomic_min_i32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8180 /* flat_atomic_min_i32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8180 /* flat_atomic_min_i32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8180 /* flat_atomic_min_i32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8180 /* flat_atomic_min_i32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8180 /* flat_atomic_min_i32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8180 /* flat_atomic_min_i32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8180 /* flat_atomic_min_i32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8180 /* flat_atomic_min_i32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8180 /* flat_atomic_min_i32 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8180 /* flat_atomic_min_i32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8180 /* flat_atomic_min_i32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8180 /* flat_atomic_min_i32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8200 /* flat_atomic_min_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8200 /* flat_atomic_min_i64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8200 /* flat_atomic_min_i64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8200 /* flat_atomic_min_i64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8200 /* flat_atomic_min_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8200 /* flat_atomic_min_i64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8200 /* flat_atomic_min_i64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8200 /* flat_atomic_min_i64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8200 /* flat_atomic_min_i64 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8200 /* flat_atomic_min_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8200 /* flat_atomic_min_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8200 /* flat_atomic_min_i64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8200 /* flat_atomic_min_i64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8200 /* flat_atomic_min_i64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8200 /* flat_atomic_min_i64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8200 /* flat_atomic_min_i64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8200 /* flat_atomic_min_i64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8200 /* flat_atomic_min_i64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8200 /* flat_atomic_min_i64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8200 /* flat_atomic_min_i64 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8200 /* flat_atomic_min_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8200 /* flat_atomic_min_i64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8200 /* flat_atomic_min_i64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8200 /* flat_atomic_min_i64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8220 /* flat_atomic_min_num_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX7GFX10GFX11_isGFX12Only },
  { 8220 /* flat_atomic_min_num_f32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX12Only },
  { 8220 /* flat_atomic_min_num_f32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX7GFX10GFX11_isGFX12Only },
  { 8220 /* flat_atomic_min_num_f32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX7GFX10GFX11_isGFX12Only },
  { 8220 /* flat_atomic_min_num_f32 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only },
  { 8220 /* flat_atomic_min_num_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only },
  { 8220 /* flat_atomic_min_num_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only },
  { 8220 /* flat_atomic_min_num_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only },
  { 8220 /* flat_atomic_min_num_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only },
  { 8220 /* flat_atomic_min_num_f32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_isGFX7GFX10GFX11_isGFX12Only },
  { 8220 /* flat_atomic_min_num_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX7GFX10GFX11_isGFX12Only },
  { 8220 /* flat_atomic_min_num_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX7GFX10GFX11_isGFX12Only },
  { 8220 /* flat_atomic_min_num_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX7GFX10GFX11_isGFX12Only },
  { 8220 /* flat_atomic_min_num_f32 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only },
  { 8220 /* flat_atomic_min_num_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only },
  { 8220 /* flat_atomic_min_num_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only },
  { 8220 /* flat_atomic_min_num_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_isGFX7GFX10GFX11_isGFX12Only },
  { 8244 /* flat_atomic_min_num_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8244 /* flat_atomic_min_num_f64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8244 /* flat_atomic_min_num_f64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8244 /* flat_atomic_min_num_f64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8244 /* flat_atomic_min_num_f64 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8244 /* flat_atomic_min_num_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8244 /* flat_atomic_min_num_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8244 /* flat_atomic_min_num_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8244 /* flat_atomic_min_num_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8244 /* flat_atomic_min_num_f64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8244 /* flat_atomic_min_num_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8244 /* flat_atomic_min_num_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8244 /* flat_atomic_min_num_f64 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8244 /* flat_atomic_min_num_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8244 /* flat_atomic_min_num_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8244 /* flat_atomic_min_num_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8244 /* flat_atomic_min_num_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasAtomicFMinFMaxF64FlatInsts_isGFX125xOnly },
  { 8268 /* flat_atomic_min_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8268 /* flat_atomic_min_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8268 /* flat_atomic_min_u32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8268 /* flat_atomic_min_u32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8268 /* flat_atomic_min_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8268 /* flat_atomic_min_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8268 /* flat_atomic_min_u32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8268 /* flat_atomic_min_u32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8268 /* flat_atomic_min_u32 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8268 /* flat_atomic_min_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8268 /* flat_atomic_min_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8268 /* flat_atomic_min_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8268 /* flat_atomic_min_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8268 /* flat_atomic_min_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8268 /* flat_atomic_min_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8268 /* flat_atomic_min_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8268 /* flat_atomic_min_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8268 /* flat_atomic_min_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8268 /* flat_atomic_min_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8268 /* flat_atomic_min_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8268 /* flat_atomic_min_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8268 /* flat_atomic_min_u32 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8268 /* flat_atomic_min_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8268 /* flat_atomic_min_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8268 /* flat_atomic_min_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8288 /* flat_atomic_min_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8288 /* flat_atomic_min_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8288 /* flat_atomic_min_u64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8288 /* flat_atomic_min_u64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8288 /* flat_atomic_min_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8288 /* flat_atomic_min_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8288 /* flat_atomic_min_u64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8288 /* flat_atomic_min_u64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8288 /* flat_atomic_min_u64 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8288 /* flat_atomic_min_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8288 /* flat_atomic_min_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8288 /* flat_atomic_min_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8288 /* flat_atomic_min_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8288 /* flat_atomic_min_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8288 /* flat_atomic_min_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8288 /* flat_atomic_min_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8288 /* flat_atomic_min_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8288 /* flat_atomic_min_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8288 /* flat_atomic_min_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8288 /* flat_atomic_min_u64 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8288 /* flat_atomic_min_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8288 /* flat_atomic_min_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8288 /* flat_atomic_min_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8288 /* flat_atomic_min_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8308 /* flat_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8308 /* flat_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8308 /* flat_atomic_or */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8308 /* flat_atomic_or */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8308 /* flat_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8308 /* flat_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8308 /* flat_atomic_or */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8308 /* flat_atomic_or */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8308 /* flat_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8308 /* flat_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8308 /* flat_atomic_or */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8308 /* flat_atomic_or */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8308 /* flat_atomic_or */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8308 /* flat_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8308 /* flat_atomic_or */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8308 /* flat_atomic_or */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8308 /* flat_atomic_or */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8308 /* flat_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8308 /* flat_atomic_or */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8308 /* flat_atomic_or */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8308 /* flat_atomic_or */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8308 /* flat_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8308 /* flat_atomic_or */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8308 /* flat_atomic_or */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8308 /* flat_atomic_or */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8308 /* flat_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8308 /* flat_atomic_or */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8308 /* flat_atomic_or */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8323 /* flat_atomic_or_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8323 /* flat_atomic_or_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8323 /* flat_atomic_or_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8323 /* flat_atomic_or_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8323 /* flat_atomic_or_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8323 /* flat_atomic_or_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8323 /* flat_atomic_or_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8323 /* flat_atomic_or_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8323 /* flat_atomic_or_b32 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8323 /* flat_atomic_or_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8323 /* flat_atomic_or_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8323 /* flat_atomic_or_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8323 /* flat_atomic_or_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8323 /* flat_atomic_or_b32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8323 /* flat_atomic_or_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8323 /* flat_atomic_or_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8323 /* flat_atomic_or_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8323 /* flat_atomic_or_b32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8323 /* flat_atomic_or_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8323 /* flat_atomic_or_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8323 /* flat_atomic_or_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8323 /* flat_atomic_or_b32 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8323 /* flat_atomic_or_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8323 /* flat_atomic_or_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8323 /* flat_atomic_or_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8342 /* flat_atomic_or_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8342 /* flat_atomic_or_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8342 /* flat_atomic_or_b64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8342 /* flat_atomic_or_b64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8342 /* flat_atomic_or_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8342 /* flat_atomic_or_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8342 /* flat_atomic_or_b64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8342 /* flat_atomic_or_b64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8342 /* flat_atomic_or_b64 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8342 /* flat_atomic_or_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8342 /* flat_atomic_or_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8342 /* flat_atomic_or_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8342 /* flat_atomic_or_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8342 /* flat_atomic_or_b64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8342 /* flat_atomic_or_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8342 /* flat_atomic_or_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8342 /* flat_atomic_or_b64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8342 /* flat_atomic_or_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8342 /* flat_atomic_or_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8342 /* flat_atomic_or_b64 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8342 /* flat_atomic_or_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8342 /* flat_atomic_or_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8342 /* flat_atomic_or_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8342 /* flat_atomic_or_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8361 /* flat_atomic_or_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8361 /* flat_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8361 /* flat_atomic_or_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8361 /* flat_atomic_or_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8361 /* flat_atomic_or_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8361 /* flat_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8361 /* flat_atomic_or_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8361 /* flat_atomic_or_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8361 /* flat_atomic_or_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8361 /* flat_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8361 /* flat_atomic_or_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8361 /* flat_atomic_or_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8361 /* flat_atomic_or_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8361 /* flat_atomic_or_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8361 /* flat_atomic_or_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8361 /* flat_atomic_or_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8361 /* flat_atomic_or_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8361 /* flat_atomic_or_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8361 /* flat_atomic_or_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8361 /* flat_atomic_or_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8361 /* flat_atomic_or_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8361 /* flat_atomic_or_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8361 /* flat_atomic_or_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8361 /* flat_atomic_or_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8361 /* flat_atomic_or_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8379 /* flat_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8379 /* flat_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8379 /* flat_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8379 /* flat_atomic_pk_add_bf16 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8379 /* flat_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8379 /* flat_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8379 /* flat_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8379 /* flat_atomic_pk_add_bf16 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8379 /* flat_atomic_pk_add_bf16 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8379 /* flat_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8379 /* flat_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8379 /* flat_atomic_pk_add_bf16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8379 /* flat_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8379 /* flat_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8379 /* flat_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8379 /* flat_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8379 /* flat_atomic_pk_add_bf16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8379 /* flat_atomic_pk_add_bf16 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8379 /* flat_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8379 /* flat_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8379 /* flat_atomic_pk_add_bf16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8379 /* flat_atomic_pk_add_bf16 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8379 /* flat_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8379 /* flat_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8379 /* flat_atomic_pk_add_bf16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8379 /* flat_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8379 /* flat_atomic_pk_add_bf16 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8379 /* flat_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8379 /* flat_atomic_pk_add_bf16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8403 /* flat_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8403 /* flat_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8403 /* flat_atomic_pk_add_f16 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8403 /* flat_atomic_pk_add_f16 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8403 /* flat_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8403 /* flat_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8403 /* flat_atomic_pk_add_f16 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8403 /* flat_atomic_pk_add_f16 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8403 /* flat_atomic_pk_add_f16 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8403 /* flat_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8403 /* flat_atomic_pk_add_f16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8403 /* flat_atomic_pk_add_f16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8403 /* flat_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8403 /* flat_atomic_pk_add_f16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8403 /* flat_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8403 /* flat_atomic_pk_add_f16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8403 /* flat_atomic_pk_add_f16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8403 /* flat_atomic_pk_add_f16 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8403 /* flat_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8403 /* flat_atomic_pk_add_f16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8403 /* flat_atomic_pk_add_f16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8403 /* flat_atomic_pk_add_f16 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8403 /* flat_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8403 /* flat_atomic_pk_add_f16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8403 /* flat_atomic_pk_add_f16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFlatPkAdd16Insts_isGFX940Plus },
  { 8403 /* flat_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8403 /* flat_atomic_pk_add_f16 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8403 /* flat_atomic_pk_add_f16 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8403 /* flat_atomic_pk_add_f16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasAtomicFlatPkAdd16Insts_isGFX12Only },
  { 8426 /* flat_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8426 /* flat_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8426 /* flat_atomic_smax */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8426 /* flat_atomic_smax */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8426 /* flat_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8426 /* flat_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8426 /* flat_atomic_smax */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8426 /* flat_atomic_smax */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8426 /* flat_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8426 /* flat_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8426 /* flat_atomic_smax */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8426 /* flat_atomic_smax */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8426 /* flat_atomic_smax */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8426 /* flat_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8426 /* flat_atomic_smax */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8426 /* flat_atomic_smax */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8426 /* flat_atomic_smax */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8426 /* flat_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8426 /* flat_atomic_smax */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8426 /* flat_atomic_smax */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8426 /* flat_atomic_smax */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8426 /* flat_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8426 /* flat_atomic_smax */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8426 /* flat_atomic_smax */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8426 /* flat_atomic_smax */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8426 /* flat_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8426 /* flat_atomic_smax */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8426 /* flat_atomic_smax */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8443 /* flat_atomic_smax_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8443 /* flat_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8443 /* flat_atomic_smax_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8443 /* flat_atomic_smax_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8443 /* flat_atomic_smax_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8443 /* flat_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8443 /* flat_atomic_smax_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8443 /* flat_atomic_smax_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8443 /* flat_atomic_smax_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8443 /* flat_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8443 /* flat_atomic_smax_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8443 /* flat_atomic_smax_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8443 /* flat_atomic_smax_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8443 /* flat_atomic_smax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8443 /* flat_atomic_smax_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8443 /* flat_atomic_smax_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8443 /* flat_atomic_smax_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8443 /* flat_atomic_smax_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8443 /* flat_atomic_smax_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8443 /* flat_atomic_smax_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8443 /* flat_atomic_smax_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8443 /* flat_atomic_smax_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8443 /* flat_atomic_smax_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8443 /* flat_atomic_smax_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8443 /* flat_atomic_smax_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8463 /* flat_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8463 /* flat_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8463 /* flat_atomic_smin */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8463 /* flat_atomic_smin */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8463 /* flat_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8463 /* flat_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8463 /* flat_atomic_smin */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8463 /* flat_atomic_smin */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8463 /* flat_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8463 /* flat_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8463 /* flat_atomic_smin */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8463 /* flat_atomic_smin */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8463 /* flat_atomic_smin */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8463 /* flat_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8463 /* flat_atomic_smin */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8463 /* flat_atomic_smin */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8463 /* flat_atomic_smin */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8463 /* flat_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8463 /* flat_atomic_smin */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8463 /* flat_atomic_smin */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8463 /* flat_atomic_smin */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8463 /* flat_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8463 /* flat_atomic_smin */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8463 /* flat_atomic_smin */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8463 /* flat_atomic_smin */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8463 /* flat_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8463 /* flat_atomic_smin */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8463 /* flat_atomic_smin */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8480 /* flat_atomic_smin_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8480 /* flat_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8480 /* flat_atomic_smin_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8480 /* flat_atomic_smin_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8480 /* flat_atomic_smin_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8480 /* flat_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8480 /* flat_atomic_smin_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8480 /* flat_atomic_smin_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8480 /* flat_atomic_smin_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8480 /* flat_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8480 /* flat_atomic_smin_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8480 /* flat_atomic_smin_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8480 /* flat_atomic_smin_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8480 /* flat_atomic_smin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8480 /* flat_atomic_smin_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8480 /* flat_atomic_smin_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8480 /* flat_atomic_smin_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8480 /* flat_atomic_smin_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8480 /* flat_atomic_smin_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8480 /* flat_atomic_smin_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8480 /* flat_atomic_smin_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8480 /* flat_atomic_smin_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8480 /* flat_atomic_smin_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8480 /* flat_atomic_smin_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8480 /* flat_atomic_smin_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8500 /* flat_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8500 /* flat_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8500 /* flat_atomic_sub */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8500 /* flat_atomic_sub */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8500 /* flat_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8500 /* flat_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8500 /* flat_atomic_sub */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8500 /* flat_atomic_sub */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8500 /* flat_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8500 /* flat_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8500 /* flat_atomic_sub */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8500 /* flat_atomic_sub */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8500 /* flat_atomic_sub */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8500 /* flat_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8500 /* flat_atomic_sub */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8500 /* flat_atomic_sub */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8500 /* flat_atomic_sub */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8500 /* flat_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8500 /* flat_atomic_sub */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8500 /* flat_atomic_sub */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8500 /* flat_atomic_sub */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8500 /* flat_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8500 /* flat_atomic_sub */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8500 /* flat_atomic_sub */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8500 /* flat_atomic_sub */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8500 /* flat_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8500 /* flat_atomic_sub */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8500 /* flat_atomic_sub */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8516 /* flat_atomic_sub_clamp_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 8516 /* flat_atomic_sub_clamp_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus_isGFX12Only },
  { 8516 /* flat_atomic_sub_clamp_u32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX12Plus_isGFX12Only },
  { 8516 /* flat_atomic_sub_clamp_u32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX12Plus_isGFX12Only },
  { 8516 /* flat_atomic_sub_clamp_u32 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_isGFX12Plus_isGFX12Only },
  { 8516 /* flat_atomic_sub_clamp_u32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_isGFX12Plus_isGFX12Only },
  { 8516 /* flat_atomic_sub_clamp_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_isGFX12Plus_isGFX12Only },
  { 8516 /* flat_atomic_sub_clamp_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_isGFX12Plus_isGFX12Only },
  { 8516 /* flat_atomic_sub_clamp_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 8516 /* flat_atomic_sub_clamp_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus_isGFX12Only },
  { 8516 /* flat_atomic_sub_clamp_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX12Plus_isGFX12Only },
  { 8516 /* flat_atomic_sub_clamp_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX12Plus_isGFX12Only },
  { 8516 /* flat_atomic_sub_clamp_u32 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_isGFX12Plus_isGFX12Only },
  { 8516 /* flat_atomic_sub_clamp_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_isGFX12Plus_isGFX12Only },
  { 8516 /* flat_atomic_sub_clamp_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_isGFX12Plus_isGFX12Only },
  { 8516 /* flat_atomic_sub_clamp_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_isGFX12Plus_isGFX12Only },
  { 8542 /* flat_atomic_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8542 /* flat_atomic_sub_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8542 /* flat_atomic_sub_u32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8542 /* flat_atomic_sub_u32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8542 /* flat_atomic_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8542 /* flat_atomic_sub_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8542 /* flat_atomic_sub_u32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8542 /* flat_atomic_sub_u32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8542 /* flat_atomic_sub_u32 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8542 /* flat_atomic_sub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8542 /* flat_atomic_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8542 /* flat_atomic_sub_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8542 /* flat_atomic_sub_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8542 /* flat_atomic_sub_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8542 /* flat_atomic_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8542 /* flat_atomic_sub_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8542 /* flat_atomic_sub_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8542 /* flat_atomic_sub_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8542 /* flat_atomic_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8542 /* flat_atomic_sub_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8542 /* flat_atomic_sub_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8542 /* flat_atomic_sub_u32 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8542 /* flat_atomic_sub_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8542 /* flat_atomic_sub_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8542 /* flat_atomic_sub_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8562 /* flat_atomic_sub_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8562 /* flat_atomic_sub_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8562 /* flat_atomic_sub_u64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8562 /* flat_atomic_sub_u64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8562 /* flat_atomic_sub_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8562 /* flat_atomic_sub_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8562 /* flat_atomic_sub_u64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8562 /* flat_atomic_sub_u64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8562 /* flat_atomic_sub_u64 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8562 /* flat_atomic_sub_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8562 /* flat_atomic_sub_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8562 /* flat_atomic_sub_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8562 /* flat_atomic_sub_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8562 /* flat_atomic_sub_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8562 /* flat_atomic_sub_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8562 /* flat_atomic_sub_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8562 /* flat_atomic_sub_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8562 /* flat_atomic_sub_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8562 /* flat_atomic_sub_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8562 /* flat_atomic_sub_u64 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8562 /* flat_atomic_sub_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8562 /* flat_atomic_sub_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8562 /* flat_atomic_sub_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8562 /* flat_atomic_sub_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8582 /* flat_atomic_sub_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8582 /* flat_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8582 /* flat_atomic_sub_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8582 /* flat_atomic_sub_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8582 /* flat_atomic_sub_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8582 /* flat_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8582 /* flat_atomic_sub_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8582 /* flat_atomic_sub_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8582 /* flat_atomic_sub_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8582 /* flat_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8582 /* flat_atomic_sub_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8582 /* flat_atomic_sub_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8582 /* flat_atomic_sub_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8582 /* flat_atomic_sub_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8582 /* flat_atomic_sub_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8582 /* flat_atomic_sub_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8582 /* flat_atomic_sub_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8582 /* flat_atomic_sub_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8582 /* flat_atomic_sub_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8582 /* flat_atomic_sub_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8582 /* flat_atomic_sub_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8582 /* flat_atomic_sub_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8582 /* flat_atomic_sub_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8582 /* flat_atomic_sub_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8582 /* flat_atomic_sub_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8601 /* flat_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8601 /* flat_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8601 /* flat_atomic_swap */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8601 /* flat_atomic_swap */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8601 /* flat_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8601 /* flat_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8601 /* flat_atomic_swap */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8601 /* flat_atomic_swap */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8601 /* flat_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8601 /* flat_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8601 /* flat_atomic_swap */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8601 /* flat_atomic_swap */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8601 /* flat_atomic_swap */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8601 /* flat_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8601 /* flat_atomic_swap */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8601 /* flat_atomic_swap */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8601 /* flat_atomic_swap */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8601 /* flat_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8601 /* flat_atomic_swap */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8601 /* flat_atomic_swap */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8601 /* flat_atomic_swap */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8601 /* flat_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8601 /* flat_atomic_swap */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8601 /* flat_atomic_swap */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8601 /* flat_atomic_swap */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8601 /* flat_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8601 /* flat_atomic_swap */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8601 /* flat_atomic_swap */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8618 /* flat_atomic_swap_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8618 /* flat_atomic_swap_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8618 /* flat_atomic_swap_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8618 /* flat_atomic_swap_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8618 /* flat_atomic_swap_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8618 /* flat_atomic_swap_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8618 /* flat_atomic_swap_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8618 /* flat_atomic_swap_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8618 /* flat_atomic_swap_b32 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8618 /* flat_atomic_swap_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8618 /* flat_atomic_swap_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8618 /* flat_atomic_swap_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8618 /* flat_atomic_swap_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8618 /* flat_atomic_swap_b32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8618 /* flat_atomic_swap_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8618 /* flat_atomic_swap_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8618 /* flat_atomic_swap_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8618 /* flat_atomic_swap_b32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8618 /* flat_atomic_swap_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8618 /* flat_atomic_swap_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8618 /* flat_atomic_swap_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8618 /* flat_atomic_swap_b32 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8618 /* flat_atomic_swap_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8618 /* flat_atomic_swap_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8618 /* flat_atomic_swap_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8639 /* flat_atomic_swap_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8639 /* flat_atomic_swap_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8639 /* flat_atomic_swap_b64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8639 /* flat_atomic_swap_b64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8639 /* flat_atomic_swap_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8639 /* flat_atomic_swap_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8639 /* flat_atomic_swap_b64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8639 /* flat_atomic_swap_b64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8639 /* flat_atomic_swap_b64 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8639 /* flat_atomic_swap_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8639 /* flat_atomic_swap_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8639 /* flat_atomic_swap_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8639 /* flat_atomic_swap_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8639 /* flat_atomic_swap_b64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8639 /* flat_atomic_swap_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8639 /* flat_atomic_swap_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8639 /* flat_atomic_swap_b64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8639 /* flat_atomic_swap_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8639 /* flat_atomic_swap_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8639 /* flat_atomic_swap_b64 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8639 /* flat_atomic_swap_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8639 /* flat_atomic_swap_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8639 /* flat_atomic_swap_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8639 /* flat_atomic_swap_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8660 /* flat_atomic_swap_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8660 /* flat_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8660 /* flat_atomic_swap_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8660 /* flat_atomic_swap_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8660 /* flat_atomic_swap_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8660 /* flat_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8660 /* flat_atomic_swap_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8660 /* flat_atomic_swap_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8660 /* flat_atomic_swap_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8660 /* flat_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8660 /* flat_atomic_swap_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8660 /* flat_atomic_swap_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8660 /* flat_atomic_swap_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8660 /* flat_atomic_swap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8660 /* flat_atomic_swap_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8660 /* flat_atomic_swap_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8660 /* flat_atomic_swap_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8660 /* flat_atomic_swap_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8660 /* flat_atomic_swap_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8660 /* flat_atomic_swap_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8660 /* flat_atomic_swap_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8660 /* flat_atomic_swap_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8660 /* flat_atomic_swap_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8660 /* flat_atomic_swap_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8660 /* flat_atomic_swap_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8680 /* flat_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8680 /* flat_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8680 /* flat_atomic_umax */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8680 /* flat_atomic_umax */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8680 /* flat_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8680 /* flat_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8680 /* flat_atomic_umax */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8680 /* flat_atomic_umax */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8680 /* flat_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8680 /* flat_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8680 /* flat_atomic_umax */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8680 /* flat_atomic_umax */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8680 /* flat_atomic_umax */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8680 /* flat_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8680 /* flat_atomic_umax */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8680 /* flat_atomic_umax */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8680 /* flat_atomic_umax */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8680 /* flat_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8680 /* flat_atomic_umax */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8680 /* flat_atomic_umax */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8680 /* flat_atomic_umax */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8680 /* flat_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8680 /* flat_atomic_umax */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8680 /* flat_atomic_umax */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8680 /* flat_atomic_umax */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8680 /* flat_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8680 /* flat_atomic_umax */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8680 /* flat_atomic_umax */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8697 /* flat_atomic_umax_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8697 /* flat_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8697 /* flat_atomic_umax_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8697 /* flat_atomic_umax_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8697 /* flat_atomic_umax_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8697 /* flat_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8697 /* flat_atomic_umax_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8697 /* flat_atomic_umax_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8697 /* flat_atomic_umax_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8697 /* flat_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8697 /* flat_atomic_umax_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8697 /* flat_atomic_umax_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8697 /* flat_atomic_umax_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8697 /* flat_atomic_umax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8697 /* flat_atomic_umax_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8697 /* flat_atomic_umax_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8697 /* flat_atomic_umax_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8697 /* flat_atomic_umax_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8697 /* flat_atomic_umax_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8697 /* flat_atomic_umax_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8697 /* flat_atomic_umax_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8697 /* flat_atomic_umax_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8697 /* flat_atomic_umax_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8697 /* flat_atomic_umax_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8697 /* flat_atomic_umax_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8717 /* flat_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8717 /* flat_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8717 /* flat_atomic_umin */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8717 /* flat_atomic_umin */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8717 /* flat_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8717 /* flat_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8717 /* flat_atomic_umin */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8717 /* flat_atomic_umin */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8717 /* flat_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8717 /* flat_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8717 /* flat_atomic_umin */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8717 /* flat_atomic_umin */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8717 /* flat_atomic_umin */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8717 /* flat_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8717 /* flat_atomic_umin */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8717 /* flat_atomic_umin */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8717 /* flat_atomic_umin */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8717 /* flat_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8717 /* flat_atomic_umin */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8717 /* flat_atomic_umin */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8717 /* flat_atomic_umin */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8717 /* flat_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8717 /* flat_atomic_umin */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8717 /* flat_atomic_umin */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8717 /* flat_atomic_umin */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8717 /* flat_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8717 /* flat_atomic_umin */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8717 /* flat_atomic_umin */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8734 /* flat_atomic_umin_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8734 /* flat_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8734 /* flat_atomic_umin_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8734 /* flat_atomic_umin_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8734 /* flat_atomic_umin_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8734 /* flat_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8734 /* flat_atomic_umin_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8734 /* flat_atomic_umin_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8734 /* flat_atomic_umin_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8734 /* flat_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8734 /* flat_atomic_umin_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8734 /* flat_atomic_umin_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8734 /* flat_atomic_umin_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8734 /* flat_atomic_umin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8734 /* flat_atomic_umin_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8734 /* flat_atomic_umin_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8734 /* flat_atomic_umin_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8734 /* flat_atomic_umin_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8734 /* flat_atomic_umin_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8734 /* flat_atomic_umin_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8734 /* flat_atomic_umin_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8734 /* flat_atomic_umin_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8734 /* flat_atomic_umin_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8734 /* flat_atomic_umin_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8734 /* flat_atomic_umin_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8754 /* flat_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8754 /* flat_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8754 /* flat_atomic_xor */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8754 /* flat_atomic_xor */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8754 /* flat_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8754 /* flat_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8754 /* flat_atomic_xor */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8754 /* flat_atomic_xor */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8754 /* flat_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8754 /* flat_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8754 /* flat_atomic_xor */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8754 /* flat_atomic_xor */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8754 /* flat_atomic_xor */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8754 /* flat_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8754 /* flat_atomic_xor */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8754 /* flat_atomic_xor */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8754 /* flat_atomic_xor */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8754 /* flat_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8754 /* flat_atomic_xor */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8754 /* flat_atomic_xor */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8754 /* flat_atomic_xor */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8754 /* flat_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8754 /* flat_atomic_xor */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8754 /* flat_atomic_xor */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8754 /* flat_atomic_xor */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8754 /* flat_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8754 /* flat_atomic_xor */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8754 /* flat_atomic_xor */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8770 /* flat_atomic_xor_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8770 /* flat_atomic_xor_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8770 /* flat_atomic_xor_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8770 /* flat_atomic_xor_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8770 /* flat_atomic_xor_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8770 /* flat_atomic_xor_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8770 /* flat_atomic_xor_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8770 /* flat_atomic_xor_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8770 /* flat_atomic_xor_b32 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8770 /* flat_atomic_xor_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8770 /* flat_atomic_xor_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8770 /* flat_atomic_xor_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8770 /* flat_atomic_xor_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8770 /* flat_atomic_xor_b32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8770 /* flat_atomic_xor_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8770 /* flat_atomic_xor_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8770 /* flat_atomic_xor_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8770 /* flat_atomic_xor_b32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8770 /* flat_atomic_xor_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8770 /* flat_atomic_xor_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8770 /* flat_atomic_xor_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8770 /* flat_atomic_xor_b32 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8770 /* flat_atomic_xor_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8770 /* flat_atomic_xor_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8770 /* flat_atomic_xor_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8790 /* flat_atomic_xor_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8790 /* flat_atomic_xor_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8790 /* flat_atomic_xor_b64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8790 /* flat_atomic_xor_b64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8790 /* flat_atomic_xor_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8790 /* flat_atomic_xor_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8790 /* flat_atomic_xor_b64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8790 /* flat_atomic_xor_b64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8790 /* flat_atomic_xor_b64 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8790 /* flat_atomic_xor_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8790 /* flat_atomic_xor_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8790 /* flat_atomic_xor_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8790 /* flat_atomic_xor_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8790 /* flat_atomic_xor_b64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8790 /* flat_atomic_xor_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8790 /* flat_atomic_xor_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8790 /* flat_atomic_xor_b64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8790 /* flat_atomic_xor_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8790 /* flat_atomic_xor_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8790 /* flat_atomic_xor_b64 */, 8 /* 3 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8790 /* flat_atomic_xor_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8790 /* flat_atomic_xor_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8790 /* flat_atomic_xor_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8790 /* flat_atomic_xor_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8810 /* flat_atomic_xor_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8810 /* flat_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8810 /* flat_atomic_xor_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8810 /* flat_atomic_xor_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8810 /* flat_atomic_xor_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8810 /* flat_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8810 /* flat_atomic_xor_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8810 /* flat_atomic_xor_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8810 /* flat_atomic_xor_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8810 /* flat_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8810 /* flat_atomic_xor_x2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8810 /* flat_atomic_xor_x2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8810 /* flat_atomic_xor_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8810 /* flat_atomic_xor_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8810 /* flat_atomic_xor_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8810 /* flat_atomic_xor_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8810 /* flat_atomic_xor_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8810 /* flat_atomic_xor_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8810 /* flat_atomic_xor_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8810 /* flat_atomic_xor_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8810 /* flat_atomic_xor_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8810 /* flat_atomic_xor_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8810 /* flat_atomic_xor_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8810 /* flat_atomic_xor_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8810 /* flat_atomic_xor_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8829 /* flat_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8829 /* flat_load_b128 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8829 /* flat_load_b128 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8829 /* flat_load_b128 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8829 /* flat_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8829 /* flat_load_b128 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8829 /* flat_load_b128 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8829 /* flat_load_b128 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8829 /* flat_load_b128 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8829 /* flat_load_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8829 /* flat_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8829 /* flat_load_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8829 /* flat_load_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8844 /* flat_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8844 /* flat_load_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8844 /* flat_load_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8844 /* flat_load_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8844 /* flat_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8844 /* flat_load_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8844 /* flat_load_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8844 /* flat_load_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8844 /* flat_load_b32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8844 /* flat_load_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8844 /* flat_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8844 /* flat_load_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8844 /* flat_load_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8858 /* flat_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8858 /* flat_load_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8858 /* flat_load_b64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8858 /* flat_load_b64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8858 /* flat_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8858 /* flat_load_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8858 /* flat_load_b64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8858 /* flat_load_b64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8858 /* flat_load_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8858 /* flat_load_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8858 /* flat_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8858 /* flat_load_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8858 /* flat_load_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8872 /* flat_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8872 /* flat_load_b96 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8872 /* flat_load_b96 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8872 /* flat_load_b96 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 8872 /* flat_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8872 /* flat_load_b96 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8872 /* flat_load_b96 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8872 /* flat_load_b96 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 8872 /* flat_load_b96 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8872 /* flat_load_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8872 /* flat_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8872 /* flat_load_b96 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8872 /* flat_load_b96 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 8886 /* flat_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8886 /* flat_load_d16_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8886 /* flat_load_d16_b16 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8886 /* flat_load_d16_b16 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8886 /* flat_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8886 /* flat_load_d16_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8886 /* flat_load_d16_b16 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8886 /* flat_load_d16_b16 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8886 /* flat_load_d16_b16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8886 /* flat_load_d16_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8886 /* flat_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8886 /* flat_load_d16_b16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8886 /* flat_load_d16_b16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8904 /* flat_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8904 /* flat_load_d16_hi_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8904 /* flat_load_d16_hi_b16 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8904 /* flat_load_d16_hi_b16 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8904 /* flat_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8904 /* flat_load_d16_hi_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8904 /* flat_load_d16_hi_b16 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8904 /* flat_load_d16_hi_b16 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8904 /* flat_load_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8904 /* flat_load_d16_hi_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8904 /* flat_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8904 /* flat_load_d16_hi_b16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8904 /* flat_load_d16_hi_b16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8925 /* flat_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8925 /* flat_load_d16_hi_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8925 /* flat_load_d16_hi_i8 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8925 /* flat_load_d16_hi_i8 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8925 /* flat_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8925 /* flat_load_d16_hi_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8925 /* flat_load_d16_hi_i8 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8925 /* flat_load_d16_hi_i8 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8925 /* flat_load_d16_hi_i8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8925 /* flat_load_d16_hi_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8925 /* flat_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8925 /* flat_load_d16_hi_i8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8925 /* flat_load_d16_hi_i8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8945 /* flat_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8945 /* flat_load_d16_hi_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8945 /* flat_load_d16_hi_u8 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8945 /* flat_load_d16_hi_u8 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8945 /* flat_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8945 /* flat_load_d16_hi_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8945 /* flat_load_d16_hi_u8 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8945 /* flat_load_d16_hi_u8 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8945 /* flat_load_d16_hi_u8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8945 /* flat_load_d16_hi_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8945 /* flat_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8945 /* flat_load_d16_hi_u8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8945 /* flat_load_d16_hi_u8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8965 /* flat_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8965 /* flat_load_d16_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8965 /* flat_load_d16_i8 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8965 /* flat_load_d16_i8 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8965 /* flat_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8965 /* flat_load_d16_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8965 /* flat_load_d16_i8 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8965 /* flat_load_d16_i8 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8965 /* flat_load_d16_i8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8965 /* flat_load_d16_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8965 /* flat_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8965 /* flat_load_d16_i8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8965 /* flat_load_d16_i8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8982 /* flat_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8982 /* flat_load_d16_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8982 /* flat_load_d16_u8 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8982 /* flat_load_d16_u8 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 8982 /* flat_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8982 /* flat_load_d16_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8982 /* flat_load_d16_u8 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8982 /* flat_load_d16_u8 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 8982 /* flat_load_d16_u8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8982 /* flat_load_d16_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8982 /* flat_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8982 /* flat_load_d16_u8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8982 /* flat_load_d16_u8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 8999 /* flat_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8999 /* flat_load_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8999 /* flat_load_dword */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8999 /* flat_load_dword */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 8999 /* flat_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8999 /* flat_load_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8999 /* flat_load_dword */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8999 /* flat_load_dword */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 8999 /* flat_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8999 /* flat_load_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8999 /* flat_load_dword */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 8999 /* flat_load_dword */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9015 /* flat_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9015 /* flat_load_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9015 /* flat_load_dwordx2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9015 /* flat_load_dwordx2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9015 /* flat_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9015 /* flat_load_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9015 /* flat_load_dwordx2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9015 /* flat_load_dwordx2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9015 /* flat_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9015 /* flat_load_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9015 /* flat_load_dwordx2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9015 /* flat_load_dwordx2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9033 /* flat_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9033 /* flat_load_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9033 /* flat_load_dwordx3 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9033 /* flat_load_dwordx3 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9033 /* flat_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9033 /* flat_load_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9033 /* flat_load_dwordx3 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9033 /* flat_load_dwordx3 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9033 /* flat_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9033 /* flat_load_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9033 /* flat_load_dwordx3 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9033 /* flat_load_dwordx3 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9051 /* flat_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9051 /* flat_load_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9051 /* flat_load_dwordx4 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9051 /* flat_load_dwordx4 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9051 /* flat_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9051 /* flat_load_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9051 /* flat_load_dwordx4 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9051 /* flat_load_dwordx4 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9051 /* flat_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9051 /* flat_load_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9051 /* flat_load_dwordx4 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9051 /* flat_load_dwordx4 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9069 /* flat_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9069 /* flat_load_i16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9069 /* flat_load_i16 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9069 /* flat_load_i16 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9069 /* flat_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9069 /* flat_load_i16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9069 /* flat_load_i16 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9069 /* flat_load_i16 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9069 /* flat_load_i16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9069 /* flat_load_i16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9069 /* flat_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9069 /* flat_load_i16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9069 /* flat_load_i16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9083 /* flat_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9083 /* flat_load_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9083 /* flat_load_i8 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9083 /* flat_load_i8 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9083 /* flat_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9083 /* flat_load_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9083 /* flat_load_i8 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9083 /* flat_load_i8 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9083 /* flat_load_i8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9083 /* flat_load_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9083 /* flat_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9083 /* flat_load_i8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9083 /* flat_load_i8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9096 /* flat_load_monitor_b128 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX125xOnly },
  { 9096 /* flat_load_monitor_b128 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX125xOnly },
  { 9096 /* flat_load_monitor_b128 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX125xOnly },
  { 9096 /* flat_load_monitor_b128 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX125xOnly },
  { 9096 /* flat_load_monitor_b128 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_isGFX125xOnly },
  { 9096 /* flat_load_monitor_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_isGFX125xOnly },
  { 9096 /* flat_load_monitor_b128 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasFlatGVSMode_isGFX125xOnly },
  { 9096 /* flat_load_monitor_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_isGFX125xOnly },
  { 9096 /* flat_load_monitor_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_isGFX125xOnly },
  { 9119 /* flat_load_monitor_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX125xOnly },
  { 9119 /* flat_load_monitor_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX125xOnly },
  { 9119 /* flat_load_monitor_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX125xOnly },
  { 9119 /* flat_load_monitor_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX125xOnly },
  { 9119 /* flat_load_monitor_b32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_isGFX125xOnly },
  { 9119 /* flat_load_monitor_b32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_isGFX125xOnly },
  { 9119 /* flat_load_monitor_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_isGFX125xOnly },
  { 9119 /* flat_load_monitor_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_isGFX125xOnly },
  { 9141 /* flat_load_monitor_b64 */, 3 /* 0, 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX125xOnly },
  { 9141 /* flat_load_monitor_b64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX125xOnly },
  { 9141 /* flat_load_monitor_b64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX125xOnly },
  { 9141 /* flat_load_monitor_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_isGFX125xOnly },
  { 9141 /* flat_load_monitor_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_isGFX125xOnly },
  { 9141 /* flat_load_monitor_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGVSMode_isGFX125xOnly },
  { 9141 /* flat_load_monitor_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_isGFX125xOnly },
  { 9141 /* flat_load_monitor_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_isGFX125xOnly },
  { 9163 /* flat_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9163 /* flat_load_sbyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9163 /* flat_load_sbyte */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9163 /* flat_load_sbyte */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9163 /* flat_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9163 /* flat_load_sbyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9163 /* flat_load_sbyte */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9163 /* flat_load_sbyte */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9163 /* flat_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9163 /* flat_load_sbyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9163 /* flat_load_sbyte */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9163 /* flat_load_sbyte */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9179 /* flat_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9179 /* flat_load_sbyte_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9179 /* flat_load_sbyte_d16 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9179 /* flat_load_sbyte_d16 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9179 /* flat_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9179 /* flat_load_sbyte_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9179 /* flat_load_sbyte_d16 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9179 /* flat_load_sbyte_d16 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9199 /* flat_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9199 /* flat_load_sbyte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9199 /* flat_load_sbyte_d16_hi */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9199 /* flat_load_sbyte_d16_hi */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9199 /* flat_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9199 /* flat_load_sbyte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9199 /* flat_load_sbyte_d16_hi */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9199 /* flat_load_sbyte_d16_hi */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9222 /* flat_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9222 /* flat_load_short_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9222 /* flat_load_short_d16 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9222 /* flat_load_short_d16 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9222 /* flat_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9222 /* flat_load_short_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9222 /* flat_load_short_d16 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9222 /* flat_load_short_d16 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9242 /* flat_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9242 /* flat_load_short_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9242 /* flat_load_short_d16_hi */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9242 /* flat_load_short_d16_hi */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9242 /* flat_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9242 /* flat_load_short_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9242 /* flat_load_short_d16_hi */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9242 /* flat_load_short_d16_hi */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9265 /* flat_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9265 /* flat_load_sshort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9265 /* flat_load_sshort */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9265 /* flat_load_sshort */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9265 /* flat_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9265 /* flat_load_sshort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9265 /* flat_load_sshort */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9265 /* flat_load_sshort */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9265 /* flat_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9265 /* flat_load_sshort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9265 /* flat_load_sshort */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9265 /* flat_load_sshort */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9282 /* flat_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9282 /* flat_load_u16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9282 /* flat_load_u16 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9282 /* flat_load_u16 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9282 /* flat_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9282 /* flat_load_u16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9282 /* flat_load_u16 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9282 /* flat_load_u16 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9282 /* flat_load_u16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9282 /* flat_load_u16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9282 /* flat_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9282 /* flat_load_u16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9282 /* flat_load_u16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9296 /* flat_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9296 /* flat_load_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9296 /* flat_load_u8 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9296 /* flat_load_u8 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9296 /* flat_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9296 /* flat_load_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9296 /* flat_load_u8 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9296 /* flat_load_u8 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9296 /* flat_load_u8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9296 /* flat_load_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9296 /* flat_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9296 /* flat_load_u8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9296 /* flat_load_u8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9309 /* flat_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9309 /* flat_load_ubyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9309 /* flat_load_ubyte */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9309 /* flat_load_ubyte */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9309 /* flat_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9309 /* flat_load_ubyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9309 /* flat_load_ubyte */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9309 /* flat_load_ubyte */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9309 /* flat_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9309 /* flat_load_ubyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9309 /* flat_load_ubyte */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9309 /* flat_load_ubyte */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9325 /* flat_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9325 /* flat_load_ubyte_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9325 /* flat_load_ubyte_d16 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9325 /* flat_load_ubyte_d16 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9325 /* flat_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9325 /* flat_load_ubyte_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9325 /* flat_load_ubyte_d16 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9325 /* flat_load_ubyte_d16 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9345 /* flat_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9345 /* flat_load_ubyte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9345 /* flat_load_ubyte_d16_hi */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9345 /* flat_load_ubyte_d16_hi */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9345 /* flat_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9345 /* flat_load_ubyte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9345 /* flat_load_ubyte_d16_hi */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9345 /* flat_load_ubyte_d16_hi */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9368 /* flat_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9368 /* flat_load_ushort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9368 /* flat_load_ushort */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9368 /* flat_load_ushort */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9368 /* flat_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9368 /* flat_load_ushort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9368 /* flat_load_ushort */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9368 /* flat_load_ushort */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9368 /* flat_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9368 /* flat_load_ushort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9368 /* flat_load_ushort */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9368 /* flat_load_ushort */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9385 /* flat_prefetch_b8 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasVmemPrefInsts_isGFX125xOnly },
  { 9385 /* flat_prefetch_b8 */, 2 /* 1 */, MCK_FlatOffset, AMFBS_HasVmemPrefInsts_isGFX125xOnly },
  { 9385 /* flat_prefetch_b8 */, 6 /* 1, 2 */, MCK_CPol, AMFBS_HasVmemPrefInsts_isGFX125xOnly },
  { 9385 /* flat_prefetch_b8 */, 2 /* 1 */, MCK_SReg_64, AMFBS_HasFlatGVSMode_HasVmemPrefInsts_isGFX125xOnly },
  { 9385 /* flat_prefetch_b8 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasVmemPrefInsts_isGFX125xOnly },
  { 9385 /* flat_prefetch_b8 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasVmemPrefInsts_isGFX125xOnly },
  { 9385 /* flat_prefetch_b8 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasVmemPrefInsts_isGFX125xOnly },
  { 9402 /* flat_store_b128 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9402 /* flat_store_b128 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9402 /* flat_store_b128 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9402 /* flat_store_b128 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9402 /* flat_store_b128 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9402 /* flat_store_b128 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9402 /* flat_store_b128 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9402 /* flat_store_b128 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9402 /* flat_store_b128 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9402 /* flat_store_b128 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9402 /* flat_store_b128 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9402 /* flat_store_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9402 /* flat_store_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9418 /* flat_store_b16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9418 /* flat_store_b16 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9418 /* flat_store_b16 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9418 /* flat_store_b16 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9418 /* flat_store_b16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9418 /* flat_store_b16 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9418 /* flat_store_b16 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9418 /* flat_store_b16 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9418 /* flat_store_b16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9418 /* flat_store_b16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9418 /* flat_store_b16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9418 /* flat_store_b16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9418 /* flat_store_b16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9433 /* flat_store_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9433 /* flat_store_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9433 /* flat_store_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9433 /* flat_store_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9433 /* flat_store_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9433 /* flat_store_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9433 /* flat_store_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9433 /* flat_store_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9433 /* flat_store_b32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9433 /* flat_store_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9433 /* flat_store_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9433 /* flat_store_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9433 /* flat_store_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9448 /* flat_store_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9448 /* flat_store_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9448 /* flat_store_b64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9448 /* flat_store_b64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9448 /* flat_store_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9448 /* flat_store_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9448 /* flat_store_b64 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9448 /* flat_store_b64 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9448 /* flat_store_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9448 /* flat_store_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9448 /* flat_store_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9448 /* flat_store_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9448 /* flat_store_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9463 /* flat_store_b8 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9463 /* flat_store_b8 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9463 /* flat_store_b8 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9463 /* flat_store_b8 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9463 /* flat_store_b8 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9463 /* flat_store_b8 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9463 /* flat_store_b8 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9463 /* flat_store_b8 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9463 /* flat_store_b8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9463 /* flat_store_b8 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9463 /* flat_store_b8 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9463 /* flat_store_b8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9463 /* flat_store_b8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9477 /* flat_store_b96 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9477 /* flat_store_b96 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9477 /* flat_store_b96 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9477 /* flat_store_b96 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX11Only },
  { 9477 /* flat_store_b96 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9477 /* flat_store_b96 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9477 /* flat_store_b96 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9477 /* flat_store_b96 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX12Only },
  { 9477 /* flat_store_b96 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9477 /* flat_store_b96 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9477 /* flat_store_b96 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9477 /* flat_store_b96 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9477 /* flat_store_b96 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasFlatAddressSpace_isGFX12Only },
  { 9492 /* flat_store_byte */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9492 /* flat_store_byte */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9492 /* flat_store_byte */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9492 /* flat_store_byte */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9492 /* flat_store_byte */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9492 /* flat_store_byte */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9492 /* flat_store_byte */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9492 /* flat_store_byte */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9492 /* flat_store_byte */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9492 /* flat_store_byte */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9492 /* flat_store_byte */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9492 /* flat_store_byte */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9508 /* flat_store_byte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9508 /* flat_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9508 /* flat_store_byte_d16_hi */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9508 /* flat_store_byte_d16_hi */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9508 /* flat_store_byte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9508 /* flat_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9508 /* flat_store_byte_d16_hi */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9508 /* flat_store_byte_d16_hi */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9531 /* flat_store_d16_hi_b16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 9531 /* flat_store_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 9531 /* flat_store_d16_hi_b16 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 9531 /* flat_store_d16_hi_b16 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 9531 /* flat_store_d16_hi_b16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 9531 /* flat_store_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 9531 /* flat_store_d16_hi_b16 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 9531 /* flat_store_d16_hi_b16 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 9531 /* flat_store_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 9531 /* flat_store_d16_hi_b16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 9531 /* flat_store_d16_hi_b16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 9531 /* flat_store_d16_hi_b16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 9531 /* flat_store_d16_hi_b16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 9553 /* flat_store_d16_hi_b8 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX11Only },
  { 9553 /* flat_store_d16_hi_b8 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX11Only },
  { 9553 /* flat_store_d16_hi_b8 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX11Only },
  { 9553 /* flat_store_d16_hi_b8 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX11Only },
  { 9553 /* flat_store_d16_hi_b8 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX12Only },
  { 9553 /* flat_store_d16_hi_b8 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX12Only },
  { 9553 /* flat_store_d16_hi_b8 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX12Only },
  { 9553 /* flat_store_d16_hi_b8 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX12Only },
  { 9553 /* flat_store_d16_hi_b8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 9553 /* flat_store_d16_hi_b8 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 9553 /* flat_store_d16_hi_b8 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 9553 /* flat_store_d16_hi_b8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 9553 /* flat_store_d16_hi_b8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGVSMode_HasD16LoadStore_isGFX12Only },
  { 9574 /* flat_store_dword */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9574 /* flat_store_dword */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9574 /* flat_store_dword */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9574 /* flat_store_dword */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9574 /* flat_store_dword */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9574 /* flat_store_dword */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9574 /* flat_store_dword */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9574 /* flat_store_dword */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9574 /* flat_store_dword */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9574 /* flat_store_dword */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9574 /* flat_store_dword */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9574 /* flat_store_dword */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9591 /* flat_store_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9591 /* flat_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9591 /* flat_store_dwordx2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9591 /* flat_store_dwordx2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9591 /* flat_store_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9591 /* flat_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9591 /* flat_store_dwordx2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9591 /* flat_store_dwordx2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9591 /* flat_store_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9591 /* flat_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9591 /* flat_store_dwordx2 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9591 /* flat_store_dwordx2 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9610 /* flat_store_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9610 /* flat_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9610 /* flat_store_dwordx3 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9610 /* flat_store_dwordx3 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9610 /* flat_store_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9610 /* flat_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9610 /* flat_store_dwordx3 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9610 /* flat_store_dwordx3 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9610 /* flat_store_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9610 /* flat_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9610 /* flat_store_dwordx3 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9610 /* flat_store_dwordx3 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9629 /* flat_store_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9629 /* flat_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9629 /* flat_store_dwordx4 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9629 /* flat_store_dwordx4 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9629 /* flat_store_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9629 /* flat_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9629 /* flat_store_dwordx4 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9629 /* flat_store_dwordx4 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9629 /* flat_store_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9629 /* flat_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9629 /* flat_store_dwordx4 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9629 /* flat_store_dwordx4 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9648 /* flat_store_short */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9648 /* flat_store_short */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9648 /* flat_store_short */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9648 /* flat_store_short */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX7Only },
  { 9648 /* flat_store_short */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9648 /* flat_store_short */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9648 /* flat_store_short */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9648 /* flat_store_short */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX10Only },
  { 9648 /* flat_store_short */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9648 /* flat_store_short */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9648 /* flat_store_short */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9648 /* flat_store_short */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatAddressSpace_isGFX8GFX9 },
  { 9665 /* flat_store_short_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9665 /* flat_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9665 /* flat_store_short_d16_hi */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9665 /* flat_store_short_d16_hi */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX10Only },
  { 9665 /* flat_store_short_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9665 /* flat_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9665 /* flat_store_short_d16_hi */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9665 /* flat_store_short_d16_hi */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasD16LoadStore_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9689 /* global_atomic_add */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9689 /* global_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9689 /* global_atomic_add */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9689 /* global_atomic_add */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9689 /* global_atomic_add */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9689 /* global_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9689 /* global_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9689 /* global_atomic_add */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9689 /* global_atomic_add */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9689 /* global_atomic_add */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9689 /* global_atomic_add */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9689 /* global_atomic_add */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9689 /* global_atomic_add */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9689 /* global_atomic_add */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9689 /* global_atomic_add */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9689 /* global_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9689 /* global_atomic_add */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9689 /* global_atomic_add */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9689 /* global_atomic_add */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9689 /* global_atomic_add */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9707 /* global_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 9707 /* global_atomic_add_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 9707 /* global_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 9707 /* global_atomic_add_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 9707 /* global_atomic_add_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 9707 /* global_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 9707 /* global_atomic_add_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 9707 /* global_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 9707 /* global_atomic_add_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 9707 /* global_atomic_add_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 9707 /* global_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 9707 /* global_atomic_add_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 9707 /* global_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 9707 /* global_atomic_add_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 9707 /* global_atomic_add_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 9707 /* global_atomic_add_f32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 4 /* 2 */, MCK_off, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 9707 /* global_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 9707 /* global_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 9707 /* global_atomic_add_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 9707 /* global_atomic_add_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFaddNoRtnInsts_isGFX11Only },
  { 9707 /* global_atomic_add_f32 */, 4 /* 2 */, MCK_off, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 9707 /* global_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 9707 /* global_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 9707 /* global_atomic_add_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 9707 /* global_atomic_add_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFaddNoRtnInsts_isGFX12Only },
  { 9707 /* global_atomic_add_f32 */, 4 /* 2 */, MCK_off, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 9707 /* global_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 9707 /* global_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 9707 /* global_atomic_add_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 9707 /* global_atomic_add_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFaddNoRtnInsts_isGFX940Plus },
  { 9707 /* global_atomic_add_f32 */, 4 /* 2 */, MCK_off, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFaddNoRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 8 /* 3 */, MCK_off, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 9707 /* global_atomic_add_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 9707 /* global_atomic_add_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 9707 /* global_atomic_add_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 9707 /* global_atomic_add_f32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 9707 /* global_atomic_add_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 9707 /* global_atomic_add_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 9707 /* global_atomic_add_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 9707 /* global_atomic_add_f32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 9707 /* global_atomic_add_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 9707 /* global_atomic_add_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 9707 /* global_atomic_add_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 9707 /* global_atomic_add_f32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 8 /* 3 */, MCK_off, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 9707 /* global_atomic_add_f32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 9707 /* global_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 9707 /* global_atomic_add_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 9707 /* global_atomic_add_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFaddRtnInsts_isGFX11Only },
  { 9707 /* global_atomic_add_f32 */, 8 /* 3 */, MCK_off, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 9707 /* global_atomic_add_f32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 9707 /* global_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 9707 /* global_atomic_add_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 9707 /* global_atomic_add_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFaddRtnInsts_isGFX12Only },
  { 9707 /* global_atomic_add_f32 */, 8 /* 3 */, MCK_off, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 9707 /* global_atomic_add_f32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 9707 /* global_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 9707 /* global_atomic_add_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 9707 /* global_atomic_add_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFaddRtnInsts_isGFX940Plus },
  { 9707 /* global_atomic_add_f32 */, 8 /* 3 */, MCK_off, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940 },
  { 9707 /* global_atomic_add_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFaddRtnInsts_isGFX8GFX9NotGFX940 },
  { 9729 /* global_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 9729 /* global_atomic_add_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 9729 /* global_atomic_add_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 9729 /* global_atomic_add_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 9729 /* global_atomic_add_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 9729 /* global_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 9729 /* global_atomic_add_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 9729 /* global_atomic_add_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 9729 /* global_atomic_add_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 9729 /* global_atomic_add_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 9729 /* global_atomic_add_f64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 9729 /* global_atomic_add_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 9729 /* global_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 9729 /* global_atomic_add_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 9729 /* global_atomic_add_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 9729 /* global_atomic_add_f64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 9729 /* global_atomic_add_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 9729 /* global_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 9729 /* global_atomic_add_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 9729 /* global_atomic_add_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 9729 /* global_atomic_add_f64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 9729 /* global_atomic_add_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 9729 /* global_atomic_add_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 9729 /* global_atomic_add_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 9729 /* global_atomic_add_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 9729 /* global_atomic_add_f64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 9729 /* global_atomic_add_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 9729 /* global_atomic_add_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 9729 /* global_atomic_add_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 9729 /* global_atomic_add_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 9729 /* global_atomic_add_f64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 9729 /* global_atomic_add_f64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 9729 /* global_atomic_add_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 9729 /* global_atomic_add_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX125xOnly },
  { 9729 /* global_atomic_add_f64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 9729 /* global_atomic_add_f64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 9729 /* global_atomic_add_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 9729 /* global_atomic_add_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX940Plus },
  { 9729 /* global_atomic_add_f64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9729 /* global_atomic_add_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatBufferGlobalAtomicFaddF64Inst_isGFX8GFX9 },
  { 9751 /* global_atomic_add_u32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9751 /* global_atomic_add_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9751 /* global_atomic_add_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9751 /* global_atomic_add_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9751 /* global_atomic_add_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9751 /* global_atomic_add_u32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9751 /* global_atomic_add_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9751 /* global_atomic_add_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9751 /* global_atomic_add_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9751 /* global_atomic_add_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9751 /* global_atomic_add_u32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9751 /* global_atomic_add_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9751 /* global_atomic_add_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9751 /* global_atomic_add_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9751 /* global_atomic_add_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9751 /* global_atomic_add_u32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9751 /* global_atomic_add_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9751 /* global_atomic_add_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9751 /* global_atomic_add_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9751 /* global_atomic_add_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9751 /* global_atomic_add_u32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9751 /* global_atomic_add_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9751 /* global_atomic_add_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9751 /* global_atomic_add_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9751 /* global_atomic_add_u32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9751 /* global_atomic_add_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9751 /* global_atomic_add_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9751 /* global_atomic_add_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9751 /* global_atomic_add_u32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9751 /* global_atomic_add_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9751 /* global_atomic_add_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9751 /* global_atomic_add_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9751 /* global_atomic_add_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9751 /* global_atomic_add_u32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9751 /* global_atomic_add_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9751 /* global_atomic_add_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9751 /* global_atomic_add_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9751 /* global_atomic_add_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9773 /* global_atomic_add_u64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9773 /* global_atomic_add_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9773 /* global_atomic_add_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9773 /* global_atomic_add_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9773 /* global_atomic_add_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9773 /* global_atomic_add_u64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9773 /* global_atomic_add_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9773 /* global_atomic_add_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9773 /* global_atomic_add_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9773 /* global_atomic_add_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9773 /* global_atomic_add_u64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9773 /* global_atomic_add_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9773 /* global_atomic_add_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9773 /* global_atomic_add_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9773 /* global_atomic_add_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9773 /* global_atomic_add_u64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9773 /* global_atomic_add_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9773 /* global_atomic_add_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9773 /* global_atomic_add_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9773 /* global_atomic_add_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9773 /* global_atomic_add_u64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9773 /* global_atomic_add_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9773 /* global_atomic_add_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9773 /* global_atomic_add_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9773 /* global_atomic_add_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9773 /* global_atomic_add_u64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9773 /* global_atomic_add_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9773 /* global_atomic_add_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9773 /* global_atomic_add_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9773 /* global_atomic_add_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9773 /* global_atomic_add_u64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9773 /* global_atomic_add_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9773 /* global_atomic_add_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9773 /* global_atomic_add_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9773 /* global_atomic_add_u64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9773 /* global_atomic_add_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9773 /* global_atomic_add_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9773 /* global_atomic_add_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9795 /* global_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9795 /* global_atomic_add_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9795 /* global_atomic_add_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9795 /* global_atomic_add_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9795 /* global_atomic_add_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9795 /* global_atomic_add_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9795 /* global_atomic_add_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9795 /* global_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9795 /* global_atomic_add_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9795 /* global_atomic_add_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9795 /* global_atomic_add_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9795 /* global_atomic_add_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9795 /* global_atomic_add_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9795 /* global_atomic_add_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9795 /* global_atomic_add_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9795 /* global_atomic_add_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9795 /* global_atomic_add_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9795 /* global_atomic_add_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9795 /* global_atomic_add_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9795 /* global_atomic_add_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9795 /* global_atomic_add_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9816 /* global_atomic_and */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9816 /* global_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9816 /* global_atomic_and */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9816 /* global_atomic_and */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9816 /* global_atomic_and */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9816 /* global_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9816 /* global_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9816 /* global_atomic_and */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9816 /* global_atomic_and */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9816 /* global_atomic_and */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9816 /* global_atomic_and */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9816 /* global_atomic_and */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9816 /* global_atomic_and */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9816 /* global_atomic_and */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9816 /* global_atomic_and */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9816 /* global_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9816 /* global_atomic_and */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9816 /* global_atomic_and */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9816 /* global_atomic_and */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9816 /* global_atomic_and */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9834 /* global_atomic_and_b32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9834 /* global_atomic_and_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9834 /* global_atomic_and_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9834 /* global_atomic_and_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9834 /* global_atomic_and_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9834 /* global_atomic_and_b32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9834 /* global_atomic_and_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9834 /* global_atomic_and_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9834 /* global_atomic_and_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9834 /* global_atomic_and_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9834 /* global_atomic_and_b32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9834 /* global_atomic_and_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9834 /* global_atomic_and_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9834 /* global_atomic_and_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9834 /* global_atomic_and_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9834 /* global_atomic_and_b32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9834 /* global_atomic_and_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9834 /* global_atomic_and_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9834 /* global_atomic_and_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9834 /* global_atomic_and_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9834 /* global_atomic_and_b32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9834 /* global_atomic_and_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9834 /* global_atomic_and_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9834 /* global_atomic_and_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9834 /* global_atomic_and_b32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9834 /* global_atomic_and_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9834 /* global_atomic_and_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9834 /* global_atomic_and_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9834 /* global_atomic_and_b32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9834 /* global_atomic_and_b32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9834 /* global_atomic_and_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9834 /* global_atomic_and_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9834 /* global_atomic_and_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9834 /* global_atomic_and_b32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9834 /* global_atomic_and_b32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9834 /* global_atomic_and_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9834 /* global_atomic_and_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9834 /* global_atomic_and_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9856 /* global_atomic_and_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9856 /* global_atomic_and_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9856 /* global_atomic_and_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9856 /* global_atomic_and_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9856 /* global_atomic_and_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9856 /* global_atomic_and_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9856 /* global_atomic_and_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9856 /* global_atomic_and_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9856 /* global_atomic_and_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9856 /* global_atomic_and_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9856 /* global_atomic_and_b64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9856 /* global_atomic_and_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9856 /* global_atomic_and_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9856 /* global_atomic_and_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9856 /* global_atomic_and_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9856 /* global_atomic_and_b64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9856 /* global_atomic_and_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9856 /* global_atomic_and_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9856 /* global_atomic_and_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9856 /* global_atomic_and_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9856 /* global_atomic_and_b64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9856 /* global_atomic_and_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9856 /* global_atomic_and_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9856 /* global_atomic_and_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9856 /* global_atomic_and_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9856 /* global_atomic_and_b64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9856 /* global_atomic_and_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9856 /* global_atomic_and_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9856 /* global_atomic_and_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9856 /* global_atomic_and_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9856 /* global_atomic_and_b64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9856 /* global_atomic_and_b64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9856 /* global_atomic_and_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9856 /* global_atomic_and_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9856 /* global_atomic_and_b64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9856 /* global_atomic_and_b64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9856 /* global_atomic_and_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9856 /* global_atomic_and_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9878 /* global_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9878 /* global_atomic_and_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9878 /* global_atomic_and_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9878 /* global_atomic_and_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9878 /* global_atomic_and_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9878 /* global_atomic_and_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9878 /* global_atomic_and_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9878 /* global_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9878 /* global_atomic_and_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9878 /* global_atomic_and_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9878 /* global_atomic_and_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9878 /* global_atomic_and_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9878 /* global_atomic_and_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9878 /* global_atomic_and_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9878 /* global_atomic_and_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9878 /* global_atomic_and_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9878 /* global_atomic_and_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9878 /* global_atomic_and_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9878 /* global_atomic_and_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9878 /* global_atomic_and_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9878 /* global_atomic_and_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9899 /* global_atomic_cmpswap */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9899 /* global_atomic_cmpswap */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9899 /* global_atomic_cmpswap */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9899 /* global_atomic_cmpswap */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9899 /* global_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9899 /* global_atomic_cmpswap */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9899 /* global_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9899 /* global_atomic_cmpswap */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9899 /* global_atomic_cmpswap */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9899 /* global_atomic_cmpswap */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 4 /* 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 1 /* 0 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 4 /* 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 1 /* 0 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9899 /* global_atomic_cmpswap */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9899 /* global_atomic_cmpswap */, 4 /* 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9899 /* global_atomic_cmpswap */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9899 /* global_atomic_cmpswap */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9899 /* global_atomic_cmpswap */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 4 /* 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9899 /* global_atomic_cmpswap */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9899 /* global_atomic_cmpswap */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9899 /* global_atomic_cmpswap */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9899 /* global_atomic_cmpswap */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9899 /* global_atomic_cmpswap */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9899 /* global_atomic_cmpswap */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9921 /* global_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 4 /* 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9921 /* global_atomic_cmpswap_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 3 /* 0, 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 3 /* 0, 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 4 /* 2 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9947 /* global_atomic_cmpswap_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 9973 /* global_atomic_cmpswap_f32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX10Plus_isGFX11Only },
  { 9973 /* global_atomic_cmpswap_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX11Only },
  { 9973 /* global_atomic_cmpswap_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Plus_isGFX11Only },
  { 9973 /* global_atomic_cmpswap_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX11Only },
  { 9973 /* global_atomic_cmpswap_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX11Only },
  { 9973 /* global_atomic_cmpswap_f32 */, 4 /* 2 */, MCK_off, AMFBS_isGFX10Plus_isGFX11Only },
  { 9973 /* global_atomic_cmpswap_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Plus_isGFX11Only },
  { 9973 /* global_atomic_cmpswap_f32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Plus_isGFX11Only },
  { 9973 /* global_atomic_cmpswap_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX11Only },
  { 9973 /* global_atomic_cmpswap_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX11Only },
  { 9973 /* global_atomic_cmpswap_f32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX10Plus_isGFX11Only },
  { 9973 /* global_atomic_cmpswap_f32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX11Only },
  { 9973 /* global_atomic_cmpswap_f32 */, 4 /* 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Plus_isGFX11Only },
  { 9973 /* global_atomic_cmpswap_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX11Only },
  { 9973 /* global_atomic_cmpswap_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX11Only },
  { 9973 /* global_atomic_cmpswap_f32 */, 8 /* 3 */, MCK_off, AMFBS_isGFX10Plus_isGFX11Only },
  { 9973 /* global_atomic_cmpswap_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX11Only },
  { 9973 /* global_atomic_cmpswap_f32 */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Plus_isGFX11Only },
  { 9973 /* global_atomic_cmpswap_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX11Only },
  { 9973 /* global_atomic_cmpswap_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX11Only },
  { 9999 /* global_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9999 /* global_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9999 /* global_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9999 /* global_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9999 /* global_atomic_cmpswap_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9999 /* global_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9999 /* global_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9999 /* global_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9999 /* global_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9999 /* global_atomic_cmpswap_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9999 /* global_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_AReg_128, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_AReg_128, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9999 /* global_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9999 /* global_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9999 /* global_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9999 /* global_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9999 /* global_atomic_cmpswap_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9999 /* global_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9999 /* global_atomic_cmpswap_x2 */, 3 /* 0, 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9999 /* global_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9999 /* global_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9999 /* global_atomic_cmpswap_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 9999 /* global_atomic_cmpswap_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 3 /* 0, 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 4 /* 2 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 9999 /* global_atomic_cmpswap_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10024 /* global_atomic_cond_sub_u32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX12Plus_isGFX12Only },
  { 10024 /* global_atomic_cond_sub_u32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 10024 /* global_atomic_cond_sub_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX12Plus_isGFX12Only },
  { 10024 /* global_atomic_cond_sub_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX12Plus_isGFX12Only },
  { 10024 /* global_atomic_cond_sub_u32 */, 4 /* 2 */, MCK_off, AMFBS_isGFX12Plus_isGFX12Only },
  { 10024 /* global_atomic_cond_sub_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 10024 /* global_atomic_cond_sub_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus_isGFX12Only },
  { 10024 /* global_atomic_cond_sub_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX12Plus_isGFX12Only },
  { 10024 /* global_atomic_cond_sub_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX12Plus_isGFX12Only },
  { 10024 /* global_atomic_cond_sub_u32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX12Plus_isGFX12Only },
  { 10024 /* global_atomic_cond_sub_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 10024 /* global_atomic_cond_sub_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX12Plus_isGFX12Only },
  { 10024 /* global_atomic_cond_sub_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Plus_isGFX12Only },
  { 10024 /* global_atomic_cond_sub_u32 */, 8 /* 3 */, MCK_off, AMFBS_isGFX12Plus_isGFX12Only },
  { 10024 /* global_atomic_cond_sub_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 10024 /* global_atomic_cond_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus_isGFX12Only },
  { 10024 /* global_atomic_cond_sub_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX12Plus_isGFX12Only },
  { 10024 /* global_atomic_cond_sub_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12Plus_isGFX12Only },
  { 10051 /* global_atomic_csub */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 10051 /* global_atomic_csub */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 10051 /* global_atomic_csub */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 10051 /* global_atomic_csub */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 10051 /* global_atomic_csub */, 4 /* 2 */, MCK_off, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 10051 /* global_atomic_csub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 10051 /* global_atomic_csub */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 10051 /* global_atomic_csub */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 10051 /* global_atomic_csub */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 10051 /* global_atomic_csub */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 10051 /* global_atomic_csub */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 10051 /* global_atomic_csub */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 10051 /* global_atomic_csub */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 10051 /* global_atomic_csub */, 8 /* 3 */, MCK_off, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 10051 /* global_atomic_csub */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 10051 /* global_atomic_csub */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 10051 /* global_atomic_csub */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 10051 /* global_atomic_csub */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_isGFX10Only },
  { 10070 /* global_atomic_csub_u32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 10070 /* global_atomic_csub_u32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 10070 /* global_atomic_csub_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 10070 /* global_atomic_csub_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 10070 /* global_atomic_csub_u32 */, 4 /* 2 */, MCK_off, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 10070 /* global_atomic_csub_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 10070 /* global_atomic_csub_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 10070 /* global_atomic_csub_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 10070 /* global_atomic_csub_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 10070 /* global_atomic_csub_u32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 10070 /* global_atomic_csub_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 10070 /* global_atomic_csub_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 10070 /* global_atomic_csub_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 10070 /* global_atomic_csub_u32 */, 8 /* 3 */, MCK_off, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 10070 /* global_atomic_csub_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 10070 /* global_atomic_csub_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 10070 /* global_atomic_csub_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 10070 /* global_atomic_csub_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_isGFX11Only },
  { 10093 /* global_atomic_dec */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10093 /* global_atomic_dec */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10093 /* global_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10093 /* global_atomic_dec */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10093 /* global_atomic_dec */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10093 /* global_atomic_dec */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10093 /* global_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10093 /* global_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10093 /* global_atomic_dec */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10093 /* global_atomic_dec */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10093 /* global_atomic_dec */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10093 /* global_atomic_dec */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10093 /* global_atomic_dec */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10093 /* global_atomic_dec */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10093 /* global_atomic_dec */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10093 /* global_atomic_dec */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10093 /* global_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10093 /* global_atomic_dec */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10093 /* global_atomic_dec */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10093 /* global_atomic_dec */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10093 /* global_atomic_dec */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10111 /* global_atomic_dec_u32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10111 /* global_atomic_dec_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10111 /* global_atomic_dec_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10111 /* global_atomic_dec_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10111 /* global_atomic_dec_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10111 /* global_atomic_dec_u32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10111 /* global_atomic_dec_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10111 /* global_atomic_dec_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10111 /* global_atomic_dec_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10111 /* global_atomic_dec_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10111 /* global_atomic_dec_u32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10111 /* global_atomic_dec_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10111 /* global_atomic_dec_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10111 /* global_atomic_dec_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10111 /* global_atomic_dec_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10111 /* global_atomic_dec_u32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10111 /* global_atomic_dec_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10111 /* global_atomic_dec_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10111 /* global_atomic_dec_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10111 /* global_atomic_dec_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10111 /* global_atomic_dec_u32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10111 /* global_atomic_dec_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10111 /* global_atomic_dec_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10111 /* global_atomic_dec_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10111 /* global_atomic_dec_u32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10111 /* global_atomic_dec_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10111 /* global_atomic_dec_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10111 /* global_atomic_dec_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10111 /* global_atomic_dec_u32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10111 /* global_atomic_dec_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10111 /* global_atomic_dec_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10111 /* global_atomic_dec_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10111 /* global_atomic_dec_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10111 /* global_atomic_dec_u32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10111 /* global_atomic_dec_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10111 /* global_atomic_dec_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10111 /* global_atomic_dec_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10111 /* global_atomic_dec_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10133 /* global_atomic_dec_u64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10133 /* global_atomic_dec_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10133 /* global_atomic_dec_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10133 /* global_atomic_dec_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10133 /* global_atomic_dec_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10133 /* global_atomic_dec_u64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10133 /* global_atomic_dec_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10133 /* global_atomic_dec_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10133 /* global_atomic_dec_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10133 /* global_atomic_dec_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10133 /* global_atomic_dec_u64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10133 /* global_atomic_dec_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10133 /* global_atomic_dec_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10133 /* global_atomic_dec_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10133 /* global_atomic_dec_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10133 /* global_atomic_dec_u64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10133 /* global_atomic_dec_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10133 /* global_atomic_dec_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10133 /* global_atomic_dec_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10133 /* global_atomic_dec_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10133 /* global_atomic_dec_u64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10133 /* global_atomic_dec_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10133 /* global_atomic_dec_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10133 /* global_atomic_dec_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10133 /* global_atomic_dec_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10133 /* global_atomic_dec_u64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10133 /* global_atomic_dec_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10133 /* global_atomic_dec_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10133 /* global_atomic_dec_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10133 /* global_atomic_dec_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10133 /* global_atomic_dec_u64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10133 /* global_atomic_dec_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10133 /* global_atomic_dec_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10133 /* global_atomic_dec_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10133 /* global_atomic_dec_u64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10133 /* global_atomic_dec_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10133 /* global_atomic_dec_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10133 /* global_atomic_dec_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10155 /* global_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10155 /* global_atomic_dec_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10155 /* global_atomic_dec_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10155 /* global_atomic_dec_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10155 /* global_atomic_dec_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10155 /* global_atomic_dec_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10155 /* global_atomic_dec_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10155 /* global_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10155 /* global_atomic_dec_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10155 /* global_atomic_dec_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10155 /* global_atomic_dec_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10155 /* global_atomic_dec_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10155 /* global_atomic_dec_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10155 /* global_atomic_dec_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10155 /* global_atomic_dec_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10155 /* global_atomic_dec_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10155 /* global_atomic_dec_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10155 /* global_atomic_dec_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10155 /* global_atomic_dec_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10155 /* global_atomic_dec_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10155 /* global_atomic_dec_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10176 /* global_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX10Plus_isGFX10Only },
  { 10176 /* global_atomic_fcmpswap */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX10Only },
  { 10176 /* global_atomic_fcmpswap */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Plus_isGFX10Only },
  { 10176 /* global_atomic_fcmpswap */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX10Only },
  { 10176 /* global_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX10Only },
  { 10176 /* global_atomic_fcmpswap */, 4 /* 2 */, MCK_off, AMFBS_isGFX10Plus_isGFX10Only },
  { 10176 /* global_atomic_fcmpswap */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_isGFX10Plus_isGFX10Only },
  { 10176 /* global_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Plus_isGFX10Only },
  { 10176 /* global_atomic_fcmpswap */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX10Only },
  { 10176 /* global_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX10Only },
  { 10176 /* global_atomic_fcmpswap */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX10Plus_isGFX10Only },
  { 10176 /* global_atomic_fcmpswap */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX10Only },
  { 10176 /* global_atomic_fcmpswap */, 4 /* 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Plus_isGFX10Only },
  { 10176 /* global_atomic_fcmpswap */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX10Only },
  { 10176 /* global_atomic_fcmpswap */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX10Only },
  { 10176 /* global_atomic_fcmpswap */, 8 /* 3 */, MCK_off, AMFBS_isGFX10Plus_isGFX10Only },
  { 10176 /* global_atomic_fcmpswap */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX10Only },
  { 10176 /* global_atomic_fcmpswap */, 6 /* 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Plus_isGFX10Only },
  { 10176 /* global_atomic_fcmpswap */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX10Only },
  { 10176 /* global_atomic_fcmpswap */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX10Only },
  { 10199 /* global_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX10Plus_isGFX10Only },
  { 10199 /* global_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX10Only },
  { 10199 /* global_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Plus_isGFX10Only },
  { 10199 /* global_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX10Only },
  { 10199 /* global_atomic_fcmpswap_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX10Only },
  { 10199 /* global_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_off, AMFBS_isGFX10Plus_isGFX10Only },
  { 10199 /* global_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_isGFX10Plus_isGFX10Only },
  { 10199 /* global_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Plus_isGFX10Only },
  { 10199 /* global_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX10Only },
  { 10199 /* global_atomic_fcmpswap_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX10Only },
  { 10199 /* global_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX10Plus_isGFX10Only },
  { 10199 /* global_atomic_fcmpswap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX10Only },
  { 10199 /* global_atomic_fcmpswap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Plus_isGFX10Only },
  { 10199 /* global_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX10Plus_isGFX10Only },
  { 10199 /* global_atomic_fcmpswap_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX10Only },
  { 10199 /* global_atomic_fcmpswap_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX10Only },
  { 10199 /* global_atomic_fcmpswap_x2 */, 8 /* 3 */, MCK_off, AMFBS_isGFX10Plus_isGFX10Only },
  { 10199 /* global_atomic_fcmpswap_x2 */, 3 /* 0, 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Plus_isGFX10Only },
  { 10199 /* global_atomic_fcmpswap_x2 */, 4 /* 2 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX10Plus_isGFX10Only },
  { 10199 /* global_atomic_fcmpswap_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX10Only },
  { 10199 /* global_atomic_fcmpswap_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX10Only },
  { 10225 /* global_atomic_fmax */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX10Plus_isGFX10Only },
  { 10225 /* global_atomic_fmax */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX10Only },
  { 10225 /* global_atomic_fmax */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Plus_isGFX10Only },
  { 10225 /* global_atomic_fmax */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX10Only },
  { 10225 /* global_atomic_fmax */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX10Only },
  { 10225 /* global_atomic_fmax */, 4 /* 2 */, MCK_off, AMFBS_isGFX10Plus_isGFX10Only },
  { 10225 /* global_atomic_fmax */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Plus_isGFX10Only },
  { 10225 /* global_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Plus_isGFX10Only },
  { 10225 /* global_atomic_fmax */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX10Only },
  { 10225 /* global_atomic_fmax */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX10Only },
  { 10225 /* global_atomic_fmax */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX10Plus_isGFX10Only },
  { 10225 /* global_atomic_fmax */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX10Only },
  { 10225 /* global_atomic_fmax */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX10Only },
  { 10225 /* global_atomic_fmax */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX10Only },
  { 10225 /* global_atomic_fmax */, 8 /* 3 */, MCK_off, AMFBS_isGFX10Plus_isGFX10Only },
  { 10225 /* global_atomic_fmax */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX10Only },
  { 10225 /* global_atomic_fmax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Plus_isGFX10Only },
  { 10225 /* global_atomic_fmax */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX10Only },
  { 10225 /* global_atomic_fmax */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX10Only },
  { 10244 /* global_atomic_fmax_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10244 /* global_atomic_fmax_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10244 /* global_atomic_fmax_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10244 /* global_atomic_fmax_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10244 /* global_atomic_fmax_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10244 /* global_atomic_fmax_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10244 /* global_atomic_fmax_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10244 /* global_atomic_fmax_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10244 /* global_atomic_fmax_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10244 /* global_atomic_fmax_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10244 /* global_atomic_fmax_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10244 /* global_atomic_fmax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10244 /* global_atomic_fmax_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10244 /* global_atomic_fmax_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10244 /* global_atomic_fmax_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10244 /* global_atomic_fmax_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10244 /* global_atomic_fmax_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10244 /* global_atomic_fmax_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10244 /* global_atomic_fmax_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10266 /* global_atomic_fmin */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX10Plus_isGFX10Only },
  { 10266 /* global_atomic_fmin */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX10Only },
  { 10266 /* global_atomic_fmin */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Plus_isGFX10Only },
  { 10266 /* global_atomic_fmin */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX10Only },
  { 10266 /* global_atomic_fmin */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX10Only },
  { 10266 /* global_atomic_fmin */, 4 /* 2 */, MCK_off, AMFBS_isGFX10Plus_isGFX10Only },
  { 10266 /* global_atomic_fmin */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Plus_isGFX10Only },
  { 10266 /* global_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Plus_isGFX10Only },
  { 10266 /* global_atomic_fmin */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX10Only },
  { 10266 /* global_atomic_fmin */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX10Only },
  { 10266 /* global_atomic_fmin */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX10Plus_isGFX10Only },
  { 10266 /* global_atomic_fmin */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX10Only },
  { 10266 /* global_atomic_fmin */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX10Only },
  { 10266 /* global_atomic_fmin */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX10Only },
  { 10266 /* global_atomic_fmin */, 8 /* 3 */, MCK_off, AMFBS_isGFX10Plus_isGFX10Only },
  { 10266 /* global_atomic_fmin */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX10Only },
  { 10266 /* global_atomic_fmin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Plus_isGFX10Only },
  { 10266 /* global_atomic_fmin */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX10Only },
  { 10266 /* global_atomic_fmin */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX10Only },
  { 10285 /* global_atomic_fmin_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10285 /* global_atomic_fmin_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10285 /* global_atomic_fmin_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10285 /* global_atomic_fmin_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10285 /* global_atomic_fmin_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10285 /* global_atomic_fmin_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10285 /* global_atomic_fmin_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10285 /* global_atomic_fmin_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10285 /* global_atomic_fmin_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10285 /* global_atomic_fmin_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10285 /* global_atomic_fmin_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10285 /* global_atomic_fmin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10285 /* global_atomic_fmin_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10285 /* global_atomic_fmin_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10285 /* global_atomic_fmin_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10285 /* global_atomic_fmin_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10285 /* global_atomic_fmin_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10285 /* global_atomic_fmin_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10285 /* global_atomic_fmin_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX10Only },
  { 10307 /* global_atomic_inc */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10307 /* global_atomic_inc */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10307 /* global_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10307 /* global_atomic_inc */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10307 /* global_atomic_inc */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10307 /* global_atomic_inc */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10307 /* global_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10307 /* global_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10307 /* global_atomic_inc */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10307 /* global_atomic_inc */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10307 /* global_atomic_inc */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10307 /* global_atomic_inc */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10307 /* global_atomic_inc */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10307 /* global_atomic_inc */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10307 /* global_atomic_inc */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10307 /* global_atomic_inc */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10307 /* global_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10307 /* global_atomic_inc */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10307 /* global_atomic_inc */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10307 /* global_atomic_inc */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10307 /* global_atomic_inc */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10325 /* global_atomic_inc_u32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10325 /* global_atomic_inc_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10325 /* global_atomic_inc_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10325 /* global_atomic_inc_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10325 /* global_atomic_inc_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10325 /* global_atomic_inc_u32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10325 /* global_atomic_inc_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10325 /* global_atomic_inc_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10325 /* global_atomic_inc_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10325 /* global_atomic_inc_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10325 /* global_atomic_inc_u32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10325 /* global_atomic_inc_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10325 /* global_atomic_inc_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10325 /* global_atomic_inc_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10325 /* global_atomic_inc_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10325 /* global_atomic_inc_u32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10325 /* global_atomic_inc_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10325 /* global_atomic_inc_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10325 /* global_atomic_inc_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10325 /* global_atomic_inc_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10325 /* global_atomic_inc_u32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10325 /* global_atomic_inc_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10325 /* global_atomic_inc_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10325 /* global_atomic_inc_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10325 /* global_atomic_inc_u32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10325 /* global_atomic_inc_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10325 /* global_atomic_inc_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10325 /* global_atomic_inc_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10325 /* global_atomic_inc_u32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10325 /* global_atomic_inc_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10325 /* global_atomic_inc_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10325 /* global_atomic_inc_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10325 /* global_atomic_inc_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10325 /* global_atomic_inc_u32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10325 /* global_atomic_inc_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10325 /* global_atomic_inc_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10325 /* global_atomic_inc_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10325 /* global_atomic_inc_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10347 /* global_atomic_inc_u64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10347 /* global_atomic_inc_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10347 /* global_atomic_inc_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10347 /* global_atomic_inc_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10347 /* global_atomic_inc_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10347 /* global_atomic_inc_u64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10347 /* global_atomic_inc_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10347 /* global_atomic_inc_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10347 /* global_atomic_inc_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10347 /* global_atomic_inc_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10347 /* global_atomic_inc_u64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10347 /* global_atomic_inc_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10347 /* global_atomic_inc_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10347 /* global_atomic_inc_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10347 /* global_atomic_inc_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10347 /* global_atomic_inc_u64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10347 /* global_atomic_inc_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10347 /* global_atomic_inc_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10347 /* global_atomic_inc_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10347 /* global_atomic_inc_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10347 /* global_atomic_inc_u64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10347 /* global_atomic_inc_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10347 /* global_atomic_inc_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10347 /* global_atomic_inc_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10347 /* global_atomic_inc_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10347 /* global_atomic_inc_u64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10347 /* global_atomic_inc_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10347 /* global_atomic_inc_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10347 /* global_atomic_inc_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10347 /* global_atomic_inc_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10347 /* global_atomic_inc_u64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10347 /* global_atomic_inc_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10347 /* global_atomic_inc_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10347 /* global_atomic_inc_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10347 /* global_atomic_inc_u64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10347 /* global_atomic_inc_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10347 /* global_atomic_inc_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10347 /* global_atomic_inc_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10369 /* global_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10369 /* global_atomic_inc_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10369 /* global_atomic_inc_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10369 /* global_atomic_inc_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10369 /* global_atomic_inc_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10369 /* global_atomic_inc_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10369 /* global_atomic_inc_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10369 /* global_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10369 /* global_atomic_inc_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10369 /* global_atomic_inc_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10369 /* global_atomic_inc_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10369 /* global_atomic_inc_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10369 /* global_atomic_inc_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10369 /* global_atomic_inc_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10369 /* global_atomic_inc_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10369 /* global_atomic_inc_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10369 /* global_atomic_inc_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10369 /* global_atomic_inc_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10369 /* global_atomic_inc_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10369 /* global_atomic_inc_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10369 /* global_atomic_inc_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10390 /* global_atomic_max_f32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX10Plus_isGFX11Only },
  { 10390 /* global_atomic_max_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX11Only },
  { 10390 /* global_atomic_max_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Plus_isGFX11Only },
  { 10390 /* global_atomic_max_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX11Only },
  { 10390 /* global_atomic_max_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX11Only },
  { 10390 /* global_atomic_max_f32 */, 4 /* 2 */, MCK_off, AMFBS_isGFX10Plus_isGFX11Only },
  { 10390 /* global_atomic_max_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Plus_isGFX11Only },
  { 10390 /* global_atomic_max_f32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Plus_isGFX11Only },
  { 10390 /* global_atomic_max_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX11Only },
  { 10390 /* global_atomic_max_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX11Only },
  { 10390 /* global_atomic_max_f32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX10Plus_isGFX11Only },
  { 10390 /* global_atomic_max_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX11Only },
  { 10390 /* global_atomic_max_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX11Only },
  { 10390 /* global_atomic_max_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX11Only },
  { 10390 /* global_atomic_max_f32 */, 8 /* 3 */, MCK_off, AMFBS_isGFX10Plus_isGFX11Only },
  { 10390 /* global_atomic_max_f32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX11Only },
  { 10390 /* global_atomic_max_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Plus_isGFX11Only },
  { 10390 /* global_atomic_max_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX11Only },
  { 10390 /* global_atomic_max_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX11Only },
  { 10412 /* global_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10412 /* global_atomic_max_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10412 /* global_atomic_max_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10412 /* global_atomic_max_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10412 /* global_atomic_max_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10412 /* global_atomic_max_f64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 4 /* 2 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10412 /* global_atomic_max_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10412 /* global_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10412 /* global_atomic_max_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10412 /* global_atomic_max_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10412 /* global_atomic_max_f64 */, 4 /* 2 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 8 /* 3 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10412 /* global_atomic_max_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10412 /* global_atomic_max_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10412 /* global_atomic_max_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10412 /* global_atomic_max_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10412 /* global_atomic_max_f64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 8 /* 3 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10412 /* global_atomic_max_f64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10412 /* global_atomic_max_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10412 /* global_atomic_max_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10412 /* global_atomic_max_f64 */, 8 /* 3 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10412 /* global_atomic_max_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10434 /* global_atomic_max_i32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10434 /* global_atomic_max_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10434 /* global_atomic_max_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10434 /* global_atomic_max_i32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10434 /* global_atomic_max_i32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10434 /* global_atomic_max_i32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10434 /* global_atomic_max_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10434 /* global_atomic_max_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10434 /* global_atomic_max_i32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10434 /* global_atomic_max_i32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10434 /* global_atomic_max_i32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10434 /* global_atomic_max_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10434 /* global_atomic_max_i32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10434 /* global_atomic_max_i32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10434 /* global_atomic_max_i32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10434 /* global_atomic_max_i32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10434 /* global_atomic_max_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10434 /* global_atomic_max_i32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10434 /* global_atomic_max_i32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10434 /* global_atomic_max_i32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10434 /* global_atomic_max_i32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10434 /* global_atomic_max_i32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10434 /* global_atomic_max_i32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10434 /* global_atomic_max_i32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10434 /* global_atomic_max_i32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10434 /* global_atomic_max_i32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10434 /* global_atomic_max_i32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10434 /* global_atomic_max_i32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10434 /* global_atomic_max_i32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10434 /* global_atomic_max_i32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10434 /* global_atomic_max_i32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10434 /* global_atomic_max_i32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10434 /* global_atomic_max_i32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10434 /* global_atomic_max_i32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10434 /* global_atomic_max_i32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10434 /* global_atomic_max_i32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10434 /* global_atomic_max_i32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10434 /* global_atomic_max_i32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10456 /* global_atomic_max_i64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10456 /* global_atomic_max_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10456 /* global_atomic_max_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10456 /* global_atomic_max_i64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10456 /* global_atomic_max_i64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10456 /* global_atomic_max_i64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10456 /* global_atomic_max_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10456 /* global_atomic_max_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10456 /* global_atomic_max_i64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10456 /* global_atomic_max_i64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10456 /* global_atomic_max_i64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10456 /* global_atomic_max_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10456 /* global_atomic_max_i64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10456 /* global_atomic_max_i64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10456 /* global_atomic_max_i64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10456 /* global_atomic_max_i64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10456 /* global_atomic_max_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10456 /* global_atomic_max_i64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10456 /* global_atomic_max_i64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10456 /* global_atomic_max_i64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10456 /* global_atomic_max_i64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10456 /* global_atomic_max_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10456 /* global_atomic_max_i64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10456 /* global_atomic_max_i64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10456 /* global_atomic_max_i64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10456 /* global_atomic_max_i64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10456 /* global_atomic_max_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10456 /* global_atomic_max_i64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10456 /* global_atomic_max_i64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10456 /* global_atomic_max_i64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10456 /* global_atomic_max_i64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10456 /* global_atomic_max_i64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10456 /* global_atomic_max_i64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10456 /* global_atomic_max_i64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10456 /* global_atomic_max_i64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10456 /* global_atomic_max_i64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10456 /* global_atomic_max_i64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10456 /* global_atomic_max_i64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10478 /* global_atomic_max_num_f32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX10Plus_isGFX12Only },
  { 10478 /* global_atomic_max_num_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX12Only },
  { 10478 /* global_atomic_max_num_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Plus_isGFX12Only },
  { 10478 /* global_atomic_max_num_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX12Only },
  { 10478 /* global_atomic_max_num_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX12Only },
  { 10478 /* global_atomic_max_num_f32 */, 4 /* 2 */, MCK_off, AMFBS_isGFX10Plus_isGFX12Only },
  { 10478 /* global_atomic_max_num_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Plus_isGFX12Only },
  { 10478 /* global_atomic_max_num_f32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Plus_isGFX12Only },
  { 10478 /* global_atomic_max_num_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX12Only },
  { 10478 /* global_atomic_max_num_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX12Only },
  { 10478 /* global_atomic_max_num_f32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX10Plus_isGFX12Only },
  { 10478 /* global_atomic_max_num_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX12Only },
  { 10478 /* global_atomic_max_num_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX12Only },
  { 10478 /* global_atomic_max_num_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX12Only },
  { 10478 /* global_atomic_max_num_f32 */, 8 /* 3 */, MCK_off, AMFBS_isGFX10Plus_isGFX12Only },
  { 10478 /* global_atomic_max_num_f32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX12Only },
  { 10478 /* global_atomic_max_num_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Plus_isGFX12Only },
  { 10478 /* global_atomic_max_num_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX12Only },
  { 10478 /* global_atomic_max_num_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX12Only },
  { 10504 /* global_atomic_max_num_f64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10504 /* global_atomic_max_num_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10504 /* global_atomic_max_num_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10504 /* global_atomic_max_num_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10504 /* global_atomic_max_num_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10504 /* global_atomic_max_num_f64 */, 4 /* 2 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10504 /* global_atomic_max_num_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10504 /* global_atomic_max_num_f64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10504 /* global_atomic_max_num_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10504 /* global_atomic_max_num_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10504 /* global_atomic_max_num_f64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10504 /* global_atomic_max_num_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10504 /* global_atomic_max_num_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10504 /* global_atomic_max_num_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10504 /* global_atomic_max_num_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10504 /* global_atomic_max_num_f64 */, 8 /* 3 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10504 /* global_atomic_max_num_f64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10504 /* global_atomic_max_num_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10504 /* global_atomic_max_num_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10530 /* global_atomic_max_u32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10530 /* global_atomic_max_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10530 /* global_atomic_max_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10530 /* global_atomic_max_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10530 /* global_atomic_max_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10530 /* global_atomic_max_u32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10530 /* global_atomic_max_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10530 /* global_atomic_max_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10530 /* global_atomic_max_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10530 /* global_atomic_max_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10530 /* global_atomic_max_u32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10530 /* global_atomic_max_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10530 /* global_atomic_max_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10530 /* global_atomic_max_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10530 /* global_atomic_max_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10530 /* global_atomic_max_u32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10530 /* global_atomic_max_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10530 /* global_atomic_max_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10530 /* global_atomic_max_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10530 /* global_atomic_max_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10530 /* global_atomic_max_u32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10530 /* global_atomic_max_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10530 /* global_atomic_max_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10530 /* global_atomic_max_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10530 /* global_atomic_max_u32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10530 /* global_atomic_max_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10530 /* global_atomic_max_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10530 /* global_atomic_max_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10530 /* global_atomic_max_u32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10530 /* global_atomic_max_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10530 /* global_atomic_max_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10530 /* global_atomic_max_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10530 /* global_atomic_max_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10530 /* global_atomic_max_u32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10530 /* global_atomic_max_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10530 /* global_atomic_max_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10530 /* global_atomic_max_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10530 /* global_atomic_max_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10552 /* global_atomic_max_u64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10552 /* global_atomic_max_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10552 /* global_atomic_max_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10552 /* global_atomic_max_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10552 /* global_atomic_max_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10552 /* global_atomic_max_u64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10552 /* global_atomic_max_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10552 /* global_atomic_max_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10552 /* global_atomic_max_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10552 /* global_atomic_max_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10552 /* global_atomic_max_u64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10552 /* global_atomic_max_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10552 /* global_atomic_max_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10552 /* global_atomic_max_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10552 /* global_atomic_max_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10552 /* global_atomic_max_u64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10552 /* global_atomic_max_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10552 /* global_atomic_max_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10552 /* global_atomic_max_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10552 /* global_atomic_max_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10552 /* global_atomic_max_u64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10552 /* global_atomic_max_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10552 /* global_atomic_max_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10552 /* global_atomic_max_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10552 /* global_atomic_max_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10552 /* global_atomic_max_u64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10552 /* global_atomic_max_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10552 /* global_atomic_max_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10552 /* global_atomic_max_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10552 /* global_atomic_max_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10552 /* global_atomic_max_u64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10552 /* global_atomic_max_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10552 /* global_atomic_max_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10552 /* global_atomic_max_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10552 /* global_atomic_max_u64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10552 /* global_atomic_max_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10552 /* global_atomic_max_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10552 /* global_atomic_max_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10574 /* global_atomic_min_f32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX10Plus_isGFX11Only },
  { 10574 /* global_atomic_min_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX11Only },
  { 10574 /* global_atomic_min_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Plus_isGFX11Only },
  { 10574 /* global_atomic_min_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX11Only },
  { 10574 /* global_atomic_min_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX11Only },
  { 10574 /* global_atomic_min_f32 */, 4 /* 2 */, MCK_off, AMFBS_isGFX10Plus_isGFX11Only },
  { 10574 /* global_atomic_min_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Plus_isGFX11Only },
  { 10574 /* global_atomic_min_f32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Plus_isGFX11Only },
  { 10574 /* global_atomic_min_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX11Only },
  { 10574 /* global_atomic_min_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX11Only },
  { 10574 /* global_atomic_min_f32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX10Plus_isGFX11Only },
  { 10574 /* global_atomic_min_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX11Only },
  { 10574 /* global_atomic_min_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX11Only },
  { 10574 /* global_atomic_min_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX11Only },
  { 10574 /* global_atomic_min_f32 */, 8 /* 3 */, MCK_off, AMFBS_isGFX10Plus_isGFX11Only },
  { 10574 /* global_atomic_min_f32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX11Only },
  { 10574 /* global_atomic_min_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Plus_isGFX11Only },
  { 10574 /* global_atomic_min_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX11Only },
  { 10574 /* global_atomic_min_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX11Only },
  { 10596 /* global_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10596 /* global_atomic_min_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10596 /* global_atomic_min_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10596 /* global_atomic_min_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10596 /* global_atomic_min_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10596 /* global_atomic_min_f64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 4 /* 2 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10596 /* global_atomic_min_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10596 /* global_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10596 /* global_atomic_min_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10596 /* global_atomic_min_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10596 /* global_atomic_min_f64 */, 4 /* 2 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 8 /* 3 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10596 /* global_atomic_min_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10596 /* global_atomic_min_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10596 /* global_atomic_min_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10596 /* global_atomic_min_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10596 /* global_atomic_min_f64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 8 /* 3 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10596 /* global_atomic_min_f64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10596 /* global_atomic_min_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10596 /* global_atomic_min_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX940Plus },
  { 10596 /* global_atomic_min_f64 */, 8 /* 3 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10596 /* global_atomic_min_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX8GFX9 },
  { 10618 /* global_atomic_min_i32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10618 /* global_atomic_min_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10618 /* global_atomic_min_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10618 /* global_atomic_min_i32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10618 /* global_atomic_min_i32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10618 /* global_atomic_min_i32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10618 /* global_atomic_min_i32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10618 /* global_atomic_min_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10618 /* global_atomic_min_i32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10618 /* global_atomic_min_i32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10618 /* global_atomic_min_i32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10618 /* global_atomic_min_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10618 /* global_atomic_min_i32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10618 /* global_atomic_min_i32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10618 /* global_atomic_min_i32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10618 /* global_atomic_min_i32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10618 /* global_atomic_min_i32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10618 /* global_atomic_min_i32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10618 /* global_atomic_min_i32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10618 /* global_atomic_min_i32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10618 /* global_atomic_min_i32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10618 /* global_atomic_min_i32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10618 /* global_atomic_min_i32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10618 /* global_atomic_min_i32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10618 /* global_atomic_min_i32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10618 /* global_atomic_min_i32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10618 /* global_atomic_min_i32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10618 /* global_atomic_min_i32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10618 /* global_atomic_min_i32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10618 /* global_atomic_min_i32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10618 /* global_atomic_min_i32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10618 /* global_atomic_min_i32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10618 /* global_atomic_min_i32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10618 /* global_atomic_min_i32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10618 /* global_atomic_min_i32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10618 /* global_atomic_min_i32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10618 /* global_atomic_min_i32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10618 /* global_atomic_min_i32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10640 /* global_atomic_min_i64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10640 /* global_atomic_min_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10640 /* global_atomic_min_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10640 /* global_atomic_min_i64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10640 /* global_atomic_min_i64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10640 /* global_atomic_min_i64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10640 /* global_atomic_min_i64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10640 /* global_atomic_min_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10640 /* global_atomic_min_i64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10640 /* global_atomic_min_i64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10640 /* global_atomic_min_i64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10640 /* global_atomic_min_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10640 /* global_atomic_min_i64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10640 /* global_atomic_min_i64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10640 /* global_atomic_min_i64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10640 /* global_atomic_min_i64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10640 /* global_atomic_min_i64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10640 /* global_atomic_min_i64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10640 /* global_atomic_min_i64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10640 /* global_atomic_min_i64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10640 /* global_atomic_min_i64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10640 /* global_atomic_min_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10640 /* global_atomic_min_i64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10640 /* global_atomic_min_i64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10640 /* global_atomic_min_i64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10640 /* global_atomic_min_i64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10640 /* global_atomic_min_i64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10640 /* global_atomic_min_i64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10640 /* global_atomic_min_i64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10640 /* global_atomic_min_i64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10640 /* global_atomic_min_i64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10640 /* global_atomic_min_i64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10640 /* global_atomic_min_i64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10640 /* global_atomic_min_i64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10640 /* global_atomic_min_i64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10640 /* global_atomic_min_i64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10640 /* global_atomic_min_i64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10640 /* global_atomic_min_i64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10662 /* global_atomic_min_num_f32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX10Plus_isGFX12Only },
  { 10662 /* global_atomic_min_num_f32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX12Only },
  { 10662 /* global_atomic_min_num_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Plus_isGFX12Only },
  { 10662 /* global_atomic_min_num_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX12Only },
  { 10662 /* global_atomic_min_num_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX12Only },
  { 10662 /* global_atomic_min_num_f32 */, 4 /* 2 */, MCK_off, AMFBS_isGFX10Plus_isGFX12Only },
  { 10662 /* global_atomic_min_num_f32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_isGFX10Plus_isGFX12Only },
  { 10662 /* global_atomic_min_num_f32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Plus_isGFX12Only },
  { 10662 /* global_atomic_min_num_f32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX12Only },
  { 10662 /* global_atomic_min_num_f32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX12Only },
  { 10662 /* global_atomic_min_num_f32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX10Plus_isGFX12Only },
  { 10662 /* global_atomic_min_num_f32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX12Only },
  { 10662 /* global_atomic_min_num_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX12Only },
  { 10662 /* global_atomic_min_num_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX12Only },
  { 10662 /* global_atomic_min_num_f32 */, 8 /* 3 */, MCK_off, AMFBS_isGFX10Plus_isGFX12Only },
  { 10662 /* global_atomic_min_num_f32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_isGFX10Plus_isGFX12Only },
  { 10662 /* global_atomic_min_num_f32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX10Plus_isGFX12Only },
  { 10662 /* global_atomic_min_num_f32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX10Plus_isGFX12Only },
  { 10662 /* global_atomic_min_num_f32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX10Plus_isGFX12Only },
  { 10688 /* global_atomic_min_num_f64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10688 /* global_atomic_min_num_f64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10688 /* global_atomic_min_num_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10688 /* global_atomic_min_num_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10688 /* global_atomic_min_num_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10688 /* global_atomic_min_num_f64 */, 4 /* 2 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10688 /* global_atomic_min_num_f64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10688 /* global_atomic_min_num_f64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10688 /* global_atomic_min_num_f64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10688 /* global_atomic_min_num_f64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10688 /* global_atomic_min_num_f64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10688 /* global_atomic_min_num_f64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10688 /* global_atomic_min_num_f64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10688 /* global_atomic_min_num_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10688 /* global_atomic_min_num_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10688 /* global_atomic_min_num_f64 */, 8 /* 3 */, MCK_off, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10688 /* global_atomic_min_num_f64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10688 /* global_atomic_min_num_f64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10688 /* global_atomic_min_num_f64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicFMinFMaxF64GlobalInsts_isGFX125xOnly },
  { 10714 /* global_atomic_min_u32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10714 /* global_atomic_min_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10714 /* global_atomic_min_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10714 /* global_atomic_min_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10714 /* global_atomic_min_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10714 /* global_atomic_min_u32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10714 /* global_atomic_min_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10714 /* global_atomic_min_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10714 /* global_atomic_min_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10714 /* global_atomic_min_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10714 /* global_atomic_min_u32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10714 /* global_atomic_min_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10714 /* global_atomic_min_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10714 /* global_atomic_min_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10714 /* global_atomic_min_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10714 /* global_atomic_min_u32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10714 /* global_atomic_min_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10714 /* global_atomic_min_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10714 /* global_atomic_min_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10714 /* global_atomic_min_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10714 /* global_atomic_min_u32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10714 /* global_atomic_min_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10714 /* global_atomic_min_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10714 /* global_atomic_min_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10714 /* global_atomic_min_u32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10714 /* global_atomic_min_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10714 /* global_atomic_min_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10714 /* global_atomic_min_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10714 /* global_atomic_min_u32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10714 /* global_atomic_min_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10714 /* global_atomic_min_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10714 /* global_atomic_min_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10714 /* global_atomic_min_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10714 /* global_atomic_min_u32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10714 /* global_atomic_min_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10714 /* global_atomic_min_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10714 /* global_atomic_min_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10714 /* global_atomic_min_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10736 /* global_atomic_min_u64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10736 /* global_atomic_min_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10736 /* global_atomic_min_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10736 /* global_atomic_min_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10736 /* global_atomic_min_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10736 /* global_atomic_min_u64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10736 /* global_atomic_min_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10736 /* global_atomic_min_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10736 /* global_atomic_min_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10736 /* global_atomic_min_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10736 /* global_atomic_min_u64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10736 /* global_atomic_min_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10736 /* global_atomic_min_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10736 /* global_atomic_min_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10736 /* global_atomic_min_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10736 /* global_atomic_min_u64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10736 /* global_atomic_min_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10736 /* global_atomic_min_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10736 /* global_atomic_min_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10736 /* global_atomic_min_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10736 /* global_atomic_min_u64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10736 /* global_atomic_min_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10736 /* global_atomic_min_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10736 /* global_atomic_min_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10736 /* global_atomic_min_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10736 /* global_atomic_min_u64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10736 /* global_atomic_min_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10736 /* global_atomic_min_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10736 /* global_atomic_min_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10736 /* global_atomic_min_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10736 /* global_atomic_min_u64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10736 /* global_atomic_min_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10736 /* global_atomic_min_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10736 /* global_atomic_min_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10736 /* global_atomic_min_u64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10736 /* global_atomic_min_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10736 /* global_atomic_min_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10736 /* global_atomic_min_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10758 /* global_atomic_or */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10758 /* global_atomic_or */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10758 /* global_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10758 /* global_atomic_or */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10758 /* global_atomic_or */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10758 /* global_atomic_or */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10758 /* global_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10758 /* global_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10758 /* global_atomic_or */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10758 /* global_atomic_or */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10758 /* global_atomic_or */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10758 /* global_atomic_or */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10758 /* global_atomic_or */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10758 /* global_atomic_or */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10758 /* global_atomic_or */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10758 /* global_atomic_or */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10758 /* global_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10758 /* global_atomic_or */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10758 /* global_atomic_or */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10758 /* global_atomic_or */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10758 /* global_atomic_or */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10775 /* global_atomic_or_b32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10775 /* global_atomic_or_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10775 /* global_atomic_or_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10775 /* global_atomic_or_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10775 /* global_atomic_or_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10775 /* global_atomic_or_b32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10775 /* global_atomic_or_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10775 /* global_atomic_or_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10775 /* global_atomic_or_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10775 /* global_atomic_or_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10775 /* global_atomic_or_b32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10775 /* global_atomic_or_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10775 /* global_atomic_or_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10775 /* global_atomic_or_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10775 /* global_atomic_or_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10775 /* global_atomic_or_b32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10775 /* global_atomic_or_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10775 /* global_atomic_or_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10775 /* global_atomic_or_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10775 /* global_atomic_or_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10775 /* global_atomic_or_b32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10775 /* global_atomic_or_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10775 /* global_atomic_or_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10775 /* global_atomic_or_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10775 /* global_atomic_or_b32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10775 /* global_atomic_or_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10775 /* global_atomic_or_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10775 /* global_atomic_or_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10775 /* global_atomic_or_b32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10775 /* global_atomic_or_b32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10775 /* global_atomic_or_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10775 /* global_atomic_or_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10775 /* global_atomic_or_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10775 /* global_atomic_or_b32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10775 /* global_atomic_or_b32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10775 /* global_atomic_or_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10775 /* global_atomic_or_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10775 /* global_atomic_or_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10796 /* global_atomic_or_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10796 /* global_atomic_or_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10796 /* global_atomic_or_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10796 /* global_atomic_or_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10796 /* global_atomic_or_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10796 /* global_atomic_or_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10796 /* global_atomic_or_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10796 /* global_atomic_or_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10796 /* global_atomic_or_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10796 /* global_atomic_or_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10796 /* global_atomic_or_b64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10796 /* global_atomic_or_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10796 /* global_atomic_or_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10796 /* global_atomic_or_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10796 /* global_atomic_or_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10796 /* global_atomic_or_b64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10796 /* global_atomic_or_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10796 /* global_atomic_or_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10796 /* global_atomic_or_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10796 /* global_atomic_or_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10796 /* global_atomic_or_b64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10796 /* global_atomic_or_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10796 /* global_atomic_or_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10796 /* global_atomic_or_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10796 /* global_atomic_or_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10796 /* global_atomic_or_b64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10796 /* global_atomic_or_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10796 /* global_atomic_or_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10796 /* global_atomic_or_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10796 /* global_atomic_or_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10796 /* global_atomic_or_b64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10796 /* global_atomic_or_b64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10796 /* global_atomic_or_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10796 /* global_atomic_or_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 10796 /* global_atomic_or_b64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10796 /* global_atomic_or_b64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10796 /* global_atomic_or_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10796 /* global_atomic_or_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 10817 /* global_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10817 /* global_atomic_or_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10817 /* global_atomic_or_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10817 /* global_atomic_or_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10817 /* global_atomic_or_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10817 /* global_atomic_or_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10817 /* global_atomic_or_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10817 /* global_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10817 /* global_atomic_or_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10817 /* global_atomic_or_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10817 /* global_atomic_or_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10817 /* global_atomic_or_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10817 /* global_atomic_or_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10817 /* global_atomic_or_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10817 /* global_atomic_or_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10817 /* global_atomic_or_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10817 /* global_atomic_or_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10817 /* global_atomic_or_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10817 /* global_atomic_or_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10817 /* global_atomic_or_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10817 /* global_atomic_or_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10837 /* global_atomic_ordered_add_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX12PlusNot12_50_isGFX12Only },
  { 10837 /* global_atomic_ordered_add_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12PlusNot12_50_isGFX12Only },
  { 10837 /* global_atomic_ordered_add_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12PlusNot12_50_isGFX12Only },
  { 10837 /* global_atomic_ordered_add_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX12PlusNot12_50_isGFX12Only },
  { 10837 /* global_atomic_ordered_add_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX12PlusNot12_50_isGFX12Only },
  { 10837 /* global_atomic_ordered_add_b64 */, 4 /* 2 */, MCK_off, AMFBS_isGFX12PlusNot12_50_isGFX12Only },
  { 10837 /* global_atomic_ordered_add_b64 */, 3 /* 0, 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12PlusNot12_50_isGFX12Only },
  { 10837 /* global_atomic_ordered_add_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX12PlusNot12_50_isGFX12Only },
  { 10837 /* global_atomic_ordered_add_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX12PlusNot12_50_isGFX12Only },
  { 10837 /* global_atomic_ordered_add_b64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX12PlusNot12_50_isGFX12Only },
  { 10837 /* global_atomic_ordered_add_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12PlusNot12_50_isGFX12Only },
  { 10837 /* global_atomic_ordered_add_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12PlusNot12_50_isGFX12Only },
  { 10837 /* global_atomic_ordered_add_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX12PlusNot12_50_isGFX12Only },
  { 10837 /* global_atomic_ordered_add_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12PlusNot12_50_isGFX12Only },
  { 10837 /* global_atomic_ordered_add_b64 */, 8 /* 3 */, MCK_off, AMFBS_isGFX12PlusNot12_50_isGFX12Only },
  { 10837 /* global_atomic_ordered_add_b64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12PlusNot12_50_isGFX12Only },
  { 10837 /* global_atomic_ordered_add_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX12PlusNot12_50_isGFX12Only },
  { 10837 /* global_atomic_ordered_add_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX12PlusNot12_50_isGFX12Only },
  { 10867 /* global_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only },
  { 10867 /* global_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only },
  { 10867 /* global_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only },
  { 10867 /* global_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only },
  { 10867 /* global_atomic_pk_add_bf16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only },
  { 10867 /* global_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_off, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only },
  { 10867 /* global_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only },
  { 10867 /* global_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only },
  { 10867 /* global_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only },
  { 10867 /* global_atomic_pk_add_bf16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only },
  { 10867 /* global_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_off, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_off, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only },
  { 10867 /* global_atomic_pk_add_bf16 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only },
  { 10867 /* global_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only },
  { 10867 /* global_atomic_pk_add_bf16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only },
  { 10867 /* global_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_off, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only },
  { 10867 /* global_atomic_pk_add_bf16 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only },
  { 10867 /* global_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only },
  { 10867 /* global_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only },
  { 10867 /* global_atomic_pk_add_bf16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX12Only },
  { 10867 /* global_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_off, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10867 /* global_atomic_pk_add_bf16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicGlobalPkAddBF16Inst_isGFX940Plus },
  { 10893 /* global_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 10893 /* global_atomic_pk_add_f16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 10893 /* global_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 10893 /* global_atomic_pk_add_f16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 10893 /* global_atomic_pk_add_f16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 10893 /* global_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 10893 /* global_atomic_pk_add_f16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 10893 /* global_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 10893 /* global_atomic_pk_add_f16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 10893 /* global_atomic_pk_add_f16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 10893 /* global_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 4 /* 2 */, MCK_off, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 10893 /* global_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 10893 /* global_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 10893 /* global_atomic_pk_add_f16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 10893 /* global_atomic_pk_add_f16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX12Only },
  { 10893 /* global_atomic_pk_add_f16 */, 4 /* 2 */, MCK_off, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 10893 /* global_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 10893 /* global_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 10893 /* global_atomic_pk_add_f16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 10893 /* global_atomic_pk_add_f16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX940Plus },
  { 10893 /* global_atomic_pk_add_f16 */, 4 /* 2 */, MCK_off, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasAtomicBufferGlobalPkAddF16NoRtnInsts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 8 /* 3 */, MCK_off, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 10893 /* global_atomic_pk_add_f16 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 10893 /* global_atomic_pk_add_f16 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 10893 /* global_atomic_pk_add_f16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 10893 /* global_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 10893 /* global_atomic_pk_add_f16 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 10893 /* global_atomic_pk_add_f16 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 10893 /* global_atomic_pk_add_f16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 10893 /* global_atomic_pk_add_f16 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 8 /* 3 */, MCK_off, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 10893 /* global_atomic_pk_add_f16 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 10893 /* global_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 10893 /* global_atomic_pk_add_f16 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 10893 /* global_atomic_pk_add_f16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX12Only },
  { 10893 /* global_atomic_pk_add_f16 */, 8 /* 3 */, MCK_off, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 10893 /* global_atomic_pk_add_f16 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 10893 /* global_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 10893 /* global_atomic_pk_add_f16 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 10893 /* global_atomic_pk_add_f16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX940Plus },
  { 10893 /* global_atomic_pk_add_f16 */, 8 /* 3 */, MCK_off, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940 },
  { 10893 /* global_atomic_pk_add_f16 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasAtomicBufferGlobalPkAddF16Insts_isGFX8GFX9NotGFX940 },
  { 10918 /* global_atomic_smax */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10918 /* global_atomic_smax */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10918 /* global_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10918 /* global_atomic_smax */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10918 /* global_atomic_smax */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10918 /* global_atomic_smax */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10918 /* global_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10918 /* global_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10918 /* global_atomic_smax */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10918 /* global_atomic_smax */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10918 /* global_atomic_smax */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10918 /* global_atomic_smax */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10918 /* global_atomic_smax */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10918 /* global_atomic_smax */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10918 /* global_atomic_smax */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10918 /* global_atomic_smax */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10918 /* global_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10918 /* global_atomic_smax */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10918 /* global_atomic_smax */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10918 /* global_atomic_smax */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10918 /* global_atomic_smax */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10937 /* global_atomic_smax_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10937 /* global_atomic_smax_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10937 /* global_atomic_smax_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10937 /* global_atomic_smax_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10937 /* global_atomic_smax_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10937 /* global_atomic_smax_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10937 /* global_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10937 /* global_atomic_smax_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10937 /* global_atomic_smax_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10937 /* global_atomic_smax_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10937 /* global_atomic_smax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10937 /* global_atomic_smax_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10937 /* global_atomic_smax_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10937 /* global_atomic_smax_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10937 /* global_atomic_smax_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10937 /* global_atomic_smax_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10937 /* global_atomic_smax_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10937 /* global_atomic_smax_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10937 /* global_atomic_smax_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10937 /* global_atomic_smax_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10959 /* global_atomic_smin */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10959 /* global_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10959 /* global_atomic_smin */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10959 /* global_atomic_smin */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10959 /* global_atomic_smin */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10959 /* global_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10959 /* global_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10959 /* global_atomic_smin */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10959 /* global_atomic_smin */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10959 /* global_atomic_smin */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10959 /* global_atomic_smin */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10959 /* global_atomic_smin */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10959 /* global_atomic_smin */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10959 /* global_atomic_smin */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10959 /* global_atomic_smin */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10959 /* global_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10959 /* global_atomic_smin */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10959 /* global_atomic_smin */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10959 /* global_atomic_smin */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10959 /* global_atomic_smin */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10978 /* global_atomic_smin_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10978 /* global_atomic_smin_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10978 /* global_atomic_smin_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10978 /* global_atomic_smin_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10978 /* global_atomic_smin_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10978 /* global_atomic_smin_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10978 /* global_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10978 /* global_atomic_smin_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10978 /* global_atomic_smin_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10978 /* global_atomic_smin_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10978 /* global_atomic_smin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10978 /* global_atomic_smin_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10978 /* global_atomic_smin_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10978 /* global_atomic_smin_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10978 /* global_atomic_smin_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10978 /* global_atomic_smin_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10978 /* global_atomic_smin_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10978 /* global_atomic_smin_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 10978 /* global_atomic_smin_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 10978 /* global_atomic_smin_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11000 /* global_atomic_sub */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11000 /* global_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11000 /* global_atomic_sub */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11000 /* global_atomic_sub */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11000 /* global_atomic_sub */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11000 /* global_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11000 /* global_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11000 /* global_atomic_sub */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11000 /* global_atomic_sub */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11000 /* global_atomic_sub */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11000 /* global_atomic_sub */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11000 /* global_atomic_sub */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11000 /* global_atomic_sub */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11000 /* global_atomic_sub */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11000 /* global_atomic_sub */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11000 /* global_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11000 /* global_atomic_sub */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11000 /* global_atomic_sub */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11000 /* global_atomic_sub */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11000 /* global_atomic_sub */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11018 /* global_atomic_sub_clamp_u32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 11018 /* global_atomic_sub_clamp_u32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 11018 /* global_atomic_sub_clamp_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 11018 /* global_atomic_sub_clamp_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 11018 /* global_atomic_sub_clamp_u32 */, 4 /* 2 */, MCK_off, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 11018 /* global_atomic_sub_clamp_u32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 11018 /* global_atomic_sub_clamp_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 11018 /* global_atomic_sub_clamp_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 11018 /* global_atomic_sub_clamp_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 11018 /* global_atomic_sub_clamp_u32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 11018 /* global_atomic_sub_clamp_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 11018 /* global_atomic_sub_clamp_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 11018 /* global_atomic_sub_clamp_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 11018 /* global_atomic_sub_clamp_u32 */, 8 /* 3 */, MCK_off, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 11018 /* global_atomic_sub_clamp_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 11018 /* global_atomic_sub_clamp_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 11018 /* global_atomic_sub_clamp_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 11018 /* global_atomic_sub_clamp_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_isGFX12Only },
  { 11046 /* global_atomic_sub_u32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11046 /* global_atomic_sub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11046 /* global_atomic_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11046 /* global_atomic_sub_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11046 /* global_atomic_sub_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11046 /* global_atomic_sub_u32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11046 /* global_atomic_sub_u32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11046 /* global_atomic_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11046 /* global_atomic_sub_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11046 /* global_atomic_sub_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11046 /* global_atomic_sub_u32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11046 /* global_atomic_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11046 /* global_atomic_sub_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11046 /* global_atomic_sub_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11046 /* global_atomic_sub_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11046 /* global_atomic_sub_u32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11046 /* global_atomic_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11046 /* global_atomic_sub_u32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11046 /* global_atomic_sub_u32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11046 /* global_atomic_sub_u32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11046 /* global_atomic_sub_u32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11046 /* global_atomic_sub_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11046 /* global_atomic_sub_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11046 /* global_atomic_sub_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11046 /* global_atomic_sub_u32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11046 /* global_atomic_sub_u32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11046 /* global_atomic_sub_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11046 /* global_atomic_sub_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11046 /* global_atomic_sub_u32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11046 /* global_atomic_sub_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11046 /* global_atomic_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11046 /* global_atomic_sub_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11046 /* global_atomic_sub_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11046 /* global_atomic_sub_u32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11046 /* global_atomic_sub_u32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11046 /* global_atomic_sub_u32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11046 /* global_atomic_sub_u32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11046 /* global_atomic_sub_u32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11068 /* global_atomic_sub_u64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11068 /* global_atomic_sub_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11068 /* global_atomic_sub_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11068 /* global_atomic_sub_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11068 /* global_atomic_sub_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11068 /* global_atomic_sub_u64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11068 /* global_atomic_sub_u64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11068 /* global_atomic_sub_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11068 /* global_atomic_sub_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11068 /* global_atomic_sub_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11068 /* global_atomic_sub_u64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11068 /* global_atomic_sub_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11068 /* global_atomic_sub_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11068 /* global_atomic_sub_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11068 /* global_atomic_sub_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11068 /* global_atomic_sub_u64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11068 /* global_atomic_sub_u64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11068 /* global_atomic_sub_u64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11068 /* global_atomic_sub_u64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11068 /* global_atomic_sub_u64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11068 /* global_atomic_sub_u64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11068 /* global_atomic_sub_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11068 /* global_atomic_sub_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11068 /* global_atomic_sub_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11068 /* global_atomic_sub_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11068 /* global_atomic_sub_u64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11068 /* global_atomic_sub_u64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11068 /* global_atomic_sub_u64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11068 /* global_atomic_sub_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11068 /* global_atomic_sub_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11068 /* global_atomic_sub_u64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11068 /* global_atomic_sub_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11068 /* global_atomic_sub_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11068 /* global_atomic_sub_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11068 /* global_atomic_sub_u64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11068 /* global_atomic_sub_u64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11068 /* global_atomic_sub_u64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11068 /* global_atomic_sub_u64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11090 /* global_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11090 /* global_atomic_sub_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11090 /* global_atomic_sub_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11090 /* global_atomic_sub_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11090 /* global_atomic_sub_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11090 /* global_atomic_sub_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11090 /* global_atomic_sub_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11090 /* global_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11090 /* global_atomic_sub_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11090 /* global_atomic_sub_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11090 /* global_atomic_sub_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11090 /* global_atomic_sub_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11090 /* global_atomic_sub_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11090 /* global_atomic_sub_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11090 /* global_atomic_sub_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11090 /* global_atomic_sub_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11090 /* global_atomic_sub_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11090 /* global_atomic_sub_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11090 /* global_atomic_sub_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11090 /* global_atomic_sub_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11090 /* global_atomic_sub_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11111 /* global_atomic_swap */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11111 /* global_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11111 /* global_atomic_swap */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11111 /* global_atomic_swap */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11111 /* global_atomic_swap */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11111 /* global_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11111 /* global_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11111 /* global_atomic_swap */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11111 /* global_atomic_swap */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11111 /* global_atomic_swap */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11111 /* global_atomic_swap */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11111 /* global_atomic_swap */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11111 /* global_atomic_swap */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11111 /* global_atomic_swap */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11111 /* global_atomic_swap */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11111 /* global_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11111 /* global_atomic_swap */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11111 /* global_atomic_swap */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11111 /* global_atomic_swap */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11111 /* global_atomic_swap */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11130 /* global_atomic_swap_b32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11130 /* global_atomic_swap_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11130 /* global_atomic_swap_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11130 /* global_atomic_swap_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11130 /* global_atomic_swap_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11130 /* global_atomic_swap_b32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11130 /* global_atomic_swap_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11130 /* global_atomic_swap_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11130 /* global_atomic_swap_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11130 /* global_atomic_swap_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11130 /* global_atomic_swap_b32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11130 /* global_atomic_swap_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11130 /* global_atomic_swap_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11130 /* global_atomic_swap_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11130 /* global_atomic_swap_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11130 /* global_atomic_swap_b32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11130 /* global_atomic_swap_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11130 /* global_atomic_swap_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11130 /* global_atomic_swap_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11130 /* global_atomic_swap_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11130 /* global_atomic_swap_b32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11130 /* global_atomic_swap_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11130 /* global_atomic_swap_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11130 /* global_atomic_swap_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11130 /* global_atomic_swap_b32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11130 /* global_atomic_swap_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11130 /* global_atomic_swap_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11130 /* global_atomic_swap_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11130 /* global_atomic_swap_b32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11130 /* global_atomic_swap_b32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11130 /* global_atomic_swap_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11130 /* global_atomic_swap_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11130 /* global_atomic_swap_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11130 /* global_atomic_swap_b32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11130 /* global_atomic_swap_b32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11130 /* global_atomic_swap_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11130 /* global_atomic_swap_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11130 /* global_atomic_swap_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11153 /* global_atomic_swap_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11153 /* global_atomic_swap_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11153 /* global_atomic_swap_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11153 /* global_atomic_swap_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11153 /* global_atomic_swap_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11153 /* global_atomic_swap_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11153 /* global_atomic_swap_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11153 /* global_atomic_swap_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11153 /* global_atomic_swap_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11153 /* global_atomic_swap_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11153 /* global_atomic_swap_b64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11153 /* global_atomic_swap_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11153 /* global_atomic_swap_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11153 /* global_atomic_swap_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11153 /* global_atomic_swap_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11153 /* global_atomic_swap_b64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11153 /* global_atomic_swap_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11153 /* global_atomic_swap_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11153 /* global_atomic_swap_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11153 /* global_atomic_swap_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11153 /* global_atomic_swap_b64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11153 /* global_atomic_swap_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11153 /* global_atomic_swap_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11153 /* global_atomic_swap_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11153 /* global_atomic_swap_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11153 /* global_atomic_swap_b64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11153 /* global_atomic_swap_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11153 /* global_atomic_swap_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11153 /* global_atomic_swap_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11153 /* global_atomic_swap_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11153 /* global_atomic_swap_b64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11153 /* global_atomic_swap_b64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11153 /* global_atomic_swap_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11153 /* global_atomic_swap_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11153 /* global_atomic_swap_b64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11153 /* global_atomic_swap_b64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11153 /* global_atomic_swap_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11153 /* global_atomic_swap_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11176 /* global_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11176 /* global_atomic_swap_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11176 /* global_atomic_swap_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11176 /* global_atomic_swap_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11176 /* global_atomic_swap_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11176 /* global_atomic_swap_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11176 /* global_atomic_swap_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11176 /* global_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11176 /* global_atomic_swap_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11176 /* global_atomic_swap_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11176 /* global_atomic_swap_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11176 /* global_atomic_swap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11176 /* global_atomic_swap_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11176 /* global_atomic_swap_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11176 /* global_atomic_swap_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11176 /* global_atomic_swap_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11176 /* global_atomic_swap_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11176 /* global_atomic_swap_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11176 /* global_atomic_swap_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11176 /* global_atomic_swap_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11176 /* global_atomic_swap_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11198 /* global_atomic_umax */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11198 /* global_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11198 /* global_atomic_umax */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11198 /* global_atomic_umax */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11198 /* global_atomic_umax */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11198 /* global_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11198 /* global_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11198 /* global_atomic_umax */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11198 /* global_atomic_umax */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11198 /* global_atomic_umax */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11198 /* global_atomic_umax */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11198 /* global_atomic_umax */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11198 /* global_atomic_umax */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11198 /* global_atomic_umax */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11198 /* global_atomic_umax */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11198 /* global_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11198 /* global_atomic_umax */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11198 /* global_atomic_umax */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11198 /* global_atomic_umax */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11198 /* global_atomic_umax */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11217 /* global_atomic_umax_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11217 /* global_atomic_umax_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11217 /* global_atomic_umax_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11217 /* global_atomic_umax_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11217 /* global_atomic_umax_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11217 /* global_atomic_umax_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11217 /* global_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11217 /* global_atomic_umax_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11217 /* global_atomic_umax_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11217 /* global_atomic_umax_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11217 /* global_atomic_umax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11217 /* global_atomic_umax_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11217 /* global_atomic_umax_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11217 /* global_atomic_umax_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11217 /* global_atomic_umax_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11217 /* global_atomic_umax_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11217 /* global_atomic_umax_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11217 /* global_atomic_umax_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11217 /* global_atomic_umax_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11217 /* global_atomic_umax_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11239 /* global_atomic_umin */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11239 /* global_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11239 /* global_atomic_umin */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11239 /* global_atomic_umin */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11239 /* global_atomic_umin */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11239 /* global_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11239 /* global_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11239 /* global_atomic_umin */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11239 /* global_atomic_umin */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11239 /* global_atomic_umin */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11239 /* global_atomic_umin */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11239 /* global_atomic_umin */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11239 /* global_atomic_umin */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11239 /* global_atomic_umin */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11239 /* global_atomic_umin */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11239 /* global_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11239 /* global_atomic_umin */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11239 /* global_atomic_umin */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11239 /* global_atomic_umin */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11239 /* global_atomic_umin */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11258 /* global_atomic_umin_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11258 /* global_atomic_umin_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11258 /* global_atomic_umin_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11258 /* global_atomic_umin_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11258 /* global_atomic_umin_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11258 /* global_atomic_umin_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11258 /* global_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11258 /* global_atomic_umin_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11258 /* global_atomic_umin_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11258 /* global_atomic_umin_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11258 /* global_atomic_umin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11258 /* global_atomic_umin_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11258 /* global_atomic_umin_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11258 /* global_atomic_umin_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11258 /* global_atomic_umin_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11258 /* global_atomic_umin_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11258 /* global_atomic_umin_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11258 /* global_atomic_umin_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11258 /* global_atomic_umin_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11258 /* global_atomic_umin_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11280 /* global_atomic_xor */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11280 /* global_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11280 /* global_atomic_xor */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11280 /* global_atomic_xor */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11280 /* global_atomic_xor */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11280 /* global_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11280 /* global_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11280 /* global_atomic_xor */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11280 /* global_atomic_xor */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11280 /* global_atomic_xor */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 5 /* 0, 2 */, MCK_AGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11280 /* global_atomic_xor */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11280 /* global_atomic_xor */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11280 /* global_atomic_xor */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11280 /* global_atomic_xor */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11280 /* global_atomic_xor */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11280 /* global_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11280 /* global_atomic_xor */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11280 /* global_atomic_xor */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11280 /* global_atomic_xor */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11280 /* global_atomic_xor */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11298 /* global_atomic_xor_b32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11298 /* global_atomic_xor_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11298 /* global_atomic_xor_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11298 /* global_atomic_xor_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11298 /* global_atomic_xor_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11298 /* global_atomic_xor_b32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11298 /* global_atomic_xor_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11298 /* global_atomic_xor_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11298 /* global_atomic_xor_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11298 /* global_atomic_xor_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11298 /* global_atomic_xor_b32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11298 /* global_atomic_xor_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11298 /* global_atomic_xor_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11298 /* global_atomic_xor_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11298 /* global_atomic_xor_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11298 /* global_atomic_xor_b32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11298 /* global_atomic_xor_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11298 /* global_atomic_xor_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11298 /* global_atomic_xor_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11298 /* global_atomic_xor_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11298 /* global_atomic_xor_b32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11298 /* global_atomic_xor_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11298 /* global_atomic_xor_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11298 /* global_atomic_xor_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11298 /* global_atomic_xor_b32 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11298 /* global_atomic_xor_b32 */, 7 /* 0, 1, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11298 /* global_atomic_xor_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11298 /* global_atomic_xor_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11298 /* global_atomic_xor_b32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11298 /* global_atomic_xor_b32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11298 /* global_atomic_xor_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11298 /* global_atomic_xor_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11298 /* global_atomic_xor_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11298 /* global_atomic_xor_b32 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11298 /* global_atomic_xor_b32 */, 5 /* 0, 2 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11298 /* global_atomic_xor_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11298 /* global_atomic_xor_b32 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11298 /* global_atomic_xor_b32 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11320 /* global_atomic_xor_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11320 /* global_atomic_xor_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11320 /* global_atomic_xor_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11320 /* global_atomic_xor_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11320 /* global_atomic_xor_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11320 /* global_atomic_xor_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11320 /* global_atomic_xor_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11320 /* global_atomic_xor_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11320 /* global_atomic_xor_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11320 /* global_atomic_xor_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11320 /* global_atomic_xor_b64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11320 /* global_atomic_xor_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11320 /* global_atomic_xor_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11320 /* global_atomic_xor_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11320 /* global_atomic_xor_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11320 /* global_atomic_xor_b64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11320 /* global_atomic_xor_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11320 /* global_atomic_xor_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11320 /* global_atomic_xor_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11320 /* global_atomic_xor_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11320 /* global_atomic_xor_b64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11320 /* global_atomic_xor_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11320 /* global_atomic_xor_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11320 /* global_atomic_xor_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11320 /* global_atomic_xor_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11320 /* global_atomic_xor_b64 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11320 /* global_atomic_xor_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11320 /* global_atomic_xor_b64 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11320 /* global_atomic_xor_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11320 /* global_atomic_xor_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11320 /* global_atomic_xor_b64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11320 /* global_atomic_xor_b64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11320 /* global_atomic_xor_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11320 /* global_atomic_xor_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11320 /* global_atomic_xor_b64 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11320 /* global_atomic_xor_b64 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11320 /* global_atomic_xor_b64 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11320 /* global_atomic_xor_b64 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11342 /* global_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11342 /* global_atomic_xor_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11342 /* global_atomic_xor_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11342 /* global_atomic_xor_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11342 /* global_atomic_xor_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11342 /* global_atomic_xor_x2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11342 /* global_atomic_xor_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11342 /* global_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11342 /* global_atomic_xor_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11342 /* global_atomic_xor_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11342 /* global_atomic_xor_x2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 8 /* 3 */, MCK_off, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 5 /* 0, 2 */, MCK_AReg_64, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_isGFX90APlus_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11342 /* global_atomic_xor_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11342 /* global_atomic_xor_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11342 /* global_atomic_xor_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11342 /* global_atomic_xor_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11342 /* global_atomic_xor_x2 */, 8 /* 3 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 5 /* 0, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11342 /* global_atomic_xor_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11342 /* global_atomic_xor_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11342 /* global_atomic_xor_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11342 /* global_atomic_xor_x2 */, 8 /* 3 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 7 /* 0, 1, 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 16 /* 4 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11342 /* global_atomic_xor_x2 */, 48 /* 4, 5 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11363 /* global_inv */, 1 /* 0 */, MCK_CPol, AMFBS_isGFX12Plus_isGFX12Only },
  { 11374 /* global_load_addtid_b32 */, 2 /* 1 */, MCK_off, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX11Only },
  { 11374 /* global_load_addtid_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX11Only },
  { 11374 /* global_load_addtid_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX11Only },
  { 11374 /* global_load_addtid_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX11Only },
  { 11374 /* global_load_addtid_b32 */, 2 /* 1 */, MCK_off, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX12Only },
  { 11374 /* global_load_addtid_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX12Only },
  { 11374 /* global_load_addtid_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX12Only },
  { 11374 /* global_load_addtid_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX12Only },
  { 11374 /* global_load_addtid_b32 */, 2 /* 1 */, MCK_SReg_64, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX11Only },
  { 11374 /* global_load_addtid_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX11Only },
  { 11374 /* global_load_addtid_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX11Only },
  { 11374 /* global_load_addtid_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX11Only },
  { 11374 /* global_load_addtid_b32 */, 2 /* 1 */, MCK_SReg_64, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX12Only },
  { 11374 /* global_load_addtid_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX12Only },
  { 11374 /* global_load_addtid_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX12Only },
  { 11374 /* global_load_addtid_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX12Only },
  { 11397 /* global_load_async_to_lds_b128 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11397 /* global_load_async_to_lds_b128 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11397 /* global_load_async_to_lds_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11397 /* global_load_async_to_lds_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11397 /* global_load_async_to_lds_b128 */, 4 /* 2 */, MCK_off, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11397 /* global_load_async_to_lds_b128 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11397 /* global_load_async_to_lds_b128 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11397 /* global_load_async_to_lds_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11397 /* global_load_async_to_lds_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11427 /* global_load_async_to_lds_b32 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11427 /* global_load_async_to_lds_b32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11427 /* global_load_async_to_lds_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11427 /* global_load_async_to_lds_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11427 /* global_load_async_to_lds_b32 */, 4 /* 2 */, MCK_off, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11427 /* global_load_async_to_lds_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11427 /* global_load_async_to_lds_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11427 /* global_load_async_to_lds_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11427 /* global_load_async_to_lds_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11456 /* global_load_async_to_lds_b64 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11456 /* global_load_async_to_lds_b64 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11456 /* global_load_async_to_lds_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11456 /* global_load_async_to_lds_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11456 /* global_load_async_to_lds_b64 */, 4 /* 2 */, MCK_off, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11456 /* global_load_async_to_lds_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11456 /* global_load_async_to_lds_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11456 /* global_load_async_to_lds_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11456 /* global_load_async_to_lds_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11485 /* global_load_async_to_lds_b8 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11485 /* global_load_async_to_lds_b8 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11485 /* global_load_async_to_lds_b8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11485 /* global_load_async_to_lds_b8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11485 /* global_load_async_to_lds_b8 */, 4 /* 2 */, MCK_off, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11485 /* global_load_async_to_lds_b8 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11485 /* global_load_async_to_lds_b8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11485 /* global_load_async_to_lds_b8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11485 /* global_load_async_to_lds_b8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 11513 /* global_load_b128 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11513 /* global_load_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11513 /* global_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11513 /* global_load_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11513 /* global_load_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11513 /* global_load_b128 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11513 /* global_load_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11513 /* global_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11513 /* global_load_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11513 /* global_load_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11513 /* global_load_b128 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11513 /* global_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11513 /* global_load_b128 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11513 /* global_load_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11513 /* global_load_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11513 /* global_load_b128 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11513 /* global_load_b128 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11513 /* global_load_b128 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11513 /* global_load_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11513 /* global_load_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11530 /* global_load_b32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11530 /* global_load_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11530 /* global_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11530 /* global_load_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11530 /* global_load_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11530 /* global_load_b32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11530 /* global_load_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11530 /* global_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11530 /* global_load_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11530 /* global_load_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11530 /* global_load_b32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11530 /* global_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11530 /* global_load_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11530 /* global_load_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11530 /* global_load_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11530 /* global_load_b32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11530 /* global_load_b32 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11530 /* global_load_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11530 /* global_load_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11530 /* global_load_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11546 /* global_load_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11546 /* global_load_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11546 /* global_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11546 /* global_load_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11546 /* global_load_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11546 /* global_load_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11546 /* global_load_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11546 /* global_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11546 /* global_load_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11546 /* global_load_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11546 /* global_load_b64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11546 /* global_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11546 /* global_load_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11546 /* global_load_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11546 /* global_load_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11546 /* global_load_b64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11546 /* global_load_b64 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11546 /* global_load_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11546 /* global_load_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11546 /* global_load_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11562 /* global_load_b96 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11562 /* global_load_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11562 /* global_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11562 /* global_load_b96 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11562 /* global_load_b96 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11562 /* global_load_b96 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11562 /* global_load_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11562 /* global_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11562 /* global_load_b96 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11562 /* global_load_b96 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11562 /* global_load_b96 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11562 /* global_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11562 /* global_load_b96 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11562 /* global_load_b96 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11562 /* global_load_b96 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11562 /* global_load_b96 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11562 /* global_load_b96 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11562 /* global_load_b96 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11562 /* global_load_b96 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11562 /* global_load_b96 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11578 /* global_load_block */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX12Plus_isGFX12Only },
  { 11578 /* global_load_block */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 11578 /* global_load_block */, 1 /* 0 */, MCK_RegByHwMode_VReg_1024_AlignTarget, AMFBS_isGFX12Plus_isGFX12Only },
  { 11578 /* global_load_block */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX12Plus_isGFX12Only },
  { 11578 /* global_load_block */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX12Plus_isGFX12Only },
  { 11578 /* global_load_block */, 4 /* 2 */, MCK_off, AMFBS_isGFX12Plus_isGFX12Only },
  { 11578 /* global_load_block */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus_isGFX12Only },
  { 11578 /* global_load_block */, 1 /* 0 */, MCK_RegByHwMode_VReg_1024_AlignTarget, AMFBS_isGFX12Plus_isGFX12Only },
  { 11578 /* global_load_block */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX12Plus_isGFX12Only },
  { 11578 /* global_load_block */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX12Plus_isGFX12Only },
  { 11596 /* global_load_d16_b16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11596 /* global_load_d16_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11596 /* global_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11596 /* global_load_d16_b16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11596 /* global_load_d16_b16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11596 /* global_load_d16_b16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11596 /* global_load_d16_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11596 /* global_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11596 /* global_load_d16_b16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11596 /* global_load_d16_b16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11596 /* global_load_d16_b16 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11596 /* global_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11596 /* global_load_d16_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11596 /* global_load_d16_b16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11596 /* global_load_d16_b16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11596 /* global_load_d16_b16 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11596 /* global_load_d16_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11596 /* global_load_d16_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11596 /* global_load_d16_b16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11596 /* global_load_d16_b16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11616 /* global_load_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11616 /* global_load_d16_hi_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11616 /* global_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11616 /* global_load_d16_hi_b16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11616 /* global_load_d16_hi_b16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11616 /* global_load_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11616 /* global_load_d16_hi_b16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11616 /* global_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11616 /* global_load_d16_hi_b16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11616 /* global_load_d16_hi_b16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11616 /* global_load_d16_hi_b16 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11616 /* global_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11616 /* global_load_d16_hi_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11616 /* global_load_d16_hi_b16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11616 /* global_load_d16_hi_b16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11616 /* global_load_d16_hi_b16 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11616 /* global_load_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11616 /* global_load_d16_hi_b16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11616 /* global_load_d16_hi_b16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11616 /* global_load_d16_hi_b16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11639 /* global_load_d16_hi_i8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11639 /* global_load_d16_hi_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11639 /* global_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11639 /* global_load_d16_hi_i8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11639 /* global_load_d16_hi_i8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11639 /* global_load_d16_hi_i8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11639 /* global_load_d16_hi_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11639 /* global_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11639 /* global_load_d16_hi_i8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11639 /* global_load_d16_hi_i8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11639 /* global_load_d16_hi_i8 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11639 /* global_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11639 /* global_load_d16_hi_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11639 /* global_load_d16_hi_i8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11639 /* global_load_d16_hi_i8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11639 /* global_load_d16_hi_i8 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11639 /* global_load_d16_hi_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11639 /* global_load_d16_hi_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11639 /* global_load_d16_hi_i8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11639 /* global_load_d16_hi_i8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11661 /* global_load_d16_hi_u8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11661 /* global_load_d16_hi_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11661 /* global_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11661 /* global_load_d16_hi_u8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11661 /* global_load_d16_hi_u8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11661 /* global_load_d16_hi_u8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11661 /* global_load_d16_hi_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11661 /* global_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11661 /* global_load_d16_hi_u8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11661 /* global_load_d16_hi_u8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11661 /* global_load_d16_hi_u8 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11661 /* global_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11661 /* global_load_d16_hi_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11661 /* global_load_d16_hi_u8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11661 /* global_load_d16_hi_u8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11661 /* global_load_d16_hi_u8 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11661 /* global_load_d16_hi_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11661 /* global_load_d16_hi_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11661 /* global_load_d16_hi_u8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11661 /* global_load_d16_hi_u8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11683 /* global_load_d16_i8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11683 /* global_load_d16_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11683 /* global_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11683 /* global_load_d16_i8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11683 /* global_load_d16_i8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11683 /* global_load_d16_i8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11683 /* global_load_d16_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11683 /* global_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11683 /* global_load_d16_i8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11683 /* global_load_d16_i8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11683 /* global_load_d16_i8 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11683 /* global_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11683 /* global_load_d16_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11683 /* global_load_d16_i8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11683 /* global_load_d16_i8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11683 /* global_load_d16_i8 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11683 /* global_load_d16_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11683 /* global_load_d16_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11683 /* global_load_d16_i8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11683 /* global_load_d16_i8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11702 /* global_load_d16_u8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11702 /* global_load_d16_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11702 /* global_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11702 /* global_load_d16_u8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11702 /* global_load_d16_u8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11702 /* global_load_d16_u8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11702 /* global_load_d16_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11702 /* global_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11702 /* global_load_d16_u8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11702 /* global_load_d16_u8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11702 /* global_load_d16_u8 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11702 /* global_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11702 /* global_load_d16_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11702 /* global_load_d16_u8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11702 /* global_load_d16_u8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11702 /* global_load_d16_u8 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11702 /* global_load_d16_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11702 /* global_load_d16_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11702 /* global_load_d16_u8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11702 /* global_load_d16_u8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11721 /* global_load_dword */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11721 /* global_load_dword */, 2 /* 1 */, MCK_SReg_64, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11721 /* global_load_dword */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11721 /* global_load_dword */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11721 /* global_load_dword */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11721 /* global_load_dword */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11721 /* global_load_dword */, 2 /* 1 */, MCK_SReg_64, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11721 /* global_load_dword */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11721 /* global_load_dword */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11721 /* global_load_dword */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11721 /* global_load_dword */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11721 /* global_load_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11721 /* global_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11721 /* global_load_dword */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11721 /* global_load_dword */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11721 /* global_load_dword */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11721 /* global_load_dword */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11721 /* global_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11721 /* global_load_dword */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11721 /* global_load_dword */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11721 /* global_load_dword */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11721 /* global_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11721 /* global_load_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11721 /* global_load_dword */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11721 /* global_load_dword */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11721 /* global_load_dword */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11721 /* global_load_dword */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11721 /* global_load_dword */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11721 /* global_load_dword */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11721 /* global_load_dword */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11721 /* global_load_dword */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11721 /* global_load_dword */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11721 /* global_load_dword */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11721 /* global_load_dword */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11721 /* global_load_dword */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11721 /* global_load_dword */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11721 /* global_load_dword */, 2 /* 1 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11721 /* global_load_dword */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11721 /* global_load_dword */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11721 /* global_load_dword */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11739 /* global_load_dword_addtid */, 2 /* 1 */, MCK_off, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX10Only },
  { 11739 /* global_load_dword_addtid */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX10Only },
  { 11739 /* global_load_dword_addtid */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX10Only },
  { 11739 /* global_load_dword_addtid */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX10Only },
  { 11739 /* global_load_dword_addtid */, 2 /* 1 */, MCK_SReg_64, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX10Only },
  { 11739 /* global_load_dword_addtid */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX10Only },
  { 11739 /* global_load_dword_addtid */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX10Only },
  { 11739 /* global_load_dword_addtid */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX10Only },
  { 11764 /* global_load_dwordx2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11764 /* global_load_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11764 /* global_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11764 /* global_load_dwordx2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11764 /* global_load_dwordx2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11764 /* global_load_dwordx2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11764 /* global_load_dwordx2 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11764 /* global_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11764 /* global_load_dwordx2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11764 /* global_load_dwordx2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11764 /* global_load_dwordx2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11764 /* global_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11764 /* global_load_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11764 /* global_load_dwordx2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11764 /* global_load_dwordx2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11764 /* global_load_dwordx2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11764 /* global_load_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11764 /* global_load_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11764 /* global_load_dwordx2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11764 /* global_load_dwordx2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11784 /* global_load_dwordx3 */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9 },
  { 11784 /* global_load_dwordx3 */, 2 /* 1 */, MCK_SReg_64, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9 },
  { 11784 /* global_load_dwordx3 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9 },
  { 11784 /* global_load_dwordx3 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9 },
  { 11784 /* global_load_dwordx3 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9 },
  { 11784 /* global_load_dwordx3 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11784 /* global_load_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11784 /* global_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11784 /* global_load_dwordx3 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11784 /* global_load_dwordx3 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11784 /* global_load_dwordx3 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11784 /* global_load_dwordx3 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11784 /* global_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11784 /* global_load_dwordx3 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11784 /* global_load_dwordx3 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11784 /* global_load_dwordx3 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11784 /* global_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11784 /* global_load_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11784 /* global_load_dwordx3 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11784 /* global_load_dwordx3 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11784 /* global_load_dwordx3 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11784 /* global_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11784 /* global_load_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11784 /* global_load_dwordx3 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11784 /* global_load_dwordx3 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11784 /* global_load_dwordx3 */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9 },
  { 11784 /* global_load_dwordx3 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9 },
  { 11784 /* global_load_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9 },
  { 11784 /* global_load_dwordx3 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9 },
  { 11784 /* global_load_dwordx3 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9 },
  { 11804 /* global_load_dwordx4 */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9 },
  { 11804 /* global_load_dwordx4 */, 2 /* 1 */, MCK_SReg_64, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9 },
  { 11804 /* global_load_dwordx4 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9 },
  { 11804 /* global_load_dwordx4 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9 },
  { 11804 /* global_load_dwordx4 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9 },
  { 11804 /* global_load_dwordx4 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11804 /* global_load_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11804 /* global_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11804 /* global_load_dwordx4 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11804 /* global_load_dwordx4 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11804 /* global_load_dwordx4 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11804 /* global_load_dwordx4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11804 /* global_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11804 /* global_load_dwordx4 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11804 /* global_load_dwordx4 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11804 /* global_load_dwordx4 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11804 /* global_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11804 /* global_load_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11804 /* global_load_dwordx4 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11804 /* global_load_dwordx4 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 11804 /* global_load_dwordx4 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11804 /* global_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11804 /* global_load_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11804 /* global_load_dwordx4 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11804 /* global_load_dwordx4 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 11804 /* global_load_dwordx4 */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9 },
  { 11804 /* global_load_dwordx4 */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9 },
  { 11804 /* global_load_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9 },
  { 11804 /* global_load_dwordx4 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9 },
  { 11804 /* global_load_dwordx4 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX940_HasGFX950Insts_isGFX8GFX9 },
  { 11824 /* global_load_i16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11824 /* global_load_i16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11824 /* global_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11824 /* global_load_i16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11824 /* global_load_i16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11824 /* global_load_i16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11824 /* global_load_i16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11824 /* global_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11824 /* global_load_i16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11824 /* global_load_i16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11824 /* global_load_i16 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11824 /* global_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11824 /* global_load_i16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11824 /* global_load_i16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11824 /* global_load_i16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11824 /* global_load_i16 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11824 /* global_load_i16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11824 /* global_load_i16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11824 /* global_load_i16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11824 /* global_load_i16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11840 /* global_load_i8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11840 /* global_load_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11840 /* global_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11840 /* global_load_i8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11840 /* global_load_i8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11840 /* global_load_i8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11840 /* global_load_i8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11840 /* global_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11840 /* global_load_i8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11840 /* global_load_i8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11840 /* global_load_i8 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11840 /* global_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11840 /* global_load_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11840 /* global_load_i8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11840 /* global_load_i8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 11840 /* global_load_i8 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11840 /* global_load_i8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11840 /* global_load_i8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11840 /* global_load_i8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11840 /* global_load_i8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 11855 /* global_load_lds_dword */, 2 /* 1 */, MCK_SReg_64, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11855 /* global_load_lds_dword */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11855 /* global_load_lds_dword */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11855 /* global_load_lds_dword */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11855 /* global_load_lds_dword */, 2 /* 1 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11855 /* global_load_lds_dword */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11855 /* global_load_lds_dword */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11855 /* global_load_lds_dword */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11877 /* global_load_lds_dwordx3 */, 2 /* 1 */, MCK_SReg_64, AMFBS_HasGFX950Insts_isGFX940Plus },
  { 11877 /* global_load_lds_dwordx3 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX950Insts_isGFX940Plus },
  { 11877 /* global_load_lds_dwordx3 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasGFX950Insts_isGFX940Plus },
  { 11877 /* global_load_lds_dwordx3 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasGFX950Insts_isGFX940Plus },
  { 11877 /* global_load_lds_dwordx3 */, 2 /* 1 */, MCK_off, AMFBS_HasGFX950Insts_isGFX940Plus },
  { 11877 /* global_load_lds_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasGFX950Insts_isGFX940Plus },
  { 11877 /* global_load_lds_dwordx3 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasGFX950Insts_isGFX940Plus },
  { 11877 /* global_load_lds_dwordx3 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasGFX950Insts_isGFX940Plus },
  { 11901 /* global_load_lds_dwordx4 */, 2 /* 1 */, MCK_SReg_64, AMFBS_HasGFX950Insts_isGFX940Plus },
  { 11901 /* global_load_lds_dwordx4 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX950Insts_isGFX940Plus },
  { 11901 /* global_load_lds_dwordx4 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasGFX950Insts_isGFX940Plus },
  { 11901 /* global_load_lds_dwordx4 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasGFX950Insts_isGFX940Plus },
  { 11901 /* global_load_lds_dwordx4 */, 2 /* 1 */, MCK_off, AMFBS_HasGFX950Insts_isGFX940Plus },
  { 11901 /* global_load_lds_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasGFX950Insts_isGFX940Plus },
  { 11901 /* global_load_lds_dwordx4 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasGFX950Insts_isGFX940Plus },
  { 11901 /* global_load_lds_dwordx4 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasGFX950Insts_isGFX940Plus },
  { 11925 /* global_load_lds_sbyte */, 2 /* 1 */, MCK_SReg_64, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11925 /* global_load_lds_sbyte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11925 /* global_load_lds_sbyte */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11925 /* global_load_lds_sbyte */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11925 /* global_load_lds_sbyte */, 2 /* 1 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11925 /* global_load_lds_sbyte */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11925 /* global_load_lds_sbyte */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11925 /* global_load_lds_sbyte */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11947 /* global_load_lds_sshort */, 2 /* 1 */, MCK_SReg_64, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11947 /* global_load_lds_sshort */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11947 /* global_load_lds_sshort */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11947 /* global_load_lds_sshort */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11947 /* global_load_lds_sshort */, 2 /* 1 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11947 /* global_load_lds_sshort */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11947 /* global_load_lds_sshort */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11947 /* global_load_lds_sshort */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11970 /* global_load_lds_ubyte */, 2 /* 1 */, MCK_SReg_64, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11970 /* global_load_lds_ubyte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11970 /* global_load_lds_ubyte */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11970 /* global_load_lds_ubyte */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11970 /* global_load_lds_ubyte */, 2 /* 1 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11970 /* global_load_lds_ubyte */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11970 /* global_load_lds_ubyte */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11970 /* global_load_lds_ubyte */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11992 /* global_load_lds_ushort */, 2 /* 1 */, MCK_SReg_64, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11992 /* global_load_lds_ushort */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11992 /* global_load_lds_ushort */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11992 /* global_load_lds_ushort */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11992 /* global_load_lds_ushort */, 2 /* 1 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11992 /* global_load_lds_ushort */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11992 /* global_load_lds_ushort */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 11992 /* global_load_lds_ushort */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX940Plus },
  { 12015 /* global_load_monitor_b128 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX125xOnly },
  { 12015 /* global_load_monitor_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX125xOnly },
  { 12015 /* global_load_monitor_b128 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX125xOnly },
  { 12015 /* global_load_monitor_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX125xOnly },
  { 12015 /* global_load_monitor_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX125xOnly },
  { 12015 /* global_load_monitor_b128 */, 4 /* 2 */, MCK_off, AMFBS_isGFX125xOnly },
  { 12015 /* global_load_monitor_b128 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX125xOnly },
  { 12015 /* global_load_monitor_b128 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX125xOnly },
  { 12015 /* global_load_monitor_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX125xOnly },
  { 12015 /* global_load_monitor_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX125xOnly },
  { 12040 /* global_load_monitor_b32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX125xOnly },
  { 12040 /* global_load_monitor_b32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_isGFX125xOnly },
  { 12040 /* global_load_monitor_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX125xOnly },
  { 12040 /* global_load_monitor_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX125xOnly },
  { 12040 /* global_load_monitor_b32 */, 4 /* 2 */, MCK_off, AMFBS_isGFX125xOnly },
  { 12040 /* global_load_monitor_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX125xOnly },
  { 12040 /* global_load_monitor_b32 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX125xOnly },
  { 12040 /* global_load_monitor_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX125xOnly },
  { 12040 /* global_load_monitor_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX125xOnly },
  { 12064 /* global_load_monitor_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX125xOnly },
  { 12064 /* global_load_monitor_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX125xOnly },
  { 12064 /* global_load_monitor_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX125xOnly },
  { 12064 /* global_load_monitor_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX125xOnly },
  { 12064 /* global_load_monitor_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX125xOnly },
  { 12064 /* global_load_monitor_b64 */, 4 /* 2 */, MCK_off, AMFBS_isGFX125xOnly },
  { 12064 /* global_load_monitor_b64 */, 3 /* 0, 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX125xOnly },
  { 12064 /* global_load_monitor_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX125xOnly },
  { 12064 /* global_load_monitor_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX125xOnly },
  { 12088 /* global_load_sbyte */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12088 /* global_load_sbyte */, 2 /* 1 */, MCK_SReg_64, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12088 /* global_load_sbyte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12088 /* global_load_sbyte */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12088 /* global_load_sbyte */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12088 /* global_load_sbyte */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12088 /* global_load_sbyte */, 2 /* 1 */, MCK_SReg_64, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12088 /* global_load_sbyte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12088 /* global_load_sbyte */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12088 /* global_load_sbyte */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12088 /* global_load_sbyte */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12088 /* global_load_sbyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12088 /* global_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12088 /* global_load_sbyte */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12088 /* global_load_sbyte */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12088 /* global_load_sbyte */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12088 /* global_load_sbyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12088 /* global_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12088 /* global_load_sbyte */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12088 /* global_load_sbyte */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12088 /* global_load_sbyte */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12088 /* global_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12088 /* global_load_sbyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12088 /* global_load_sbyte */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12088 /* global_load_sbyte */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12088 /* global_load_sbyte */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12088 /* global_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12088 /* global_load_sbyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12088 /* global_load_sbyte */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12088 /* global_load_sbyte */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12088 /* global_load_sbyte */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12088 /* global_load_sbyte */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12088 /* global_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12088 /* global_load_sbyte */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12088 /* global_load_sbyte */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12088 /* global_load_sbyte */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12088 /* global_load_sbyte */, 2 /* 1 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12088 /* global_load_sbyte */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12088 /* global_load_sbyte */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12088 /* global_load_sbyte */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12106 /* global_load_sbyte_d16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12106 /* global_load_sbyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12106 /* global_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12106 /* global_load_sbyte_d16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12106 /* global_load_sbyte_d16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12106 /* global_load_sbyte_d16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12106 /* global_load_sbyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12106 /* global_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12106 /* global_load_sbyte_d16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12106 /* global_load_sbyte_d16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12106 /* global_load_sbyte_d16 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12106 /* global_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12106 /* global_load_sbyte_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12106 /* global_load_sbyte_d16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12106 /* global_load_sbyte_d16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12106 /* global_load_sbyte_d16 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12106 /* global_load_sbyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12106 /* global_load_sbyte_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12106 /* global_load_sbyte_d16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12106 /* global_load_sbyte_d16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12128 /* global_load_sbyte_d16_hi */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12128 /* global_load_sbyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12128 /* global_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12128 /* global_load_sbyte_d16_hi */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12128 /* global_load_sbyte_d16_hi */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12128 /* global_load_sbyte_d16_hi */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12128 /* global_load_sbyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12128 /* global_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12128 /* global_load_sbyte_d16_hi */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12128 /* global_load_sbyte_d16_hi */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12128 /* global_load_sbyte_d16_hi */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12128 /* global_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12128 /* global_load_sbyte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12128 /* global_load_sbyte_d16_hi */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12128 /* global_load_sbyte_d16_hi */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12128 /* global_load_sbyte_d16_hi */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12128 /* global_load_sbyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12128 /* global_load_sbyte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12128 /* global_load_sbyte_d16_hi */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12128 /* global_load_sbyte_d16_hi */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12153 /* global_load_short_d16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12153 /* global_load_short_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12153 /* global_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12153 /* global_load_short_d16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12153 /* global_load_short_d16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12153 /* global_load_short_d16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12153 /* global_load_short_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12153 /* global_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12153 /* global_load_short_d16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12153 /* global_load_short_d16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12153 /* global_load_short_d16 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12153 /* global_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12153 /* global_load_short_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12153 /* global_load_short_d16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12153 /* global_load_short_d16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12153 /* global_load_short_d16 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12153 /* global_load_short_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12153 /* global_load_short_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12153 /* global_load_short_d16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12153 /* global_load_short_d16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12175 /* global_load_short_d16_hi */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12175 /* global_load_short_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12175 /* global_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12175 /* global_load_short_d16_hi */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12175 /* global_load_short_d16_hi */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12175 /* global_load_short_d16_hi */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12175 /* global_load_short_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12175 /* global_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12175 /* global_load_short_d16_hi */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12175 /* global_load_short_d16_hi */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12175 /* global_load_short_d16_hi */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12175 /* global_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12175 /* global_load_short_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12175 /* global_load_short_d16_hi */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12175 /* global_load_short_d16_hi */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12175 /* global_load_short_d16_hi */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12175 /* global_load_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12175 /* global_load_short_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12175 /* global_load_short_d16_hi */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12175 /* global_load_short_d16_hi */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12200 /* global_load_sshort */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12200 /* global_load_sshort */, 2 /* 1 */, MCK_SReg_64, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12200 /* global_load_sshort */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12200 /* global_load_sshort */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12200 /* global_load_sshort */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12200 /* global_load_sshort */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12200 /* global_load_sshort */, 2 /* 1 */, MCK_SReg_64, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12200 /* global_load_sshort */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12200 /* global_load_sshort */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12200 /* global_load_sshort */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12200 /* global_load_sshort */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12200 /* global_load_sshort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12200 /* global_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12200 /* global_load_sshort */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12200 /* global_load_sshort */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12200 /* global_load_sshort */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12200 /* global_load_sshort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12200 /* global_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12200 /* global_load_sshort */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12200 /* global_load_sshort */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12200 /* global_load_sshort */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12200 /* global_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12200 /* global_load_sshort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12200 /* global_load_sshort */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12200 /* global_load_sshort */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12200 /* global_load_sshort */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12200 /* global_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12200 /* global_load_sshort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12200 /* global_load_sshort */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12200 /* global_load_sshort */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12200 /* global_load_sshort */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12200 /* global_load_sshort */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12200 /* global_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12200 /* global_load_sshort */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12200 /* global_load_sshort */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12200 /* global_load_sshort */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12200 /* global_load_sshort */, 2 /* 1 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12200 /* global_load_sshort */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12200 /* global_load_sshort */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12200 /* global_load_sshort */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12219 /* global_load_tr16_b128 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32 },
  { 12219 /* global_load_tr16_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32 },
  { 12219 /* global_load_tr16_b128 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32 },
  { 12219 /* global_load_tr16_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32 },
  { 12219 /* global_load_tr16_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32 },
  { 12219 /* global_load_tr16_b128 */, 4 /* 2 */, MCK_off, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32 },
  { 12219 /* global_load_tr16_b128 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32 },
  { 12219 /* global_load_tr16_b128 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32 },
  { 12219 /* global_load_tr16_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32 },
  { 12219 /* global_load_tr16_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32 },
  { 12241 /* global_load_tr4_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32 },
  { 12241 /* global_load_tr4_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32 },
  { 12241 /* global_load_tr4_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32 },
  { 12241 /* global_load_tr4_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32 },
  { 12241 /* global_load_tr4_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32 },
  { 12241 /* global_load_tr4_b64 */, 4 /* 2 */, MCK_off, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32 },
  { 12241 /* global_load_tr4_b64 */, 3 /* 0, 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32 },
  { 12241 /* global_load_tr4_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32 },
  { 12241 /* global_load_tr4_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32 },
  { 12261 /* global_load_tr6_b96 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32 },
  { 12261 /* global_load_tr6_b96 */, 1 /* 0 */, MCK_VReg_96, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32 },
  { 12261 /* global_load_tr6_b96 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32 },
  { 12261 /* global_load_tr6_b96 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32 },
  { 12261 /* global_load_tr6_b96 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32 },
  { 12261 /* global_load_tr6_b96 */, 4 /* 2 */, MCK_off, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32 },
  { 12261 /* global_load_tr6_b96 */, 1 /* 0 */, MCK_VReg_96, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32 },
  { 12261 /* global_load_tr6_b96 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32 },
  { 12261 /* global_load_tr6_b96 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32 },
  { 12261 /* global_load_tr6_b96 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasTransposeLoadF4F6Insts_isGFX125xOnly_isWave32 },
  { 12281 /* global_load_tr8_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32 },
  { 12281 /* global_load_tr8_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32 },
  { 12281 /* global_load_tr8_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32 },
  { 12281 /* global_load_tr8_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32 },
  { 12281 /* global_load_tr8_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32 },
  { 12281 /* global_load_tr8_b64 */, 4 /* 2 */, MCK_off, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32 },
  { 12281 /* global_load_tr8_b64 */, 3 /* 0, 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32 },
  { 12281 /* global_load_tr8_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32 },
  { 12281 /* global_load_tr8_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX12Plus_isGFX125xOnly_isWave32 },
  { 12301 /* global_load_tr_b128 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64 },
  { 12301 /* global_load_tr_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64 },
  { 12301 /* global_load_tr_b128 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64 },
  { 12301 /* global_load_tr_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64 },
  { 12301 /* global_load_tr_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64 },
  { 12301 /* global_load_tr_b128 */, 4 /* 2 */, MCK_off, AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64 },
  { 12301 /* global_load_tr_b128 */, 3 /* 0, 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64 },
  { 12301 /* global_load_tr_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64 },
  { 12301 /* global_load_tr_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64 },
  { 12301 /* global_load_tr_b128 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32 },
  { 12301 /* global_load_tr_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32 },
  { 12301 /* global_load_tr_b128 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32 },
  { 12301 /* global_load_tr_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32 },
  { 12301 /* global_load_tr_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32 },
  { 12301 /* global_load_tr_b128 */, 4 /* 2 */, MCK_off, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32 },
  { 12301 /* global_load_tr_b128 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32 },
  { 12301 /* global_load_tr_b128 */, 1 /* 0 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32 },
  { 12301 /* global_load_tr_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32 },
  { 12301 /* global_load_tr_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32 },
  { 12321 /* global_load_tr_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64 },
  { 12321 /* global_load_tr_b64 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64 },
  { 12321 /* global_load_tr_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64 },
  { 12321 /* global_load_tr_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64 },
  { 12321 /* global_load_tr_b64 */, 4 /* 2 */, MCK_off, AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64 },
  { 12321 /* global_load_tr_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64 },
  { 12321 /* global_load_tr_b64 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64 },
  { 12321 /* global_load_tr_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64 },
  { 12321 /* global_load_tr_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX12PlusNot12_50_isGFX12Only_isWave64 },
  { 12321 /* global_load_tr_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32 },
  { 12321 /* global_load_tr_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32 },
  { 12321 /* global_load_tr_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32 },
  { 12321 /* global_load_tr_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32 },
  { 12321 /* global_load_tr_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32 },
  { 12321 /* global_load_tr_b64 */, 4 /* 2 */, MCK_off, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32 },
  { 12321 /* global_load_tr_b64 */, 3 /* 0, 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32 },
  { 12321 /* global_load_tr_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32 },
  { 12321 /* global_load_tr_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX12Plus_isGFX12Not12_50_isWave32 },
  { 12340 /* global_load_u16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12340 /* global_load_u16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12340 /* global_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12340 /* global_load_u16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12340 /* global_load_u16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12340 /* global_load_u16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12340 /* global_load_u16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12340 /* global_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12340 /* global_load_u16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12340 /* global_load_u16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12340 /* global_load_u16 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12340 /* global_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12340 /* global_load_u16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12340 /* global_load_u16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12340 /* global_load_u16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12340 /* global_load_u16 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12340 /* global_load_u16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12340 /* global_load_u16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12340 /* global_load_u16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12340 /* global_load_u16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12356 /* global_load_u8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12356 /* global_load_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12356 /* global_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12356 /* global_load_u8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12356 /* global_load_u8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12356 /* global_load_u8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12356 /* global_load_u8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12356 /* global_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12356 /* global_load_u8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12356 /* global_load_u8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12356 /* global_load_u8 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12356 /* global_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12356 /* global_load_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12356 /* global_load_u8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12356 /* global_load_u8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12356 /* global_load_u8 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12356 /* global_load_u8 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12356 /* global_load_u8 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12356 /* global_load_u8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12356 /* global_load_u8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12371 /* global_load_ubyte */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12371 /* global_load_ubyte */, 2 /* 1 */, MCK_SReg_64, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12371 /* global_load_ubyte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12371 /* global_load_ubyte */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12371 /* global_load_ubyte */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12371 /* global_load_ubyte */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12371 /* global_load_ubyte */, 2 /* 1 */, MCK_SReg_64, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12371 /* global_load_ubyte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12371 /* global_load_ubyte */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12371 /* global_load_ubyte */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12371 /* global_load_ubyte */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12371 /* global_load_ubyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12371 /* global_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12371 /* global_load_ubyte */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12371 /* global_load_ubyte */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12371 /* global_load_ubyte */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12371 /* global_load_ubyte */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12371 /* global_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12371 /* global_load_ubyte */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12371 /* global_load_ubyte */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12371 /* global_load_ubyte */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12371 /* global_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12371 /* global_load_ubyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12371 /* global_load_ubyte */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12371 /* global_load_ubyte */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12371 /* global_load_ubyte */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12371 /* global_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12371 /* global_load_ubyte */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12371 /* global_load_ubyte */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12371 /* global_load_ubyte */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12371 /* global_load_ubyte */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12371 /* global_load_ubyte */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12371 /* global_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12371 /* global_load_ubyte */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12371 /* global_load_ubyte */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12371 /* global_load_ubyte */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12371 /* global_load_ubyte */, 2 /* 1 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12371 /* global_load_ubyte */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12371 /* global_load_ubyte */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12371 /* global_load_ubyte */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12389 /* global_load_ubyte_d16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12389 /* global_load_ubyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12389 /* global_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12389 /* global_load_ubyte_d16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12389 /* global_load_ubyte_d16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12389 /* global_load_ubyte_d16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12389 /* global_load_ubyte_d16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12389 /* global_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12389 /* global_load_ubyte_d16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12389 /* global_load_ubyte_d16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12389 /* global_load_ubyte_d16 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12389 /* global_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12389 /* global_load_ubyte_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12389 /* global_load_ubyte_d16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12389 /* global_load_ubyte_d16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12389 /* global_load_ubyte_d16 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12389 /* global_load_ubyte_d16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12389 /* global_load_ubyte_d16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12389 /* global_load_ubyte_d16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12389 /* global_load_ubyte_d16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12411 /* global_load_ubyte_d16_hi */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12411 /* global_load_ubyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12411 /* global_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12411 /* global_load_ubyte_d16_hi */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12411 /* global_load_ubyte_d16_hi */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12411 /* global_load_ubyte_d16_hi */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12411 /* global_load_ubyte_d16_hi */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12411 /* global_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12411 /* global_load_ubyte_d16_hi */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12411 /* global_load_ubyte_d16_hi */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12411 /* global_load_ubyte_d16_hi */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12411 /* global_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12411 /* global_load_ubyte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12411 /* global_load_ubyte_d16_hi */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12411 /* global_load_ubyte_d16_hi */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12411 /* global_load_ubyte_d16_hi */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12411 /* global_load_ubyte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12411 /* global_load_ubyte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12411 /* global_load_ubyte_d16_hi */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12411 /* global_load_ubyte_d16_hi */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12436 /* global_load_ushort */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12436 /* global_load_ushort */, 2 /* 1 */, MCK_SReg_64, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12436 /* global_load_ushort */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12436 /* global_load_ushort */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12436 /* global_load_ushort */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12436 /* global_load_ushort */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12436 /* global_load_ushort */, 2 /* 1 */, MCK_SReg_64, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12436 /* global_load_ushort */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12436 /* global_load_ushort */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12436 /* global_load_ushort */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12436 /* global_load_ushort */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12436 /* global_load_ushort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12436 /* global_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12436 /* global_load_ushort */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12436 /* global_load_ushort */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12436 /* global_load_ushort */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12436 /* global_load_ushort */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12436 /* global_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12436 /* global_load_ushort */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12436 /* global_load_ushort */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12436 /* global_load_ushort */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12436 /* global_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12436 /* global_load_ushort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12436 /* global_load_ushort */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12436 /* global_load_ushort */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12436 /* global_load_ushort */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12436 /* global_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12436 /* global_load_ushort */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12436 /* global_load_ushort */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12436 /* global_load_ushort */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12436 /* global_load_ushort */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12436 /* global_load_ushort */, 2 /* 1 */, MCK_off, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12436 /* global_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12436 /* global_load_ushort */, 4 /* 2 */, MCK_FlatOffset, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12436 /* global_load_ushort */, 12 /* 2, 3 */, MCK_CPol, AMFBS_isGFX8GFX9NotGFX940_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12436 /* global_load_ushort */, 28 /* 2, 3, 4 */, MCK_lds, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12436 /* global_load_ushort */, 2 /* 1 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12436 /* global_load_ushort */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12436 /* global_load_ushort */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12436 /* global_load_ushort */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12455 /* global_prefetch_b8 */, 2 /* 1 */, MCK_SReg_64, AMFBS_HasVmemPrefInsts_isGFX125xOnly },
  { 12455 /* global_prefetch_b8 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasVmemPrefInsts_isGFX125xOnly },
  { 12455 /* global_prefetch_b8 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasVmemPrefInsts_isGFX125xOnly },
  { 12455 /* global_prefetch_b8 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasVmemPrefInsts_isGFX125xOnly },
  { 12455 /* global_prefetch_b8 */, 2 /* 1 */, MCK_off, AMFBS_HasVmemPrefInsts_isGFX125xOnly },
  { 12455 /* global_prefetch_b8 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasVmemPrefInsts_isGFX125xOnly },
  { 12455 /* global_prefetch_b8 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasVmemPrefInsts_isGFX125xOnly },
  { 12455 /* global_prefetch_b8 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasVmemPrefInsts_isGFX125xOnly },
  { 12474 /* global_store_addtid_b32 */, 2 /* 1 */, MCK_off, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX11Only },
  { 12474 /* global_store_addtid_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX11Only },
  { 12474 /* global_store_addtid_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX11Only },
  { 12474 /* global_store_addtid_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX11Only },
  { 12474 /* global_store_addtid_b32 */, 2 /* 1 */, MCK_off, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX12Only },
  { 12474 /* global_store_addtid_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX12Only },
  { 12474 /* global_store_addtid_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX12Only },
  { 12474 /* global_store_addtid_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX12Only },
  { 12474 /* global_store_addtid_b32 */, 2 /* 1 */, MCK_SReg_64, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX11Only },
  { 12474 /* global_store_addtid_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX11Only },
  { 12474 /* global_store_addtid_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX11Only },
  { 12474 /* global_store_addtid_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX11Only },
  { 12474 /* global_store_addtid_b32 */, 2 /* 1 */, MCK_SReg_64, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX12Only },
  { 12474 /* global_store_addtid_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX12Only },
  { 12474 /* global_store_addtid_b32 */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX12Only },
  { 12474 /* global_store_addtid_b32 */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX12Only },
  { 12498 /* global_store_async_from_lds_b128 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12498 /* global_store_async_from_lds_b128 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12498 /* global_store_async_from_lds_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12498 /* global_store_async_from_lds_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12498 /* global_store_async_from_lds_b128 */, 4 /* 2 */, MCK_off, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12498 /* global_store_async_from_lds_b128 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12498 /* global_store_async_from_lds_b128 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12498 /* global_store_async_from_lds_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12498 /* global_store_async_from_lds_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12531 /* global_store_async_from_lds_b32 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12531 /* global_store_async_from_lds_b32 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12531 /* global_store_async_from_lds_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12531 /* global_store_async_from_lds_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12531 /* global_store_async_from_lds_b32 */, 4 /* 2 */, MCK_off, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12531 /* global_store_async_from_lds_b32 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12531 /* global_store_async_from_lds_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12531 /* global_store_async_from_lds_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12531 /* global_store_async_from_lds_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12563 /* global_store_async_from_lds_b64 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12563 /* global_store_async_from_lds_b64 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12563 /* global_store_async_from_lds_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12563 /* global_store_async_from_lds_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12563 /* global_store_async_from_lds_b64 */, 4 /* 2 */, MCK_off, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12563 /* global_store_async_from_lds_b64 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12563 /* global_store_async_from_lds_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12563 /* global_store_async_from_lds_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12563 /* global_store_async_from_lds_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12595 /* global_store_async_from_lds_b8 */, 4 /* 2 */, MCK_SReg_64, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12595 /* global_store_async_from_lds_b8 */, 3 /* 0, 1 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12595 /* global_store_async_from_lds_b8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12595 /* global_store_async_from_lds_b8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12595 /* global_store_async_from_lds_b8 */, 4 /* 2 */, MCK_off, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12595 /* global_store_async_from_lds_b8 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12595 /* global_store_async_from_lds_b8 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12595 /* global_store_async_from_lds_b8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12595 /* global_store_async_from_lds_b8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasMcastLoadInsts_isGFX125xOnly },
  { 12626 /* global_store_b128 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12626 /* global_store_b128 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12626 /* global_store_b128 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12626 /* global_store_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12626 /* global_store_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12626 /* global_store_b128 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12626 /* global_store_b128 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12626 /* global_store_b128 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12626 /* global_store_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12626 /* global_store_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12626 /* global_store_b128 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12626 /* global_store_b128 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12626 /* global_store_b128 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12626 /* global_store_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12626 /* global_store_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12626 /* global_store_b128 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12626 /* global_store_b128 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12626 /* global_store_b128 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12626 /* global_store_b128 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12626 /* global_store_b128 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12644 /* global_store_b16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12644 /* global_store_b16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12644 /* global_store_b16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12644 /* global_store_b16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12644 /* global_store_b16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12644 /* global_store_b16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12644 /* global_store_b16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12644 /* global_store_b16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12644 /* global_store_b16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12644 /* global_store_b16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12644 /* global_store_b16 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12644 /* global_store_b16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12644 /* global_store_b16 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12644 /* global_store_b16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12644 /* global_store_b16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12644 /* global_store_b16 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12644 /* global_store_b16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12644 /* global_store_b16 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12644 /* global_store_b16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12644 /* global_store_b16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12661 /* global_store_b32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12661 /* global_store_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12661 /* global_store_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12661 /* global_store_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12661 /* global_store_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12661 /* global_store_b32 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12661 /* global_store_b32 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12661 /* global_store_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12661 /* global_store_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12661 /* global_store_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12661 /* global_store_b32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12661 /* global_store_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12661 /* global_store_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12661 /* global_store_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12661 /* global_store_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12661 /* global_store_b32 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12661 /* global_store_b32 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12661 /* global_store_b32 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12661 /* global_store_b32 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12661 /* global_store_b32 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12678 /* global_store_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12678 /* global_store_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12678 /* global_store_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12678 /* global_store_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12678 /* global_store_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12678 /* global_store_b64 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12678 /* global_store_b64 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12678 /* global_store_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12678 /* global_store_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12678 /* global_store_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12678 /* global_store_b64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12678 /* global_store_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12678 /* global_store_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12678 /* global_store_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12678 /* global_store_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12678 /* global_store_b64 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12678 /* global_store_b64 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12678 /* global_store_b64 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12678 /* global_store_b64 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12678 /* global_store_b64 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12695 /* global_store_b8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12695 /* global_store_b8 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12695 /* global_store_b8 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12695 /* global_store_b8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12695 /* global_store_b8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12695 /* global_store_b8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12695 /* global_store_b8 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12695 /* global_store_b8 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12695 /* global_store_b8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12695 /* global_store_b8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12695 /* global_store_b8 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12695 /* global_store_b8 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12695 /* global_store_b8 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12695 /* global_store_b8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12695 /* global_store_b8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12695 /* global_store_b8 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12695 /* global_store_b8 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12695 /* global_store_b8 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12695 /* global_store_b8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12695 /* global_store_b8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12711 /* global_store_b96 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12711 /* global_store_b96 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12711 /* global_store_b96 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12711 /* global_store_b96 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12711 /* global_store_b96 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12711 /* global_store_b96 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12711 /* global_store_b96 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12711 /* global_store_b96 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12711 /* global_store_b96 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12711 /* global_store_b96 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12711 /* global_store_b96 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12711 /* global_store_b96 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12711 /* global_store_b96 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12711 /* global_store_b96 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12711 /* global_store_b96 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12711 /* global_store_b96 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12711 /* global_store_b96 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12711 /* global_store_b96 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12711 /* global_store_b96 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12711 /* global_store_b96 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12728 /* global_store_block */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_isGFX12Plus_isGFX12Only },
  { 12728 /* global_store_block */, 1 /* 0 */, MCK_VGPR_32, AMFBS_isGFX12Plus_isGFX12Only },
  { 12728 /* global_store_block */, 2 /* 1 */, MCK_RegByHwMode_VReg_1024_AlignTarget, AMFBS_isGFX12Plus_isGFX12Only },
  { 12728 /* global_store_block */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX12Plus_isGFX12Only },
  { 12728 /* global_store_block */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX12Plus_isGFX12Only },
  { 12728 /* global_store_block */, 4 /* 2 */, MCK_off, AMFBS_isGFX12Plus_isGFX12Only },
  { 12728 /* global_store_block */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_isGFX12Plus_isGFX12Only },
  { 12728 /* global_store_block */, 2 /* 1 */, MCK_RegByHwMode_VReg_1024_AlignTarget, AMFBS_isGFX12Plus_isGFX12Only },
  { 12728 /* global_store_block */, 8 /* 3 */, MCK_FlatOffset, AMFBS_isGFX12Plus_isGFX12Only },
  { 12728 /* global_store_block */, 24 /* 3, 4 */, MCK_CPol, AMFBS_isGFX12Plus_isGFX12Only },
  { 12747 /* global_store_byte */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12747 /* global_store_byte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12747 /* global_store_byte */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12747 /* global_store_byte */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12747 /* global_store_byte */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12747 /* global_store_byte */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12747 /* global_store_byte */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12747 /* global_store_byte */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12747 /* global_store_byte */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12747 /* global_store_byte */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12747 /* global_store_byte */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12747 /* global_store_byte */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12747 /* global_store_byte */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12747 /* global_store_byte */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12747 /* global_store_byte */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12747 /* global_store_byte */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12747 /* global_store_byte */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12747 /* global_store_byte */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12747 /* global_store_byte */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12747 /* global_store_byte */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12765 /* global_store_byte_d16_hi */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12765 /* global_store_byte_d16_hi */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12765 /* global_store_byte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12765 /* global_store_byte_d16_hi */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12765 /* global_store_byte_d16_hi */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12765 /* global_store_byte_d16_hi */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12765 /* global_store_byte_d16_hi */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12765 /* global_store_byte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12765 /* global_store_byte_d16_hi */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12765 /* global_store_byte_d16_hi */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12765 /* global_store_byte_d16_hi */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12765 /* global_store_byte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12765 /* global_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12765 /* global_store_byte_d16_hi */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12765 /* global_store_byte_d16_hi */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12765 /* global_store_byte_d16_hi */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12765 /* global_store_byte_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12765 /* global_store_byte_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12765 /* global_store_byte_d16_hi */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12765 /* global_store_byte_d16_hi */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12790 /* global_store_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12790 /* global_store_d16_hi_b16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12790 /* global_store_d16_hi_b16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12790 /* global_store_d16_hi_b16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12790 /* global_store_d16_hi_b16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12790 /* global_store_d16_hi_b16 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12790 /* global_store_d16_hi_b16 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12790 /* global_store_d16_hi_b16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12790 /* global_store_d16_hi_b16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12790 /* global_store_d16_hi_b16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12790 /* global_store_d16_hi_b16 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12790 /* global_store_d16_hi_b16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12790 /* global_store_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12790 /* global_store_d16_hi_b16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12790 /* global_store_d16_hi_b16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12790 /* global_store_d16_hi_b16 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12790 /* global_store_d16_hi_b16 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12790 /* global_store_d16_hi_b16 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12790 /* global_store_d16_hi_b16 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12790 /* global_store_d16_hi_b16 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12814 /* global_store_d16_hi_b8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12814 /* global_store_d16_hi_b8 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12814 /* global_store_d16_hi_b8 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12814 /* global_store_d16_hi_b8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12814 /* global_store_d16_hi_b8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12814 /* global_store_d16_hi_b8 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12814 /* global_store_d16_hi_b8 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12814 /* global_store_d16_hi_b8 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12814 /* global_store_d16_hi_b8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12814 /* global_store_d16_hi_b8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12814 /* global_store_d16_hi_b8 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12814 /* global_store_d16_hi_b8 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12814 /* global_store_d16_hi_b8 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12814 /* global_store_d16_hi_b8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12814 /* global_store_d16_hi_b8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX11Only },
  { 12814 /* global_store_d16_hi_b8 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12814 /* global_store_d16_hi_b8 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12814 /* global_store_d16_hi_b8 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12814 /* global_store_d16_hi_b8 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12814 /* global_store_d16_hi_b8 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX12Only },
  { 12837 /* global_store_dword */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12837 /* global_store_dword */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12837 /* global_store_dword */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12837 /* global_store_dword */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12837 /* global_store_dword */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12837 /* global_store_dword */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12837 /* global_store_dword */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12837 /* global_store_dword */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12837 /* global_store_dword */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12837 /* global_store_dword */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12837 /* global_store_dword */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12837 /* global_store_dword */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12837 /* global_store_dword */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12837 /* global_store_dword */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12837 /* global_store_dword */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12837 /* global_store_dword */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12837 /* global_store_dword */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12837 /* global_store_dword */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12837 /* global_store_dword */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12837 /* global_store_dword */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12856 /* global_store_dword_addtid */, 2 /* 1 */, MCK_off, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX10Only },
  { 12856 /* global_store_dword_addtid */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX10Only },
  { 12856 /* global_store_dword_addtid */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX10Only },
  { 12856 /* global_store_dword_addtid */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX10Only },
  { 12856 /* global_store_dword_addtid */, 2 /* 1 */, MCK_SReg_64, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX10Only },
  { 12856 /* global_store_dword_addtid */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX10Only },
  { 12856 /* global_store_dword_addtid */, 4 /* 2 */, MCK_FlatOffset, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX10Only },
  { 12856 /* global_store_dword_addtid */, 12 /* 2, 3 */, MCK_CPol, AMFBS_HasGFX10_BEncoding_HasFlatGlobalInsts_isGFX10Only },
  { 12882 /* global_store_dwordx2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12882 /* global_store_dwordx2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12882 /* global_store_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12882 /* global_store_dwordx2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12882 /* global_store_dwordx2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12882 /* global_store_dwordx2 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12882 /* global_store_dwordx2 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12882 /* global_store_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12882 /* global_store_dwordx2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12882 /* global_store_dwordx2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12882 /* global_store_dwordx2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12882 /* global_store_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12882 /* global_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12882 /* global_store_dwordx2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12882 /* global_store_dwordx2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12882 /* global_store_dwordx2 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12882 /* global_store_dwordx2 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12882 /* global_store_dwordx2 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12882 /* global_store_dwordx2 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12882 /* global_store_dwordx2 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12903 /* global_store_dwordx3 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12903 /* global_store_dwordx3 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12903 /* global_store_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12903 /* global_store_dwordx3 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12903 /* global_store_dwordx3 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12903 /* global_store_dwordx3 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12903 /* global_store_dwordx3 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12903 /* global_store_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12903 /* global_store_dwordx3 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12903 /* global_store_dwordx3 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12903 /* global_store_dwordx3 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12903 /* global_store_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12903 /* global_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12903 /* global_store_dwordx3 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12903 /* global_store_dwordx3 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12903 /* global_store_dwordx3 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12903 /* global_store_dwordx3 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12903 /* global_store_dwordx3 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12903 /* global_store_dwordx3 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12903 /* global_store_dwordx3 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12924 /* global_store_dwordx4 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12924 /* global_store_dwordx4 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12924 /* global_store_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12924 /* global_store_dwordx4 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12924 /* global_store_dwordx4 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12924 /* global_store_dwordx4 */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12924 /* global_store_dwordx4 */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12924 /* global_store_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12924 /* global_store_dwordx4 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12924 /* global_store_dwordx4 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12924 /* global_store_dwordx4 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12924 /* global_store_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12924 /* global_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12924 /* global_store_dwordx4 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12924 /* global_store_dwordx4 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12924 /* global_store_dwordx4 */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12924 /* global_store_dwordx4 */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12924 /* global_store_dwordx4 */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12924 /* global_store_dwordx4 */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12924 /* global_store_dwordx4 */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12945 /* global_store_short */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12945 /* global_store_short */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12945 /* global_store_short */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12945 /* global_store_short */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12945 /* global_store_short */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12945 /* global_store_short */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12945 /* global_store_short */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12945 /* global_store_short */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12945 /* global_store_short */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12945 /* global_store_short */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12945 /* global_store_short */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12945 /* global_store_short */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12945 /* global_store_short */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12945 /* global_store_short */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12945 /* global_store_short */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12945 /* global_store_short */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12945 /* global_store_short */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12945 /* global_store_short */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12945 /* global_store_short */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12945 /* global_store_short */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12964 /* global_store_short_d16_hi */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12964 /* global_store_short_d16_hi */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12964 /* global_store_short_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12964 /* global_store_short_d16_hi */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12964 /* global_store_short_d16_hi */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12964 /* global_store_short_d16_hi */, 4 /* 2 */, MCK_SReg_64_XEXEC_XNULL, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12964 /* global_store_short_d16_hi */, 1 /* 0 */, MCK_VGPR_32, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12964 /* global_store_short_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12964 /* global_store_short_d16_hi */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12964 /* global_store_short_d16_hi */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12964 /* global_store_short_d16_hi */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12964 /* global_store_short_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12964 /* global_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12964 /* global_store_short_d16_hi */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12964 /* global_store_short_d16_hi */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX10Only },
  { 12964 /* global_store_short_d16_hi */, 4 /* 2 */, MCK_off, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12964 /* global_store_short_d16_hi */, 2 /* 1 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12964 /* global_store_short_d16_hi */, 1 /* 0 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12964 /* global_store_short_d16_hi */, 8 /* 3 */, MCK_FlatOffset, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12964 /* global_store_short_d16_hi */, 24 /* 3, 4 */, MCK_CPol, AMFBS_HasFlatGlobalInsts_isGFX8GFX9 },
  { 12990 /* global_wb */, 1 /* 0 */, MCK_CPol, AMFBS_isGFX12Plus_isGFX12Only },
  { 13000 /* global_wbinv */, 1 /* 0 */, MCK_CPol, AMFBS_isGFX12Plus_isGFX12Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13013 /* image_atomic_add */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13013 /* image_atomic_add */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13030 /* image_atomic_add_flt */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13030 /* image_atomic_add_flt */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13051 /* image_atomic_add_uint */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13073 /* image_atomic_and */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13073 /* image_atomic_and */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13090 /* image_atomic_cmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13090 /* image_atomic_cmpswap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13111 /* image_atomic_dec */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13111 /* image_atomic_dec */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13128 /* image_atomic_dec_uint */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13128 /* image_atomic_dec_uint */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13150 /* image_atomic_fcmpswap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13172 /* image_atomic_fmax */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13190 /* image_atomic_fmin */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13208 /* image_atomic_inc */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13208 /* image_atomic_inc */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13225 /* image_atomic_inc_uint */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13225 /* image_atomic_inc_uint */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13247 /* image_atomic_max_flt */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13268 /* image_atomic_max_int */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13289 /* image_atomic_max_uint */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13311 /* image_atomic_min_flt */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13332 /* image_atomic_min_int */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13353 /* image_atomic_min_uint */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13375 /* image_atomic_or */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13375 /* image_atomic_or */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13391 /* image_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13391 /* image_atomic_pk_add_bf16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13416 /* image_atomic_pk_add_f16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13440 /* image_atomic_rsub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13440 /* image_atomic_rsub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13458 /* image_atomic_smax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13458 /* image_atomic_smax */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13476 /* image_atomic_smin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13476 /* image_atomic_smin */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13494 /* image_atomic_sub */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13494 /* image_atomic_sub */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13511 /* image_atomic_sub_uint */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13511 /* image_atomic_sub_uint */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13533 /* image_atomic_swap */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13533 /* image_atomic_swap */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13551 /* image_atomic_umax */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13551 /* image_atomic_umax */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13569 /* image_atomic_umin */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13569 /* image_atomic_umin */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX6GFX7 },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A_isGFX8GFX9NotGFX90A },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_128, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_96, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VReg_64, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 13587 /* image_atomic_xor */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 13587 /* image_atomic_xor */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13604 /* image_bvh64_intersect_ray */, 1 /* 0 */, MCK_VReg_128, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13604 /* image_bvh64_intersect_ray */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13604 /* image_bvh64_intersect_ray */, 8 /* 3 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13604 /* image_bvh64_intersect_ray */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 1 /* 0 */, MCK_VReg_128, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 8 /* 3 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13604 /* image_bvh64_intersect_ray */, 1 /* 0 */, MCK_VReg_128, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13604 /* image_bvh64_intersect_ray */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13604 /* image_bvh64_intersect_ray */, 8 /* 3 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13604 /* image_bvh64_intersect_ray */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 1 /* 0 */, MCK_VReg_128, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 8 /* 3 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13604 /* image_bvh64_intersect_ray */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13604 /* image_bvh64_intersect_ray */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13604 /* image_bvh64_intersect_ray */, 1 /* 0 */, MCK_VReg_128, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13604 /* image_bvh64_intersect_ray */, 8 /* 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13604 /* image_bvh64_intersect_ray */, 4 /* 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13604 /* image_bvh64_intersect_ray */, 48 /* 4, 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13604 /* image_bvh64_intersect_ray */, 256 /* 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13604 /* image_bvh64_intersect_ray */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 1 /* 0 */, MCK_VReg_128, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 8 /* 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 4 /* 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 48 /* 4, 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 256 /* 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13604 /* image_bvh64_intersect_ray */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13604 /* image_bvh64_intersect_ray */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13604 /* image_bvh64_intersect_ray */, 1 /* 0 */, MCK_VReg_128, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13604 /* image_bvh64_intersect_ray */, 8 /* 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13604 /* image_bvh64_intersect_ray */, 4 /* 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13604 /* image_bvh64_intersect_ray */, 112 /* 4, 5, 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13604 /* image_bvh64_intersect_ray */, 512 /* 9 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13604 /* image_bvh64_intersect_ray */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 1 /* 0 */, MCK_VReg_128, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 8 /* 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 4 /* 2 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 112 /* 4, 5, 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 512 /* 9 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13604 /* image_bvh64_intersect_ray */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13604 /* image_bvh64_intersect_ray */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13604 /* image_bvh64_intersect_ray */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13604 /* image_bvh64_intersect_ray */, 1 /* 0 */, MCK_VReg_128, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13604 /* image_bvh64_intersect_ray */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13604 /* image_bvh64_intersect_ray */, 8192 /* 13 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13604 /* image_bvh64_intersect_ray */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13604 /* image_bvh64_intersect_ray */, 16384 /* 14 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13604 /* image_bvh64_intersect_ray */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13604 /* image_bvh64_intersect_ray */, 1 /* 0 */, MCK_VReg_128, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13604 /* image_bvh64_intersect_ray */, 16380 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13604 /* image_bvh64_intersect_ray */, 65536 /* 16 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13630 /* image_bvh8_intersect_ray */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13630 /* image_bvh8_intersect_ray */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13630 /* image_bvh8_intersect_ray */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13630 /* image_bvh8_intersect_ray */, 1 /* 0 */, MCK_VReg_320, AMFBS_HasImageInsts_isGFX12Plus },
  { 13630 /* image_bvh8_intersect_ray */, 64 /* 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 13630 /* image_bvh8_intersect_ray */, 12 /* 2, 3 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13630 /* image_bvh8_intersect_ray */, 48 /* 4, 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13655 /* image_bvh_dual_intersect_ray */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13655 /* image_bvh_dual_intersect_ray */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 13655 /* image_bvh_dual_intersect_ray */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 13655 /* image_bvh_dual_intersect_ray */, 1 /* 0 */, MCK_VReg_320, AMFBS_HasImageInsts_isGFX12Plus },
  { 13655 /* image_bvh_dual_intersect_ray */, 76 /* 2, 3, 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13655 /* image_bvh_dual_intersect_ray */, 48 /* 4, 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 13684 /* image_bvh_intersect_ray */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13684 /* image_bvh_intersect_ray */, 1 /* 0 */, MCK_VReg_128, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13684 /* image_bvh_intersect_ray */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13684 /* image_bvh_intersect_ray */, 8 /* 3 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13684 /* image_bvh_intersect_ray */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13684 /* image_bvh_intersect_ray */, 1 /* 0 */, MCK_VReg_128, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13684 /* image_bvh_intersect_ray */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13684 /* image_bvh_intersect_ray */, 8 /* 3 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13684 /* image_bvh_intersect_ray */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13684 /* image_bvh_intersect_ray */, 1 /* 0 */, MCK_VReg_128, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13684 /* image_bvh_intersect_ray */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13684 /* image_bvh_intersect_ray */, 8 /* 3 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13684 /* image_bvh_intersect_ray */, 4 /* 2 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13684 /* image_bvh_intersect_ray */, 1 /* 0 */, MCK_VReg_128, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13684 /* image_bvh_intersect_ray */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13684 /* image_bvh_intersect_ray */, 8 /* 3 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13684 /* image_bvh_intersect_ray */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13684 /* image_bvh_intersect_ray */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13684 /* image_bvh_intersect_ray */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13684 /* image_bvh_intersect_ray */, 1 /* 0 */, MCK_VReg_128, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13684 /* image_bvh_intersect_ray */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13684 /* image_bvh_intersect_ray */, 48 /* 4, 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13684 /* image_bvh_intersect_ray */, 256 /* 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13684 /* image_bvh_intersect_ray */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13684 /* image_bvh_intersect_ray */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13684 /* image_bvh_intersect_ray */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13684 /* image_bvh_intersect_ray */, 1 /* 0 */, MCK_VReg_128, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13684 /* image_bvh_intersect_ray */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13684 /* image_bvh_intersect_ray */, 48 /* 4, 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13684 /* image_bvh_intersect_ray */, 256 /* 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13684 /* image_bvh_intersect_ray */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13684 /* image_bvh_intersect_ray */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13684 /* image_bvh_intersect_ray */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13684 /* image_bvh_intersect_ray */, 1 /* 0 */, MCK_VReg_128, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13684 /* image_bvh_intersect_ray */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13684 /* image_bvh_intersect_ray */, 112 /* 4, 5, 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13684 /* image_bvh_intersect_ray */, 512 /* 9 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 13684 /* image_bvh_intersect_ray */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13684 /* image_bvh_intersect_ray */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13684 /* image_bvh_intersect_ray */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13684 /* image_bvh_intersect_ray */, 1 /* 0 */, MCK_VReg_128, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13684 /* image_bvh_intersect_ray */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13684 /* image_bvh_intersect_ray */, 112 /* 4, 5, 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13684 /* image_bvh_intersect_ray */, 512 /* 9 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 13684 /* image_bvh_intersect_ray */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13684 /* image_bvh_intersect_ray */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13684 /* image_bvh_intersect_ray */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13684 /* image_bvh_intersect_ray */, 1 /* 0 */, MCK_VReg_128, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13684 /* image_bvh_intersect_ray */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13684 /* image_bvh_intersect_ray */, 4096 /* 12 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13684 /* image_bvh_intersect_ray */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13684 /* image_bvh_intersect_ray */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13684 /* image_bvh_intersect_ray */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13684 /* image_bvh_intersect_ray */, 1 /* 0 */, MCK_VReg_128, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13684 /* image_bvh_intersect_ray */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13684 /* image_bvh_intersect_ray */, 32768 /* 15 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13708 /* image_gather4 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13708 /* image_gather4 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13722 /* image_gather4_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13722 /* image_gather4_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13738 /* image_gather4_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13738 /* image_gather4_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13757 /* image_gather4_b_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13778 /* image_gather4_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13796 /* image_gather4_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13796 /* image_gather4_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13812 /* image_gather4_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13812 /* image_gather4_c_b */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13830 /* image_gather4_c_b_cl */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13851 /* image_gather4_c_b_cl_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13874 /* image_gather4_c_b_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13894 /* image_gather4_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13894 /* image_gather4_c_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13913 /* image_gather4_c_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13934 /* image_gather4_c_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13934 /* image_gather4_c_l */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13952 /* image_gather4_c_l_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13972 /* image_gather4_c_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13972 /* image_gather4_c_lz */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 13991 /* image_gather4_c_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 13991 /* image_gather4_c_lz_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14012 /* image_gather4_c_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14030 /* image_gather4_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14030 /* image_gather4_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14047 /* image_gather4_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14066 /* image_gather4_l */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14066 /* image_gather4_l */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14082 /* image_gather4_l_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14100 /* image_gather4_lz */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14100 /* image_gather4_lz */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14117 /* image_gather4_lz_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14117 /* image_gather4_lz_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14136 /* image_gather4_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14136 /* image_gather4_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX12Plus },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX10Only },
  { 14152 /* image_gather4h */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14152 /* image_gather4h */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX9Plus_isGFX11Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX90APlus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14167 /* image_get_lod */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14167 /* image_get_lod */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14181 /* image_get_resinfo */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14181 /* image_get_resinfo */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14199 /* image_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14199 /* image_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14210 /* image_load_mip */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14210 /* image_load_mip */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14225 /* image_load_mip_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14225 /* image_load_mip_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14244 /* image_load_mip_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14244 /* image_load_mip_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14267 /* image_load_pck */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14267 /* image_load_pck */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VReg_128_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VReg_96_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VReg_64_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_Align2, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 448 /* 6, 7, 8 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 896 /* 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14282 /* image_load_pck_sgn */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14282 /* image_load_pck_sgn */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 120 /* 3, 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1016 /* 3, 4, 5, 6, 7, 8, 9 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 56 /* 3, 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 248 /* 3, 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 504 /* 3, 4, 5, 6, 7, 8 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4088 /* 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2040 /* 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8 /* 3 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 24 /* 3, 4 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 960 /* 6, 7, 8, 9 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8128 /* 6, 7, 8, 9, 10, 11, 12 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 448 /* 6, 7, 8 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1984 /* 6, 7, 8, 9, 10 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 4032 /* 6, 7, 8, 9, 10, 11 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32704 /* 6, 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 16320 /* 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 192 /* 6, 7 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX12Plus },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX11Only },
  { 14301 /* image_msaa_load */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14301 /* image_msaa_load */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasGFX10_AEncoding_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_DA, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_D16, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_LWE, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX90APlus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX12Plus },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX10Only },
  { 14317 /* image_sample */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_isGFX11Only },
  { 14317 /* image_sample */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14330 /* image_sample_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14330 /* image_sample_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14345 /* image_sample_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14345 /* image_sample_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14363 /* image_sample_b_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14383 /* image_sample_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14383 /* image_sample_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14400 /* image_sample_c */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14400 /* image_sample_c */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14415 /* image_sample_c_b */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14415 /* image_sample_c_b */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14432 /* image_sample_c_b_cl */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14452 /* image_sample_c_b_cl_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14474 /* image_sample_c_b_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14493 /* image_sample_c_cd */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14511 /* image_sample_c_cd_cl */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14532 /* image_sample_c_cd_cl_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32768 /* 15 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 65536 /* 16 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16380 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1966080 /* 17, 18, 19, 20 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16646144 /* 17, 18, 19, 20, 21, 22, 23 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 917504 /* 17, 18, 19 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4063232 /* 17, 18, 19, 20, 21 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8257536 /* 17, 18, 19, 20, 21, 22 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 66977792 /* 17, 18, 19, 20, 21, 22, 23, 24, 25 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 33423360 /* 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 131072 /* 17 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 393216 /* 17, 18 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32768 /* 15 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 65536 /* 16 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16380 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1966080 /* 17, 18, 19, 20 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16646144 /* 17, 18, 19, 20, 21, 22, 23 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 917504 /* 17, 18, 19 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4063232 /* 17, 18, 19, 20, 21 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8257536 /* 17, 18, 19, 20, 21, 22 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 66977792 /* 17, 18, 19, 20, 21, 22, 23, 24, 25 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 33423360 /* 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 131072 /* 17 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 393216 /* 17, 18 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32768 /* 15 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 65536 /* 16 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16380 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1966080 /* 17, 18, 19, 20 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16646144 /* 17, 18, 19, 20, 21, 22, 23 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 917504 /* 17, 18, 19 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4063232 /* 17, 18, 19, 20, 21 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8257536 /* 17, 18, 19, 20, 21, 22 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 66977792 /* 17, 18, 19, 20, 21, 22, 23, 24, 25 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 33423360 /* 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 131072 /* 17 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 393216 /* 17, 18 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32768 /* 15 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 65536 /* 16 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16380 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1966080 /* 17, 18, 19, 20 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16646144 /* 17, 18, 19, 20, 21, 22, 23 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 917504 /* 17, 18, 19 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4063232 /* 17, 18, 19, 20, 21 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8257536 /* 17, 18, 19, 20, 21, 22 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 66977792 /* 17, 18, 19, 20, 21, 22, 23, 24, 25 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 33423360 /* 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 131072 /* 17 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 393216 /* 17, 18 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32768 /* 15 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 65536 /* 16 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16380 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1966080 /* 17, 18, 19, 20 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16646144 /* 17, 18, 19, 20, 21, 22, 23 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 917504 /* 17, 18, 19 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4063232 /* 17, 18, 19, 20, 21 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8257536 /* 17, 18, 19, 20, 21, 22 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 66977792 /* 17, 18, 19, 20, 21, 22, 23, 24, 25 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 33423360 /* 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 131072 /* 17 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 393216 /* 17, 18 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16384 /* 14 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 32768 /* 15 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 65536 /* 16 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16380 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 1966080 /* 17, 18, 19, 20 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 16646144 /* 17, 18, 19, 20, 21, 22, 23 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 917504 /* 17, 18, 19 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 4063232 /* 17, 18, 19, 20, 21 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 8257536 /* 17, 18, 19, 20, 21, 22 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 66977792 /* 17, 18, 19, 20, 21, 22, 23, 24, 25 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 33423360 /* 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 131072 /* 17 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14557 /* image_sample_c_cd_cl_o */, 393216 /* 17, 18 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14580 /* image_sample_c_cd_cl_o_g16 */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14607 /* image_sample_c_cd_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14629 /* image_sample_c_cd_o */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14649 /* image_sample_c_cd_o_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16 /* 4 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 12 /* 2, 3 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1920 /* 7, 8, 9, 10 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16256 /* 7, 8, 9, 10, 11, 12, 13 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 896 /* 7, 8, 9 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3968 /* 7, 8, 9, 10, 11 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 8064 /* 7, 8, 9, 10, 11, 12 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 65408 /* 7, 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32640 /* 7, 8, 9, 10, 11, 12, 13, 14 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 384 /* 7, 8 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14673 /* image_sample_c_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14673 /* image_sample_c_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14691 /* image_sample_c_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32 /* 5 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64 /* 6 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14711 /* image_sample_c_d */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32 /* 5 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64 /* 6 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14728 /* image_sample_c_d_cl */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3840 /* 8, 9, 10, 11 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32512 /* 8, 9, 10, 11, 12, 13, 14 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1792 /* 8, 9, 10 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7936 /* 8, 9, 10, 11, 12 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16128 /* 8, 9, 10, 11, 12, 13 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130816 /* 8, 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65280 /* 8, 9, 10, 11, 12, 13, 14, 15 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 768 /* 8, 9 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX12Plus },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX11Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14748 /* image_sample_c_d_cl_g16 */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_HasG16_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_DA, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX6GFX7GFX8GFX9NotGFX90A },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_320_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_352_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4 /* 2 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8 /* 3 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK_RegByHwMode_VReg_384_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 240 /* 4, 5, 6, 7 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2032 /* 4, 5, 6, 7, 8, 9, 10 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 112 /* 4, 5, 6 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 496 /* 4, 5, 6, 7, 8 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1008 /* 4, 5, 6, 7, 8, 9 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 8176 /* 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 4080 /* 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 16 /* 4 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 48 /* 4, 5 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 28 /* 2, 3, 4 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32 /* 5 */, MCK_RegByHwMode_VReg_288_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 7680 /* 9, 10, 11, 12 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 65024 /* 9, 10, 11, 12, 13, 14, 15 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 3584 /* 9, 10, 11 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 15872 /* 9, 10, 11, 12, 13 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 32256 /* 9, 10, 11, 12, 13, 14 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 261632 /* 9, 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 130560 /* 9, 10, 11, 12, 13, 14, 15, 16 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 1536 /* 9, 10 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX12Plus },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 124 /* 2, 3, 4, 5, 6 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_192_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_224_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 128 /* 7 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 60 /* 2, 3, 4, 5 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64 /* 6 */, MCK_RegByHwMode_VReg_256_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 15360 /* 10, 11, 12, 13 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 130048 /* 10, 11, 12, 13, 14, 15, 16 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 7168 /* 10, 11, 12 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 31744 /* 10, 11, 12, 13, 14 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 64512 /* 10, 11, 12, 13, 14, 15 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 523264 /* 10, 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 261120 /* 10, 11, 12, 13, 14, 15, 16, 17 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 3072 /* 10, 11 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX11Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 256 /* 8 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 252 /* 2, 3, 4, 5, 6, 7 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 30720 /* 11, 12, 13, 14 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 260096 /* 11, 12, 13, 14, 15, 16, 17 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 14336 /* 11, 12, 13 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 63488 /* 11, 12, 13, 14, 15 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 129024 /* 11, 12, 13, 14, 15, 16 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1046528 /* 11, 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 522240 /* 11, 12, 13, 14, 15, 16, 17, 18 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 6144 /* 11, 12 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 512 /* 9 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 508 /* 2, 3, 4, 5, 6, 7, 8 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 61440 /* 12, 13, 14, 15 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 520192 /* 12, 13, 14, 15, 16, 17, 18 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 28672 /* 12, 13, 14 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 126976 /* 12, 13, 14, 15, 16 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 258048 /* 12, 13, 14, 15, 16, 17 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2093056 /* 12, 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1044480 /* 12, 13, 14, 15, 16, 17, 18, 19 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 12288 /* 12, 13 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1024 /* 10 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1020 /* 2, 3, 4, 5, 6, 7, 8, 9 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 122880 /* 13, 14, 15, 16 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1040384 /* 13, 14, 15, 16, 17, 18, 19 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 57344 /* 13, 14, 15 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 253952 /* 13, 14, 15, 16, 17 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 516096 /* 13, 14, 15, 16, 17, 18 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4186112 /* 13, 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2088960 /* 13, 14, 15, 16, 17, 18, 19, 20 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8192 /* 13 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 24576 /* 13, 14 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2048 /* 11 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8192 /* 13 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2044 /* 2, 3, 4, 5, 6, 7, 8, 9, 10 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 245760 /* 14, 15, 16, 17 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2080768 /* 14, 15, 16, 17, 18, 19, 20 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 114688 /* 14, 15, 16 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 507904 /* 14, 15, 16, 17, 18 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1032192 /* 14, 15, 16, 17, 18, 19 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8372224 /* 14, 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4177920 /* 14, 15, 16, 17, 18, 19, 20, 21 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16384 /* 14 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 49152 /* 14, 15 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_96_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_128_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4096 /* 12 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8192 /* 13 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16384 /* 14 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4092 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_160_AlignTarget, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 491520 /* 15, 16, 17, 18 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4161536 /* 15, 16, 17, 18, 19, 20, 21 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 229376 /* 15, 16, 17 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1015808 /* 15, 16, 17, 18, 19 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2064384 /* 15, 16, 17, 18, 19, 20 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16744448 /* 15, 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8355840 /* 15, 16, 17, 18, 19, 20, 21, 22 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 32768 /* 15 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 98304 /* 15, 16 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_off, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_32_Target, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 983040 /* 16, 17, 18, 19 */, MCK_CPol, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8323072 /* 16, 17, 18, 19, 20, 21, 22 */, MCK_TFE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 458752 /* 16, 17, 18 */, MCK_UNorm, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2031616 /* 16, 17, 18, 19, 20 */, MCK_R128A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 4128768 /* 16, 17, 18, 19, 20, 21 */, MCK_A16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 33488896 /* 16, 17, 18, 19, 20, 21, 22, 23, 24 */, MCK_D16, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16711680 /* 16, 17, 18, 19, 20, 21, 22, 23 */, MCK_LWE, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 65536 /* 16 */, MCK_DMask, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 196608 /* 16, 17 */, MCK_Dim, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 2 /* 1 */, MCK__91_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8192 /* 13 */, MCK__93_, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 16384 /* 14 */, MCK_SReg_256_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 32768 /* 15 */, MCK_SReg_128_XNULL, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 8188 /* 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 */, MCK_VGPR_32, AMFBS_HasImageInsts_HasExtendedImageInsts_isGFX10Only },
  { 14772 /* image_sample_c_d_cl_o */, 1 /* 0 */, MCK_RegByHwMode_AV_LdSt_64